AssociateGlossaryTermsFluentBuilder

Struct AssociateGlossaryTermsFluentBuilder 

pub struct AssociateGlossaryTermsFluentBuilder { /* private fields */ }
Fluent builder constructing a request to AssociateGlossaryTerms.

Associates one or more glossary terms with an asset in Glue Data Catalog.

Implementations

Source

impl AssociateGlossaryTermsFluentBuilder

pub fn as_input(&self) -> &AssociateGlossaryTermsInputBuilder

Access the AssociateGlossaryTerms as a reference.

pub async fn send( self, ) -> Result<AssociateGlossaryTermsOutput, SdkError<AssociateGlossaryTermsError, HttpResponse>>

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

pub fn customize( self, ) -> CustomizableOperation<AssociateGlossaryTermsOutput, AssociateGlossaryTermsError, Self>

Consumes this builder, creating a customizable operation that can be modified before being sent.

pub fn asset_identifier(self, input: impl Into<String>) -> Self

The unique identifier of the asset to associate glossary terms with.

pub fn set_asset_identifier(self, input: Option<String>) -> Self

The unique identifier of the asset to associate glossary terms with.

pub fn get_asset_identifier(&self) -> &Option<String>

The unique identifier of the asset to associate glossary terms with.

pub fn iterable_form_name(self, input: impl Into<String>) -> Self

The name of the iterable form. When specified along with itemIdentifier, the glossary terms are associated with an item within the iterable form rather than the asset itself.

pub fn set_iterable_form_name(self, input: Option<String>) -> Self

The name of the iterable form. When specified along with itemIdentifier, the glossary terms are associated with an item within the iterable form rather than the asset itself.

pub fn get_iterable_form_name(&self) -> &Option<String>

The name of the iterable form. When specified along with itemIdentifier, the glossary terms are associated with an item within the iterable form rather than the asset itself.

pub fn item_identifier(self, input: impl Into<String>) -> Self

The identifier of the item within the iterable form. Required when iterableFormName is specified.

pub fn set_item_identifier(self, input: Option<String>) -> Self

The identifier of the item within the iterable form. Required when iterableFormName is specified.

pub fn get_item_identifier(&self) -> &Option<String>

The identifier of the item within the iterable form. Required when iterableFormName is specified.

pub fn glossary_term_identifiers(self, input: impl Into<String>) -> Self

Appends an item to GlossaryTermIdentifiers.

To override the contents of this collection use set_glossary_term_identifiers.

The list of glossary term identifiers to associate with the asset.

pub fn set_glossary_term_identifiers(self, input: Option<Vec<String>>) -> Self

The list of glossary term identifiers to associate with the asset.

pub fn get_glossary_term_identifiers(&self) -> &Option<Vec<String>>

The list of glossary term identifiers to associate with the asset.

pub fn client_token(self, input: impl Into<String>) -> Self

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

pub fn set_client_token(self, input: Option<String>) -> Self

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

pub fn get_client_token(&self) -> &Option<String>

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.