#[non_exhaustive]pub struct AssociateGlossaryTermsOutput {
pub asset_identifier: Option<String>,
pub iterable_form_name: Option<String>,
pub item_identifier: Option<String>,
pub glossary_terms: Option<Vec<String>>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.asset_identifier: Option<String>The unique identifier of the asset.
iterable_form_name: Option<String>The name of the iterable form, if the association targets an item.
item_identifier: Option<String>The identifier of the item within the iterable form, if applicable.
glossary_terms: Option<Vec<String>>The glossary terms now associated with the asset.
Implementations
Sourceimpl AssociateGlossaryTermsOutput
impl AssociateGlossaryTermsOutput
Sourcepub fn asset_identifier(&self) -> Option<&str>
pub fn asset_identifier(&self) -> Option<&str>
The unique identifier of the asset.
Sourcepub fn iterable_form_name(&self) -> Option<&str>
pub fn iterable_form_name(&self) -> Option<&str>
The name of the iterable form, if the association targets an item.
Sourcepub fn item_identifier(&self) -> Option<&str>
pub fn item_identifier(&self) -> Option<&str>
The identifier of the item within the iterable form, if applicable.
Sourcepub fn glossary_terms(&self) -> &[String]
pub fn glossary_terms(&self) -> &[String]
The glossary terms now associated with the asset.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .glossary_terms.is_none().
Sourceimpl AssociateGlossaryTermsOutput
impl AssociateGlossaryTermsOutput
Sourcepub fn builder() -> AssociateGlossaryTermsOutputBuilder
pub fn builder() -> AssociateGlossaryTermsOutputBuilder
Creates a new builder-style object to manufacture AssociateGlossaryTermsOutput.