#[non_exhaustive]pub struct BatchGetCrawlersInputBuilder { /* private fields */ }Expand description
A builder for BatchGetCrawlersInput.
Implementations
Sourceimpl BatchGetCrawlersInputBuilder
impl BatchGetCrawlersInputBuilder
Sourcepub fn crawler_names(self, input: impl Into<String>) -> Self
pub fn crawler_names(self, input: impl Into<String>) -> Self
Appends an item to crawler_names.
To override the contents of this collection use set_crawler_names.
A list of crawler names, which might be the names returned from the ListCrawlers operation.
Sourcepub fn set_crawler_names(self, input: Option<Vec<String>>) -> Self
pub fn set_crawler_names(self, input: Option<Vec<String>>) -> Self
A list of crawler names, which might be the names returned from the ListCrawlers operation.
Sourcepub fn get_crawler_names(&self) -> &Option<Vec<String>>
pub fn get_crawler_names(&self) -> &Option<Vec<String>>
A list of crawler names, which might be the names returned from the ListCrawlers operation.
Sourcepub fn build(self) -> Result<BatchGetCrawlersInput, BuildError>
pub fn build(self) -> Result<BatchGetCrawlersInput, BuildError>
Consumes the builder and constructs a BatchGetCrawlersInput.
Sourceimpl BatchGetCrawlersInputBuilder
impl BatchGetCrawlersInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<BatchGetCrawlersOutput, SdkError<BatchGetCrawlersError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<BatchGetCrawlersOutput, SdkError<BatchGetCrawlersError, HttpResponse>>
Sends a request with this input using the given client.