#[non_exhaustive]pub struct BatchGetCrawlersOutputBuilder { /* private fields */ }Expand description
A builder for BatchGetCrawlersOutput.
Implementations
Sourceimpl BatchGetCrawlersOutputBuilder
impl BatchGetCrawlersOutputBuilder
Sourcepub fn crawlers(self, input: Crawler) -> Self
pub fn crawlers(self, input: Crawler) -> Self
Appends an item to crawlers.
To override the contents of this collection use set_crawlers.
A list of crawler definitions.
Sourcepub fn set_crawlers(self, input: Option<Vec<Crawler>>) -> Self
pub fn set_crawlers(self, input: Option<Vec<Crawler>>) -> Self
A list of crawler definitions.
Sourcepub fn get_crawlers(&self) -> &Option<Vec<Crawler>>
pub fn get_crawlers(&self) -> &Option<Vec<Crawler>>
A list of crawler definitions.
Sourcepub fn crawlers_not_found(self, input: impl Into<String>) -> Self
pub fn crawlers_not_found(self, input: impl Into<String>) -> Self
Appends an item to crawlers_not_found.
To override the contents of this collection use set_crawlers_not_found.
A list of names of crawlers that were not found.
Sourcepub fn set_crawlers_not_found(self, input: Option<Vec<String>>) -> Self
pub fn set_crawlers_not_found(self, input: Option<Vec<String>>) -> Self
A list of names of crawlers that were not found.
Sourcepub fn get_crawlers_not_found(&self) -> &Option<Vec<String>>
pub fn get_crawlers_not_found(&self) -> &Option<Vec<String>>
A list of names of crawlers that were not found.
Sourcepub fn build(self) -> BatchGetCrawlersOutput
pub fn build(self) -> BatchGetCrawlersOutput
Consumes the builder and constructs a BatchGetCrawlersOutput.