#[non_exhaustive]pub struct BatchGetCrawlersInput {
pub crawler_names: Option<Vec<String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.crawler_names: Option<Vec<String>>A list of crawler names, which might be the names returned from the ListCrawlers operation.
Implementations
Sourceimpl BatchGetCrawlersInput
impl BatchGetCrawlersInput
Sourcepub fn crawler_names(&self) -> &[String]
pub fn crawler_names(&self) -> &[String]
A list of crawler names, which might be the names returned from the ListCrawlers operation.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .crawler_names.is_none().
Sourceimpl BatchGetCrawlersInput
impl BatchGetCrawlersInput
Sourcepub fn builder() -> BatchGetCrawlersInputBuilder
pub fn builder() -> BatchGetCrawlersInputBuilder
Creates a new builder-style object to manufacture BatchGetCrawlersInput.