#[non_exhaustive]pub struct BatchGetDataQualityRulesetEvaluationRunOutput {
pub runs: Option<Vec<DataQualityRulesetEvaluationRun>>,
pub runs_not_found: Option<Vec<String>>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.runs: Option<Vec<DataQualityRulesetEvaluationRun>>A list of evaluation run details for the requested run IDs.
runs_not_found: Option<Vec<String>>A list of run IDs that were not found.
Implementations
Sourceimpl BatchGetDataQualityRulesetEvaluationRunOutput
impl BatchGetDataQualityRulesetEvaluationRunOutput
Sourcepub fn runs(&self) -> &[DataQualityRulesetEvaluationRun]
pub fn runs(&self) -> &[DataQualityRulesetEvaluationRun]
A list of evaluation run details for the requested run IDs.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .runs.is_none().
Sourcepub fn runs_not_found(&self) -> &[String]
pub fn runs_not_found(&self) -> &[String]
A list of run IDs that were not found.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .runs_not_found.is_none().
Sourceimpl BatchGetDataQualityRulesetEvaluationRunOutput
impl BatchGetDataQualityRulesetEvaluationRunOutput
Sourcepub fn builder() -> BatchGetDataQualityRulesetEvaluationRunOutputBuilder
pub fn builder() -> BatchGetDataQualityRulesetEvaluationRunOutputBuilder
Creates a new builder-style object to manufacture BatchGetDataQualityRulesetEvaluationRunOutput.