BatchGetIterableFormsFluentBuilder

Struct BatchGetIterableFormsFluentBuilder 

pub struct BatchGetIterableFormsFluentBuilder { /* private fields */ }
Fluent builder constructing a request to BatchGetIterableForms.

Retrieves multiple items from an iterable form on an asset in Glue Data Catalog in a single request.

Implementations

Source

impl BatchGetIterableFormsFluentBuilder

pub fn as_input(&self) -> &BatchGetIterableFormsInputBuilder

Access the BatchGetIterableForms as a reference.

pub async fn send( self, ) -> Result<BatchGetIterableFormsOutput, SdkError<BatchGetIterableFormsError, HttpResponse>>

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

pub fn customize( self, ) -> CustomizableOperation<BatchGetIterableFormsOutput, BatchGetIterableFormsError, Self>

Consumes this builder, creating a customizable operation that can be modified before being sent.

pub fn asset_identifier(self, input: impl Into<String>) -> Self

The unique identifier of the asset.

pub fn set_asset_identifier(self, input: Option<String>) -> Self

The unique identifier of the asset.

pub fn get_asset_identifier(&self) -> &Option<String>

The unique identifier of the asset.

pub fn iterable_form_name(self, input: impl Into<String>) -> Self

The name of the iterable form to retrieve items from.

pub fn set_iterable_form_name(self, input: Option<String>) -> Self

The name of the iterable form to retrieve items from.

pub fn get_iterable_form_name(&self) -> &Option<String>

The name of the iterable form to retrieve items from.

pub fn item_identifiers(self, input: impl Into<String>) -> Self

Appends an item to ItemIdentifiers.

To override the contents of this collection use set_item_identifiers.

The list of item identifiers to retrieve. Each identifier can be an item ID or item name.

pub fn set_item_identifiers(self, input: Option<Vec<String>>) -> Self

The list of item identifiers to retrieve. Each identifier can be an item ID or item name.

pub fn get_item_identifiers(&self) -> &Option<Vec<String>>

The list of item identifiers to retrieve. Each identifier can be an item ID or item name.