#[non_exhaustive]pub struct BatchGetIterableFormsInputBuilder { /* private fields */ }Expand description
A builder for BatchGetIterableFormsInput.
Implementations
Sourceimpl BatchGetIterableFormsInputBuilder
impl BatchGetIterableFormsInputBuilder
Sourcepub fn asset_identifier(self, input: impl Into<String>) -> Self
pub fn asset_identifier(self, input: impl Into<String>) -> Self
The unique identifier of the asset.
This field is required.Sourcepub fn set_asset_identifier(self, input: Option<String>) -> Self
pub fn set_asset_identifier(self, input: Option<String>) -> Self
The unique identifier of the asset.
Sourcepub fn get_asset_identifier(&self) -> &Option<String>
pub fn get_asset_identifier(&self) -> &Option<String>
The unique identifier of the asset.
Sourcepub fn iterable_form_name(self, input: impl Into<String>) -> Self
pub fn iterable_form_name(self, input: impl Into<String>) -> Self
The name of the iterable form to retrieve items from.
This field is required.Sourcepub fn set_iterable_form_name(self, input: Option<String>) -> Self
pub fn set_iterable_form_name(self, input: Option<String>) -> Self
The name of the iterable form to retrieve items from.
Sourcepub fn get_iterable_form_name(&self) -> &Option<String>
pub fn get_iterable_form_name(&self) -> &Option<String>
The name of the iterable form to retrieve items from.
Sourcepub fn item_identifiers(self, input: impl Into<String>) -> Self
pub fn item_identifiers(self, input: impl Into<String>) -> Self
Appends an item to item_identifiers.
To override the contents of this collection use set_item_identifiers.
The list of item identifiers to retrieve. Each identifier can be an item ID or item name.
Sourcepub fn set_item_identifiers(self, input: Option<Vec<String>>) -> Self
pub fn set_item_identifiers(self, input: Option<Vec<String>>) -> Self
The list of item identifiers to retrieve. Each identifier can be an item ID or item name.
Sourcepub fn get_item_identifiers(&self) -> &Option<Vec<String>>
pub fn get_item_identifiers(&self) -> &Option<Vec<String>>
The list of item identifiers to retrieve. Each identifier can be an item ID or item name.
Sourcepub fn build(self) -> Result<BatchGetIterableFormsInput, BuildError>
pub fn build(self) -> Result<BatchGetIterableFormsInput, BuildError>
Consumes the builder and constructs a BatchGetIterableFormsInput.
Sourceimpl BatchGetIterableFormsInputBuilder
impl BatchGetIterableFormsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<BatchGetIterableFormsOutput, SdkError<BatchGetIterableFormsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<BatchGetIterableFormsOutput, SdkError<BatchGetIterableFormsError, HttpResponse>>
Sends a request with this input using the given client.