#[non_exhaustive]pub struct BatchGetIterableFormsOutputBuilder { /* private fields */ }Expand description
A builder for BatchGetIterableFormsOutput.
Implementations
Sourceimpl BatchGetIterableFormsOutputBuilder
impl BatchGetIterableFormsOutputBuilder
Sourcepub fn items(self, input: IterableFormItem) -> Self
pub fn items(self, input: IterableFormItem) -> Self
Appends an item to items.
To override the contents of this collection use set_items.
The list of retrieved iterable form items.
Sourcepub fn set_items(self, input: Option<Vec<IterableFormItem>>) -> Self
pub fn set_items(self, input: Option<Vec<IterableFormItem>>) -> Self
The list of retrieved iterable form items.
Sourcepub fn get_items(&self) -> &Option<Vec<IterableFormItem>>
pub fn get_items(&self) -> &Option<Vec<IterableFormItem>>
The list of retrieved iterable form items.
Sourcepub fn errors(self, input: ItemError) -> Self
pub fn errors(self, input: ItemError) -> Self
Appends an item to errors.
To override the contents of this collection use set_errors.
The list of errors for items that could not be retrieved.
Sourcepub fn set_errors(self, input: Option<Vec<ItemError>>) -> Self
pub fn set_errors(self, input: Option<Vec<ItemError>>) -> Self
The list of errors for items that could not be retrieved.
Sourcepub fn get_errors(&self) -> &Option<Vec<ItemError>>
pub fn get_errors(&self) -> &Option<Vec<ItemError>>
The list of errors for items that could not be retrieved.
Sourcepub fn build(self) -> BatchGetIterableFormsOutput
pub fn build(self) -> BatchGetIterableFormsOutput
Consumes the builder and constructs a BatchGetIterableFormsOutput.