#[non_exhaustive]pub struct BatchGetIterableFormsInput {
pub asset_identifier: Option<String>,
pub iterable_form_name: Option<String>,
pub item_identifiers: Option<Vec<String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.asset_identifier: Option<String>The unique identifier of the asset.
iterable_form_name: Option<String>The name of the iterable form to retrieve items from.
item_identifiers: Option<Vec<String>>The list of item identifiers to retrieve. Each identifier can be an item ID or item name.
Implementations
Sourceimpl BatchGetIterableFormsInput
impl BatchGetIterableFormsInput
Sourcepub fn asset_identifier(&self) -> Option<&str>
pub fn asset_identifier(&self) -> Option<&str>
The unique identifier of the asset.
Sourcepub fn iterable_form_name(&self) -> Option<&str>
pub fn iterable_form_name(&self) -> Option<&str>
The name of the iterable form to retrieve items from.
Sourcepub fn item_identifiers(&self) -> &[String]
pub fn item_identifiers(&self) -> &[String]
The list of item identifiers to retrieve. Each identifier can be an item ID or item name.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .item_identifiers.is_none().
Sourceimpl BatchGetIterableFormsInput
impl BatchGetIterableFormsInput
Sourcepub fn builder() -> BatchGetIterableFormsInputBuilder
pub fn builder() -> BatchGetIterableFormsInputBuilder
Creates a new builder-style object to manufacture BatchGetIterableFormsInput.