#[non_exhaustive]pub struct BatchGetIterableFormsOutput {
pub items: Option<Vec<IterableFormItem>>,
pub errors: Option<Vec<ItemError>>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.items: Option<Vec<IterableFormItem>>The list of retrieved iterable form items.
errors: Option<Vec<ItemError>>The list of errors for items that could not be retrieved.
Implementations
Sourceimpl BatchGetIterableFormsOutput
impl BatchGetIterableFormsOutput
Sourcepub fn items(&self) -> &[IterableFormItem]
pub fn items(&self) -> &[IterableFormItem]
The list of retrieved iterable form items.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .items.is_none().
Sourceimpl BatchGetIterableFormsOutput
impl BatchGetIterableFormsOutput
Sourcepub fn builder() -> BatchGetIterableFormsOutputBuilder
pub fn builder() -> BatchGetIterableFormsOutputBuilder
Creates a new builder-style object to manufacture BatchGetIterableFormsOutput.