pub struct BatchGetJobsFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to BatchGetJobs.
Returns a list of resource metadata for a given list of job names. After calling the ListJobs operation, you can call this operation to access the data to which you have been granted permissions. This operation supports all IAM permissions, including permission conditions that uses tags.
Implementations
Sourceimpl BatchGetJobsFluentBuilder
impl BatchGetJobsFluentBuilder
Sourcepub fn as_input(&self) -> &BatchGetJobsInputBuilder
pub fn as_input(&self) -> &BatchGetJobsInputBuilder
Access the BatchGetJobs as a reference.
Sourcepub async fn send(
self,
) -> Result<BatchGetJobsOutput, SdkError<BatchGetJobsError, HttpResponse>>
pub async fn send( self, ) -> Result<BatchGetJobsOutput, SdkError<BatchGetJobsError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<BatchGetJobsOutput, BatchGetJobsError, Self>
pub fn customize( self, ) -> CustomizableOperation<BatchGetJobsOutput, BatchGetJobsError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn job_names(self, input: impl Into<String>) -> Self
pub fn job_names(self, input: impl Into<String>) -> Self
Appends an item to JobNames.
To override the contents of this collection use set_job_names.
A list of job names, which might be the names returned from the ListJobs operation.
Sourcepub fn set_job_names(self, input: Option<Vec<String>>) -> Self
pub fn set_job_names(self, input: Option<Vec<String>>) -> Self
A list of job names, which might be the names returned from the ListJobs operation.
Sourcepub fn get_job_names(&self) -> &Option<Vec<String>>
pub fn get_job_names(&self) -> &Option<Vec<String>>
A list of job names, which might be the names returned from the ListJobs operation.