#[non_exhaustive]pub struct BatchGetJobsInputBuilder { /* private fields */ }Expand description
A builder for BatchGetJobsInput.
Implementations
Sourceimpl BatchGetJobsInputBuilder
impl BatchGetJobsInputBuilder
Sourcepub fn job_names(self, input: impl Into<String>) -> Self
pub fn job_names(self, input: impl Into<String>) -> Self
Appends an item to job_names.
To override the contents of this collection use set_job_names.
A list of job names, which might be the names returned from the ListJobs operation.
Sourcepub fn set_job_names(self, input: Option<Vec<String>>) -> Self
pub fn set_job_names(self, input: Option<Vec<String>>) -> Self
A list of job names, which might be the names returned from the ListJobs operation.
Sourcepub fn get_job_names(&self) -> &Option<Vec<String>>
pub fn get_job_names(&self) -> &Option<Vec<String>>
A list of job names, which might be the names returned from the ListJobs operation.
Sourcepub fn build(self) -> Result<BatchGetJobsInput, BuildError>
pub fn build(self) -> Result<BatchGetJobsInput, BuildError>
Consumes the builder and constructs a BatchGetJobsInput.
Sourceimpl BatchGetJobsInputBuilder
impl BatchGetJobsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<BatchGetJobsOutput, SdkError<BatchGetJobsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<BatchGetJobsOutput, SdkError<BatchGetJobsError, HttpResponse>>
Sends a request with this input using the given client.