#[non_exhaustive]pub struct BatchGetJobsOutputBuilder { /* private fields */ }Expand description
A builder for BatchGetJobsOutput.
Implementations
Sourceimpl BatchGetJobsOutputBuilder
impl BatchGetJobsOutputBuilder
Sourcepub fn jobs(self, input: Job) -> Self
pub fn jobs(self, input: Job) -> Self
Appends an item to jobs.
To override the contents of this collection use set_jobs.
A list of job definitions.
Sourcepub fn jobs_not_found(self, input: impl Into<String>) -> Self
pub fn jobs_not_found(self, input: impl Into<String>) -> Self
Appends an item to jobs_not_found.
To override the contents of this collection use set_jobs_not_found.
A list of names of jobs not found.
Sourcepub fn set_jobs_not_found(self, input: Option<Vec<String>>) -> Self
pub fn set_jobs_not_found(self, input: Option<Vec<String>>) -> Self
A list of names of jobs not found.
Sourcepub fn get_jobs_not_found(&self) -> &Option<Vec<String>>
pub fn get_jobs_not_found(&self) -> &Option<Vec<String>>
A list of names of jobs not found.
Sourcepub fn build(self) -> BatchGetJobsOutput
pub fn build(self) -> BatchGetJobsOutput
Consumes the builder and constructs a BatchGetJobsOutput.