#[non_exhaustive]pub struct BatchGetJobsOutput {
pub jobs: Option<Vec<Job>>,
pub jobs_not_found: Option<Vec<String>>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.jobs: Option<Vec<Job>>A list of job definitions.
jobs_not_found: Option<Vec<String>>A list of names of jobs not found.
Implementations
Sourceimpl BatchGetJobsOutput
impl BatchGetJobsOutput
Sourcepub fn jobs(&self) -> &[Job]
pub fn jobs(&self) -> &[Job]
A list of job definitions.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .jobs.is_none().
Sourcepub fn jobs_not_found(&self) -> &[String]
pub fn jobs_not_found(&self) -> &[String]
A list of names of jobs not found.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .jobs_not_found.is_none().
Sourceimpl BatchGetJobsOutput
impl BatchGetJobsOutput
Sourcepub fn builder() -> BatchGetJobsOutputBuilder
pub fn builder() -> BatchGetJobsOutputBuilder
Creates a new builder-style object to manufacture BatchGetJobsOutput.