pub struct BatchGetPartitionFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to BatchGetPartition.
Retrieves partitions in a batch request.
Implementations
Sourceimpl BatchGetPartitionFluentBuilder
impl BatchGetPartitionFluentBuilder
Sourcepub fn as_input(&self) -> &BatchGetPartitionInputBuilder
pub fn as_input(&self) -> &BatchGetPartitionInputBuilder
Access the BatchGetPartition as a reference.
Sourcepub async fn send(
self,
) -> Result<BatchGetPartitionOutput, SdkError<BatchGetPartitionError, HttpResponse>>
pub async fn send( self, ) -> Result<BatchGetPartitionOutput, SdkError<BatchGetPartitionError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<BatchGetPartitionOutput, BatchGetPartitionError, Self>
pub fn customize( self, ) -> CustomizableOperation<BatchGetPartitionOutput, BatchGetPartitionError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn catalog_id(self, input: impl Into<String>) -> Self
pub fn catalog_id(self, input: impl Into<String>) -> Self
The ID of the Data Catalog where the partitions in question reside. If none is supplied, the Amazon Web Services account ID is used by default.
Sourcepub fn set_catalog_id(self, input: Option<String>) -> Self
pub fn set_catalog_id(self, input: Option<String>) -> Self
The ID of the Data Catalog where the partitions in question reside. If none is supplied, the Amazon Web Services account ID is used by default.
Sourcepub fn get_catalog_id(&self) -> &Option<String>
pub fn get_catalog_id(&self) -> &Option<String>
The ID of the Data Catalog where the partitions in question reside. If none is supplied, the Amazon Web Services account ID is used by default.
Sourcepub fn database_name(self, input: impl Into<String>) -> Self
pub fn database_name(self, input: impl Into<String>) -> Self
The name of the catalog database where the partitions reside.
Sourcepub fn set_database_name(self, input: Option<String>) -> Self
pub fn set_database_name(self, input: Option<String>) -> Self
The name of the catalog database where the partitions reside.
Sourcepub fn get_database_name(&self) -> &Option<String>
pub fn get_database_name(&self) -> &Option<String>
The name of the catalog database where the partitions reside.
Sourcepub fn table_name(self, input: impl Into<String>) -> Self
pub fn table_name(self, input: impl Into<String>) -> Self
The name of the partitions' table.
Sourcepub fn set_table_name(self, input: Option<String>) -> Self
pub fn set_table_name(self, input: Option<String>) -> Self
The name of the partitions' table.
Sourcepub fn get_table_name(&self) -> &Option<String>
pub fn get_table_name(&self) -> &Option<String>
The name of the partitions' table.
Sourcepub fn partitions_to_get(self, input: PartitionValueList) -> Self
pub fn partitions_to_get(self, input: PartitionValueList) -> Self
Appends an item to PartitionsToGet.
To override the contents of this collection use set_partitions_to_get.
A list of partition values identifying the partitions to retrieve.
Sourcepub fn set_partitions_to_get(
self,
input: Option<Vec<PartitionValueList>>,
) -> Self
pub fn set_partitions_to_get( self, input: Option<Vec<PartitionValueList>>, ) -> Self
A list of partition values identifying the partitions to retrieve.
Sourcepub fn get_partitions_to_get(&self) -> &Option<Vec<PartitionValueList>>
pub fn get_partitions_to_get(&self) -> &Option<Vec<PartitionValueList>>
A list of partition values identifying the partitions to retrieve.
Sourcepub fn audit_context(self, input: AuditContext) -> Self
pub fn audit_context(self, input: AuditContext) -> Self
A structure containing the Lake Formation audit context.
Sourcepub fn set_audit_context(self, input: Option<AuditContext>) -> Self
pub fn set_audit_context(self, input: Option<AuditContext>) -> Self
A structure containing the Lake Formation audit context.
Sourcepub fn get_audit_context(&self) -> &Option<AuditContext>
pub fn get_audit_context(&self) -> &Option<AuditContext>
A structure containing the Lake Formation audit context.
Sourcepub fn query_session_context(self, input: QuerySessionContext) -> Self
pub fn query_session_context(self, input: QuerySessionContext) -> Self
A structure used as a protocol between query engines and Lake Formation or Glue. Contains both a Lake Formation generated authorization identifier and information from the request's authorization context.
Sourcepub fn set_query_session_context(
self,
input: Option<QuerySessionContext>,
) -> Self
pub fn set_query_session_context( self, input: Option<QuerySessionContext>, ) -> Self
A structure used as a protocol between query engines and Lake Formation or Glue. Contains both a Lake Formation generated authorization identifier and information from the request's authorization context.
Sourcepub fn get_query_session_context(&self) -> &Option<QuerySessionContext>
pub fn get_query_session_context(&self) -> &Option<QuerySessionContext>
A structure used as a protocol between query engines and Lake Formation or Glue. Contains both a Lake Formation generated authorization identifier and information from the request's authorization context.