#[non_exhaustive]pub struct BatchPutDataQualityStatisticAnnotationInputBuilder { /* private fields */ }Expand description
A builder for BatchPutDataQualityStatisticAnnotationInput.
Implementations
Sourceimpl BatchPutDataQualityStatisticAnnotationInputBuilder
impl BatchPutDataQualityStatisticAnnotationInputBuilder
Sourcepub fn inclusion_annotations(self, input: DatapointInclusionAnnotation) -> Self
pub fn inclusion_annotations(self, input: DatapointInclusionAnnotation) -> Self
Appends an item to inclusion_annotations.
To override the contents of this collection use set_inclusion_annotations.
A list of DatapointInclusionAnnotation's. The InclusionAnnotations must contain a profileId and statisticId. If there are multiple InclusionAnnotations, the list must refer to a single statisticId across multiple profileIds.
Sourcepub fn set_inclusion_annotations(
self,
input: Option<Vec<DatapointInclusionAnnotation>>,
) -> Self
pub fn set_inclusion_annotations( self, input: Option<Vec<DatapointInclusionAnnotation>>, ) -> Self
A list of DatapointInclusionAnnotation's. The InclusionAnnotations must contain a profileId and statisticId. If there are multiple InclusionAnnotations, the list must refer to a single statisticId across multiple profileIds.
Sourcepub fn get_inclusion_annotations(
&self,
) -> &Option<Vec<DatapointInclusionAnnotation>>
pub fn get_inclusion_annotations( &self, ) -> &Option<Vec<DatapointInclusionAnnotation>>
A list of DatapointInclusionAnnotation's. The InclusionAnnotations must contain a profileId and statisticId. If there are multiple InclusionAnnotations, the list must refer to a single statisticId across multiple profileIds.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
Client Token.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
Client Token.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
Client Token.
Sourcepub fn build(
self,
) -> Result<BatchPutDataQualityStatisticAnnotationInput, BuildError>
pub fn build( self, ) -> Result<BatchPutDataQualityStatisticAnnotationInput, BuildError>
Consumes the builder and constructs a BatchPutDataQualityStatisticAnnotationInput.
Sourceimpl BatchPutDataQualityStatisticAnnotationInputBuilder
impl BatchPutDataQualityStatisticAnnotationInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<BatchPutDataQualityStatisticAnnotationOutput, SdkError<BatchPutDataQualityStatisticAnnotationError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<BatchPutDataQualityStatisticAnnotationOutput, SdkError<BatchPutDataQualityStatisticAnnotationError, HttpResponse>>
Sends a request with this input using the given client.