#[non_exhaustive]pub struct CreateBlueprintOutputBuilder { /* private fields */ }Expand description
A builder for CreateBlueprintOutput.
Implementations
Sourceimpl CreateBlueprintOutputBuilder
impl CreateBlueprintOutputBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
Returns the name of the blueprint that was registered.
Sourcepub fn set_name(self, input: Option<String>) -> Self
pub fn set_name(self, input: Option<String>) -> Self
Returns the name of the blueprint that was registered.
Sourcepub fn get_name(&self) -> &Option<String>
pub fn get_name(&self) -> &Option<String>
Returns the name of the blueprint that was registered.
Sourcepub fn build(self) -> CreateBlueprintOutput
pub fn build(self) -> CreateBlueprintOutput
Consumes the builder and constructs a CreateBlueprintOutput.