pub struct CreateCatalogFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to CreateCatalog.
Creates a new catalog in the Glue Data Catalog.
Implementations
Sourceimpl CreateCatalogFluentBuilder
impl CreateCatalogFluentBuilder
Sourcepub fn as_input(&self) -> &CreateCatalogInputBuilder
pub fn as_input(&self) -> &CreateCatalogInputBuilder
Access the CreateCatalog as a reference.
Sourcepub async fn send(
self,
) -> Result<CreateCatalogOutput, SdkError<CreateCatalogError, HttpResponse>>
pub async fn send( self, ) -> Result<CreateCatalogOutput, SdkError<CreateCatalogError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<CreateCatalogOutput, CreateCatalogError, Self>
pub fn customize( self, ) -> CustomizableOperation<CreateCatalogOutput, CreateCatalogError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn catalog_input(self, input: CatalogInput) -> Self
pub fn catalog_input(self, input: CatalogInput) -> Self
A CatalogInput object that defines the metadata for the catalog.
Sourcepub fn set_catalog_input(self, input: Option<CatalogInput>) -> Self
pub fn set_catalog_input(self, input: Option<CatalogInput>) -> Self
A CatalogInput object that defines the metadata for the catalog.
Sourcepub fn get_catalog_input(&self) -> &Option<CatalogInput>
pub fn get_catalog_input(&self) -> &Option<CatalogInput>
A CatalogInput object that defines the metadata for the catalog.
Adds a key-value pair to Tags.
To override the contents of this collection use set_tags.
A map array of key-value pairs, not more than 50 pairs. Each key is a UTF-8 string, not less than 1 or more than 128 bytes long. Each value is a UTF-8 string, not more than 256 bytes long. The tags you assign to the catalog.
A map array of key-value pairs, not more than 50 pairs. Each key is a UTF-8 string, not less than 1 or more than 128 bytes long. Each value is a UTF-8 string, not more than 256 bytes long. The tags you assign to the catalog.
A map array of key-value pairs, not more than 50 pairs. Each key is a UTF-8 string, not less than 1 or more than 128 bytes long. Each value is a UTF-8 string, not more than 256 bytes long. The tags you assign to the catalog.