#[non_exhaustive]pub struct CreateCatalogInputBuilder { /* private fields */ }Expand description
A builder for CreateCatalogInput.
Implementations
Sourceimpl CreateCatalogInputBuilder
impl CreateCatalogInputBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the catalog to create.
This field is required.Sourcepub fn catalog_input(self, input: CatalogInput) -> Self
pub fn catalog_input(self, input: CatalogInput) -> Self
A CatalogInput object that defines the metadata for the catalog.
Sourcepub fn set_catalog_input(self, input: Option<CatalogInput>) -> Self
pub fn set_catalog_input(self, input: Option<CatalogInput>) -> Self
A CatalogInput object that defines the metadata for the catalog.
Sourcepub fn get_catalog_input(&self) -> &Option<CatalogInput>
pub fn get_catalog_input(&self) -> &Option<CatalogInput>
A CatalogInput object that defines the metadata for the catalog.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
A map array of key-value pairs, not more than 50 pairs. Each key is a UTF-8 string, not less than 1 or more than 128 bytes long. Each value is a UTF-8 string, not more than 256 bytes long. The tags you assign to the catalog.
A map array of key-value pairs, not more than 50 pairs. Each key is a UTF-8 string, not less than 1 or more than 128 bytes long. Each value is a UTF-8 string, not more than 256 bytes long. The tags you assign to the catalog.
A map array of key-value pairs, not more than 50 pairs. Each key is a UTF-8 string, not less than 1 or more than 128 bytes long. Each value is a UTF-8 string, not more than 256 bytes long. The tags you assign to the catalog.
Sourcepub fn build(self) -> Result<CreateCatalogInput, BuildError>
pub fn build(self) -> Result<CreateCatalogInput, BuildError>
Consumes the builder and constructs a CreateCatalogInput.
Sourceimpl CreateCatalogInputBuilder
impl CreateCatalogInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateCatalogOutput, SdkError<CreateCatalogError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateCatalogOutput, SdkError<CreateCatalogError, HttpResponse>>
Sends a request with this input using the given client.