#[non_exhaustive]pub struct CreateCatalogInput {
pub name: Option<String>,
pub catalog_input: Option<CatalogInput>,
pub tags: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>The name of the catalog to create.
catalog_input: Option<CatalogInput>A CatalogInput object that defines the metadata for the catalog.
A map array of key-value pairs, not more than 50 pairs. Each key is a UTF-8 string, not less than 1 or more than 128 bytes long. Each value is a UTF-8 string, not more than 256 bytes long. The tags you assign to the catalog.
Implementations
Sourceimpl CreateCatalogInput
impl CreateCatalogInput
Sourcepub fn catalog_input(&self) -> Option<&CatalogInput>
pub fn catalog_input(&self) -> Option<&CatalogInput>
A CatalogInput object that defines the metadata for the catalog.
A map array of key-value pairs, not more than 50 pairs. Each key is a UTF-8 string, not less than 1 or more than 128 bytes long. Each value is a UTF-8 string, not more than 256 bytes long. The tags you assign to the catalog.
Sourceimpl CreateCatalogInput
impl CreateCatalogInput
Sourcepub fn builder() -> CreateCatalogInputBuilder
pub fn builder() -> CreateCatalogInputBuilder
Creates a new builder-style object to manufacture CreateCatalogInput.