pub struct CreateColumnStatisticsTaskSettingsFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to CreateColumnStatisticsTaskSettings.
Creates settings for a column statistics task.
Implementations
Sourceimpl CreateColumnStatisticsTaskSettingsFluentBuilder
impl CreateColumnStatisticsTaskSettingsFluentBuilder
Sourcepub fn as_input(&self) -> &CreateColumnStatisticsTaskSettingsInputBuilder
pub fn as_input(&self) -> &CreateColumnStatisticsTaskSettingsInputBuilder
Access the CreateColumnStatisticsTaskSettings as a reference.
Sourcepub async fn send(
self,
) -> Result<CreateColumnStatisticsTaskSettingsOutput, SdkError<CreateColumnStatisticsTaskSettingsError, HttpResponse>>
pub async fn send( self, ) -> Result<CreateColumnStatisticsTaskSettingsOutput, SdkError<CreateColumnStatisticsTaskSettingsError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<CreateColumnStatisticsTaskSettingsOutput, CreateColumnStatisticsTaskSettingsError, Self>
pub fn customize( self, ) -> CustomizableOperation<CreateColumnStatisticsTaskSettingsOutput, CreateColumnStatisticsTaskSettingsError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn database_name(self, input: impl Into<String>) -> Self
pub fn database_name(self, input: impl Into<String>) -> Self
The name of the database where the table resides.
Sourcepub fn set_database_name(self, input: Option<String>) -> Self
pub fn set_database_name(self, input: Option<String>) -> Self
The name of the database where the table resides.
Sourcepub fn get_database_name(&self) -> &Option<String>
pub fn get_database_name(&self) -> &Option<String>
The name of the database where the table resides.
Sourcepub fn table_name(self, input: impl Into<String>) -> Self
pub fn table_name(self, input: impl Into<String>) -> Self
The name of the table for which to generate column statistics.
Sourcepub fn set_table_name(self, input: Option<String>) -> Self
pub fn set_table_name(self, input: Option<String>) -> Self
The name of the table for which to generate column statistics.
Sourcepub fn get_table_name(&self) -> &Option<String>
pub fn get_table_name(&self) -> &Option<String>
The name of the table for which to generate column statistics.
Sourcepub fn role(self, input: impl Into<String>) -> Self
pub fn role(self, input: impl Into<String>) -> Self
The role used for running the column statistics.
Sourcepub fn set_role(self, input: Option<String>) -> Self
pub fn set_role(self, input: Option<String>) -> Self
The role used for running the column statistics.
Sourcepub fn schedule(self, input: impl Into<String>) -> Self
pub fn schedule(self, input: impl Into<String>) -> Self
A schedule for running the column statistics, specified in CRON syntax.
Sourcepub fn set_schedule(self, input: Option<String>) -> Self
pub fn set_schedule(self, input: Option<String>) -> Self
A schedule for running the column statistics, specified in CRON syntax.
Sourcepub fn get_schedule(&self) -> &Option<String>
pub fn get_schedule(&self) -> &Option<String>
A schedule for running the column statistics, specified in CRON syntax.
Sourcepub fn column_name_list(self, input: impl Into<String>) -> Self
pub fn column_name_list(self, input: impl Into<String>) -> Self
Appends an item to ColumnNameList.
To override the contents of this collection use set_column_name_list.
A list of column names for which to run statistics.
Sourcepub fn set_column_name_list(self, input: Option<Vec<String>>) -> Self
pub fn set_column_name_list(self, input: Option<Vec<String>>) -> Self
A list of column names for which to run statistics.
Sourcepub fn get_column_name_list(&self) -> &Option<Vec<String>>
pub fn get_column_name_list(&self) -> &Option<Vec<String>>
A list of column names for which to run statistics.
Sourcepub fn sample_size(self, input: f64) -> Self
pub fn sample_size(self, input: f64) -> Self
The percentage of data to sample.
Sourcepub fn set_sample_size(self, input: Option<f64>) -> Self
pub fn set_sample_size(self, input: Option<f64>) -> Self
The percentage of data to sample.
Sourcepub fn get_sample_size(&self) -> &Option<f64>
pub fn get_sample_size(&self) -> &Option<f64>
The percentage of data to sample.
Sourcepub fn catalog_id(self, input: impl Into<String>) -> Self
pub fn catalog_id(self, input: impl Into<String>) -> Self
The ID of the Data Catalog in which the database resides.
Sourcepub fn set_catalog_id(self, input: Option<String>) -> Self
pub fn set_catalog_id(self, input: Option<String>) -> Self
The ID of the Data Catalog in which the database resides.
Sourcepub fn get_catalog_id(&self) -> &Option<String>
pub fn get_catalog_id(&self) -> &Option<String>
The ID of the Data Catalog in which the database resides.
Sourcepub fn security_configuration(self, input: impl Into<String>) -> Self
pub fn security_configuration(self, input: impl Into<String>) -> Self
Name of the security configuration that is used to encrypt CloudWatch logs.
Sourcepub fn set_security_configuration(self, input: Option<String>) -> Self
pub fn set_security_configuration(self, input: Option<String>) -> Self
Name of the security configuration that is used to encrypt CloudWatch logs.
Sourcepub fn get_security_configuration(&self) -> &Option<String>
pub fn get_security_configuration(&self) -> &Option<String>
Name of the security configuration that is used to encrypt CloudWatch logs.
Adds a key-value pair to Tags.
To override the contents of this collection use set_tags.
A map of tags.
A map of tags.
A map of tags.