#[non_exhaustive]pub struct CreateColumnStatisticsTaskSettingsInput {
pub database_name: Option<String>,
pub table_name: Option<String>,
pub role: Option<String>,
pub schedule: Option<String>,
pub column_name_list: Option<Vec<String>>,
pub sample_size: Option<f64>,
pub catalog_id: Option<String>,
pub security_configuration: Option<String>,
pub tags: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.database_name: Option<String>The name of the database where the table resides.
table_name: Option<String>The name of the table for which to generate column statistics.
role: Option<String>The role used for running the column statistics.
schedule: Option<String>A schedule for running the column statistics, specified in CRON syntax.
column_name_list: Option<Vec<String>>A list of column names for which to run statistics.
sample_size: Option<f64>The percentage of data to sample.
catalog_id: Option<String>The ID of the Data Catalog in which the database resides.
security_configuration: Option<String>Name of the security configuration that is used to encrypt CloudWatch logs.
A map of tags.
Implementations
Sourceimpl CreateColumnStatisticsTaskSettingsInput
impl CreateColumnStatisticsTaskSettingsInput
Sourcepub fn database_name(&self) -> Option<&str>
pub fn database_name(&self) -> Option<&str>
The name of the database where the table resides.
Sourcepub fn table_name(&self) -> Option<&str>
pub fn table_name(&self) -> Option<&str>
The name of the table for which to generate column statistics.
Sourcepub fn schedule(&self) -> Option<&str>
pub fn schedule(&self) -> Option<&str>
A schedule for running the column statistics, specified in CRON syntax.
Sourcepub fn column_name_list(&self) -> &[String]
pub fn column_name_list(&self) -> &[String]
A list of column names for which to run statistics.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .column_name_list.is_none().
Sourcepub fn sample_size(&self) -> Option<f64>
pub fn sample_size(&self) -> Option<f64>
The percentage of data to sample.
Sourcepub fn catalog_id(&self) -> Option<&str>
pub fn catalog_id(&self) -> Option<&str>
The ID of the Data Catalog in which the database resides.
Sourcepub fn security_configuration(&self) -> Option<&str>
pub fn security_configuration(&self) -> Option<&str>
Name of the security configuration that is used to encrypt CloudWatch logs.
A map of tags.
Sourceimpl CreateColumnStatisticsTaskSettingsInput
impl CreateColumnStatisticsTaskSettingsInput
Sourcepub fn builder() -> CreateColumnStatisticsTaskSettingsInputBuilder
pub fn builder() -> CreateColumnStatisticsTaskSettingsInputBuilder
Creates a new builder-style object to manufacture CreateColumnStatisticsTaskSettingsInput.