pub struct CreateGlossaryFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to CreateGlossary.
Creates a business glossary in Glue Data Catalog. A glossary is a container for glossary terms that define business concepts.
Implementations
Sourceimpl CreateGlossaryFluentBuilder
impl CreateGlossaryFluentBuilder
Sourcepub fn as_input(&self) -> &CreateGlossaryInputBuilder
pub fn as_input(&self) -> &CreateGlossaryInputBuilder
Access the CreateGlossary as a reference.
Sourcepub async fn send(
self,
) -> Result<CreateGlossaryOutput, SdkError<CreateGlossaryError, HttpResponse>>
pub async fn send( self, ) -> Result<CreateGlossaryOutput, SdkError<CreateGlossaryError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<CreateGlossaryOutput, CreateGlossaryError, Self>
pub fn customize( self, ) -> CustomizableOperation<CreateGlossaryOutput, CreateGlossaryError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
The description of the glossary.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
The description of the glossary.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
The description of the glossary.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.