#[non_exhaustive]pub struct CreateGlossaryInputBuilder { /* private fields */ }Expand description
A builder for CreateGlossaryInput.
Implementations
Sourceimpl CreateGlossaryInputBuilder
impl CreateGlossaryInputBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the glossary.
This field is required.Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
The description of the glossary.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
The description of the glossary.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
The description of the glossary.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn build(self) -> Result<CreateGlossaryInput, BuildError>
pub fn build(self) -> Result<CreateGlossaryInput, BuildError>
Consumes the builder and constructs a CreateGlossaryInput.
Sourceimpl CreateGlossaryInputBuilder
impl CreateGlossaryInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateGlossaryOutput, SdkError<CreateGlossaryError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateGlossaryOutput, SdkError<CreateGlossaryError, HttpResponse>>
Sends a request with this input using the given client.