pub struct CreateGlossaryTermFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to CreateGlossaryTerm.
Creates a glossary term within a business glossary in Glue Data Catalog.
Implementations
Sourceimpl CreateGlossaryTermFluentBuilder
impl CreateGlossaryTermFluentBuilder
Sourcepub fn as_input(&self) -> &CreateGlossaryTermInputBuilder
pub fn as_input(&self) -> &CreateGlossaryTermInputBuilder
Access the CreateGlossaryTerm as a reference.
Sourcepub async fn send(
self,
) -> Result<CreateGlossaryTermOutput, SdkError<CreateGlossaryTermError, HttpResponse>>
pub async fn send( self, ) -> Result<CreateGlossaryTermOutput, SdkError<CreateGlossaryTermError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<CreateGlossaryTermOutput, CreateGlossaryTermError, Self>
pub fn customize( self, ) -> CustomizableOperation<CreateGlossaryTermOutput, CreateGlossaryTermError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn glossary_identifier(self, input: impl Into<String>) -> Self
pub fn glossary_identifier(self, input: impl Into<String>) -> Self
The unique identifier of the glossary in which to create the term.
Sourcepub fn set_glossary_identifier(self, input: Option<String>) -> Self
pub fn set_glossary_identifier(self, input: Option<String>) -> Self
The unique identifier of the glossary in which to create the term.
Sourcepub fn get_glossary_identifier(&self) -> &Option<String>
pub fn get_glossary_identifier(&self) -> &Option<String>
The unique identifier of the glossary in which to create the term.
Sourcepub fn short_description(self, input: impl Into<String>) -> Self
pub fn short_description(self, input: impl Into<String>) -> Self
A short description of the glossary term.
Sourcepub fn set_short_description(self, input: Option<String>) -> Self
pub fn set_short_description(self, input: Option<String>) -> Self
A short description of the glossary term.
Sourcepub fn get_short_description(&self) -> &Option<String>
pub fn get_short_description(&self) -> &Option<String>
A short description of the glossary term.
Sourcepub fn long_description(self, input: impl Into<String>) -> Self
pub fn long_description(self, input: impl Into<String>) -> Self
A long description of the glossary term.
Sourcepub fn set_long_description(self, input: Option<String>) -> Self
pub fn set_long_description(self, input: Option<String>) -> Self
A long description of the glossary term.
Sourcepub fn get_long_description(&self) -> &Option<String>
pub fn get_long_description(&self) -> &Option<String>
A long description of the glossary term.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.