#[non_exhaustive]pub struct CreateGlossaryTermInputBuilder { /* private fields */ }Expand description
A builder for CreateGlossaryTermInput.
Implementations
Sourceimpl CreateGlossaryTermInputBuilder
impl CreateGlossaryTermInputBuilder
Sourcepub fn glossary_identifier(self, input: impl Into<String>) -> Self
pub fn glossary_identifier(self, input: impl Into<String>) -> Self
The unique identifier of the glossary in which to create the term.
This field is required.Sourcepub fn set_glossary_identifier(self, input: Option<String>) -> Self
pub fn set_glossary_identifier(self, input: Option<String>) -> Self
The unique identifier of the glossary in which to create the term.
Sourcepub fn get_glossary_identifier(&self) -> &Option<String>
pub fn get_glossary_identifier(&self) -> &Option<String>
The unique identifier of the glossary in which to create the term.
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the glossary term.
This field is required.Sourcepub fn short_description(self, input: impl Into<String>) -> Self
pub fn short_description(self, input: impl Into<String>) -> Self
A short description of the glossary term.
Sourcepub fn set_short_description(self, input: Option<String>) -> Self
pub fn set_short_description(self, input: Option<String>) -> Self
A short description of the glossary term.
Sourcepub fn get_short_description(&self) -> &Option<String>
pub fn get_short_description(&self) -> &Option<String>
A short description of the glossary term.
Sourcepub fn long_description(self, input: impl Into<String>) -> Self
pub fn long_description(self, input: impl Into<String>) -> Self
A long description of the glossary term.
Sourcepub fn set_long_description(self, input: Option<String>) -> Self
pub fn set_long_description(self, input: Option<String>) -> Self
A long description of the glossary term.
Sourcepub fn get_long_description(&self) -> &Option<String>
pub fn get_long_description(&self) -> &Option<String>
A long description of the glossary term.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn build(self) -> Result<CreateGlossaryTermInput, BuildError>
pub fn build(self) -> Result<CreateGlossaryTermInput, BuildError>
Consumes the builder and constructs a CreateGlossaryTermInput.
Sourceimpl CreateGlossaryTermInputBuilder
impl CreateGlossaryTermInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateGlossaryTermOutput, SdkError<CreateGlossaryTermError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateGlossaryTermOutput, SdkError<CreateGlossaryTermError, HttpResponse>>
Sends a request with this input using the given client.