#[non_exhaustive]pub struct CreateGlossaryTermInput {
pub glossary_identifier: Option<String>,
pub name: Option<String>,
pub short_description: Option<String>,
pub long_description: Option<String>,
pub client_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.glossary_identifier: Option<String>The unique identifier of the glossary in which to create the term.
name: Option<String>The name of the glossary term.
short_description: Option<String>A short description of the glossary term.
long_description: Option<String>A long description of the glossary term.
client_token: Option<String>A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Implementations
Sourceimpl CreateGlossaryTermInput
impl CreateGlossaryTermInput
Sourcepub fn glossary_identifier(&self) -> Option<&str>
pub fn glossary_identifier(&self) -> Option<&str>
The unique identifier of the glossary in which to create the term.
Sourcepub fn short_description(&self) -> Option<&str>
pub fn short_description(&self) -> Option<&str>
A short description of the glossary term.
Sourcepub fn long_description(&self) -> Option<&str>
pub fn long_description(&self) -> Option<&str>
A long description of the glossary term.
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourceimpl CreateGlossaryTermInput
impl CreateGlossaryTermInput
Sourcepub fn builder() -> CreateGlossaryTermInputBuilder
pub fn builder() -> CreateGlossaryTermInputBuilder
Creates a new builder-style object to manufacture CreateGlossaryTermInput.