#[non_exhaustive]pub struct CreateGlossaryTermOutput {
pub id: Option<String>,
pub glossary_id: Option<String>,
pub name: Option<String>,
pub short_description: Option<String>,
pub long_description: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<String>The unique identifier of the glossary term.
glossary_id: Option<String>The unique identifier of the glossary containing this term.
name: Option<String>The name of the glossary term.
short_description: Option<String>The short description of the glossary term.
long_description: Option<String>The long description of the glossary term.
Implementations
Sourceimpl CreateGlossaryTermOutput
impl CreateGlossaryTermOutput
Sourcepub fn glossary_id(&self) -> Option<&str>
pub fn glossary_id(&self) -> Option<&str>
The unique identifier of the glossary containing this term.
Sourcepub fn short_description(&self) -> Option<&str>
pub fn short_description(&self) -> Option<&str>
The short description of the glossary term.
Sourcepub fn long_description(&self) -> Option<&str>
pub fn long_description(&self) -> Option<&str>
The long description of the glossary term.
Sourceimpl CreateGlossaryTermOutput
impl CreateGlossaryTermOutput
Sourcepub fn builder() -> CreateGlossaryTermOutputBuilder
pub fn builder() -> CreateGlossaryTermOutputBuilder
Creates a new builder-style object to manufacture CreateGlossaryTermOutput.