pub struct CreateGlueIdentityCenterConfigurationFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to CreateGlueIdentityCenterConfiguration.
Creates a new Glue Identity Center configuration to enable integration between Glue and Amazon Web Services IAM Identity Center for authentication and authorization.
Implementations
Sourceimpl CreateGlueIdentityCenterConfigurationFluentBuilder
impl CreateGlueIdentityCenterConfigurationFluentBuilder
Sourcepub fn as_input(&self) -> &CreateGlueIdentityCenterConfigurationInputBuilder
pub fn as_input(&self) -> &CreateGlueIdentityCenterConfigurationInputBuilder
Access the CreateGlueIdentityCenterConfiguration as a reference.
Sourcepub async fn send(
self,
) -> Result<CreateGlueIdentityCenterConfigurationOutput, SdkError<CreateGlueIdentityCenterConfigurationError, HttpResponse>>
pub async fn send( self, ) -> Result<CreateGlueIdentityCenterConfigurationOutput, SdkError<CreateGlueIdentityCenterConfigurationError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<CreateGlueIdentityCenterConfigurationOutput, CreateGlueIdentityCenterConfigurationError, Self>
pub fn customize( self, ) -> CustomizableOperation<CreateGlueIdentityCenterConfigurationOutput, CreateGlueIdentityCenterConfigurationError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn instance_arn(self, input: impl Into<String>) -> Self
pub fn instance_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the Identity Center instance to be associated with the Glue configuration.
Sourcepub fn set_instance_arn(self, input: Option<String>) -> Self
pub fn set_instance_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the Identity Center instance to be associated with the Glue configuration.
Sourcepub fn get_instance_arn(&self) -> &Option<String>
pub fn get_instance_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the Identity Center instance to be associated with the Glue configuration.
Sourcepub fn scopes(self, input: impl Into<String>) -> Self
pub fn scopes(self, input: impl Into<String>) -> Self
Appends an item to Scopes.
To override the contents of this collection use set_scopes.
A list of Identity Center scopes that define the permissions and access levels for the Glue configuration.
Sourcepub fn set_scopes(self, input: Option<Vec<String>>) -> Self
pub fn set_scopes(self, input: Option<Vec<String>>) -> Self
A list of Identity Center scopes that define the permissions and access levels for the Glue configuration.
Sourcepub fn get_scopes(&self) -> &Option<Vec<String>>
pub fn get_scopes(&self) -> &Option<Vec<String>>
A list of Identity Center scopes that define the permissions and access levels for the Glue configuration.
Sourcepub fn user_background_sessions_enabled(self, input: bool) -> Self
pub fn user_background_sessions_enabled(self, input: bool) -> Self
Specifies whether users can run background sessions when using Identity Center authentication with Glue services.
Sourcepub fn set_user_background_sessions_enabled(self, input: Option<bool>) -> Self
pub fn set_user_background_sessions_enabled(self, input: Option<bool>) -> Self
Specifies whether users can run background sessions when using Identity Center authentication with Glue services.
Sourcepub fn get_user_background_sessions_enabled(&self) -> &Option<bool>
pub fn get_user_background_sessions_enabled(&self) -> &Option<bool>
Specifies whether users can run background sessions when using Identity Center authentication with Glue services.