#[non_exhaustive]pub struct CreateGlueIdentityCenterConfigurationInputBuilder { /* private fields */ }Expand description
A builder for CreateGlueIdentityCenterConfigurationInput.
Implementations
Sourceimpl CreateGlueIdentityCenterConfigurationInputBuilder
impl CreateGlueIdentityCenterConfigurationInputBuilder
Sourcepub fn instance_arn(self, input: impl Into<String>) -> Self
pub fn instance_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the Identity Center instance to be associated with the Glue configuration.
This field is required.Sourcepub fn set_instance_arn(self, input: Option<String>) -> Self
pub fn set_instance_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the Identity Center instance to be associated with the Glue configuration.
Sourcepub fn get_instance_arn(&self) -> &Option<String>
pub fn get_instance_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the Identity Center instance to be associated with the Glue configuration.
Sourcepub fn scopes(self, input: impl Into<String>) -> Self
pub fn scopes(self, input: impl Into<String>) -> Self
Appends an item to scopes.
To override the contents of this collection use set_scopes.
A list of Identity Center scopes that define the permissions and access levels for the Glue configuration.
Sourcepub fn set_scopes(self, input: Option<Vec<String>>) -> Self
pub fn set_scopes(self, input: Option<Vec<String>>) -> Self
A list of Identity Center scopes that define the permissions and access levels for the Glue configuration.
Sourcepub fn get_scopes(&self) -> &Option<Vec<String>>
pub fn get_scopes(&self) -> &Option<Vec<String>>
A list of Identity Center scopes that define the permissions and access levels for the Glue configuration.
Sourcepub fn user_background_sessions_enabled(self, input: bool) -> Self
pub fn user_background_sessions_enabled(self, input: bool) -> Self
Specifies whether users can run background sessions when using Identity Center authentication with Glue services.
Sourcepub fn set_user_background_sessions_enabled(self, input: Option<bool>) -> Self
pub fn set_user_background_sessions_enabled(self, input: Option<bool>) -> Self
Specifies whether users can run background sessions when using Identity Center authentication with Glue services.
Sourcepub fn get_user_background_sessions_enabled(&self) -> &Option<bool>
pub fn get_user_background_sessions_enabled(&self) -> &Option<bool>
Specifies whether users can run background sessions when using Identity Center authentication with Glue services.
Sourcepub fn build(
self,
) -> Result<CreateGlueIdentityCenterConfigurationInput, BuildError>
pub fn build( self, ) -> Result<CreateGlueIdentityCenterConfigurationInput, BuildError>
Consumes the builder and constructs a CreateGlueIdentityCenterConfigurationInput.
Sourceimpl CreateGlueIdentityCenterConfigurationInputBuilder
impl CreateGlueIdentityCenterConfigurationInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateGlueIdentityCenterConfigurationOutput, SdkError<CreateGlueIdentityCenterConfigurationError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateGlueIdentityCenterConfigurationOutput, SdkError<CreateGlueIdentityCenterConfigurationError, HttpResponse>>
Sends a request with this input using the given client.