#[non_exhaustive]pub struct CreateGlueIdentityCenterConfigurationOutputBuilder { /* private fields */ }Expand description
A builder for CreateGlueIdentityCenterConfigurationOutput.
Implementations
Sourceimpl CreateGlueIdentityCenterConfigurationOutputBuilder
impl CreateGlueIdentityCenterConfigurationOutputBuilder
Sourcepub fn application_arn(self, input: impl Into<String>) -> Self
pub fn application_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the Identity Center application that was created for the Glue configuration.
Sourcepub fn set_application_arn(self, input: Option<String>) -> Self
pub fn set_application_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the Identity Center application that was created for the Glue configuration.
Sourcepub fn get_application_arn(&self) -> &Option<String>
pub fn get_application_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the Identity Center application that was created for the Glue configuration.
Sourcepub fn build(self) -> CreateGlueIdentityCenterConfigurationOutput
pub fn build(self) -> CreateGlueIdentityCenterConfigurationOutput
Consumes the builder and constructs a CreateGlueIdentityCenterConfigurationOutput.