#[non_exhaustive]pub struct CreateGlueIdentityCenterConfigurationOutput {
pub application_arn: Option<String>,
/* private fields */
}Expand description
Response from creating a new Glue Identity Center configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.application_arn: Option<String>The Amazon Resource Name (ARN) of the Identity Center application that was created for the Glue configuration.
Implementations
Sourceimpl CreateGlueIdentityCenterConfigurationOutput
impl CreateGlueIdentityCenterConfigurationOutput
Sourcepub fn application_arn(&self) -> Option<&str>
pub fn application_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the Identity Center application that was created for the Glue configuration.
Sourceimpl CreateGlueIdentityCenterConfigurationOutput
impl CreateGlueIdentityCenterConfigurationOutput
Sourcepub fn builder() -> CreateGlueIdentityCenterConfigurationOutputBuilder
pub fn builder() -> CreateGlueIdentityCenterConfigurationOutputBuilder
Creates a new builder-style object to manufacture CreateGlueIdentityCenterConfigurationOutput.