CreateIntegrationFluentBuilder

Struct CreateIntegrationFluentBuilder 

pub struct CreateIntegrationFluentBuilder { /* private fields */ }
Fluent builder constructing a request to CreateIntegration.

Creates a Zero-ETL integration in the caller's account between two resources with Amazon Resource Names (ARNs): the SourceArn and TargetArn.

Implementations

Source

impl CreateIntegrationFluentBuilder

pub fn as_input(&self) -> &CreateIntegrationInputBuilder

Access the CreateIntegration as a reference.

pub async fn send( self, ) -> Result<CreateIntegrationOutput, SdkError<CreateIntegrationError, HttpResponse>>

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

pub fn customize( self, ) -> CustomizableOperation<CreateIntegrationOutput, CreateIntegrationError, Self>

Consumes this builder, creating a customizable operation that can be modified before being sent.

pub fn integration_name(self, input: impl Into<String>) -> Self

A unique name for an integration in Glue.

pub fn set_integration_name(self, input: Option<String>) -> Self

A unique name for an integration in Glue.

pub fn get_integration_name(&self) -> &Option<String>

A unique name for an integration in Glue.

pub fn source_arn(self, input: impl Into<String>) -> Self

The ARN of the source resource for the integration.

pub fn set_source_arn(self, input: Option<String>) -> Self

The ARN of the source resource for the integration.

pub fn get_source_arn(&self) -> &Option<String>

The ARN of the source resource for the integration.

pub fn target_arn(self, input: impl Into<String>) -> Self

The ARN of the target resource for the integration.

pub fn set_target_arn(self, input: Option<String>) -> Self

The ARN of the target resource for the integration.

pub fn get_target_arn(&self) -> &Option<String>

The ARN of the target resource for the integration.

pub fn description(self, input: impl Into<String>) -> Self

A description of the integration.

pub fn set_description(self, input: Option<String>) -> Self

A description of the integration.

pub fn get_description(&self) -> &Option<String>

A description of the integration.

pub fn data_filter(self, input: impl Into<String>) -> Self

Selects source tables for the integration using Maxwell filter syntax.

pub fn set_data_filter(self, input: Option<String>) -> Self

Selects source tables for the integration using Maxwell filter syntax.

pub fn get_data_filter(&self) -> &Option<String>

Selects source tables for the integration using Maxwell filter syntax.

pub fn kms_key_id(self, input: impl Into<String>) -> Self

The ARN of a KMS key used for encrypting the channel.

pub fn set_kms_key_id(self, input: Option<String>) -> Self

The ARN of a KMS key used for encrypting the channel.

pub fn get_kms_key_id(&self) -> &Option<String>

The ARN of a KMS key used for encrypting the channel.

pub fn additional_encryption_context( self, k: impl Into<String>, v: impl Into<String>, ) -> Self

Adds a key-value pair to AdditionalEncryptionContext.

To override the contents of this collection use set_additional_encryption_context.

An optional set of non-secret key–value pairs that contains additional contextual information for encryption. This can only be provided if KMSKeyId is provided.

pub fn set_additional_encryption_context( self, input: Option<HashMap<String, String>>, ) -> Self

An optional set of non-secret key–value pairs that contains additional contextual information for encryption. This can only be provided if KMSKeyId is provided.

pub fn get_additional_encryption_context( &self, ) -> &Option<HashMap<String, String>>

An optional set of non-secret key–value pairs that contains additional contextual information for encryption. This can only be provided if KMSKeyId is provided.

pub fn tags(self, input: Tag) -> Self

Appends an item to Tags.

To override the contents of this collection use set_tags.

Metadata assigned to the resource consisting of a list of key-value pairs.

pub fn set_tags(self, input: Option<Vec<Tag>>) -> Self

Metadata assigned to the resource consisting of a list of key-value pairs.

pub fn get_tags(&self) -> &Option<Vec<Tag>>

Metadata assigned to the resource consisting of a list of key-value pairs.

pub fn integration_config(self, input: IntegrationConfig) -> Self

The configuration settings.

pub fn set_integration_config(self, input: Option<IntegrationConfig>) -> Self

The configuration settings.

pub fn get_integration_config(&self) -> &Option<IntegrationConfig>

The configuration settings.