#[non_exhaustive]pub struct CreateIntegrationInputBuilder { /* private fields */ }Expand description
A builder for CreateIntegrationInput.
Implementations
Sourceimpl CreateIntegrationInputBuilder
impl CreateIntegrationInputBuilder
Sourcepub fn integration_name(self, input: impl Into<String>) -> Self
pub fn integration_name(self, input: impl Into<String>) -> Self
A unique name for an integration in Glue.
This field is required.Sourcepub fn set_integration_name(self, input: Option<String>) -> Self
pub fn set_integration_name(self, input: Option<String>) -> Self
A unique name for an integration in Glue.
Sourcepub fn get_integration_name(&self) -> &Option<String>
pub fn get_integration_name(&self) -> &Option<String>
A unique name for an integration in Glue.
Sourcepub fn source_arn(self, input: impl Into<String>) -> Self
pub fn source_arn(self, input: impl Into<String>) -> Self
The ARN of the source resource for the integration.
This field is required.Sourcepub fn set_source_arn(self, input: Option<String>) -> Self
pub fn set_source_arn(self, input: Option<String>) -> Self
The ARN of the source resource for the integration.
Sourcepub fn get_source_arn(&self) -> &Option<String>
pub fn get_source_arn(&self) -> &Option<String>
The ARN of the source resource for the integration.
Sourcepub fn target_arn(self, input: impl Into<String>) -> Self
pub fn target_arn(self, input: impl Into<String>) -> Self
The ARN of the target resource for the integration.
This field is required.Sourcepub fn set_target_arn(self, input: Option<String>) -> Self
pub fn set_target_arn(self, input: Option<String>) -> Self
The ARN of the target resource for the integration.
Sourcepub fn get_target_arn(&self) -> &Option<String>
pub fn get_target_arn(&self) -> &Option<String>
The ARN of the target resource for the integration.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
A description of the integration.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
A description of the integration.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
A description of the integration.
Sourcepub fn data_filter(self, input: impl Into<String>) -> Self
pub fn data_filter(self, input: impl Into<String>) -> Self
Selects source tables for the integration using Maxwell filter syntax.
Sourcepub fn set_data_filter(self, input: Option<String>) -> Self
pub fn set_data_filter(self, input: Option<String>) -> Self
Selects source tables for the integration using Maxwell filter syntax.
Sourcepub fn get_data_filter(&self) -> &Option<String>
pub fn get_data_filter(&self) -> &Option<String>
Selects source tables for the integration using Maxwell filter syntax.
Sourcepub fn kms_key_id(self, input: impl Into<String>) -> Self
pub fn kms_key_id(self, input: impl Into<String>) -> Self
The ARN of a KMS key used for encrypting the channel.
Sourcepub fn set_kms_key_id(self, input: Option<String>) -> Self
pub fn set_kms_key_id(self, input: Option<String>) -> Self
The ARN of a KMS key used for encrypting the channel.
Sourcepub fn get_kms_key_id(&self) -> &Option<String>
pub fn get_kms_key_id(&self) -> &Option<String>
The ARN of a KMS key used for encrypting the channel.
Sourcepub fn additional_encryption_context(
self,
k: impl Into<String>,
v: impl Into<String>,
) -> Self
pub fn additional_encryption_context( self, k: impl Into<String>, v: impl Into<String>, ) -> Self
Adds a key-value pair to additional_encryption_context.
To override the contents of this collection use set_additional_encryption_context.
An optional set of non-secret key–value pairs that contains additional contextual information for encryption. This can only be provided if KMSKeyId is provided.
Sourcepub fn set_additional_encryption_context(
self,
input: Option<HashMap<String, String>>,
) -> Self
pub fn set_additional_encryption_context( self, input: Option<HashMap<String, String>>, ) -> Self
An optional set of non-secret key–value pairs that contains additional contextual information for encryption. This can only be provided if KMSKeyId is provided.
Sourcepub fn get_additional_encryption_context(
&self,
) -> &Option<HashMap<String, String>>
pub fn get_additional_encryption_context( &self, ) -> &Option<HashMap<String, String>>
An optional set of non-secret key–value pairs that contains additional contextual information for encryption. This can only be provided if KMSKeyId is provided.
Appends an item to tags.
To override the contents of this collection use set_tags.
Metadata assigned to the resource consisting of a list of key-value pairs.
Metadata assigned to the resource consisting of a list of key-value pairs.
Metadata assigned to the resource consisting of a list of key-value pairs.
Sourcepub fn integration_config(self, input: IntegrationConfig) -> Self
pub fn integration_config(self, input: IntegrationConfig) -> Self
The configuration settings.
Sourcepub fn set_integration_config(self, input: Option<IntegrationConfig>) -> Self
pub fn set_integration_config(self, input: Option<IntegrationConfig>) -> Self
The configuration settings.
Sourcepub fn get_integration_config(&self) -> &Option<IntegrationConfig>
pub fn get_integration_config(&self) -> &Option<IntegrationConfig>
The configuration settings.
Sourcepub fn build(self) -> Result<CreateIntegrationInput, BuildError>
pub fn build(self) -> Result<CreateIntegrationInput, BuildError>
Consumes the builder and constructs a CreateIntegrationInput.
Sourceimpl CreateIntegrationInputBuilder
impl CreateIntegrationInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateIntegrationOutput, SdkError<CreateIntegrationError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateIntegrationOutput, SdkError<CreateIntegrationError, HttpResponse>>
Sends a request with this input using the given client.