#[non_exhaustive]pub enum CreateIntegrationError {
Show 13 variants
AccessDeniedException(AccessDeniedException),
ConflictException(ConflictException),
EntityNotFoundException(EntityNotFoundException),
IntegrationConflictOperationFault(IntegrationConflictOperationFault),
IntegrationQuotaExceededFault(IntegrationQuotaExceededFault),
InternalServerException(InternalServerException),
InternalServiceException(InternalServiceException),
InvalidInputException(InvalidInputException),
KmsKeyNotAccessibleFault(KmsKeyNotAccessibleFault),
ResourceNotFoundException(ResourceNotFoundException),
ResourceNumberLimitExceededException(ResourceNumberLimitExceededException),
ValidationException(ValidationException),
Unhandled(Unhandled),
}Expand description
Error type for the CreateIntegrationError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AccessDeniedException(AccessDeniedException)
Access to a resource was denied.
ConflictException(ConflictException)
The CreatePartitions API was called on a table that has indexes enabled.
EntityNotFoundException(EntityNotFoundException)
A specified entity does not exist
IntegrationConflictOperationFault(IntegrationConflictOperationFault)
The requested operation conflicts with another operation.
IntegrationQuotaExceededFault(IntegrationQuotaExceededFault)
The data processed through your integration exceeded your quota.
InternalServerException(InternalServerException)
An internal server error occurred.
InternalServiceException(InternalServiceException)
An internal service error occurred.
InvalidInputException(InvalidInputException)
The input provided was not valid.
KmsKeyNotAccessibleFault(KmsKeyNotAccessibleFault)
The KMS key specified is not accessible.
ResourceNotFoundException(ResourceNotFoundException)
The resource could not be found.
ResourceNumberLimitExceededException(ResourceNumberLimitExceededException)
A resource numerical limit was exceeded.
ValidationException(ValidationException)
A value could not be validated.
Unhandled(Unhandled)
Matching Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
Sourceimpl CreateIntegrationError
impl CreateIntegrationError
Sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the CreateIntegrationError::Unhandled variant from any error type.
Sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the CreateIntegrationError::Unhandled variant from an ErrorMetadata.
Sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
Sourcepub fn is_access_denied_exception(&self) -> bool
pub fn is_access_denied_exception(&self) -> bool
Returns true if the error kind is CreateIntegrationError::AccessDeniedException.
Sourcepub fn is_conflict_exception(&self) -> bool
pub fn is_conflict_exception(&self) -> bool
Returns true if the error kind is CreateIntegrationError::ConflictException.
Sourcepub fn is_entity_not_found_exception(&self) -> bool
pub fn is_entity_not_found_exception(&self) -> bool
Returns true if the error kind is CreateIntegrationError::EntityNotFoundException.
Sourcepub fn is_integration_conflict_operation_fault(&self) -> bool
pub fn is_integration_conflict_operation_fault(&self) -> bool
Returns true if the error kind is CreateIntegrationError::IntegrationConflictOperationFault.
Sourcepub fn is_integration_quota_exceeded_fault(&self) -> bool
pub fn is_integration_quota_exceeded_fault(&self) -> bool
Returns true if the error kind is CreateIntegrationError::IntegrationQuotaExceededFault.
Sourcepub fn is_internal_server_exception(&self) -> bool
pub fn is_internal_server_exception(&self) -> bool
Returns true if the error kind is CreateIntegrationError::InternalServerException.
Sourcepub fn is_internal_service_exception(&self) -> bool
pub fn is_internal_service_exception(&self) -> bool
Returns true if the error kind is CreateIntegrationError::InternalServiceException.
Sourcepub fn is_invalid_input_exception(&self) -> bool
pub fn is_invalid_input_exception(&self) -> bool
Returns true if the error kind is CreateIntegrationError::InvalidInputException.
Sourcepub fn is_kms_key_not_accessible_fault(&self) -> bool
pub fn is_kms_key_not_accessible_fault(&self) -> bool
Returns true if the error kind is CreateIntegrationError::KmsKeyNotAccessibleFault.
Sourcepub fn is_resource_not_found_exception(&self) -> bool
pub fn is_resource_not_found_exception(&self) -> bool
Returns true if the error kind is CreateIntegrationError::ResourceNotFoundException.
Sourcepub fn is_resource_number_limit_exceeded_exception(&self) -> bool
pub fn is_resource_number_limit_exceeded_exception(&self) -> bool
Returns true if the error kind is CreateIntegrationError::ResourceNumberLimitExceededException.
Sourcepub fn is_validation_exception(&self) -> bool
pub fn is_validation_exception(&self) -> bool
Returns true if the error kind is CreateIntegrationError::ValidationException.