#[non_exhaustive]pub struct CreateIntegrationInput {
pub integration_name: Option<String>,
pub source_arn: Option<String>,
pub target_arn: Option<String>,
pub description: Option<String>,
pub data_filter: Option<String>,
pub kms_key_id: Option<String>,
pub additional_encryption_context: Option<HashMap<String, String>>,
pub tags: Option<Vec<Tag>>,
pub integration_config: Option<IntegrationConfig>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.integration_name: Option<String>A unique name for an integration in Glue.
source_arn: Option<String>The ARN of the source resource for the integration.
target_arn: Option<String>The ARN of the target resource for the integration.
description: Option<String>A description of the integration.
data_filter: Option<String>Selects source tables for the integration using Maxwell filter syntax.
kms_key_id: Option<String>The ARN of a KMS key used for encrypting the channel.
additional_encryption_context: Option<HashMap<String, String>>An optional set of non-secret key–value pairs that contains additional contextual information for encryption. This can only be provided if KMSKeyId is provided.
Metadata assigned to the resource consisting of a list of key-value pairs.
integration_config: Option<IntegrationConfig>The configuration settings.
Implementations
Sourceimpl CreateIntegrationInput
impl CreateIntegrationInput
Sourcepub fn integration_name(&self) -> Option<&str>
pub fn integration_name(&self) -> Option<&str>
A unique name for an integration in Glue.
Sourcepub fn source_arn(&self) -> Option<&str>
pub fn source_arn(&self) -> Option<&str>
The ARN of the source resource for the integration.
Sourcepub fn target_arn(&self) -> Option<&str>
pub fn target_arn(&self) -> Option<&str>
The ARN of the target resource for the integration.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A description of the integration.
Sourcepub fn data_filter(&self) -> Option<&str>
pub fn data_filter(&self) -> Option<&str>
Selects source tables for the integration using Maxwell filter syntax.
Sourcepub fn kms_key_id(&self) -> Option<&str>
pub fn kms_key_id(&self) -> Option<&str>
The ARN of a KMS key used for encrypting the channel.
Sourcepub fn additional_encryption_context(&self) -> Option<&HashMap<String, String>>
pub fn additional_encryption_context(&self) -> Option<&HashMap<String, String>>
An optional set of non-secret key–value pairs that contains additional contextual information for encryption. This can only be provided if KMSKeyId is provided.
Metadata assigned to the resource consisting of a list of key-value pairs.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .tags.is_none().
Sourcepub fn integration_config(&self) -> Option<&IntegrationConfig>
pub fn integration_config(&self) -> Option<&IntegrationConfig>
The configuration settings.
Sourceimpl CreateIntegrationInput
impl CreateIntegrationInput
Sourcepub fn builder() -> CreateIntegrationInputBuilder
pub fn builder() -> CreateIntegrationInputBuilder
Creates a new builder-style object to manufacture CreateIntegrationInput.