pub struct CreateIntegrationTablePropertiesFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to CreateIntegrationTableProperties.
This API is used to provide optional override properties for the the tables that need to be replicated. These properties can include properties for filtering and partitioning for the source and target tables. To set both source and target properties the same API need to be invoked with the Glue connection ARN as ResourceArn with SourceTableConfig, and the Glue database ARN as ResourceArn with TargetTableConfig respectively.
Implementations
Sourceimpl CreateIntegrationTablePropertiesFluentBuilder
impl CreateIntegrationTablePropertiesFluentBuilder
Sourcepub fn as_input(&self) -> &CreateIntegrationTablePropertiesInputBuilder
pub fn as_input(&self) -> &CreateIntegrationTablePropertiesInputBuilder
Access the CreateIntegrationTableProperties as a reference.
Sourcepub async fn send(
self,
) -> Result<CreateIntegrationTablePropertiesOutput, SdkError<CreateIntegrationTablePropertiesError, HttpResponse>>
pub async fn send( self, ) -> Result<CreateIntegrationTablePropertiesOutput, SdkError<CreateIntegrationTablePropertiesError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<CreateIntegrationTablePropertiesOutput, CreateIntegrationTablePropertiesError, Self>
pub fn customize( self, ) -> CustomizableOperation<CreateIntegrationTablePropertiesOutput, CreateIntegrationTablePropertiesError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn resource_arn(self, input: impl Into<String>) -> Self
pub fn resource_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the target table for which to create integration table properties. Currently, this API only supports creating integration table properties for target tables, and the provided ARN should be the ARN of the target table in the Glue Data Catalog. Support for creating integration table properties for source connections (using the connection ARN) is not yet implemented and will be added in a future release.
Sourcepub fn set_resource_arn(self, input: Option<String>) -> Self
pub fn set_resource_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the target table for which to create integration table properties. Currently, this API only supports creating integration table properties for target tables, and the provided ARN should be the ARN of the target table in the Glue Data Catalog. Support for creating integration table properties for source connections (using the connection ARN) is not yet implemented and will be added in a future release.
Sourcepub fn get_resource_arn(&self) -> &Option<String>
pub fn get_resource_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the target table for which to create integration table properties. Currently, this API only supports creating integration table properties for target tables, and the provided ARN should be the ARN of the target table in the Glue Data Catalog. Support for creating integration table properties for source connections (using the connection ARN) is not yet implemented and will be added in a future release.
Sourcepub fn table_name(self, input: impl Into<String>) -> Self
pub fn table_name(self, input: impl Into<String>) -> Self
The name of the table to be replicated.
Sourcepub fn set_table_name(self, input: Option<String>) -> Self
pub fn set_table_name(self, input: Option<String>) -> Self
The name of the table to be replicated.
Sourcepub fn get_table_name(&self) -> &Option<String>
pub fn get_table_name(&self) -> &Option<String>
The name of the table to be replicated.
Sourcepub fn source_table_config(self, input: SourceTableConfig) -> Self
pub fn source_table_config(self, input: SourceTableConfig) -> Self
A structure for the source table configuration. See the SourceTableConfig structure to see list of supported source properties.
Sourcepub fn set_source_table_config(self, input: Option<SourceTableConfig>) -> Self
pub fn set_source_table_config(self, input: Option<SourceTableConfig>) -> Self
A structure for the source table configuration. See the SourceTableConfig structure to see list of supported source properties.
Sourcepub fn get_source_table_config(&self) -> &Option<SourceTableConfig>
pub fn get_source_table_config(&self) -> &Option<SourceTableConfig>
A structure for the source table configuration. See the SourceTableConfig structure to see list of supported source properties.
Sourcepub fn target_table_config(self, input: TargetTableConfig) -> Self
pub fn target_table_config(self, input: TargetTableConfig) -> Self
A structure for the target table configuration.
Sourcepub fn set_target_table_config(self, input: Option<TargetTableConfig>) -> Self
pub fn set_target_table_config(self, input: Option<TargetTableConfig>) -> Self
A structure for the target table configuration.
Sourcepub fn get_target_table_config(&self) -> &Option<TargetTableConfig>
pub fn get_target_table_config(&self) -> &Option<TargetTableConfig>
A structure for the target table configuration.