#[non_exhaustive]pub struct CreateIntegrationTablePropertiesInput {
pub resource_arn: Option<String>,
pub table_name: Option<String>,
pub source_table_config: Option<SourceTableConfig>,
pub target_table_config: Option<TargetTableConfig>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.resource_arn: Option<String>The Amazon Resource Name (ARN) of the target table for which to create integration table properties. Currently, this API only supports creating integration table properties for target tables, and the provided ARN should be the ARN of the target table in the Glue Data Catalog. Support for creating integration table properties for source connections (using the connection ARN) is not yet implemented and will be added in a future release.
table_name: Option<String>The name of the table to be replicated.
source_table_config: Option<SourceTableConfig>A structure for the source table configuration. See the SourceTableConfig structure to see list of supported source properties.
target_table_config: Option<TargetTableConfig>A structure for the target table configuration.
Implementations
Sourceimpl CreateIntegrationTablePropertiesInput
impl CreateIntegrationTablePropertiesInput
Sourcepub fn resource_arn(&self) -> Option<&str>
pub fn resource_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the target table for which to create integration table properties. Currently, this API only supports creating integration table properties for target tables, and the provided ARN should be the ARN of the target table in the Glue Data Catalog. Support for creating integration table properties for source connections (using the connection ARN) is not yet implemented and will be added in a future release.
Sourcepub fn table_name(&self) -> Option<&str>
pub fn table_name(&self) -> Option<&str>
The name of the table to be replicated.
Sourcepub fn source_table_config(&self) -> Option<&SourceTableConfig>
pub fn source_table_config(&self) -> Option<&SourceTableConfig>
A structure for the source table configuration. See the SourceTableConfig structure to see list of supported source properties.
Sourcepub fn target_table_config(&self) -> Option<&TargetTableConfig>
pub fn target_table_config(&self) -> Option<&TargetTableConfig>
A structure for the target table configuration.
Sourceimpl CreateIntegrationTablePropertiesInput
impl CreateIntegrationTablePropertiesInput
Sourcepub fn builder() -> CreateIntegrationTablePropertiesInputBuilder
pub fn builder() -> CreateIntegrationTablePropertiesInputBuilder
Creates a new builder-style object to manufacture CreateIntegrationTablePropertiesInput.