pub struct DeleteAssetFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to DeleteAsset.
Deletes an asset from Glue Data Catalog.
Implementations
Sourceimpl DeleteAssetFluentBuilder
impl DeleteAssetFluentBuilder
Sourcepub fn as_input(&self) -> &DeleteAssetInputBuilder
pub fn as_input(&self) -> &DeleteAssetInputBuilder
Access the DeleteAsset as a reference.
Sourcepub async fn send(
self,
) -> Result<DeleteAssetOutput, SdkError<DeleteAssetError, HttpResponse>>
pub async fn send( self, ) -> Result<DeleteAssetOutput, SdkError<DeleteAssetError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<DeleteAssetOutput, DeleteAssetError, Self>
pub fn customize( self, ) -> CustomizableOperation<DeleteAssetOutput, DeleteAssetError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn identifier(self, input: impl Into<String>) -> Self
pub fn identifier(self, input: impl Into<String>) -> Self
The unique identifier of the asset to delete.
Sourcepub fn set_identifier(self, input: Option<String>) -> Self
pub fn set_identifier(self, input: Option<String>) -> Self
The unique identifier of the asset to delete.
Sourcepub fn get_identifier(&self) -> &Option<String>
pub fn get_identifier(&self) -> &Option<String>
The unique identifier of the asset to delete.