pub struct DeleteAttachmentFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to DeleteAttachment.
Deletes a form attachment from an asset in Glue Data Catalog.
Implementations
Sourceimpl DeleteAttachmentFluentBuilder
impl DeleteAttachmentFluentBuilder
Sourcepub fn as_input(&self) -> &DeleteAttachmentInputBuilder
pub fn as_input(&self) -> &DeleteAttachmentInputBuilder
Access the DeleteAttachment as a reference.
Sourcepub async fn send(
self,
) -> Result<DeleteAttachmentOutput, SdkError<DeleteAttachmentError, HttpResponse>>
pub async fn send( self, ) -> Result<DeleteAttachmentOutput, SdkError<DeleteAttachmentError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<DeleteAttachmentOutput, DeleteAttachmentError, Self>
pub fn customize( self, ) -> CustomizableOperation<DeleteAttachmentOutput, DeleteAttachmentError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn asset_identifier(self, input: impl Into<String>) -> Self
pub fn asset_identifier(self, input: impl Into<String>) -> Self
The unique identifier of the asset from which to delete the attachment.
Sourcepub fn set_asset_identifier(self, input: Option<String>) -> Self
pub fn set_asset_identifier(self, input: Option<String>) -> Self
The unique identifier of the asset from which to delete the attachment.
Sourcepub fn get_asset_identifier(&self) -> &Option<String>
pub fn get_asset_identifier(&self) -> &Option<String>
The unique identifier of the asset from which to delete the attachment.
Sourcepub fn iterable_form_name(self, input: impl Into<String>) -> Self
pub fn iterable_form_name(self, input: impl Into<String>) -> Self
The name of the iterable form. When specified along with itemIdentifier, the attachment is deleted from an item within the iterable form rather than from the asset itself.
Sourcepub fn set_iterable_form_name(self, input: Option<String>) -> Self
pub fn set_iterable_form_name(self, input: Option<String>) -> Self
The name of the iterable form. When specified along with itemIdentifier, the attachment is deleted from an item within the iterable form rather than from the asset itself.
Sourcepub fn get_iterable_form_name(&self) -> &Option<String>
pub fn get_iterable_form_name(&self) -> &Option<String>
The name of the iterable form. When specified along with itemIdentifier, the attachment is deleted from an item within the iterable form rather than from the asset itself.
Sourcepub fn item_identifier(self, input: impl Into<String>) -> Self
pub fn item_identifier(self, input: impl Into<String>) -> Self
The identifier of the item within the iterable form. Required when iterableFormName is specified.
Sourcepub fn set_item_identifier(self, input: Option<String>) -> Self
pub fn set_item_identifier(self, input: Option<String>) -> Self
The identifier of the item within the iterable form. Required when iterableFormName is specified.
Sourcepub fn get_item_identifier(&self) -> &Option<String>
pub fn get_item_identifier(&self) -> &Option<String>
The identifier of the item within the iterable form. Required when iterableFormName is specified.
Sourcepub fn attachment_name(self, input: impl Into<String>) -> Self
pub fn attachment_name(self, input: impl Into<String>) -> Self
The name of the attachment to delete.
Sourcepub fn set_attachment_name(self, input: Option<String>) -> Self
pub fn set_attachment_name(self, input: Option<String>) -> Self
The name of the attachment to delete.
Sourcepub fn get_attachment_name(&self) -> &Option<String>
pub fn get_attachment_name(&self) -> &Option<String>
The name of the attachment to delete.