#[non_exhaustive]pub struct DeleteAttachmentInputBuilder { /* private fields */ }Expand description
A builder for DeleteAttachmentInput.
Implementations
Sourceimpl DeleteAttachmentInputBuilder
impl DeleteAttachmentInputBuilder
Sourcepub fn asset_identifier(self, input: impl Into<String>) -> Self
pub fn asset_identifier(self, input: impl Into<String>) -> Self
The unique identifier of the asset from which to delete the attachment.
This field is required.Sourcepub fn set_asset_identifier(self, input: Option<String>) -> Self
pub fn set_asset_identifier(self, input: Option<String>) -> Self
The unique identifier of the asset from which to delete the attachment.
Sourcepub fn get_asset_identifier(&self) -> &Option<String>
pub fn get_asset_identifier(&self) -> &Option<String>
The unique identifier of the asset from which to delete the attachment.
Sourcepub fn iterable_form_name(self, input: impl Into<String>) -> Self
pub fn iterable_form_name(self, input: impl Into<String>) -> Self
The name of the iterable form. When specified along with itemIdentifier, the attachment is deleted from an item within the iterable form rather than from the asset itself.
Sourcepub fn set_iterable_form_name(self, input: Option<String>) -> Self
pub fn set_iterable_form_name(self, input: Option<String>) -> Self
The name of the iterable form. When specified along with itemIdentifier, the attachment is deleted from an item within the iterable form rather than from the asset itself.
Sourcepub fn get_iterable_form_name(&self) -> &Option<String>
pub fn get_iterable_form_name(&self) -> &Option<String>
The name of the iterable form. When specified along with itemIdentifier, the attachment is deleted from an item within the iterable form rather than from the asset itself.
Sourcepub fn item_identifier(self, input: impl Into<String>) -> Self
pub fn item_identifier(self, input: impl Into<String>) -> Self
The identifier of the item within the iterable form. Required when iterableFormName is specified.
Sourcepub fn set_item_identifier(self, input: Option<String>) -> Self
pub fn set_item_identifier(self, input: Option<String>) -> Self
The identifier of the item within the iterable form. Required when iterableFormName is specified.
Sourcepub fn get_item_identifier(&self) -> &Option<String>
pub fn get_item_identifier(&self) -> &Option<String>
The identifier of the item within the iterable form. Required when iterableFormName is specified.
Sourcepub fn attachment_name(self, input: impl Into<String>) -> Self
pub fn attachment_name(self, input: impl Into<String>) -> Self
The name of the attachment to delete.
This field is required.Sourcepub fn set_attachment_name(self, input: Option<String>) -> Self
pub fn set_attachment_name(self, input: Option<String>) -> Self
The name of the attachment to delete.
Sourcepub fn get_attachment_name(&self) -> &Option<String>
pub fn get_attachment_name(&self) -> &Option<String>
The name of the attachment to delete.
Sourcepub fn build(self) -> Result<DeleteAttachmentInput, BuildError>
pub fn build(self) -> Result<DeleteAttachmentInput, BuildError>
Consumes the builder and constructs a DeleteAttachmentInput.
Sourceimpl DeleteAttachmentInputBuilder
impl DeleteAttachmentInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<DeleteAttachmentOutput, SdkError<DeleteAttachmentError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<DeleteAttachmentOutput, SdkError<DeleteAttachmentError, HttpResponse>>
Sends a request with this input using the given client.