DeleteAttachmentInput

Struct DeleteAttachmentInput 

#[non_exhaustive]
pub struct DeleteAttachmentInput { pub asset_identifier: Option<String>, pub iterable_form_name: Option<String>, pub item_identifier: Option<String>, pub attachment_name: Option<String>, }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
asset_identifier: Option<String>

The unique identifier of the asset from which to delete the attachment.

iterable_form_name: Option<String>

The name of the iterable form. When specified along with itemIdentifier, the attachment is deleted from an item within the iterable form rather than from the asset itself.

item_identifier: Option<String>

The identifier of the item within the iterable form. Required when iterableFormName is specified.

attachment_name: Option<String>

The name of the attachment to delete.

Implementations

Source

impl DeleteAttachmentInput

pub fn asset_identifier(&self) -> Option<&str>

The unique identifier of the asset from which to delete the attachment.

pub fn iterable_form_name(&self) -> Option<&str>

The name of the iterable form. When specified along with itemIdentifier, the attachment is deleted from an item within the iterable form rather than from the asset itself.

pub fn item_identifier(&self) -> Option<&str>

The identifier of the item within the iterable form. Required when iterableFormName is specified.

pub fn attachment_name(&self) -> Option<&str>

The name of the attachment to delete.

Source

impl DeleteAttachmentInput

pub fn builder() -> DeleteAttachmentInputBuilder

Creates a new builder-style object to manufacture DeleteAttachmentInput.