pub struct DeleteBlueprintFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to DeleteBlueprint.
Deletes an existing blueprint.
Implementations
Sourceimpl DeleteBlueprintFluentBuilder
impl DeleteBlueprintFluentBuilder
Sourcepub fn as_input(&self) -> &DeleteBlueprintInputBuilder
pub fn as_input(&self) -> &DeleteBlueprintInputBuilder
Access the DeleteBlueprint as a reference.
Sourcepub async fn send(
self,
) -> Result<DeleteBlueprintOutput, SdkError<DeleteBlueprintError, HttpResponse>>
pub async fn send( self, ) -> Result<DeleteBlueprintOutput, SdkError<DeleteBlueprintError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<DeleteBlueprintOutput, DeleteBlueprintError, Self>
pub fn customize( self, ) -> CustomizableOperation<DeleteBlueprintOutput, DeleteBlueprintError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.