#[non_exhaustive]pub struct DeleteBlueprintOutputBuilder { /* private fields */ }Expand description
A builder for DeleteBlueprintOutput.
Implementations
Sourceimpl DeleteBlueprintOutputBuilder
impl DeleteBlueprintOutputBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
Returns the name of the blueprint that was deleted.
Sourcepub fn set_name(self, input: Option<String>) -> Self
pub fn set_name(self, input: Option<String>) -> Self
Returns the name of the blueprint that was deleted.
Sourcepub fn build(self) -> DeleteBlueprintOutput
pub fn build(self) -> DeleteBlueprintOutput
Consumes the builder and constructs a DeleteBlueprintOutput.