pub struct DeleteCatalogFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to DeleteCatalog.
Removes the specified catalog from the Glue Data Catalog.
After completing this operation, you no longer have access to the databases, tables (and all table versions and partitions that might belong to the tables) and the user-defined functions in the deleted catalog. Glue deletes these "orphaned" resources asynchronously in a timely manner, at the discretion of the service.
To ensure the immediate deletion of all related resources before calling the DeleteCatalog operation, use DeleteTableVersion (or BatchDeleteTableVersion), DeletePartition (or BatchDeletePartition), DeleteTable (or BatchDeleteTable), DeleteUserDefinedFunction and DeleteDatabase to delete any resources that belong to the catalog.
Implementations
Sourceimpl DeleteCatalogFluentBuilder
impl DeleteCatalogFluentBuilder
Sourcepub fn as_input(&self) -> &DeleteCatalogInputBuilder
pub fn as_input(&self) -> &DeleteCatalogInputBuilder
Access the DeleteCatalog as a reference.
Sourcepub async fn send(
self,
) -> Result<DeleteCatalogOutput, SdkError<DeleteCatalogError, HttpResponse>>
pub async fn send( self, ) -> Result<DeleteCatalogOutput, SdkError<DeleteCatalogError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<DeleteCatalogOutput, DeleteCatalogError, Self>
pub fn customize( self, ) -> CustomizableOperation<DeleteCatalogOutput, DeleteCatalogError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn catalog_id(self, input: impl Into<String>) -> Self
pub fn catalog_id(self, input: impl Into<String>) -> Self
The ID of the catalog.
Sourcepub fn set_catalog_id(self, input: Option<String>) -> Self
pub fn set_catalog_id(self, input: Option<String>) -> Self
The ID of the catalog.
Sourcepub fn get_catalog_id(&self) -> &Option<String>
pub fn get_catalog_id(&self) -> &Option<String>
The ID of the catalog.