pub struct DeleteColumnStatisticsTaskSettingsFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to DeleteColumnStatisticsTaskSettings.
Deletes settings for a column statistics task.
Implementations
Sourceimpl DeleteColumnStatisticsTaskSettingsFluentBuilder
impl DeleteColumnStatisticsTaskSettingsFluentBuilder
Sourcepub fn as_input(&self) -> &DeleteColumnStatisticsTaskSettingsInputBuilder
pub fn as_input(&self) -> &DeleteColumnStatisticsTaskSettingsInputBuilder
Access the DeleteColumnStatisticsTaskSettings as a reference.
Sourcepub async fn send(
self,
) -> Result<DeleteColumnStatisticsTaskSettingsOutput, SdkError<DeleteColumnStatisticsTaskSettingsError, HttpResponse>>
pub async fn send( self, ) -> Result<DeleteColumnStatisticsTaskSettingsOutput, SdkError<DeleteColumnStatisticsTaskSettingsError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<DeleteColumnStatisticsTaskSettingsOutput, DeleteColumnStatisticsTaskSettingsError, Self>
pub fn customize( self, ) -> CustomizableOperation<DeleteColumnStatisticsTaskSettingsOutput, DeleteColumnStatisticsTaskSettingsError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn database_name(self, input: impl Into<String>) -> Self
pub fn database_name(self, input: impl Into<String>) -> Self
The name of the database where the table resides.
Sourcepub fn set_database_name(self, input: Option<String>) -> Self
pub fn set_database_name(self, input: Option<String>) -> Self
The name of the database where the table resides.
Sourcepub fn get_database_name(&self) -> &Option<String>
pub fn get_database_name(&self) -> &Option<String>
The name of the database where the table resides.
Sourcepub fn table_name(self, input: impl Into<String>) -> Self
pub fn table_name(self, input: impl Into<String>) -> Self
The name of the table for which to delete column statistics.
Sourcepub fn set_table_name(self, input: Option<String>) -> Self
pub fn set_table_name(self, input: Option<String>) -> Self
The name of the table for which to delete column statistics.
Sourcepub fn get_table_name(&self) -> &Option<String>
pub fn get_table_name(&self) -> &Option<String>
The name of the table for which to delete column statistics.