#[non_exhaustive]pub struct DeleteColumnStatisticsTaskSettingsInput {
pub database_name: Option<String>,
pub table_name: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.database_name: Option<String>The name of the database where the table resides.
table_name: Option<String>The name of the table for which to delete column statistics.
Implementations
Sourceimpl DeleteColumnStatisticsTaskSettingsInput
impl DeleteColumnStatisticsTaskSettingsInput
Sourcepub fn database_name(&self) -> Option<&str>
pub fn database_name(&self) -> Option<&str>
The name of the database where the table resides.
Sourcepub fn table_name(&self) -> Option<&str>
pub fn table_name(&self) -> Option<&str>
The name of the table for which to delete column statistics.
Sourceimpl DeleteColumnStatisticsTaskSettingsInput
impl DeleteColumnStatisticsTaskSettingsInput
Sourcepub fn builder() -> DeleteColumnStatisticsTaskSettingsInputBuilder
pub fn builder() -> DeleteColumnStatisticsTaskSettingsInputBuilder
Creates a new builder-style object to manufacture DeleteColumnStatisticsTaskSettingsInput.