pub struct DeleteGlossaryFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to DeleteGlossary.
Deletes a business glossary from Glue Data Catalog. A glossary cannot be deleted if it still contains glossary terms.
Implementations
Sourceimpl DeleteGlossaryFluentBuilder
impl DeleteGlossaryFluentBuilder
Sourcepub fn as_input(&self) -> &DeleteGlossaryInputBuilder
pub fn as_input(&self) -> &DeleteGlossaryInputBuilder
Access the DeleteGlossary as a reference.
Sourcepub async fn send(
self,
) -> Result<DeleteGlossaryOutput, SdkError<DeleteGlossaryError, HttpResponse>>
pub async fn send( self, ) -> Result<DeleteGlossaryOutput, SdkError<DeleteGlossaryError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<DeleteGlossaryOutput, DeleteGlossaryError, Self>
pub fn customize( self, ) -> CustomizableOperation<DeleteGlossaryOutput, DeleteGlossaryError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn identifier(self, input: impl Into<String>) -> Self
pub fn identifier(self, input: impl Into<String>) -> Self
The unique identifier of the glossary to delete.
Sourcepub fn set_identifier(self, input: Option<String>) -> Self
pub fn set_identifier(self, input: Option<String>) -> Self
The unique identifier of the glossary to delete.
Sourcepub fn get_identifier(&self) -> &Option<String>
pub fn get_identifier(&self) -> &Option<String>
The unique identifier of the glossary to delete.