pub struct DeleteGlossaryTermFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to DeleteGlossaryTerm.
Deletes a glossary term from Glue Data Catalog.
Implementations
Sourceimpl DeleteGlossaryTermFluentBuilder
impl DeleteGlossaryTermFluentBuilder
Sourcepub fn as_input(&self) -> &DeleteGlossaryTermInputBuilder
pub fn as_input(&self) -> &DeleteGlossaryTermInputBuilder
Access the DeleteGlossaryTerm as a reference.
Sourcepub async fn send(
self,
) -> Result<DeleteGlossaryTermOutput, SdkError<DeleteGlossaryTermError, HttpResponse>>
pub async fn send( self, ) -> Result<DeleteGlossaryTermOutput, SdkError<DeleteGlossaryTermError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<DeleteGlossaryTermOutput, DeleteGlossaryTermError, Self>
pub fn customize( self, ) -> CustomizableOperation<DeleteGlossaryTermOutput, DeleteGlossaryTermError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn identifier(self, input: impl Into<String>) -> Self
pub fn identifier(self, input: impl Into<String>) -> Self
The unique identifier of the glossary term to delete.
Sourcepub fn set_identifier(self, input: Option<String>) -> Self
pub fn set_identifier(self, input: Option<String>) -> Self
The unique identifier of the glossary term to delete.
Sourcepub fn get_identifier(&self) -> &Option<String>
pub fn get_identifier(&self) -> &Option<String>
The unique identifier of the glossary term to delete.