#[non_exhaustive]pub struct DeleteGlossaryTermInputBuilder { /* private fields */ }Expand description
A builder for DeleteGlossaryTermInput.
Implementations
Sourceimpl DeleteGlossaryTermInputBuilder
impl DeleteGlossaryTermInputBuilder
Sourcepub fn identifier(self, input: impl Into<String>) -> Self
pub fn identifier(self, input: impl Into<String>) -> Self
The unique identifier of the glossary term to delete.
This field is required.Sourcepub fn set_identifier(self, input: Option<String>) -> Self
pub fn set_identifier(self, input: Option<String>) -> Self
The unique identifier of the glossary term to delete.
Sourcepub fn get_identifier(&self) -> &Option<String>
pub fn get_identifier(&self) -> &Option<String>
The unique identifier of the glossary term to delete.
Sourcepub fn build(self) -> Result<DeleteGlossaryTermInput, BuildError>
pub fn build(self) -> Result<DeleteGlossaryTermInput, BuildError>
Consumes the builder and constructs a DeleteGlossaryTermInput.
Sourceimpl DeleteGlossaryTermInputBuilder
impl DeleteGlossaryTermInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<DeleteGlossaryTermOutput, SdkError<DeleteGlossaryTermError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<DeleteGlossaryTermOutput, SdkError<DeleteGlossaryTermError, HttpResponse>>
Sends a request with this input using the given client.