pub struct DeleteGlueIdentityCenterConfigurationFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to DeleteGlueIdentityCenterConfiguration.
Deletes the existing Glue Identity Center configuration, removing the integration between Glue and Amazon Web Services IAM Identity Center.
Implementations
Sourceimpl DeleteGlueIdentityCenterConfigurationFluentBuilder
impl DeleteGlueIdentityCenterConfigurationFluentBuilder
Sourcepub fn as_input(&self) -> &DeleteGlueIdentityCenterConfigurationInputBuilder
pub fn as_input(&self) -> &DeleteGlueIdentityCenterConfigurationInputBuilder
Access the DeleteGlueIdentityCenterConfiguration as a reference.
Sourcepub async fn send(
self,
) -> Result<DeleteGlueIdentityCenterConfigurationOutput, SdkError<DeleteGlueIdentityCenterConfigurationError, HttpResponse>>
pub async fn send( self, ) -> Result<DeleteGlueIdentityCenterConfigurationOutput, SdkError<DeleteGlueIdentityCenterConfigurationError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<DeleteGlueIdentityCenterConfigurationOutput, DeleteGlueIdentityCenterConfigurationError, Self>
pub fn customize( self, ) -> CustomizableOperation<DeleteGlueIdentityCenterConfigurationOutput, DeleteGlueIdentityCenterConfigurationError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.