#[non_exhaustive]pub enum DeleteIntegrationError {
AccessDeniedException(AccessDeniedException),
ConflictException(ConflictException),
EntityNotFoundException(EntityNotFoundException),
IntegrationConflictOperationFault(IntegrationConflictOperationFault),
IntegrationNotFoundFault(IntegrationNotFoundFault),
InternalServerException(InternalServerException),
InternalServiceException(InternalServiceException),
InvalidInputException(InvalidInputException),
InvalidIntegrationStateFault(InvalidIntegrationStateFault),
InvalidStateException(InvalidStateException),
ValidationException(ValidationException),
Unhandled(Unhandled),
}Expand description
Error type for the DeleteIntegrationError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AccessDeniedException(AccessDeniedException)
Access to a resource was denied.
ConflictException(ConflictException)
The CreatePartitions API was called on a table that has indexes enabled.
EntityNotFoundException(EntityNotFoundException)
A specified entity does not exist
IntegrationConflictOperationFault(IntegrationConflictOperationFault)
The requested operation conflicts with another operation.
IntegrationNotFoundFault(IntegrationNotFoundFault)
The specified integration could not be found.
InternalServerException(InternalServerException)
An internal server error occurred.
InternalServiceException(InternalServiceException)
An internal service error occurred.
InvalidInputException(InvalidInputException)
The input provided was not valid.
InvalidIntegrationStateFault(InvalidIntegrationStateFault)
The integration is in an invalid state.
InvalidStateException(InvalidStateException)
An error that indicates your data is in an invalid state.
ValidationException(ValidationException)
A value could not be validated.
Unhandled(Unhandled)
Matching Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
Sourceimpl DeleteIntegrationError
impl DeleteIntegrationError
Sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the DeleteIntegrationError::Unhandled variant from any error type.
Sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the DeleteIntegrationError::Unhandled variant from an ErrorMetadata.
Sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
Sourcepub fn is_access_denied_exception(&self) -> bool
pub fn is_access_denied_exception(&self) -> bool
Returns true if the error kind is DeleteIntegrationError::AccessDeniedException.
Sourcepub fn is_conflict_exception(&self) -> bool
pub fn is_conflict_exception(&self) -> bool
Returns true if the error kind is DeleteIntegrationError::ConflictException.
Sourcepub fn is_entity_not_found_exception(&self) -> bool
pub fn is_entity_not_found_exception(&self) -> bool
Returns true if the error kind is DeleteIntegrationError::EntityNotFoundException.
Sourcepub fn is_integration_conflict_operation_fault(&self) -> bool
pub fn is_integration_conflict_operation_fault(&self) -> bool
Returns true if the error kind is DeleteIntegrationError::IntegrationConflictOperationFault.
Sourcepub fn is_integration_not_found_fault(&self) -> bool
pub fn is_integration_not_found_fault(&self) -> bool
Returns true if the error kind is DeleteIntegrationError::IntegrationNotFoundFault.
Sourcepub fn is_internal_server_exception(&self) -> bool
pub fn is_internal_server_exception(&self) -> bool
Returns true if the error kind is DeleteIntegrationError::InternalServerException.
Sourcepub fn is_internal_service_exception(&self) -> bool
pub fn is_internal_service_exception(&self) -> bool
Returns true if the error kind is DeleteIntegrationError::InternalServiceException.
Sourcepub fn is_invalid_input_exception(&self) -> bool
pub fn is_invalid_input_exception(&self) -> bool
Returns true if the error kind is DeleteIntegrationError::InvalidInputException.
Sourcepub fn is_invalid_integration_state_fault(&self) -> bool
pub fn is_invalid_integration_state_fault(&self) -> bool
Returns true if the error kind is DeleteIntegrationError::InvalidIntegrationStateFault.
Sourcepub fn is_invalid_state_exception(&self) -> bool
pub fn is_invalid_state_exception(&self) -> bool
Returns true if the error kind is DeleteIntegrationError::InvalidStateException.
Sourcepub fn is_validation_exception(&self) -> bool
pub fn is_validation_exception(&self) -> bool
Returns true if the error kind is DeleteIntegrationError::ValidationException.