DeleteIntegrationOutput

Struct DeleteIntegrationOutput 

#[non_exhaustive]
pub struct DeleteIntegrationOutput { pub source_arn: String, pub target_arn: String, pub integration_name: String, pub description: Option<String>, pub integration_arn: String, pub kms_key_id: Option<String>, pub additional_encryption_context: Option<HashMap<String, String>>, pub tags: Option<Vec<Tag>>, pub status: IntegrationStatus, pub create_time: DateTime, pub errors: Option<Vec<IntegrationError>>, pub data_filter: Option<String>, /* private fields */ }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
source_arn: String

The ARN of the source for the integration.

target_arn: String

The ARN of the target for the integration.

integration_name: String

A unique name for an integration in Glue.

description: Option<String>

A description of the integration.

integration_arn: String

The Amazon Resource Name (ARN) for the integration.

kms_key_id: Option<String>

The ARN of a KMS key used for encrypting the channel.

additional_encryption_context: Option<HashMap<String, String>>

An optional set of non-secret key–value pairs that contains additional contextual information for encryption.

tags: Option<Vec<Tag>>

Metadata assigned to the resource consisting of a list of key-value pairs.

status: IntegrationStatus

The status of the integration being deleted.

The possible statuses are:

  • CREATING: The integration is being created.

  • ACTIVE: The integration creation succeeds.

  • MODIFYING: The integration is being modified.

  • FAILED: The integration creation fails.

  • DELETING: The integration is deleted.

  • SYNCING: The integration is synchronizing.

  • NEEDS_ATTENTION: The integration needs attention, such as synchronization.

create_time: DateTime

The time when the integration was created, in UTC.

errors: Option<Vec<IntegrationError>>

A list of errors associated with the integration.

data_filter: Option<String>

Selects source tables for the integration using Maxwell filter syntax.

Implementations

Source

impl DeleteIntegrationOutput

pub fn source_arn(&self) -> &str

The ARN of the source for the integration.

pub fn target_arn(&self) -> &str

The ARN of the target for the integration.

pub fn integration_name(&self) -> &str

A unique name for an integration in Glue.

pub fn description(&self) -> Option<&str>

A description of the integration.

pub fn integration_arn(&self) -> &str

The Amazon Resource Name (ARN) for the integration.

pub fn kms_key_id(&self) -> Option<&str>

The ARN of a KMS key used for encrypting the channel.

pub fn additional_encryption_context(&self) -> Option<&HashMap<String, String>>

An optional set of non-secret key–value pairs that contains additional contextual information for encryption.

pub fn tags(&self) -> &[Tag]

Metadata assigned to the resource consisting of a list of key-value pairs.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .tags.is_none().

pub fn status(&self) -> &IntegrationStatus

The status of the integration being deleted.

The possible statuses are:

  • CREATING: The integration is being created.

  • ACTIVE: The integration creation succeeds.

  • MODIFYING: The integration is being modified.

  • FAILED: The integration creation fails.

  • DELETING: The integration is deleted.

  • SYNCING: The integration is synchronizing.

  • NEEDS_ATTENTION: The integration needs attention, such as synchronization.

pub fn create_time(&self) -> &DateTime

The time when the integration was created, in UTC.

pub fn errors(&self) -> &[IntegrationError]

A list of errors associated with the integration.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .errors.is_none().

pub fn data_filter(&self) -> Option<&str>

Selects source tables for the integration using Maxwell filter syntax.

Source

impl DeleteIntegrationOutput

pub fn builder() -> DeleteIntegrationOutputBuilder

Creates a new builder-style object to manufacture DeleteIntegrationOutput.