pub struct DeleteIntegrationTablePropertiesFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to DeleteIntegrationTableProperties.
Deletes the table properties that have been created for the tables that need to be replicated.
Implementations
Sourceimpl DeleteIntegrationTablePropertiesFluentBuilder
impl DeleteIntegrationTablePropertiesFluentBuilder
Sourcepub fn as_input(&self) -> &DeleteIntegrationTablePropertiesInputBuilder
pub fn as_input(&self) -> &DeleteIntegrationTablePropertiesInputBuilder
Access the DeleteIntegrationTableProperties as a reference.
Sourcepub async fn send(
self,
) -> Result<DeleteIntegrationTablePropertiesOutput, SdkError<DeleteIntegrationTablePropertiesError, HttpResponse>>
pub async fn send( self, ) -> Result<DeleteIntegrationTablePropertiesOutput, SdkError<DeleteIntegrationTablePropertiesError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<DeleteIntegrationTablePropertiesOutput, DeleteIntegrationTablePropertiesError, Self>
pub fn customize( self, ) -> CustomizableOperation<DeleteIntegrationTablePropertiesOutput, DeleteIntegrationTablePropertiesError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn resource_arn(self, input: impl Into<String>) -> Self
pub fn resource_arn(self, input: impl Into<String>) -> Self
The connection ARN of the source, or the database ARN of the target.
Sourcepub fn set_resource_arn(self, input: Option<String>) -> Self
pub fn set_resource_arn(self, input: Option<String>) -> Self
The connection ARN of the source, or the database ARN of the target.
Sourcepub fn get_resource_arn(&self) -> &Option<String>
pub fn get_resource_arn(&self) -> &Option<String>
The connection ARN of the source, or the database ARN of the target.
Sourcepub fn table_name(self, input: impl Into<String>) -> Self
pub fn table_name(self, input: impl Into<String>) -> Self
The name of the table to be replicated.
Sourcepub fn set_table_name(self, input: Option<String>) -> Self
pub fn set_table_name(self, input: Option<String>) -> Self
The name of the table to be replicated.
Sourcepub fn get_table_name(&self) -> &Option<String>
pub fn get_table_name(&self) -> &Option<String>
The name of the table to be replicated.