#[non_exhaustive]pub enum DeleteIntegrationTablePropertiesError {
AccessDeniedException(AccessDeniedException),
EntityNotFoundException(EntityNotFoundException),
InternalServerException(InternalServerException),
InternalServiceException(InternalServiceException),
InvalidInputException(InvalidInputException),
ResourceNotFoundException(ResourceNotFoundException),
ValidationException(ValidationException),
Unhandled(Unhandled),
}Expand description
Error type for the DeleteIntegrationTablePropertiesError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AccessDeniedException(AccessDeniedException)
Access to a resource was denied.
EntityNotFoundException(EntityNotFoundException)
A specified entity does not exist
InternalServerException(InternalServerException)
An internal server error occurred.
InternalServiceException(InternalServiceException)
An internal service error occurred.
InvalidInputException(InvalidInputException)
The input provided was not valid.
ResourceNotFoundException(ResourceNotFoundException)
The resource could not be found.
ValidationException(ValidationException)
A value could not be validated.
Unhandled(Unhandled)
Matching Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
Sourceimpl DeleteIntegrationTablePropertiesError
impl DeleteIntegrationTablePropertiesError
Sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the DeleteIntegrationTablePropertiesError::Unhandled variant from any error type.
Sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the DeleteIntegrationTablePropertiesError::Unhandled variant from an ErrorMetadata.
Sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
Sourcepub fn is_access_denied_exception(&self) -> bool
pub fn is_access_denied_exception(&self) -> bool
Returns true if the error kind is DeleteIntegrationTablePropertiesError::AccessDeniedException.
Sourcepub fn is_entity_not_found_exception(&self) -> bool
pub fn is_entity_not_found_exception(&self) -> bool
Returns true if the error kind is DeleteIntegrationTablePropertiesError::EntityNotFoundException.
Sourcepub fn is_internal_server_exception(&self) -> bool
pub fn is_internal_server_exception(&self) -> bool
Returns true if the error kind is DeleteIntegrationTablePropertiesError::InternalServerException.
Sourcepub fn is_internal_service_exception(&self) -> bool
pub fn is_internal_service_exception(&self) -> bool
Returns true if the error kind is DeleteIntegrationTablePropertiesError::InternalServiceException.
Sourcepub fn is_invalid_input_exception(&self) -> bool
pub fn is_invalid_input_exception(&self) -> bool
Returns true if the error kind is DeleteIntegrationTablePropertiesError::InvalidInputException.
Sourcepub fn is_resource_not_found_exception(&self) -> bool
pub fn is_resource_not_found_exception(&self) -> bool
Returns true if the error kind is DeleteIntegrationTablePropertiesError::ResourceNotFoundException.
Sourcepub fn is_validation_exception(&self) -> bool
pub fn is_validation_exception(&self) -> bool
Returns true if the error kind is DeleteIntegrationTablePropertiesError::ValidationException.