#[non_exhaustive]pub struct DeleteJobOutputBuilder { /* private fields */ }Expand description
A builder for DeleteJobOutput.
Implementations
Sourceimpl DeleteJobOutputBuilder
impl DeleteJobOutputBuilder
Sourcepub fn job_name(self, input: impl Into<String>) -> Self
pub fn job_name(self, input: impl Into<String>) -> Self
The name of the job definition that was deleted.
Sourcepub fn set_job_name(self, input: Option<String>) -> Self
pub fn set_job_name(self, input: Option<String>) -> Self
The name of the job definition that was deleted.
Sourcepub fn get_job_name(&self) -> &Option<String>
pub fn get_job_name(&self) -> &Option<String>
The name of the job definition that was deleted.
Sourcepub fn build(self) -> DeleteJobOutput
pub fn build(self) -> DeleteJobOutput
Consumes the builder and constructs a DeleteJobOutput.