pub struct DescribeEntityFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to DescribeEntity.
Provides details regarding the entity used with the connection type, with a description of the data model for each field in the selected entity.
The response includes all the fields which make up the entity.
Implementations
Sourceimpl DescribeEntityFluentBuilder
impl DescribeEntityFluentBuilder
Sourcepub fn as_input(&self) -> &DescribeEntityInputBuilder
pub fn as_input(&self) -> &DescribeEntityInputBuilder
Access the DescribeEntity as a reference.
Sourcepub async fn send(
self,
) -> Result<DescribeEntityOutput, SdkError<DescribeEntityError, HttpResponse>>
pub async fn send( self, ) -> Result<DescribeEntityOutput, SdkError<DescribeEntityError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<DescribeEntityOutput, DescribeEntityError, Self>
pub fn customize( self, ) -> CustomizableOperation<DescribeEntityOutput, DescribeEntityError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn into_paginator(self) -> DescribeEntityPaginator
pub fn into_paginator(self) -> DescribeEntityPaginator
Create a paginator for this request
Paginators are used by calling send().await which returns a PaginationStream.
Sourcepub fn connection_name(self, input: impl Into<String>) -> Self
pub fn connection_name(self, input: impl Into<String>) -> Self
The name of the connection that contains the connection type credentials.
Sourcepub fn set_connection_name(self, input: Option<String>) -> Self
pub fn set_connection_name(self, input: Option<String>) -> Self
The name of the connection that contains the connection type credentials.
Sourcepub fn get_connection_name(&self) -> &Option<String>
pub fn get_connection_name(&self) -> &Option<String>
The name of the connection that contains the connection type credentials.
Sourcepub fn catalog_id(self, input: impl Into<String>) -> Self
pub fn catalog_id(self, input: impl Into<String>) -> Self
The catalog ID of the catalog that contains the connection. This can be null, By default, the Amazon Web Services Account ID is the catalog ID.
Sourcepub fn set_catalog_id(self, input: Option<String>) -> Self
pub fn set_catalog_id(self, input: Option<String>) -> Self
The catalog ID of the catalog that contains the connection. This can be null, By default, the Amazon Web Services Account ID is the catalog ID.
Sourcepub fn get_catalog_id(&self) -> &Option<String>
pub fn get_catalog_id(&self) -> &Option<String>
The catalog ID of the catalog that contains the connection. This can be null, By default, the Amazon Web Services Account ID is the catalog ID.
Sourcepub fn entity_name(self, input: impl Into<String>) -> Self
pub fn entity_name(self, input: impl Into<String>) -> Self
The name of the entity that you want to describe from the connection type.
Sourcepub fn set_entity_name(self, input: Option<String>) -> Self
pub fn set_entity_name(self, input: Option<String>) -> Self
The name of the entity that you want to describe from the connection type.
Sourcepub fn get_entity_name(&self) -> &Option<String>
pub fn get_entity_name(&self) -> &Option<String>
The name of the entity that you want to describe from the connection type.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token, included if this is a continuation call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token, included if this is a continuation call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token, included if this is a continuation call.
Sourcepub fn data_store_api_version(self, input: impl Into<String>) -> Self
pub fn data_store_api_version(self, input: impl Into<String>) -> Self
The version of the API used for the data store.
Sourcepub fn set_data_store_api_version(self, input: Option<String>) -> Self
pub fn set_data_store_api_version(self, input: Option<String>) -> Self
The version of the API used for the data store.
Sourcepub fn get_data_store_api_version(&self) -> &Option<String>
pub fn get_data_store_api_version(&self) -> &Option<String>
The version of the API used for the data store.