#[non_exhaustive]pub struct DescribeEntityOutputBuilder { /* private fields */ }Expand description
A builder for DescribeEntityOutput.
Implementations
Sourceimpl DescribeEntityOutputBuilder
impl DescribeEntityOutputBuilder
Sourcepub fn fields(self, input: Field) -> Self
pub fn fields(self, input: Field) -> Self
Appends an item to fields.
To override the contents of this collection use set_fields.
Describes the fields for that connector entity. This is the list of Field objects. Field is very similar to column in a database. The Field object has information about different properties associated with fields in the connector.
Sourcepub fn set_fields(self, input: Option<Vec<Field>>) -> Self
pub fn set_fields(self, input: Option<Vec<Field>>) -> Self
Describes the fields for that connector entity. This is the list of Field objects. Field is very similar to column in a database. The Field object has information about different properties associated with fields in the connector.
Sourcepub fn get_fields(&self) -> &Option<Vec<Field>>
pub fn get_fields(&self) -> &Option<Vec<Field>>
Describes the fields for that connector entity. This is the list of Field objects. Field is very similar to column in a database. The Field object has information about different properties associated with fields in the connector.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token, present if the current segment is not the last.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token, present if the current segment is not the last.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token, present if the current segment is not the last.
Sourcepub fn build(self) -> DescribeEntityOutput
pub fn build(self) -> DescribeEntityOutput
Consumes the builder and constructs a DescribeEntityOutput.