pub struct DescribeEntityPaginator { /* private fields */ }Expand description
Paginator for DescribeEntity
Implementations
Sourceimpl DescribeEntityPaginator
impl DescribeEntityPaginator
Sourcepub fn items(self) -> DescribeEntityPaginatorItems
pub fn items(self) -> DescribeEntityPaginatorItems
Create a flattened paginator
This paginator automatically flattens results using fields. Queries to the underlying service
are dispatched lazily.
Sourcepub fn stop_on_duplicate_token(self, stop_on_duplicate_token: bool) -> Self
pub fn stop_on_duplicate_token(self, stop_on_duplicate_token: bool) -> Self
Stop paginating when the service returns the same pagination token twice in a row.
Defaults to true.
For certain operations, it may be useful to continue on duplicate token. For example,
if an operation is for tailing a log file in real-time, then continuing may be desired.
This option can be set to false to accommodate these use cases.
Sourcepub fn send(
self,
) -> PaginationStream<Result<DescribeEntityOutput, SdkError<DescribeEntityError, HttpResponse>>>
pub fn send( self, ) -> PaginationStream<Result<DescribeEntityOutput, SdkError<DescribeEntityError, HttpResponse>>>
Create the pagination stream
Note: No requests will be dispatched until the stream is used
(e.g. with the .next().await method).