pub struct DescribeEntityPaginatorItems(/* private fields */);Expand description
Flattened paginator for DescribeEntityPaginator
This is created with .items()
Implementations
Sourceimpl DescribeEntityPaginatorItems
impl DescribeEntityPaginatorItems
Sourcepub fn send(
self,
) -> PaginationStream<Result<Field, SdkError<DescribeEntityError, HttpResponse>>>
pub fn send( self, ) -> PaginationStream<Result<Field, SdkError<DescribeEntityError, HttpResponse>>>
Create the pagination stream
Note: No requests will be dispatched until the stream is used
(e.g. with the .next().await method).
To read the entirety of the paginator, use .collect::<Result<Vec<_>, _>().