#[non_exhaustive]pub struct DescribeEntityInput {
pub connection_name: Option<String>,
pub catalog_id: Option<String>,
pub entity_name: Option<String>,
pub next_token: Option<String>,
pub data_store_api_version: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.connection_name: Option<String>The name of the connection that contains the connection type credentials.
catalog_id: Option<String>The catalog ID of the catalog that contains the connection. This can be null, By default, the Amazon Web Services Account ID is the catalog ID.
entity_name: Option<String>The name of the entity that you want to describe from the connection type.
next_token: Option<String>A continuation token, included if this is a continuation call.
data_store_api_version: Option<String>The version of the API used for the data store.
Implementations
Sourceimpl DescribeEntityInput
impl DescribeEntityInput
Sourcepub fn connection_name(&self) -> Option<&str>
pub fn connection_name(&self) -> Option<&str>
The name of the connection that contains the connection type credentials.
Sourcepub fn catalog_id(&self) -> Option<&str>
pub fn catalog_id(&self) -> Option<&str>
The catalog ID of the catalog that contains the connection. This can be null, By default, the Amazon Web Services Account ID is the catalog ID.
Sourcepub fn entity_name(&self) -> Option<&str>
pub fn entity_name(&self) -> Option<&str>
The name of the entity that you want to describe from the connection type.
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A continuation token, included if this is a continuation call.
Sourcepub fn data_store_api_version(&self) -> Option<&str>
pub fn data_store_api_version(&self) -> Option<&str>
The version of the API used for the data store.
Sourceimpl DescribeEntityInput
impl DescribeEntityInput
Sourcepub fn builder() -> DescribeEntityInputBuilder
pub fn builder() -> DescribeEntityInputBuilder
Creates a new builder-style object to manufacture DescribeEntityInput.