DescribeInboundIntegrationsFluentBuilder

Struct DescribeInboundIntegrationsFluentBuilder 

pub struct DescribeInboundIntegrationsFluentBuilder { /* private fields */ }
Fluent builder constructing a request to DescribeInboundIntegrations.

Returns a list of inbound integrations for the specified integration.

Implementations

Source

impl DescribeInboundIntegrationsFluentBuilder

pub fn as_input(&self) -> &DescribeInboundIntegrationsInputBuilder

Access the DescribeInboundIntegrations as a reference.

pub async fn send( self, ) -> Result<DescribeInboundIntegrationsOutput, SdkError<DescribeInboundIntegrationsError, HttpResponse>>

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

pub fn customize( self, ) -> CustomizableOperation<DescribeInboundIntegrationsOutput, DescribeInboundIntegrationsError, Self>

Consumes this builder, creating a customizable operation that can be modified before being sent.

pub fn integration_arn(self, input: impl Into<String>) -> Self

The Amazon Resource Name (ARN) of the integration.

pub fn set_integration_arn(self, input: Option<String>) -> Self

The Amazon Resource Name (ARN) of the integration.

pub fn get_integration_arn(&self) -> &Option<String>

The Amazon Resource Name (ARN) of the integration.

pub fn marker(self, input: impl Into<String>) -> Self

A token to specify where to start paginating. This is the marker from a previously truncated response.

pub fn set_marker(self, input: Option<String>) -> Self

A token to specify where to start paginating. This is the marker from a previously truncated response.

pub fn get_marker(&self) -> &Option<String>

A token to specify where to start paginating. This is the marker from a previously truncated response.

pub fn max_records(self, input: i32) -> Self

The total number of items to return in the output.

pub fn set_max_records(self, input: Option<i32>) -> Self

The total number of items to return in the output.

pub fn get_max_records(&self) -> &Option<i32>

The total number of items to return in the output.

pub fn target_arn(self, input: impl Into<String>) -> Self

The Amazon Resource Name (ARN) of the target resource in the integration.

pub fn set_target_arn(self, input: Option<String>) -> Self

The Amazon Resource Name (ARN) of the target resource in the integration.

pub fn get_target_arn(&self) -> &Option<String>

The Amazon Resource Name (ARN) of the target resource in the integration.