#[non_exhaustive]pub struct DescribeInboundIntegrationsInputBuilder { /* private fields */ }Expand description
A builder for DescribeInboundIntegrationsInput.
Implementations
Sourceimpl DescribeInboundIntegrationsInputBuilder
impl DescribeInboundIntegrationsInputBuilder
Sourcepub fn integration_arn(self, input: impl Into<String>) -> Self
pub fn integration_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the integration.
Sourcepub fn set_integration_arn(self, input: Option<String>) -> Self
pub fn set_integration_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the integration.
Sourcepub fn get_integration_arn(&self) -> &Option<String>
pub fn get_integration_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the integration.
Sourcepub fn marker(self, input: impl Into<String>) -> Self
pub fn marker(self, input: impl Into<String>) -> Self
A token to specify where to start paginating. This is the marker from a previously truncated response.
Sourcepub fn set_marker(self, input: Option<String>) -> Self
pub fn set_marker(self, input: Option<String>) -> Self
A token to specify where to start paginating. This is the marker from a previously truncated response.
Sourcepub fn get_marker(&self) -> &Option<String>
pub fn get_marker(&self) -> &Option<String>
A token to specify where to start paginating. This is the marker from a previously truncated response.
Sourcepub fn max_records(self, input: i32) -> Self
pub fn max_records(self, input: i32) -> Self
The total number of items to return in the output.
Sourcepub fn set_max_records(self, input: Option<i32>) -> Self
pub fn set_max_records(self, input: Option<i32>) -> Self
The total number of items to return in the output.
Sourcepub fn get_max_records(&self) -> &Option<i32>
pub fn get_max_records(&self) -> &Option<i32>
The total number of items to return in the output.
Sourcepub fn target_arn(self, input: impl Into<String>) -> Self
pub fn target_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the target resource in the integration.
Sourcepub fn set_target_arn(self, input: Option<String>) -> Self
pub fn set_target_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the target resource in the integration.
Sourcepub fn get_target_arn(&self) -> &Option<String>
pub fn get_target_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the target resource in the integration.
Sourcepub fn build(self) -> Result<DescribeInboundIntegrationsInput, BuildError>
pub fn build(self) -> Result<DescribeInboundIntegrationsInput, BuildError>
Consumes the builder and constructs a DescribeInboundIntegrationsInput.
Sourceimpl DescribeInboundIntegrationsInputBuilder
impl DescribeInboundIntegrationsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<DescribeInboundIntegrationsOutput, SdkError<DescribeInboundIntegrationsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<DescribeInboundIntegrationsOutput, SdkError<DescribeInboundIntegrationsError, HttpResponse>>
Sends a request with this input using the given client.