#[non_exhaustive]pub struct DescribeInboundIntegrationsOutputBuilder { /* private fields */ }Expand description
A builder for DescribeInboundIntegrationsOutput.
Implementations
Sourceimpl DescribeInboundIntegrationsOutputBuilder
impl DescribeInboundIntegrationsOutputBuilder
Sourcepub fn inbound_integrations(self, input: InboundIntegration) -> Self
pub fn inbound_integrations(self, input: InboundIntegration) -> Self
Appends an item to inbound_integrations.
To override the contents of this collection use set_inbound_integrations.
A list of inbound integrations.
Sourcepub fn set_inbound_integrations(
self,
input: Option<Vec<InboundIntegration>>,
) -> Self
pub fn set_inbound_integrations( self, input: Option<Vec<InboundIntegration>>, ) -> Self
A list of inbound integrations.
Sourcepub fn get_inbound_integrations(&self) -> &Option<Vec<InboundIntegration>>
pub fn get_inbound_integrations(&self) -> &Option<Vec<InboundIntegration>>
A list of inbound integrations.
Sourcepub fn marker(self, input: impl Into<String>) -> Self
pub fn marker(self, input: impl Into<String>) -> Self
A value that indicates the starting point for the next set of response records in a subsequent request.
Sourcepub fn set_marker(self, input: Option<String>) -> Self
pub fn set_marker(self, input: Option<String>) -> Self
A value that indicates the starting point for the next set of response records in a subsequent request.
Sourcepub fn get_marker(&self) -> &Option<String>
pub fn get_marker(&self) -> &Option<String>
A value that indicates the starting point for the next set of response records in a subsequent request.
Sourcepub fn build(self) -> DescribeInboundIntegrationsOutput
pub fn build(self) -> DescribeInboundIntegrationsOutput
Consumes the builder and constructs a DescribeInboundIntegrationsOutput.