#[non_exhaustive]pub struct DescribeInboundIntegrationsInput {
pub integration_arn: Option<String>,
pub marker: Option<String>,
pub max_records: Option<i32>,
pub target_arn: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.integration_arn: Option<String>The Amazon Resource Name (ARN) of the integration.
marker: Option<String>A token to specify where to start paginating. This is the marker from a previously truncated response.
max_records: Option<i32>The total number of items to return in the output.
target_arn: Option<String>The Amazon Resource Name (ARN) of the target resource in the integration.
Implementations
Sourceimpl DescribeInboundIntegrationsInput
impl DescribeInboundIntegrationsInput
Sourcepub fn integration_arn(&self) -> Option<&str>
pub fn integration_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the integration.
Sourcepub fn marker(&self) -> Option<&str>
pub fn marker(&self) -> Option<&str>
A token to specify where to start paginating. This is the marker from a previously truncated response.
Sourcepub fn max_records(&self) -> Option<i32>
pub fn max_records(&self) -> Option<i32>
The total number of items to return in the output.
Sourcepub fn target_arn(&self) -> Option<&str>
pub fn target_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the target resource in the integration.
Sourceimpl DescribeInboundIntegrationsInput
impl DescribeInboundIntegrationsInput
Sourcepub fn builder() -> DescribeInboundIntegrationsInputBuilder
pub fn builder() -> DescribeInboundIntegrationsInputBuilder
Creates a new builder-style object to manufacture DescribeInboundIntegrationsInput.