#[non_exhaustive]pub struct DescribeInboundIntegrationsOutput {
pub inbound_integrations: Option<Vec<InboundIntegration>>,
pub marker: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.inbound_integrations: Option<Vec<InboundIntegration>>A list of inbound integrations.
marker: Option<String>A value that indicates the starting point for the next set of response records in a subsequent request.
Implementations
Sourceimpl DescribeInboundIntegrationsOutput
impl DescribeInboundIntegrationsOutput
Sourcepub fn inbound_integrations(&self) -> &[InboundIntegration]
pub fn inbound_integrations(&self) -> &[InboundIntegration]
A list of inbound integrations.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .inbound_integrations.is_none().
Sourceimpl DescribeInboundIntegrationsOutput
impl DescribeInboundIntegrationsOutput
Sourcepub fn builder() -> DescribeInboundIntegrationsOutputBuilder
pub fn builder() -> DescribeInboundIntegrationsOutputBuilder
Creates a new builder-style object to manufacture DescribeInboundIntegrationsOutput.