#[non_exhaustive]pub struct DescribeIntegrationsInputBuilder { /* private fields */ }Expand description
A builder for DescribeIntegrationsInput.
Implementations
Sourceimpl DescribeIntegrationsInputBuilder
impl DescribeIntegrationsInputBuilder
Sourcepub fn integration_identifier(self, input: impl Into<String>) -> Self
pub fn integration_identifier(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) for the integration.
Sourcepub fn set_integration_identifier(self, input: Option<String>) -> Self
pub fn set_integration_identifier(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) for the integration.
Sourcepub fn get_integration_identifier(&self) -> &Option<String>
pub fn get_integration_identifier(&self) -> &Option<String>
The Amazon Resource Name (ARN) for the integration.
Sourcepub fn marker(self, input: impl Into<String>) -> Self
pub fn marker(self, input: impl Into<String>) -> Self
A value that indicates the starting point for the next set of response records in a subsequent request.
Sourcepub fn set_marker(self, input: Option<String>) -> Self
pub fn set_marker(self, input: Option<String>) -> Self
A value that indicates the starting point for the next set of response records in a subsequent request.
Sourcepub fn get_marker(&self) -> &Option<String>
pub fn get_marker(&self) -> &Option<String>
A value that indicates the starting point for the next set of response records in a subsequent request.
Sourcepub fn max_records(self, input: i32) -> Self
pub fn max_records(self, input: i32) -> Self
The total number of items to return in the output.
Sourcepub fn set_max_records(self, input: Option<i32>) -> Self
pub fn set_max_records(self, input: Option<i32>) -> Self
The total number of items to return in the output.
Sourcepub fn get_max_records(&self) -> &Option<i32>
pub fn get_max_records(&self) -> &Option<i32>
The total number of items to return in the output.
Sourcepub fn filters(self, input: IntegrationFilter) -> Self
pub fn filters(self, input: IntegrationFilter) -> Self
Appends an item to filters.
To override the contents of this collection use set_filters.
A list of key and values, to filter down the results. Supported keys are "Status", "IntegrationName", and "SourceArn". IntegrationName is limited to only one value.
Sourcepub fn set_filters(self, input: Option<Vec<IntegrationFilter>>) -> Self
pub fn set_filters(self, input: Option<Vec<IntegrationFilter>>) -> Self
A list of key and values, to filter down the results. Supported keys are "Status", "IntegrationName", and "SourceArn". IntegrationName is limited to only one value.
Sourcepub fn get_filters(&self) -> &Option<Vec<IntegrationFilter>>
pub fn get_filters(&self) -> &Option<Vec<IntegrationFilter>>
A list of key and values, to filter down the results. Supported keys are "Status", "IntegrationName", and "SourceArn". IntegrationName is limited to only one value.
Sourcepub fn build(self) -> Result<DescribeIntegrationsInput, BuildError>
pub fn build(self) -> Result<DescribeIntegrationsInput, BuildError>
Consumes the builder and constructs a DescribeIntegrationsInput.
Sourceimpl DescribeIntegrationsInputBuilder
impl DescribeIntegrationsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<DescribeIntegrationsOutput, SdkError<DescribeIntegrationsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<DescribeIntegrationsOutput, SdkError<DescribeIntegrationsError, HttpResponse>>
Sends a request with this input using the given client.