#[non_exhaustive]pub struct DescribeIntegrationsOutputBuilder { /* private fields */ }Expand description
A builder for DescribeIntegrationsOutput.
Implementations
Sourceimpl DescribeIntegrationsOutputBuilder
impl DescribeIntegrationsOutputBuilder
Sourcepub fn integrations(self, input: Integration) -> Self
pub fn integrations(self, input: Integration) -> Self
Appends an item to integrations.
To override the contents of this collection use set_integrations.
A list of zero-ETL integrations.
Sourcepub fn set_integrations(self, input: Option<Vec<Integration>>) -> Self
pub fn set_integrations(self, input: Option<Vec<Integration>>) -> Self
A list of zero-ETL integrations.
Sourcepub fn get_integrations(&self) -> &Option<Vec<Integration>>
pub fn get_integrations(&self) -> &Option<Vec<Integration>>
A list of zero-ETL integrations.
Sourcepub fn marker(self, input: impl Into<String>) -> Self
pub fn marker(self, input: impl Into<String>) -> Self
A value that indicates the starting point for the next set of response records in a subsequent request.
Sourcepub fn set_marker(self, input: Option<String>) -> Self
pub fn set_marker(self, input: Option<String>) -> Self
A value that indicates the starting point for the next set of response records in a subsequent request.
Sourcepub fn get_marker(&self) -> &Option<String>
pub fn get_marker(&self) -> &Option<String>
A value that indicates the starting point for the next set of response records in a subsequent request.
Sourcepub fn build(self) -> DescribeIntegrationsOutput
pub fn build(self) -> DescribeIntegrationsOutput
Consumes the builder and constructs a DescribeIntegrationsOutput.