#[non_exhaustive]pub struct DescribeIntegrationsInput {
pub integration_identifier: Option<String>,
pub marker: Option<String>,
pub max_records: Option<i32>,
pub filters: Option<Vec<IntegrationFilter>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.integration_identifier: Option<String>The Amazon Resource Name (ARN) for the integration.
marker: Option<String>A value that indicates the starting point for the next set of response records in a subsequent request.
max_records: Option<i32>The total number of items to return in the output.
filters: Option<Vec<IntegrationFilter>>A list of key and values, to filter down the results. Supported keys are "Status", "IntegrationName", and "SourceArn". IntegrationName is limited to only one value.
Implementations
Sourceimpl DescribeIntegrationsInput
impl DescribeIntegrationsInput
Sourcepub fn integration_identifier(&self) -> Option<&str>
pub fn integration_identifier(&self) -> Option<&str>
The Amazon Resource Name (ARN) for the integration.
Sourcepub fn marker(&self) -> Option<&str>
pub fn marker(&self) -> Option<&str>
A value that indicates the starting point for the next set of response records in a subsequent request.
Sourcepub fn max_records(&self) -> Option<i32>
pub fn max_records(&self) -> Option<i32>
The total number of items to return in the output.
Sourcepub fn filters(&self) -> &[IntegrationFilter]
pub fn filters(&self) -> &[IntegrationFilter]
A list of key and values, to filter down the results. Supported keys are "Status", "IntegrationName", and "SourceArn". IntegrationName is limited to only one value.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .filters.is_none().
Sourceimpl DescribeIntegrationsInput
impl DescribeIntegrationsInput
Sourcepub fn builder() -> DescribeIntegrationsInputBuilder
pub fn builder() -> DescribeIntegrationsInputBuilder
Creates a new builder-style object to manufacture DescribeIntegrationsInput.