#[non_exhaustive]pub struct DescribeIntegrationsOutput {
pub integrations: Option<Vec<Integration>>,
pub marker: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.integrations: Option<Vec<Integration>>A list of zero-ETL integrations.
marker: Option<String>A value that indicates the starting point for the next set of response records in a subsequent request.
Implementations
Sourceimpl DescribeIntegrationsOutput
impl DescribeIntegrationsOutput
Sourcepub fn integrations(&self) -> &[Integration]
pub fn integrations(&self) -> &[Integration]
A list of zero-ETL integrations.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .integrations.is_none().
Sourceimpl DescribeIntegrationsOutput
impl DescribeIntegrationsOutput
Sourcepub fn builder() -> DescribeIntegrationsOutputBuilder
pub fn builder() -> DescribeIntegrationsOutputBuilder
Creates a new builder-style object to manufacture DescribeIntegrationsOutput.