pub struct DisassociateGlossaryTermsFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to DisassociateGlossaryTerms.
Removes the association of one or more glossary terms from an asset in Glue Data Catalog.
Implementations
Sourceimpl DisassociateGlossaryTermsFluentBuilder
impl DisassociateGlossaryTermsFluentBuilder
Sourcepub fn as_input(&self) -> &DisassociateGlossaryTermsInputBuilder
pub fn as_input(&self) -> &DisassociateGlossaryTermsInputBuilder
Access the DisassociateGlossaryTerms as a reference.
Sourcepub async fn send(
self,
) -> Result<DisassociateGlossaryTermsOutput, SdkError<DisassociateGlossaryTermsError, HttpResponse>>
pub async fn send( self, ) -> Result<DisassociateGlossaryTermsOutput, SdkError<DisassociateGlossaryTermsError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<DisassociateGlossaryTermsOutput, DisassociateGlossaryTermsError, Self>
pub fn customize( self, ) -> CustomizableOperation<DisassociateGlossaryTermsOutput, DisassociateGlossaryTermsError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn asset_identifier(self, input: impl Into<String>) -> Self
pub fn asset_identifier(self, input: impl Into<String>) -> Self
The unique identifier of the asset to disassociate glossary terms from.
Sourcepub fn set_asset_identifier(self, input: Option<String>) -> Self
pub fn set_asset_identifier(self, input: Option<String>) -> Self
The unique identifier of the asset to disassociate glossary terms from.
Sourcepub fn get_asset_identifier(&self) -> &Option<String>
pub fn get_asset_identifier(&self) -> &Option<String>
The unique identifier of the asset to disassociate glossary terms from.
Sourcepub fn iterable_form_name(self, input: impl Into<String>) -> Self
pub fn iterable_form_name(self, input: impl Into<String>) -> Self
The name of the iterable form. When specified along with itemIdentifier, the glossary terms are disassociated from an item within the iterable form rather than the asset itself.
Sourcepub fn set_iterable_form_name(self, input: Option<String>) -> Self
pub fn set_iterable_form_name(self, input: Option<String>) -> Self
The name of the iterable form. When specified along with itemIdentifier, the glossary terms are disassociated from an item within the iterable form rather than the asset itself.
Sourcepub fn get_iterable_form_name(&self) -> &Option<String>
pub fn get_iterable_form_name(&self) -> &Option<String>
The name of the iterable form. When specified along with itemIdentifier, the glossary terms are disassociated from an item within the iterable form rather than the asset itself.
Sourcepub fn item_identifier(self, input: impl Into<String>) -> Self
pub fn item_identifier(self, input: impl Into<String>) -> Self
The identifier of the item within the iterable form. Required when iterableFormName is specified.
Sourcepub fn set_item_identifier(self, input: Option<String>) -> Self
pub fn set_item_identifier(self, input: Option<String>) -> Self
The identifier of the item within the iterable form. Required when iterableFormName is specified.
Sourcepub fn get_item_identifier(&self) -> &Option<String>
pub fn get_item_identifier(&self) -> &Option<String>
The identifier of the item within the iterable form. Required when iterableFormName is specified.
Sourcepub fn glossary_term_identifiers(self, input: impl Into<String>) -> Self
pub fn glossary_term_identifiers(self, input: impl Into<String>) -> Self
Appends an item to GlossaryTermIdentifiers.
To override the contents of this collection use set_glossary_term_identifiers.
The list of glossary term identifiers to disassociate from the asset.
Sourcepub fn set_glossary_term_identifiers(self, input: Option<Vec<String>>) -> Self
pub fn set_glossary_term_identifiers(self, input: Option<Vec<String>>) -> Self
The list of glossary term identifiers to disassociate from the asset.
Sourcepub fn get_glossary_term_identifiers(&self) -> &Option<Vec<String>>
pub fn get_glossary_term_identifiers(&self) -> &Option<Vec<String>>
The list of glossary term identifiers to disassociate from the asset.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.