#[non_exhaustive]pub struct DisassociateGlossaryTermsInputBuilder { /* private fields */ }Expand description
A builder for DisassociateGlossaryTermsInput.
Implementations
Sourceimpl DisassociateGlossaryTermsInputBuilder
impl DisassociateGlossaryTermsInputBuilder
Sourcepub fn asset_identifier(self, input: impl Into<String>) -> Self
pub fn asset_identifier(self, input: impl Into<String>) -> Self
The unique identifier of the asset to disassociate glossary terms from.
This field is required.Sourcepub fn set_asset_identifier(self, input: Option<String>) -> Self
pub fn set_asset_identifier(self, input: Option<String>) -> Self
The unique identifier of the asset to disassociate glossary terms from.
Sourcepub fn get_asset_identifier(&self) -> &Option<String>
pub fn get_asset_identifier(&self) -> &Option<String>
The unique identifier of the asset to disassociate glossary terms from.
Sourcepub fn iterable_form_name(self, input: impl Into<String>) -> Self
pub fn iterable_form_name(self, input: impl Into<String>) -> Self
The name of the iterable form. When specified along with itemIdentifier, the glossary terms are disassociated from an item within the iterable form rather than the asset itself.
Sourcepub fn set_iterable_form_name(self, input: Option<String>) -> Self
pub fn set_iterable_form_name(self, input: Option<String>) -> Self
The name of the iterable form. When specified along with itemIdentifier, the glossary terms are disassociated from an item within the iterable form rather than the asset itself.
Sourcepub fn get_iterable_form_name(&self) -> &Option<String>
pub fn get_iterable_form_name(&self) -> &Option<String>
The name of the iterable form. When specified along with itemIdentifier, the glossary terms are disassociated from an item within the iterable form rather than the asset itself.
Sourcepub fn item_identifier(self, input: impl Into<String>) -> Self
pub fn item_identifier(self, input: impl Into<String>) -> Self
The identifier of the item within the iterable form. Required when iterableFormName is specified.
Sourcepub fn set_item_identifier(self, input: Option<String>) -> Self
pub fn set_item_identifier(self, input: Option<String>) -> Self
The identifier of the item within the iterable form. Required when iterableFormName is specified.
Sourcepub fn get_item_identifier(&self) -> &Option<String>
pub fn get_item_identifier(&self) -> &Option<String>
The identifier of the item within the iterable form. Required when iterableFormName is specified.
Sourcepub fn glossary_term_identifiers(self, input: impl Into<String>) -> Self
pub fn glossary_term_identifiers(self, input: impl Into<String>) -> Self
Appends an item to glossary_term_identifiers.
To override the contents of this collection use set_glossary_term_identifiers.
The list of glossary term identifiers to disassociate from the asset.
Sourcepub fn set_glossary_term_identifiers(self, input: Option<Vec<String>>) -> Self
pub fn set_glossary_term_identifiers(self, input: Option<Vec<String>>) -> Self
The list of glossary term identifiers to disassociate from the asset.
Sourcepub fn get_glossary_term_identifiers(&self) -> &Option<Vec<String>>
pub fn get_glossary_term_identifiers(&self) -> &Option<Vec<String>>
The list of glossary term identifiers to disassociate from the asset.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn build(self) -> Result<DisassociateGlossaryTermsInput, BuildError>
pub fn build(self) -> Result<DisassociateGlossaryTermsInput, BuildError>
Consumes the builder and constructs a DisassociateGlossaryTermsInput.
Sourceimpl DisassociateGlossaryTermsInputBuilder
impl DisassociateGlossaryTermsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<DisassociateGlossaryTermsOutput, SdkError<DisassociateGlossaryTermsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<DisassociateGlossaryTermsOutput, SdkError<DisassociateGlossaryTermsError, HttpResponse>>
Sends a request with this input using the given client.