#[non_exhaustive]pub struct DisassociateGlossaryTermsOutputBuilder { /* private fields */ }Expand description
A builder for DisassociateGlossaryTermsOutput.
Implementations
Sourceimpl DisassociateGlossaryTermsOutputBuilder
impl DisassociateGlossaryTermsOutputBuilder
Sourcepub fn asset_identifier(self, input: impl Into<String>) -> Self
pub fn asset_identifier(self, input: impl Into<String>) -> Self
The unique identifier of the asset.
Sourcepub fn set_asset_identifier(self, input: Option<String>) -> Self
pub fn set_asset_identifier(self, input: Option<String>) -> Self
The unique identifier of the asset.
Sourcepub fn get_asset_identifier(&self) -> &Option<String>
pub fn get_asset_identifier(&self) -> &Option<String>
The unique identifier of the asset.
Sourcepub fn iterable_form_name(self, input: impl Into<String>) -> Self
pub fn iterable_form_name(self, input: impl Into<String>) -> Self
The name of the iterable form, if the disassociation targets an item.
Sourcepub fn set_iterable_form_name(self, input: Option<String>) -> Self
pub fn set_iterable_form_name(self, input: Option<String>) -> Self
The name of the iterable form, if the disassociation targets an item.
Sourcepub fn get_iterable_form_name(&self) -> &Option<String>
pub fn get_iterable_form_name(&self) -> &Option<String>
The name of the iterable form, if the disassociation targets an item.
Sourcepub fn item_identifier(self, input: impl Into<String>) -> Self
pub fn item_identifier(self, input: impl Into<String>) -> Self
The identifier of the item within the iterable form, if applicable.
Sourcepub fn set_item_identifier(self, input: Option<String>) -> Self
pub fn set_item_identifier(self, input: Option<String>) -> Self
The identifier of the item within the iterable form, if applicable.
Sourcepub fn get_item_identifier(&self) -> &Option<String>
pub fn get_item_identifier(&self) -> &Option<String>
The identifier of the item within the iterable form, if applicable.
Sourcepub fn glossary_terms(self, input: impl Into<String>) -> Self
pub fn glossary_terms(self, input: impl Into<String>) -> Self
Appends an item to glossary_terms.
To override the contents of this collection use set_glossary_terms.
The remaining glossary terms associated with the asset.
Sourcepub fn set_glossary_terms(self, input: Option<Vec<String>>) -> Self
pub fn set_glossary_terms(self, input: Option<Vec<String>>) -> Self
The remaining glossary terms associated with the asset.
Sourcepub fn get_glossary_terms(&self) -> &Option<Vec<String>>
pub fn get_glossary_terms(&self) -> &Option<Vec<String>>
The remaining glossary terms associated with the asset.
Sourcepub fn build(self) -> DisassociateGlossaryTermsOutput
pub fn build(self) -> DisassociateGlossaryTermsOutput
Consumes the builder and constructs a DisassociateGlossaryTermsOutput.