#[non_exhaustive]pub struct DisassociateGlossaryTermsInput {
pub asset_identifier: Option<String>,
pub iterable_form_name: Option<String>,
pub item_identifier: Option<String>,
pub glossary_term_identifiers: Option<Vec<String>>,
pub client_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.asset_identifier: Option<String>The unique identifier of the asset to disassociate glossary terms from.
iterable_form_name: Option<String>The name of the iterable form. When specified along with itemIdentifier, the glossary terms are disassociated from an item within the iterable form rather than the asset itself.
item_identifier: Option<String>The identifier of the item within the iterable form. Required when iterableFormName is specified.
glossary_term_identifiers: Option<Vec<String>>The list of glossary term identifiers to disassociate from the asset.
client_token: Option<String>A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Implementations
Sourceimpl DisassociateGlossaryTermsInput
impl DisassociateGlossaryTermsInput
Sourcepub fn asset_identifier(&self) -> Option<&str>
pub fn asset_identifier(&self) -> Option<&str>
The unique identifier of the asset to disassociate glossary terms from.
Sourcepub fn iterable_form_name(&self) -> Option<&str>
pub fn iterable_form_name(&self) -> Option<&str>
The name of the iterable form. When specified along with itemIdentifier, the glossary terms are disassociated from an item within the iterable form rather than the asset itself.
Sourcepub fn item_identifier(&self) -> Option<&str>
pub fn item_identifier(&self) -> Option<&str>
The identifier of the item within the iterable form. Required when iterableFormName is specified.
Sourcepub fn glossary_term_identifiers(&self) -> &[String]
pub fn glossary_term_identifiers(&self) -> &[String]
The list of glossary term identifiers to disassociate from the asset.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .glossary_term_identifiers.is_none().
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourceimpl DisassociateGlossaryTermsInput
impl DisassociateGlossaryTermsInput
Sourcepub fn builder() -> DisassociateGlossaryTermsInputBuilder
pub fn builder() -> DisassociateGlossaryTermsInputBuilder
Creates a new builder-style object to manufacture DisassociateGlossaryTermsInput.