pub struct GetAssetFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to GetAsset.
Retrieves the metadata for an asset in Glue Data Catalog, including its forms, additional attachments, and associated glossary terms.
Implementations
Sourceimpl GetAssetFluentBuilder
impl GetAssetFluentBuilder
Sourcepub fn as_input(&self) -> &GetAssetInputBuilder
pub fn as_input(&self) -> &GetAssetInputBuilder
Access the GetAsset as a reference.
Sourcepub async fn send(
self,
) -> Result<GetAssetOutput, SdkError<GetAssetError, HttpResponse>>
pub async fn send( self, ) -> Result<GetAssetOutput, SdkError<GetAssetError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<GetAssetOutput, GetAssetError, Self>
pub fn customize( self, ) -> CustomizableOperation<GetAssetOutput, GetAssetError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn identifier(self, input: impl Into<String>) -> Self
pub fn identifier(self, input: impl Into<String>) -> Self
The unique identifier of the asset to retrieve.
Sourcepub fn set_identifier(self, input: Option<String>) -> Self
pub fn set_identifier(self, input: Option<String>) -> Self
The unique identifier of the asset to retrieve.
Sourcepub fn get_identifier(&self) -> &Option<String>
pub fn get_identifier(&self) -> &Option<String>
The unique identifier of the asset to retrieve.