GetAssetOutputBuilder

Struct GetAssetOutputBuilder 

#[non_exhaustive]
pub struct GetAssetOutputBuilder { /* private fields */ }
A builder for GetAssetOutput.

Implementations

Source

impl GetAssetOutputBuilder

pub fn id(self, input: impl Into<String>) -> Self

The unique identifier of the asset.

This field is required.
pub fn set_id(self, input: Option<String>) -> Self

The unique identifier of the asset.

pub fn get_id(&self) -> &Option<String>

The unique identifier of the asset.

pub fn name(self, input: impl Into<String>) -> Self

The name of the asset.

pub fn set_name(self, input: Option<String>) -> Self

The name of the asset.

pub fn get_name(&self) -> &Option<String>

The name of the asset.

pub fn description(self, input: impl Into<String>) -> Self

The description of the asset.

pub fn set_description(self, input: Option<String>) -> Self

The description of the asset.

pub fn get_description(&self) -> &Option<String>

The description of the asset.

pub fn created_at(self, input: DateTime) -> Self

The timestamp at which the asset was created.

pub fn set_created_at(self, input: Option<DateTime>) -> Self

The timestamp at which the asset was created.

pub fn get_created_at(&self) -> &Option<DateTime>

The timestamp at which the asset was created.

pub fn updated_at(self, input: DateTime) -> Self

The timestamp at which the asset was last updated.

pub fn set_updated_at(self, input: Option<DateTime>) -> Self

The timestamp at which the asset was last updated.

pub fn get_updated_at(&self) -> &Option<DateTime>

The timestamp at which the asset was last updated.

pub fn asset_type_id(self, input: impl Into<String>) -> Self

The identifier of the asset type for this asset.

This field is required.
pub fn set_asset_type_id(self, input: Option<String>) -> Self

The identifier of the asset type for this asset.

pub fn get_asset_type_id(&self) -> &Option<String>

The identifier of the asset type for this asset.

pub fn glossary_terms(self, input: impl Into<String>) -> Self

Appends an item to glossary_terms.

To override the contents of this collection use set_glossary_terms.

The identifiers of the glossary terms associated with the asset.

pub fn set_glossary_terms(self, input: Option<Vec<String>>) -> Self

The identifiers of the glossary terms associated with the asset.

pub fn get_glossary_terms(&self) -> &Option<Vec<String>>

The identifiers of the glossary terms associated with the asset.

pub fn forms(self, k: impl Into<String>, v: AssetFormEntry) -> Self

Adds a key-value pair to forms.

To override the contents of this collection use set_forms.

The forms on the asset, keyed by form name.

pub fn set_forms(self, input: Option<HashMap<String, AssetFormEntry>>) -> Self

The forms on the asset, keyed by form name.

pub fn get_forms(&self) -> &Option<HashMap<String, AssetFormEntry>>

The forms on the asset, keyed by form name.

pub fn attachments(self, k: impl Into<String>, v: AssetFormEntry) -> Self

Adds a key-value pair to attachments.

To override the contents of this collection use set_attachments.

Additional attachments on the asset for more context, keyed by attachment name.

pub fn set_attachments( self, input: Option<HashMap<String, AssetFormEntry>>, ) -> Self

Additional attachments on the asset for more context, keyed by attachment name.

pub fn get_attachments(&self) -> &Option<HashMap<String, AssetFormEntry>>

Additional attachments on the asset for more context, keyed by attachment name.

pub fn iterable_forms(self, k: impl Into<String>, v: IterableFormEntry) -> Self

Adds a key-value pair to iterable_forms.

To override the contents of this collection use set_iterable_forms.

The iterable forms available on the asset, keyed by form name (for example, columns). Use the form name with ListIterableForms or BatchGetIterableForms to retrieve the form's items.

pub fn set_iterable_forms( self, input: Option<HashMap<String, IterableFormEntry>>, ) -> Self

The iterable forms available on the asset, keyed by form name (for example, columns). Use the form name with ListIterableForms or BatchGetIterableForms to retrieve the form's items.

pub fn get_iterable_forms(&self) -> &Option<HashMap<String, IterableFormEntry>>

The iterable forms available on the asset, keyed by form name (for example, columns). Use the form name with ListIterableForms or BatchGetIterableForms to retrieve the form's items.

pub fn build(self) -> Result<GetAssetOutput, BuildError>

Consumes the builder and constructs a GetAssetOutput. This method will fail if any of the following fields are not set: