pub struct GetBlueprintFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to GetBlueprint.
Retrieves the details of a blueprint.
Implementations
Sourceimpl GetBlueprintFluentBuilder
impl GetBlueprintFluentBuilder
Sourcepub fn as_input(&self) -> &GetBlueprintInputBuilder
pub fn as_input(&self) -> &GetBlueprintInputBuilder
Access the GetBlueprint as a reference.
Sourcepub async fn send(
self,
) -> Result<GetBlueprintOutput, SdkError<GetBlueprintError, HttpResponse>>
pub async fn send( self, ) -> Result<GetBlueprintOutput, SdkError<GetBlueprintError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<GetBlueprintOutput, GetBlueprintError, Self>
pub fn customize( self, ) -> CustomizableOperation<GetBlueprintOutput, GetBlueprintError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn include_blueprint(self, input: bool) -> Self
pub fn include_blueprint(self, input: bool) -> Self
Specifies whether or not to include the blueprint in the response.
Sourcepub fn set_include_blueprint(self, input: Option<bool>) -> Self
pub fn set_include_blueprint(self, input: Option<bool>) -> Self
Specifies whether or not to include the blueprint in the response.
Sourcepub fn get_include_blueprint(&self) -> &Option<bool>
pub fn get_include_blueprint(&self) -> &Option<bool>
Specifies whether or not to include the blueprint in the response.
Sourcepub fn include_parameter_spec(self, input: bool) -> Self
pub fn include_parameter_spec(self, input: bool) -> Self
Specifies whether or not to include the parameter specification.
Sourcepub fn set_include_parameter_spec(self, input: Option<bool>) -> Self
pub fn set_include_parameter_spec(self, input: Option<bool>) -> Self
Specifies whether or not to include the parameter specification.
Sourcepub fn get_include_parameter_spec(&self) -> &Option<bool>
pub fn get_include_parameter_spec(&self) -> &Option<bool>
Specifies whether or not to include the parameter specification.