#[non_exhaustive]pub struct GetBlueprintInputBuilder { /* private fields */ }Expand description
A builder for GetBlueprintInput.
Implementations
Sourceimpl GetBlueprintInputBuilder
impl GetBlueprintInputBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the blueprint.
This field is required.Sourcepub fn include_blueprint(self, input: bool) -> Self
pub fn include_blueprint(self, input: bool) -> Self
Specifies whether or not to include the blueprint in the response.
Sourcepub fn set_include_blueprint(self, input: Option<bool>) -> Self
pub fn set_include_blueprint(self, input: Option<bool>) -> Self
Specifies whether or not to include the blueprint in the response.
Sourcepub fn get_include_blueprint(&self) -> &Option<bool>
pub fn get_include_blueprint(&self) -> &Option<bool>
Specifies whether or not to include the blueprint in the response.
Sourcepub fn include_parameter_spec(self, input: bool) -> Self
pub fn include_parameter_spec(self, input: bool) -> Self
Specifies whether or not to include the parameter specification.
Sourcepub fn set_include_parameter_spec(self, input: Option<bool>) -> Self
pub fn set_include_parameter_spec(self, input: Option<bool>) -> Self
Specifies whether or not to include the parameter specification.
Sourcepub fn get_include_parameter_spec(&self) -> &Option<bool>
pub fn get_include_parameter_spec(&self) -> &Option<bool>
Specifies whether or not to include the parameter specification.
Sourcepub fn build(self) -> Result<GetBlueprintInput, BuildError>
pub fn build(self) -> Result<GetBlueprintInput, BuildError>
Consumes the builder and constructs a GetBlueprintInput.
Sourceimpl GetBlueprintInputBuilder
impl GetBlueprintInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<GetBlueprintOutput, SdkError<GetBlueprintError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<GetBlueprintOutput, SdkError<GetBlueprintError, HttpResponse>>
Sends a request with this input using the given client.