#[non_exhaustive]pub struct GetBlueprintInput {
pub name: Option<String>,
pub include_blueprint: Option<bool>,
pub include_parameter_spec: Option<bool>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>The name of the blueprint.
include_blueprint: Option<bool>Specifies whether or not to include the blueprint in the response.
include_parameter_spec: Option<bool>Specifies whether or not to include the parameter specification.
Implementations
Sourceimpl GetBlueprintInput
impl GetBlueprintInput
Sourcepub fn include_blueprint(&self) -> Option<bool>
pub fn include_blueprint(&self) -> Option<bool>
Specifies whether or not to include the blueprint in the response.
Sourcepub fn include_parameter_spec(&self) -> Option<bool>
pub fn include_parameter_spec(&self) -> Option<bool>
Specifies whether or not to include the parameter specification.
Sourceimpl GetBlueprintInput
impl GetBlueprintInput
Sourcepub fn builder() -> GetBlueprintInputBuilder
pub fn builder() -> GetBlueprintInputBuilder
Creates a new builder-style object to manufacture GetBlueprintInput.