pub struct GetBlueprintRunFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to GetBlueprintRun.
Retrieves the details of a blueprint run.
Implementations
Sourceimpl GetBlueprintRunFluentBuilder
impl GetBlueprintRunFluentBuilder
Sourcepub fn as_input(&self) -> &GetBlueprintRunInputBuilder
pub fn as_input(&self) -> &GetBlueprintRunInputBuilder
Access the GetBlueprintRun as a reference.
Sourcepub async fn send(
self,
) -> Result<GetBlueprintRunOutput, SdkError<GetBlueprintRunError, HttpResponse>>
pub async fn send( self, ) -> Result<GetBlueprintRunOutput, SdkError<GetBlueprintRunError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<GetBlueprintRunOutput, GetBlueprintRunError, Self>
pub fn customize( self, ) -> CustomizableOperation<GetBlueprintRunOutput, GetBlueprintRunError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn blueprint_name(self, input: impl Into<String>) -> Self
pub fn blueprint_name(self, input: impl Into<String>) -> Self
The name of the blueprint.
Sourcepub fn set_blueprint_name(self, input: Option<String>) -> Self
pub fn set_blueprint_name(self, input: Option<String>) -> Self
The name of the blueprint.
Sourcepub fn get_blueprint_name(&self) -> &Option<String>
pub fn get_blueprint_name(&self) -> &Option<String>
The name of the blueprint.
Sourcepub fn run_id(self, input: impl Into<String>) -> Self
pub fn run_id(self, input: impl Into<String>) -> Self
The run ID for the blueprint run you want to retrieve.
Sourcepub fn set_run_id(self, input: Option<String>) -> Self
pub fn set_run_id(self, input: Option<String>) -> Self
The run ID for the blueprint run you want to retrieve.
Sourcepub fn get_run_id(&self) -> &Option<String>
pub fn get_run_id(&self) -> &Option<String>
The run ID for the blueprint run you want to retrieve.