#[non_exhaustive]pub struct GetBlueprintRunInputBuilder { /* private fields */ }Expand description
A builder for GetBlueprintRunInput.
Implementations
Sourceimpl GetBlueprintRunInputBuilder
impl GetBlueprintRunInputBuilder
Sourcepub fn blueprint_name(self, input: impl Into<String>) -> Self
pub fn blueprint_name(self, input: impl Into<String>) -> Self
The name of the blueprint.
This field is required.Sourcepub fn set_blueprint_name(self, input: Option<String>) -> Self
pub fn set_blueprint_name(self, input: Option<String>) -> Self
The name of the blueprint.
Sourcepub fn get_blueprint_name(&self) -> &Option<String>
pub fn get_blueprint_name(&self) -> &Option<String>
The name of the blueprint.
Sourcepub fn run_id(self, input: impl Into<String>) -> Self
pub fn run_id(self, input: impl Into<String>) -> Self
The run ID for the blueprint run you want to retrieve.
This field is required.Sourcepub fn set_run_id(self, input: Option<String>) -> Self
pub fn set_run_id(self, input: Option<String>) -> Self
The run ID for the blueprint run you want to retrieve.
Sourcepub fn get_run_id(&self) -> &Option<String>
pub fn get_run_id(&self) -> &Option<String>
The run ID for the blueprint run you want to retrieve.
Sourcepub fn build(self) -> Result<GetBlueprintRunInput, BuildError>
pub fn build(self) -> Result<GetBlueprintRunInput, BuildError>
Consumes the builder and constructs a GetBlueprintRunInput.
Sourceimpl GetBlueprintRunInputBuilder
impl GetBlueprintRunInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<GetBlueprintRunOutput, SdkError<GetBlueprintRunError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<GetBlueprintRunOutput, SdkError<GetBlueprintRunError, HttpResponse>>
Sends a request with this input using the given client.