pub struct GetBlueprintRunsFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to GetBlueprintRuns.
Retrieves the details of blueprint runs for a specified blueprint.
Implementations
Sourceimpl GetBlueprintRunsFluentBuilder
impl GetBlueprintRunsFluentBuilder
Sourcepub fn as_input(&self) -> &GetBlueprintRunsInputBuilder
pub fn as_input(&self) -> &GetBlueprintRunsInputBuilder
Access the GetBlueprintRuns as a reference.
Sourcepub async fn send(
self,
) -> Result<GetBlueprintRunsOutput, SdkError<GetBlueprintRunsError, HttpResponse>>
pub async fn send( self, ) -> Result<GetBlueprintRunsOutput, SdkError<GetBlueprintRunsError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<GetBlueprintRunsOutput, GetBlueprintRunsError, Self>
pub fn customize( self, ) -> CustomizableOperation<GetBlueprintRunsOutput, GetBlueprintRunsError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn into_paginator(self) -> GetBlueprintRunsPaginator
pub fn into_paginator(self) -> GetBlueprintRunsPaginator
Create a paginator for this request
Paginators are used by calling send().await which returns a PaginationStream.
Sourcepub fn blueprint_name(self, input: impl Into<String>) -> Self
pub fn blueprint_name(self, input: impl Into<String>) -> Self
The name of the blueprint.
Sourcepub fn set_blueprint_name(self, input: Option<String>) -> Self
pub fn set_blueprint_name(self, input: Option<String>) -> Self
The name of the blueprint.
Sourcepub fn get_blueprint_name(&self) -> &Option<String>
pub fn get_blueprint_name(&self) -> &Option<String>
The name of the blueprint.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token, if this is a continuation request.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token, if this is a continuation request.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token, if this is a continuation request.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum size of a list to return.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum size of a list to return.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The maximum size of a list to return.