#[non_exhaustive]pub struct GetBlueprintRunsInputBuilder { /* private fields */ }Expand description
A builder for GetBlueprintRunsInput.
Implementations
Sourceimpl GetBlueprintRunsInputBuilder
impl GetBlueprintRunsInputBuilder
Sourcepub fn blueprint_name(self, input: impl Into<String>) -> Self
pub fn blueprint_name(self, input: impl Into<String>) -> Self
The name of the blueprint.
This field is required.Sourcepub fn set_blueprint_name(self, input: Option<String>) -> Self
pub fn set_blueprint_name(self, input: Option<String>) -> Self
The name of the blueprint.
Sourcepub fn get_blueprint_name(&self) -> &Option<String>
pub fn get_blueprint_name(&self) -> &Option<String>
The name of the blueprint.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token, if this is a continuation request.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token, if this is a continuation request.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token, if this is a continuation request.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum size of a list to return.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum size of a list to return.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The maximum size of a list to return.
Sourcepub fn build(self) -> Result<GetBlueprintRunsInput, BuildError>
pub fn build(self) -> Result<GetBlueprintRunsInput, BuildError>
Consumes the builder and constructs a GetBlueprintRunsInput.
Sourceimpl GetBlueprintRunsInputBuilder
impl GetBlueprintRunsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<GetBlueprintRunsOutput, SdkError<GetBlueprintRunsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<GetBlueprintRunsOutput, SdkError<GetBlueprintRunsError, HttpResponse>>
Sends a request with this input using the given client.