#[non_exhaustive]pub struct GetBlueprintRunsOutputBuilder { /* private fields */ }Expand description
A builder for GetBlueprintRunsOutput.
Implementations
Sourceimpl GetBlueprintRunsOutputBuilder
impl GetBlueprintRunsOutputBuilder
Sourcepub fn blueprint_runs(self, input: BlueprintRun) -> Self
pub fn blueprint_runs(self, input: BlueprintRun) -> Self
Appends an item to blueprint_runs.
To override the contents of this collection use set_blueprint_runs.
Returns a list of BlueprintRun objects.
Sourcepub fn set_blueprint_runs(self, input: Option<Vec<BlueprintRun>>) -> Self
pub fn set_blueprint_runs(self, input: Option<Vec<BlueprintRun>>) -> Self
Returns a list of BlueprintRun objects.
Sourcepub fn get_blueprint_runs(&self) -> &Option<Vec<BlueprintRun>>
pub fn get_blueprint_runs(&self) -> &Option<Vec<BlueprintRun>>
Returns a list of BlueprintRun objects.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token, if not all blueprint runs have been returned.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token, if not all blueprint runs have been returned.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token, if not all blueprint runs have been returned.
Sourcepub fn build(self) -> GetBlueprintRunsOutput
pub fn build(self) -> GetBlueprintRunsOutput
Consumes the builder and constructs a GetBlueprintRunsOutput.