#[non_exhaustive]pub struct GetBlueprintRunsInput {
pub blueprint_name: Option<String>,
pub next_token: Option<String>,
pub max_results: Option<i32>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.blueprint_name: Option<String>The name of the blueprint.
next_token: Option<String>A continuation token, if this is a continuation request.
max_results: Option<i32>The maximum size of a list to return.
Implementations
Sourceimpl GetBlueprintRunsInput
impl GetBlueprintRunsInput
Sourcepub fn blueprint_name(&self) -> Option<&str>
pub fn blueprint_name(&self) -> Option<&str>
The name of the blueprint.
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A continuation token, if this is a continuation request.
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
The maximum size of a list to return.
Sourceimpl GetBlueprintRunsInput
impl GetBlueprintRunsInput
Sourcepub fn builder() -> GetBlueprintRunsInputBuilder
pub fn builder() -> GetBlueprintRunsInputBuilder
Creates a new builder-style object to manufacture GetBlueprintRunsInput.