pub struct GetCatalogFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to GetCatalog.
The name of the Catalog to retrieve. This should be all lowercase.
Implementations
Sourceimpl GetCatalogFluentBuilder
impl GetCatalogFluentBuilder
Sourcepub fn as_input(&self) -> &GetCatalogInputBuilder
pub fn as_input(&self) -> &GetCatalogInputBuilder
Access the GetCatalog as a reference.
Sourcepub async fn send(
self,
) -> Result<GetCatalogOutput, SdkError<GetCatalogError, HttpResponse>>
pub async fn send( self, ) -> Result<GetCatalogOutput, SdkError<GetCatalogError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<GetCatalogOutput, GetCatalogError, Self>
pub fn customize( self, ) -> CustomizableOperation<GetCatalogOutput, GetCatalogError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn catalog_id(self, input: impl Into<String>) -> Self
pub fn catalog_id(self, input: impl Into<String>) -> Self
The ID of the parent catalog in which the catalog resides. If none is provided, the Amazon Web Services Account Number is used by default.
Sourcepub fn set_catalog_id(self, input: Option<String>) -> Self
pub fn set_catalog_id(self, input: Option<String>) -> Self
The ID of the parent catalog in which the catalog resides. If none is provided, the Amazon Web Services Account Number is used by default.
Sourcepub fn get_catalog_id(&self) -> &Option<String>
pub fn get_catalog_id(&self) -> &Option<String>
The ID of the parent catalog in which the catalog resides. If none is provided, the Amazon Web Services Account Number is used by default.