#[non_exhaustive]pub struct GetCatalogInputBuilder { /* private fields */ }Expand description
A builder for GetCatalogInput.
Implementations
Sourceimpl GetCatalogInputBuilder
impl GetCatalogInputBuilder
Sourcepub fn catalog_id(self, input: impl Into<String>) -> Self
pub fn catalog_id(self, input: impl Into<String>) -> Self
The ID of the parent catalog in which the catalog resides. If none is provided, the Amazon Web Services Account Number is used by default.
This field is required.Sourcepub fn set_catalog_id(self, input: Option<String>) -> Self
pub fn set_catalog_id(self, input: Option<String>) -> Self
The ID of the parent catalog in which the catalog resides. If none is provided, the Amazon Web Services Account Number is used by default.
Sourcepub fn get_catalog_id(&self) -> &Option<String>
pub fn get_catalog_id(&self) -> &Option<String>
The ID of the parent catalog in which the catalog resides. If none is provided, the Amazon Web Services Account Number is used by default.
Sourcepub fn build(self) -> Result<GetCatalogInput, BuildError>
pub fn build(self) -> Result<GetCatalogInput, BuildError>
Consumes the builder and constructs a GetCatalogInput.
Sourceimpl GetCatalogInputBuilder
impl GetCatalogInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<GetCatalogOutput, SdkError<GetCatalogError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<GetCatalogOutput, SdkError<GetCatalogError, HttpResponse>>
Sends a request with this input using the given client.