#[non_exhaustive]pub struct GetCatalogOutputBuilder { /* private fields */ }Expand description
A builder for GetCatalogOutput.
Implementations
Sourceimpl GetCatalogOutputBuilder
impl GetCatalogOutputBuilder
Sourcepub fn catalog(self, input: Catalog) -> Self
pub fn catalog(self, input: Catalog) -> Self
A Catalog object. The definition of the specified catalog in the Glue Data Catalog.
Sourcepub fn set_catalog(self, input: Option<Catalog>) -> Self
pub fn set_catalog(self, input: Option<Catalog>) -> Self
A Catalog object. The definition of the specified catalog in the Glue Data Catalog.
Sourcepub fn get_catalog(&self) -> &Option<Catalog>
pub fn get_catalog(&self) -> &Option<Catalog>
A Catalog object. The definition of the specified catalog in the Glue Data Catalog.
Sourcepub fn build(self) -> GetCatalogOutput
pub fn build(self) -> GetCatalogOutput
Consumes the builder and constructs a GetCatalogOutput.