#[non_exhaustive]pub struct GetCatalogInput {
pub catalog_id: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.catalog_id: Option<String>The ID of the parent catalog in which the catalog resides. If none is provided, the Amazon Web Services Account Number is used by default.
Implementations
Sourceimpl GetCatalogInput
impl GetCatalogInput
Sourcepub fn catalog_id(&self) -> Option<&str>
pub fn catalog_id(&self) -> Option<&str>
The ID of the parent catalog in which the catalog resides. If none is provided, the Amazon Web Services Account Number is used by default.
Sourceimpl GetCatalogInput
impl GetCatalogInput
Sourcepub fn builder() -> GetCatalogInputBuilder
pub fn builder() -> GetCatalogInputBuilder
Creates a new builder-style object to manufacture GetCatalogInput.