GetCatalogsInputBuilder

Struct GetCatalogsInputBuilder 

#[non_exhaustive]
pub struct GetCatalogsInputBuilder { /* private fields */ }
A builder for GetCatalogsInput.

Implementations

Source

impl GetCatalogsInputBuilder

pub fn parent_catalog_id(self, input: impl Into<String>) -> Self

The ID of the parent catalog in which the catalog resides. If none is provided, the Amazon Web Services Account Number is used by default.

pub fn set_parent_catalog_id(self, input: Option<String>) -> Self

The ID of the parent catalog in which the catalog resides. If none is provided, the Amazon Web Services Account Number is used by default.

pub fn get_parent_catalog_id(&self) -> &Option<String>

The ID of the parent catalog in which the catalog resides. If none is provided, the Amazon Web Services Account Number is used by default.

pub fn next_token(self, input: impl Into<String>) -> Self

A continuation token, if this is a continuation call.

pub fn set_next_token(self, input: Option<String>) -> Self

A continuation token, if this is a continuation call.

pub fn get_next_token(&self) -> &Option<String>

A continuation token, if this is a continuation call.

pub fn max_results(self, input: i32) -> Self

The maximum number of catalogs to return in one response.

pub fn set_max_results(self, input: Option<i32>) -> Self

The maximum number of catalogs to return in one response.

pub fn get_max_results(&self) -> &Option<i32>

The maximum number of catalogs to return in one response.

pub fn recursive(self, input: bool) -> Self

Whether to list all catalogs across the catalog hierarchy, starting from the ParentCatalogId. Defaults to false . When true, all catalog objects in the ParentCatalogID hierarchy are enumerated in the response.

pub fn set_recursive(self, input: Option<bool>) -> Self

Whether to list all catalogs across the catalog hierarchy, starting from the ParentCatalogId. Defaults to false . When true, all catalog objects in the ParentCatalogID hierarchy are enumerated in the response.

pub fn get_recursive(&self) -> &Option<bool>

Whether to list all catalogs across the catalog hierarchy, starting from the ParentCatalogId. Defaults to false . When true, all catalog objects in the ParentCatalogID hierarchy are enumerated in the response.

pub fn include_root(self, input: bool) -> Self

Whether to list the default catalog in the account and region in the response. Defaults to false. When true and ParentCatalogId = NULL | Amazon Web Services Account ID, all catalogs and the default catalog are enumerated in the response.

When the ParentCatalogId is not equal to null, and this attribute is passed as false or true, an InvalidInputException is thrown.

pub fn set_include_root(self, input: Option<bool>) -> Self

Whether to list the default catalog in the account and region in the response. Defaults to false. When true and ParentCatalogId = NULL | Amazon Web Services Account ID, all catalogs and the default catalog are enumerated in the response.

When the ParentCatalogId is not equal to null, and this attribute is passed as false or true, an InvalidInputException is thrown.

pub fn get_include_root(&self) -> &Option<bool>

Whether to list the default catalog in the account and region in the response. Defaults to false. When true and ParentCatalogId = NULL | Amazon Web Services Account ID, all catalogs and the default catalog are enumerated in the response.

When the ParentCatalogId is not equal to null, and this attribute is passed as false or true, an InvalidInputException is thrown.

pub fn build(self) -> Result<GetCatalogsInput, BuildError>

Consumes the builder and constructs a GetCatalogsInput.

Source

impl GetCatalogsInputBuilder

pub async fn send_with( self, client: &Client, ) -> Result<GetCatalogsOutput, SdkError<GetCatalogsError, HttpResponse>>

Sends a request with this input using the given client.