#[non_exhaustive]pub struct GetCatalogsOutputBuilder { /* private fields */ }Expand description
A builder for GetCatalogsOutput.
Implementations
Sourceimpl GetCatalogsOutputBuilder
impl GetCatalogsOutputBuilder
Sourcepub fn catalog_list(self, input: Catalog) -> Self
pub fn catalog_list(self, input: Catalog) -> Self
Appends an item to catalog_list.
To override the contents of this collection use set_catalog_list.
An array of Catalog objects. A list of Catalog objects from the specified parent catalog.
Sourcepub fn set_catalog_list(self, input: Option<Vec<Catalog>>) -> Self
pub fn set_catalog_list(self, input: Option<Vec<Catalog>>) -> Self
An array of Catalog objects. A list of Catalog objects from the specified parent catalog.
Sourcepub fn get_catalog_list(&self) -> &Option<Vec<Catalog>>
pub fn get_catalog_list(&self) -> &Option<Vec<Catalog>>
An array of Catalog objects. A list of Catalog objects from the specified parent catalog.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token for paginating the returned list of tokens, returned if the current segment of the list is not the last.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token for paginating the returned list of tokens, returned if the current segment of the list is not the last.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token for paginating the returned list of tokens, returned if the current segment of the list is not the last.
Sourcepub fn build(self) -> Result<GetCatalogsOutput, BuildError>
pub fn build(self) -> Result<GetCatalogsOutput, BuildError>
Consumes the builder and constructs a GetCatalogsOutput.
This method will fail if any of the following fields are not set: