GetCatalogsInput

Struct GetCatalogsInput 

#[non_exhaustive]
pub struct GetCatalogsInput { pub parent_catalog_id: Option<String>, pub next_token: Option<String>, pub max_results: Option<i32>, pub recursive: Option<bool>, pub include_root: Option<bool>, }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
parent_catalog_id: Option<String>

The ID of the parent catalog in which the catalog resides. If none is provided, the Amazon Web Services Account Number is used by default.

next_token: Option<String>

A continuation token, if this is a continuation call.

max_results: Option<i32>

The maximum number of catalogs to return in one response.

recursive: Option<bool>

Whether to list all catalogs across the catalog hierarchy, starting from the ParentCatalogId. Defaults to false . When true, all catalog objects in the ParentCatalogID hierarchy are enumerated in the response.

include_root: Option<bool>

Whether to list the default catalog in the account and region in the response. Defaults to false. When true and ParentCatalogId = NULL | Amazon Web Services Account ID, all catalogs and the default catalog are enumerated in the response.

When the ParentCatalogId is not equal to null, and this attribute is passed as false or true, an InvalidInputException is thrown.

Implementations

Source

impl GetCatalogsInput

pub fn parent_catalog_id(&self) -> Option<&str>

The ID of the parent catalog in which the catalog resides. If none is provided, the Amazon Web Services Account Number is used by default.

pub fn next_token(&self) -> Option<&str>

A continuation token, if this is a continuation call.

pub fn max_results(&self) -> Option<i32>

The maximum number of catalogs to return in one response.

pub fn recursive(&self) -> Option<bool>

Whether to list all catalogs across the catalog hierarchy, starting from the ParentCatalogId. Defaults to false . When true, all catalog objects in the ParentCatalogID hierarchy are enumerated in the response.

pub fn include_root(&self) -> Option<bool>

Whether to list the default catalog in the account and region in the response. Defaults to false. When true and ParentCatalogId = NULL | Amazon Web Services Account ID, all catalogs and the default catalog are enumerated in the response.

When the ParentCatalogId is not equal to null, and this attribute is passed as false or true, an InvalidInputException is thrown.

Source

impl GetCatalogsInput

pub fn builder() -> GetCatalogsInputBuilder

Creates a new builder-style object to manufacture GetCatalogsInput.