#[non_exhaustive]pub struct GetCatalogsOutput {
pub catalog_list: Vec<Catalog>,
pub next_token: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.catalog_list: Vec<Catalog>An array of Catalog objects. A list of Catalog objects from the specified parent catalog.
next_token: Option<String>A continuation token for paginating the returned list of tokens, returned if the current segment of the list is not the last.
Implementations
Sourceimpl GetCatalogsOutput
impl GetCatalogsOutput
Sourcepub fn catalog_list(&self) -> &[Catalog]
pub fn catalog_list(&self) -> &[Catalog]
An array of Catalog objects. A list of Catalog objects from the specified parent catalog.
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A continuation token for paginating the returned list of tokens, returned if the current segment of the list is not the last.
Sourceimpl GetCatalogsOutput
impl GetCatalogsOutput
Sourcepub fn builder() -> GetCatalogsOutputBuilder
pub fn builder() -> GetCatalogsOutputBuilder
Creates a new builder-style object to manufacture GetCatalogsOutput.