#[non_exhaustive]pub struct GetColumnStatisticsTaskSettingsInputBuilder { /* private fields */ }Expand description
A builder for GetColumnStatisticsTaskSettingsInput.
Implementations
Sourceimpl GetColumnStatisticsTaskSettingsInputBuilder
impl GetColumnStatisticsTaskSettingsInputBuilder
Sourcepub fn database_name(self, input: impl Into<String>) -> Self
pub fn database_name(self, input: impl Into<String>) -> Self
The name of the database where the table resides.
This field is required.Sourcepub fn set_database_name(self, input: Option<String>) -> Self
pub fn set_database_name(self, input: Option<String>) -> Self
The name of the database where the table resides.
Sourcepub fn get_database_name(&self) -> &Option<String>
pub fn get_database_name(&self) -> &Option<String>
The name of the database where the table resides.
Sourcepub fn table_name(self, input: impl Into<String>) -> Self
pub fn table_name(self, input: impl Into<String>) -> Self
The name of the table for which to retrieve column statistics.
This field is required.Sourcepub fn set_table_name(self, input: Option<String>) -> Self
pub fn set_table_name(self, input: Option<String>) -> Self
The name of the table for which to retrieve column statistics.
Sourcepub fn get_table_name(&self) -> &Option<String>
pub fn get_table_name(&self) -> &Option<String>
The name of the table for which to retrieve column statistics.
Sourcepub fn build(self) -> Result<GetColumnStatisticsTaskSettingsInput, BuildError>
pub fn build(self) -> Result<GetColumnStatisticsTaskSettingsInput, BuildError>
Consumes the builder and constructs a GetColumnStatisticsTaskSettingsInput.
Sourceimpl GetColumnStatisticsTaskSettingsInputBuilder
impl GetColumnStatisticsTaskSettingsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<GetColumnStatisticsTaskSettingsOutput, SdkError<GetColumnStatisticsTaskSettingsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<GetColumnStatisticsTaskSettingsOutput, SdkError<GetColumnStatisticsTaskSettingsError, HttpResponse>>
Sends a request with this input using the given client.