#[non_exhaustive]pub struct GetColumnStatisticsTaskSettingsOutputBuilder { /* private fields */ }Expand description
A builder for GetColumnStatisticsTaskSettingsOutput.
Implementations
Sourceimpl GetColumnStatisticsTaskSettingsOutputBuilder
impl GetColumnStatisticsTaskSettingsOutputBuilder
Sourcepub fn column_statistics_task_settings(
self,
input: ColumnStatisticsTaskSettings,
) -> Self
pub fn column_statistics_task_settings( self, input: ColumnStatisticsTaskSettings, ) -> Self
A ColumnStatisticsTaskSettings object representing the settings for the column statistics task.
Sourcepub fn set_column_statistics_task_settings(
self,
input: Option<ColumnStatisticsTaskSettings>,
) -> Self
pub fn set_column_statistics_task_settings( self, input: Option<ColumnStatisticsTaskSettings>, ) -> Self
A ColumnStatisticsTaskSettings object representing the settings for the column statistics task.
Sourcepub fn get_column_statistics_task_settings(
&self,
) -> &Option<ColumnStatisticsTaskSettings>
pub fn get_column_statistics_task_settings( &self, ) -> &Option<ColumnStatisticsTaskSettings>
A ColumnStatisticsTaskSettings object representing the settings for the column statistics task.
Sourcepub fn build(self) -> GetColumnStatisticsTaskSettingsOutput
pub fn build(self) -> GetColumnStatisticsTaskSettingsOutput
Consumes the builder and constructs a GetColumnStatisticsTaskSettingsOutput.