#[non_exhaustive]pub struct GetColumnStatisticsTaskSettingsOutput {
pub column_statistics_task_settings: Option<ColumnStatisticsTaskSettings>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.column_statistics_task_settings: Option<ColumnStatisticsTaskSettings>A ColumnStatisticsTaskSettings object representing the settings for the column statistics task.
Implementations
Sourceimpl GetColumnStatisticsTaskSettingsOutput
impl GetColumnStatisticsTaskSettingsOutput
Sourcepub fn column_statistics_task_settings(
&self,
) -> Option<&ColumnStatisticsTaskSettings>
pub fn column_statistics_task_settings( &self, ) -> Option<&ColumnStatisticsTaskSettings>
A ColumnStatisticsTaskSettings object representing the settings for the column statistics task.
Sourceimpl GetColumnStatisticsTaskSettingsOutput
impl GetColumnStatisticsTaskSettingsOutput
Sourcepub fn builder() -> GetColumnStatisticsTaskSettingsOutputBuilder
pub fn builder() -> GetColumnStatisticsTaskSettingsOutputBuilder
Creates a new builder-style object to manufacture GetColumnStatisticsTaskSettingsOutput.