pub struct GetCrawlersFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to GetCrawlers.
Retrieves metadata for all crawlers defined in the customer account.
Implementations
Sourceimpl GetCrawlersFluentBuilder
impl GetCrawlersFluentBuilder
Sourcepub fn as_input(&self) -> &GetCrawlersInputBuilder
pub fn as_input(&self) -> &GetCrawlersInputBuilder
Access the GetCrawlers as a reference.
Sourcepub async fn send(
self,
) -> Result<GetCrawlersOutput, SdkError<GetCrawlersError, HttpResponse>>
pub async fn send( self, ) -> Result<GetCrawlersOutput, SdkError<GetCrawlersError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<GetCrawlersOutput, GetCrawlersError, Self>
pub fn customize( self, ) -> CustomizableOperation<GetCrawlersOutput, GetCrawlersError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn into_paginator(self) -> GetCrawlersPaginator
pub fn into_paginator(self) -> GetCrawlersPaginator
Create a paginator for this request
Paginators are used by calling send().await which returns a PaginationStream.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The number of crawlers to return on each call.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The number of crawlers to return on each call.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The number of crawlers to return on each call.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token, if this is a continuation request.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token, if this is a continuation request.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token, if this is a continuation request.