#[non_exhaustive]pub struct GetCrawlersOutputBuilder { /* private fields */ }Expand description
A builder for GetCrawlersOutput.
Implementations
Sourceimpl GetCrawlersOutputBuilder
impl GetCrawlersOutputBuilder
Sourcepub fn crawlers(self, input: Crawler) -> Self
pub fn crawlers(self, input: Crawler) -> Self
Appends an item to crawlers.
To override the contents of this collection use set_crawlers.
A list of crawler metadata.
Sourcepub fn set_crawlers(self, input: Option<Vec<Crawler>>) -> Self
pub fn set_crawlers(self, input: Option<Vec<Crawler>>) -> Self
A list of crawler metadata.
Sourcepub fn get_crawlers(&self) -> &Option<Vec<Crawler>>
pub fn get_crawlers(&self) -> &Option<Vec<Crawler>>
A list of crawler metadata.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token, if the returned list has not reached the end of those defined in this customer account.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token, if the returned list has not reached the end of those defined in this customer account.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token, if the returned list has not reached the end of those defined in this customer account.
Sourcepub fn build(self) -> GetCrawlersOutput
pub fn build(self) -> GetCrawlersOutput
Consumes the builder and constructs a GetCrawlersOutput.