pub struct GetDashboardUrlFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to GetDashboardUrl.
Retrieves the URL for the Spark monitoring dashboard for a Glue resource.
Implementations
Sourceimpl GetDashboardUrlFluentBuilder
impl GetDashboardUrlFluentBuilder
Sourcepub fn as_input(&self) -> &GetDashboardUrlInputBuilder
pub fn as_input(&self) -> &GetDashboardUrlInputBuilder
Access the GetDashboardUrl as a reference.
Sourcepub async fn send(
self,
) -> Result<GetDashboardUrlOutput, SdkError<GetDashboardUrlError, HttpResponse>>
pub async fn send( self, ) -> Result<GetDashboardUrlOutput, SdkError<GetDashboardUrlError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<GetDashboardUrlOutput, GetDashboardUrlError, Self>
pub fn customize( self, ) -> CustomizableOperation<GetDashboardUrlOutput, GetDashboardUrlError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn resource_id(self, input: impl Into<String>) -> Self
pub fn resource_id(self, input: impl Into<String>) -> Self
The unique identifier of the resource for which to retrieve the dashboard URL.
Sourcepub fn set_resource_id(self, input: Option<String>) -> Self
pub fn set_resource_id(self, input: Option<String>) -> Self
The unique identifier of the resource for which to retrieve the dashboard URL.
Sourcepub fn get_resource_id(&self) -> &Option<String>
pub fn get_resource_id(&self) -> &Option<String>
The unique identifier of the resource for which to retrieve the dashboard URL.
Sourcepub fn resource_type(self, input: GlueResourceType) -> Self
pub fn resource_type(self, input: GlueResourceType) -> Self
The type of the resource. Valid values are SESSION and JOB.
Sourcepub fn set_resource_type(self, input: Option<GlueResourceType>) -> Self
pub fn set_resource_type(self, input: Option<GlueResourceType>) -> Self
The type of the resource. Valid values are SESSION and JOB.
Sourcepub fn get_resource_type(&self) -> &Option<GlueResourceType>
pub fn get_resource_type(&self) -> &Option<GlueResourceType>
The type of the resource. Valid values are SESSION and JOB.
Sourcepub fn request_origin(self, input: impl Into<String>) -> Self
pub fn request_origin(self, input: impl Into<String>) -> Self
The origin of the request.
Sourcepub fn set_request_origin(self, input: Option<String>) -> Self
pub fn set_request_origin(self, input: Option<String>) -> Self
The origin of the request.
Sourcepub fn get_request_origin(&self) -> &Option<String>
pub fn get_request_origin(&self) -> &Option<String>
The origin of the request.