#[non_exhaustive]pub struct GetDashboardUrlInputBuilder { /* private fields */ }Expand description
A builder for GetDashboardUrlInput.
Implementations
Sourceimpl GetDashboardUrlInputBuilder
impl GetDashboardUrlInputBuilder
Sourcepub fn resource_id(self, input: impl Into<String>) -> Self
pub fn resource_id(self, input: impl Into<String>) -> Self
The unique identifier of the resource for which to retrieve the dashboard URL.
This field is required.Sourcepub fn set_resource_id(self, input: Option<String>) -> Self
pub fn set_resource_id(self, input: Option<String>) -> Self
The unique identifier of the resource for which to retrieve the dashboard URL.
Sourcepub fn get_resource_id(&self) -> &Option<String>
pub fn get_resource_id(&self) -> &Option<String>
The unique identifier of the resource for which to retrieve the dashboard URL.
Sourcepub fn resource_type(self, input: GlueResourceType) -> Self
pub fn resource_type(self, input: GlueResourceType) -> Self
The type of the resource. Valid values are SESSION and JOB.
Sourcepub fn set_resource_type(self, input: Option<GlueResourceType>) -> Self
pub fn set_resource_type(self, input: Option<GlueResourceType>) -> Self
The type of the resource. Valid values are SESSION and JOB.
Sourcepub fn get_resource_type(&self) -> &Option<GlueResourceType>
pub fn get_resource_type(&self) -> &Option<GlueResourceType>
The type of the resource. Valid values are SESSION and JOB.
Sourcepub fn request_origin(self, input: impl Into<String>) -> Self
pub fn request_origin(self, input: impl Into<String>) -> Self
The origin of the request.
Sourcepub fn set_request_origin(self, input: Option<String>) -> Self
pub fn set_request_origin(self, input: Option<String>) -> Self
The origin of the request.
Sourcepub fn get_request_origin(&self) -> &Option<String>
pub fn get_request_origin(&self) -> &Option<String>
The origin of the request.
Sourcepub fn build(self) -> Result<GetDashboardUrlInput, BuildError>
pub fn build(self) -> Result<GetDashboardUrlInput, BuildError>
Consumes the builder and constructs a GetDashboardUrlInput.
Sourceimpl GetDashboardUrlInputBuilder
impl GetDashboardUrlInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<GetDashboardUrlOutput, SdkError<GetDashboardUrlError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<GetDashboardUrlOutput, SdkError<GetDashboardUrlError, HttpResponse>>
Sends a request with this input using the given client.