#[non_exhaustive]pub struct GetDashboardUrlInput {
pub resource_id: Option<String>,
pub resource_type: Option<GlueResourceType>,
pub request_origin: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.resource_id: Option<String>The unique identifier of the resource for which to retrieve the dashboard URL.
resource_type: Option<GlueResourceType>The type of the resource. Valid values are SESSION and JOB.
request_origin: Option<String>The origin of the request.
Implementations
Sourceimpl GetDashboardUrlInput
impl GetDashboardUrlInput
Sourcepub fn resource_id(&self) -> Option<&str>
pub fn resource_id(&self) -> Option<&str>
The unique identifier of the resource for which to retrieve the dashboard URL.
Sourcepub fn resource_type(&self) -> Option<&GlueResourceType>
pub fn resource_type(&self) -> Option<&GlueResourceType>
The type of the resource. Valid values are SESSION and JOB.
Sourcepub fn request_origin(&self) -> Option<&str>
pub fn request_origin(&self) -> Option<&str>
The origin of the request.
Sourceimpl GetDashboardUrlInput
impl GetDashboardUrlInput
Sourcepub fn builder() -> GetDashboardUrlInputBuilder
pub fn builder() -> GetDashboardUrlInputBuilder
Creates a new builder-style object to manufacture GetDashboardUrlInput.