pub struct GetDataQualityModelResultFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to GetDataQualityModelResult.
Retrieve a statistic's predictions for a given Profile ID.
Implementations
Sourceimpl GetDataQualityModelResultFluentBuilder
impl GetDataQualityModelResultFluentBuilder
Sourcepub fn as_input(&self) -> &GetDataQualityModelResultInputBuilder
pub fn as_input(&self) -> &GetDataQualityModelResultInputBuilder
Access the GetDataQualityModelResult as a reference.
Sourcepub async fn send(
self,
) -> Result<GetDataQualityModelResultOutput, SdkError<GetDataQualityModelResultError, HttpResponse>>
pub async fn send( self, ) -> Result<GetDataQualityModelResultOutput, SdkError<GetDataQualityModelResultError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<GetDataQualityModelResultOutput, GetDataQualityModelResultError, Self>
pub fn customize( self, ) -> CustomizableOperation<GetDataQualityModelResultOutput, GetDataQualityModelResultError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn statistic_id(self, input: impl Into<String>) -> Self
pub fn statistic_id(self, input: impl Into<String>) -> Self
The Statistic ID.
Sourcepub fn set_statistic_id(self, input: Option<String>) -> Self
pub fn set_statistic_id(self, input: Option<String>) -> Self
The Statistic ID.
Sourcepub fn get_statistic_id(&self) -> &Option<String>
pub fn get_statistic_id(&self) -> &Option<String>
The Statistic ID.
Sourcepub fn profile_id(self, input: impl Into<String>) -> Self
pub fn profile_id(self, input: impl Into<String>) -> Self
The Profile ID.
Sourcepub fn set_profile_id(self, input: Option<String>) -> Self
pub fn set_profile_id(self, input: Option<String>) -> Self
The Profile ID.
Sourcepub fn get_profile_id(&self) -> &Option<String>
pub fn get_profile_id(&self) -> &Option<String>
The Profile ID.