pub struct GetDataQualityRuleRecommendationRunFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to GetDataQualityRuleRecommendationRun.
Gets the specified recommendation run that was used to generate rules.
Implementations
Sourceimpl GetDataQualityRuleRecommendationRunFluentBuilder
impl GetDataQualityRuleRecommendationRunFluentBuilder
Sourcepub fn as_input(&self) -> &GetDataQualityRuleRecommendationRunInputBuilder
pub fn as_input(&self) -> &GetDataQualityRuleRecommendationRunInputBuilder
Access the GetDataQualityRuleRecommendationRun as a reference.
Sourcepub async fn send(
self,
) -> Result<GetDataQualityRuleRecommendationRunOutput, SdkError<GetDataQualityRuleRecommendationRunError, HttpResponse>>
pub async fn send( self, ) -> Result<GetDataQualityRuleRecommendationRunOutput, SdkError<GetDataQualityRuleRecommendationRunError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<GetDataQualityRuleRecommendationRunOutput, GetDataQualityRuleRecommendationRunError, Self>
pub fn customize( self, ) -> CustomizableOperation<GetDataQualityRuleRecommendationRunOutput, GetDataQualityRuleRecommendationRunError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn run_id(self, input: impl Into<String>) -> Self
pub fn run_id(self, input: impl Into<String>) -> Self
The unique run identifier associated with this run.
Sourcepub fn set_run_id(self, input: Option<String>) -> Self
pub fn set_run_id(self, input: Option<String>) -> Self
The unique run identifier associated with this run.
Sourcepub fn get_run_id(&self) -> &Option<String>
pub fn get_run_id(&self) -> &Option<String>
The unique run identifier associated with this run.