pub struct GetDataQualityRulesetEvaluationRunFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to GetDataQualityRulesetEvaluationRun.
Retrieves a specific run where a ruleset is evaluated against a data source.
Implementations
Sourceimpl GetDataQualityRulesetEvaluationRunFluentBuilder
impl GetDataQualityRulesetEvaluationRunFluentBuilder
Sourcepub fn as_input(&self) -> &GetDataQualityRulesetEvaluationRunInputBuilder
pub fn as_input(&self) -> &GetDataQualityRulesetEvaluationRunInputBuilder
Access the GetDataQualityRulesetEvaluationRun as a reference.
Sourcepub async fn send(
self,
) -> Result<GetDataQualityRulesetEvaluationRunOutput, SdkError<GetDataQualityRulesetEvaluationRunError, HttpResponse>>
pub async fn send( self, ) -> Result<GetDataQualityRulesetEvaluationRunOutput, SdkError<GetDataQualityRulesetEvaluationRunError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<GetDataQualityRulesetEvaluationRunOutput, GetDataQualityRulesetEvaluationRunError, Self>
pub fn customize( self, ) -> CustomizableOperation<GetDataQualityRulesetEvaluationRunOutput, GetDataQualityRulesetEvaluationRunError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn run_id(self, input: impl Into<String>) -> Self
pub fn run_id(self, input: impl Into<String>) -> Self
The unique run identifier associated with this run.
Sourcepub fn set_run_id(self, input: Option<String>) -> Self
pub fn set_run_id(self, input: Option<String>) -> Self
The unique run identifier associated with this run.
Sourcepub fn get_run_id(&self) -> &Option<String>
pub fn get_run_id(&self) -> &Option<String>
The unique run identifier associated with this run.