#[non_exhaustive]pub struct GetDataQualityRulesetEvaluationRunOutput {Show 15 fields
pub run_id: Option<String>,
pub data_source: Option<DataSource>,
pub role: Option<String>,
pub number_of_workers: Option<i32>,
pub timeout: Option<i32>,
pub additional_run_options: Option<DataQualityEvaluationRunAdditionalRunOptions>,
pub status: Option<TaskStatusType>,
pub error_string: Option<String>,
pub started_on: Option<DateTime>,
pub last_modified_on: Option<DateTime>,
pub completed_on: Option<DateTime>,
pub execution_time: i32,
pub ruleset_names: Option<Vec<String>>,
pub result_ids: Option<Vec<String>>,
pub additional_data_sources: Option<HashMap<String, DataSource>>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.run_id: Option<String>The unique run identifier associated with this run.
data_source: Option<DataSource>The data source (an Glue table) associated with this evaluation run.
role: Option<String>An IAM role supplied to encrypt the results of the run.
number_of_workers: Option<i32>The number of G.1X workers to be used in the run. The default is 5.
timeout: Option<i32>The timeout for a run in minutes. This is the maximum time that a run can consume resources before it is terminated and enters TIMEOUT status. The default is 2,880 minutes (48 hours).
additional_run_options: Option<DataQualityEvaluationRunAdditionalRunOptions>Additional run options you can specify for an evaluation run.
status: Option<TaskStatusType>The status for this run.
error_string: Option<String>The error strings that are associated with the run.
started_on: Option<DateTime>The date and time when this run started.
last_modified_on: Option<DateTime>A timestamp. The last point in time when this data quality rule recommendation run was modified.
completed_on: Option<DateTime>The date and time when this run was completed.
execution_time: i32The amount of time (in seconds) that the run consumed resources.
ruleset_names: Option<Vec<String>>A list of ruleset names for the run. Currently, this parameter takes only one Ruleset name.
result_ids: Option<Vec<String>>A list of result IDs for the data quality results for the run.
additional_data_sources: Option<HashMap<String, DataSource>>A map of reference strings to additional data sources you can specify for an evaluation run.
Implementations
Sourceimpl GetDataQualityRulesetEvaluationRunOutput
impl GetDataQualityRulesetEvaluationRunOutput
Sourcepub fn data_source(&self) -> Option<&DataSource>
pub fn data_source(&self) -> Option<&DataSource>
The data source (an Glue table) associated with this evaluation run.
Sourcepub fn number_of_workers(&self) -> Option<i32>
pub fn number_of_workers(&self) -> Option<i32>
The number of G.1X workers to be used in the run. The default is 5.
Sourcepub fn timeout(&self) -> Option<i32>
pub fn timeout(&self) -> Option<i32>
The timeout for a run in minutes. This is the maximum time that a run can consume resources before it is terminated and enters TIMEOUT status. The default is 2,880 minutes (48 hours).
Sourcepub fn additional_run_options(
&self,
) -> Option<&DataQualityEvaluationRunAdditionalRunOptions>
pub fn additional_run_options( &self, ) -> Option<&DataQualityEvaluationRunAdditionalRunOptions>
Additional run options you can specify for an evaluation run.
Sourcepub fn status(&self) -> Option<&TaskStatusType>
pub fn status(&self) -> Option<&TaskStatusType>
The status for this run.
Sourcepub fn error_string(&self) -> Option<&str>
pub fn error_string(&self) -> Option<&str>
The error strings that are associated with the run.
Sourcepub fn started_on(&self) -> Option<&DateTime>
pub fn started_on(&self) -> Option<&DateTime>
The date and time when this run started.
Sourcepub fn last_modified_on(&self) -> Option<&DateTime>
pub fn last_modified_on(&self) -> Option<&DateTime>
A timestamp. The last point in time when this data quality rule recommendation run was modified.
Sourcepub fn completed_on(&self) -> Option<&DateTime>
pub fn completed_on(&self) -> Option<&DateTime>
The date and time when this run was completed.
Sourcepub fn execution_time(&self) -> i32
pub fn execution_time(&self) -> i32
The amount of time (in seconds) that the run consumed resources.
Sourcepub fn ruleset_names(&self) -> &[String]
pub fn ruleset_names(&self) -> &[String]
A list of ruleset names for the run. Currently, this parameter takes only one Ruleset name.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .ruleset_names.is_none().
Sourcepub fn result_ids(&self) -> &[String]
pub fn result_ids(&self) -> &[String]
A list of result IDs for the data quality results for the run.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .result_ids.is_none().
Sourcepub fn additional_data_sources(&self) -> Option<&HashMap<String, DataSource>>
pub fn additional_data_sources(&self) -> Option<&HashMap<String, DataSource>>
A map of reference strings to additional data sources you can specify for an evaluation run.
Sourceimpl GetDataQualityRulesetEvaluationRunOutput
impl GetDataQualityRulesetEvaluationRunOutput
Sourcepub fn builder() -> GetDataQualityRulesetEvaluationRunOutputBuilder
pub fn builder() -> GetDataQualityRulesetEvaluationRunOutputBuilder
Creates a new builder-style object to manufacture GetDataQualityRulesetEvaluationRunOutput.