#[non_exhaustive]pub struct GetEntityRecordsInput {
pub connection_name: Option<String>,
pub catalog_id: Option<String>,
pub entity_name: Option<String>,
pub next_token: Option<String>,
pub data_store_api_version: Option<String>,
pub connection_options: Option<HashMap<String, String>>,
pub filter_predicate: Option<String>,
pub limit: Option<i64>,
pub order_by: Option<String>,
pub selected_fields: Option<Vec<String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.connection_name: Option<String>The name of the connection that contains the connection type credentials.
catalog_id: Option<String>The catalog ID of the catalog that contains the connection. This can be null, By default, the Amazon Web Services Account ID is the catalog ID.
entity_name: Option<String>Name of the entity that we want to query the preview data from the given connection type.
next_token: Option<String>A continuation token, included if this is a continuation call.
data_store_api_version: Option<String>The API version of the SaaS connector.
connection_options: Option<HashMap<String, String>>Connector options that are required to query the data.
filter_predicate: Option<String>A filter predicate that you can apply in the query request.
limit: Option<i64>Limits the number of records fetched with the request.
order_by: Option<String>A parameter that orders the response preview data.
selected_fields: Option<Vec<String>>List of fields that we want to fetch as part of preview data.
Implementations
Sourceimpl GetEntityRecordsInput
impl GetEntityRecordsInput
Sourcepub fn connection_name(&self) -> Option<&str>
pub fn connection_name(&self) -> Option<&str>
The name of the connection that contains the connection type credentials.
Sourcepub fn catalog_id(&self) -> Option<&str>
pub fn catalog_id(&self) -> Option<&str>
The catalog ID of the catalog that contains the connection. This can be null, By default, the Amazon Web Services Account ID is the catalog ID.
Sourcepub fn entity_name(&self) -> Option<&str>
pub fn entity_name(&self) -> Option<&str>
Name of the entity that we want to query the preview data from the given connection type.
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A continuation token, included if this is a continuation call.
Sourcepub fn data_store_api_version(&self) -> Option<&str>
pub fn data_store_api_version(&self) -> Option<&str>
The API version of the SaaS connector.
Sourcepub fn connection_options(&self) -> Option<&HashMap<String, String>>
pub fn connection_options(&self) -> Option<&HashMap<String, String>>
Connector options that are required to query the data.
Sourcepub fn filter_predicate(&self) -> Option<&str>
pub fn filter_predicate(&self) -> Option<&str>
A filter predicate that you can apply in the query request.
Sourcepub fn selected_fields(&self) -> &[String]
pub fn selected_fields(&self) -> &[String]
List of fields that we want to fetch as part of preview data.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .selected_fields.is_none().
Sourceimpl GetEntityRecordsInput
impl GetEntityRecordsInput
Sourcepub fn builder() -> GetEntityRecordsInputBuilder
pub fn builder() -> GetEntityRecordsInputBuilder
Creates a new builder-style object to manufacture GetEntityRecordsInput.