#[non_exhaustive]pub struct GetEntityRecordsOutput {
pub records: Option<Vec<Document>>,
pub next_token: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.records: Option<Vec<Document>>A list of the requested objects.
next_token: Option<String>A continuation token, present if the current segment is not the last.
Implementations
Sourceimpl GetEntityRecordsOutput
impl GetEntityRecordsOutput
Sourcepub fn records(&self) -> &[Document]
pub fn records(&self) -> &[Document]
A list of the requested objects.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .records.is_none().
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A continuation token, present if the current segment is not the last.
Sourceimpl GetEntityRecordsOutput
impl GetEntityRecordsOutput
Sourcepub fn builder() -> GetEntityRecordsOutputBuilder
pub fn builder() -> GetEntityRecordsOutputBuilder
Creates a new builder-style object to manufacture GetEntityRecordsOutput.