pub struct GetGlossaryTermFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to GetGlossaryTerm.
Retrieves a glossary term in Glue Data Catalog by its identifier.
Implementations
Sourceimpl GetGlossaryTermFluentBuilder
impl GetGlossaryTermFluentBuilder
Sourcepub fn as_input(&self) -> &GetGlossaryTermInputBuilder
pub fn as_input(&self) -> &GetGlossaryTermInputBuilder
Access the GetGlossaryTerm as a reference.
Sourcepub async fn send(
self,
) -> Result<GetGlossaryTermOutput, SdkError<GetGlossaryTermError, HttpResponse>>
pub async fn send( self, ) -> Result<GetGlossaryTermOutput, SdkError<GetGlossaryTermError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<GetGlossaryTermOutput, GetGlossaryTermError, Self>
pub fn customize( self, ) -> CustomizableOperation<GetGlossaryTermOutput, GetGlossaryTermError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn identifier(self, input: impl Into<String>) -> Self
pub fn identifier(self, input: impl Into<String>) -> Self
The unique identifier of the glossary term to retrieve.
Sourcepub fn set_identifier(self, input: Option<String>) -> Self
pub fn set_identifier(self, input: Option<String>) -> Self
The unique identifier of the glossary term to retrieve.
Sourcepub fn get_identifier(&self) -> &Option<String>
pub fn get_identifier(&self) -> &Option<String>
The unique identifier of the glossary term to retrieve.