#[non_exhaustive]pub struct GetGlossaryTermInputBuilder { /* private fields */ }Expand description
A builder for GetGlossaryTermInput.
Implementations
Sourceimpl GetGlossaryTermInputBuilder
impl GetGlossaryTermInputBuilder
Sourcepub fn identifier(self, input: impl Into<String>) -> Self
pub fn identifier(self, input: impl Into<String>) -> Self
The unique identifier of the glossary term to retrieve.
This field is required.Sourcepub fn set_identifier(self, input: Option<String>) -> Self
pub fn set_identifier(self, input: Option<String>) -> Self
The unique identifier of the glossary term to retrieve.
Sourcepub fn get_identifier(&self) -> &Option<String>
pub fn get_identifier(&self) -> &Option<String>
The unique identifier of the glossary term to retrieve.
Sourcepub fn build(self) -> Result<GetGlossaryTermInput, BuildError>
pub fn build(self) -> Result<GetGlossaryTermInput, BuildError>
Consumes the builder and constructs a GetGlossaryTermInput.
Sourceimpl GetGlossaryTermInputBuilder
impl GetGlossaryTermInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<GetGlossaryTermOutput, SdkError<GetGlossaryTermError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<GetGlossaryTermOutput, SdkError<GetGlossaryTermError, HttpResponse>>
Sends a request with this input using the given client.