#[non_exhaustive]pub struct GetGlossaryTermOutputBuilder { /* private fields */ }Expand description
A builder for GetGlossaryTermOutput.
Implementations
Sourceimpl GetGlossaryTermOutputBuilder
impl GetGlossaryTermOutputBuilder
Sourcepub fn glossary_id(self, input: impl Into<String>) -> Self
pub fn glossary_id(self, input: impl Into<String>) -> Self
The unique identifier of the glossary containing this term.
Sourcepub fn set_glossary_id(self, input: Option<String>) -> Self
pub fn set_glossary_id(self, input: Option<String>) -> Self
The unique identifier of the glossary containing this term.
Sourcepub fn get_glossary_id(&self) -> &Option<String>
pub fn get_glossary_id(&self) -> &Option<String>
The unique identifier of the glossary containing this term.
Sourcepub fn short_description(self, input: impl Into<String>) -> Self
pub fn short_description(self, input: impl Into<String>) -> Self
The short description of the glossary term.
Sourcepub fn set_short_description(self, input: Option<String>) -> Self
pub fn set_short_description(self, input: Option<String>) -> Self
The short description of the glossary term.
Sourcepub fn get_short_description(&self) -> &Option<String>
pub fn get_short_description(&self) -> &Option<String>
The short description of the glossary term.
Sourcepub fn long_description(self, input: impl Into<String>) -> Self
pub fn long_description(self, input: impl Into<String>) -> Self
The long description of the glossary term.
Sourcepub fn set_long_description(self, input: Option<String>) -> Self
pub fn set_long_description(self, input: Option<String>) -> Self
The long description of the glossary term.
Sourcepub fn get_long_description(&self) -> &Option<String>
pub fn get_long_description(&self) -> &Option<String>
The long description of the glossary term.
Sourcepub fn build(self) -> GetGlossaryTermOutput
pub fn build(self) -> GetGlossaryTermOutput
Consumes the builder and constructs a GetGlossaryTermOutput.