pub struct GetGlueIdentityCenterConfigurationFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to GetGlueIdentityCenterConfiguration.
Retrieves the current Glue Identity Center configuration details, including the associated Identity Center instance and application information.
Implementations
Sourceimpl GetGlueIdentityCenterConfigurationFluentBuilder
impl GetGlueIdentityCenterConfigurationFluentBuilder
Sourcepub fn as_input(&self) -> &GetGlueIdentityCenterConfigurationInputBuilder
pub fn as_input(&self) -> &GetGlueIdentityCenterConfigurationInputBuilder
Access the GetGlueIdentityCenterConfiguration as a reference.
Sourcepub async fn send(
self,
) -> Result<GetGlueIdentityCenterConfigurationOutput, SdkError<GetGlueIdentityCenterConfigurationError, HttpResponse>>
pub async fn send( self, ) -> Result<GetGlueIdentityCenterConfigurationOutput, SdkError<GetGlueIdentityCenterConfigurationError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<GetGlueIdentityCenterConfigurationOutput, GetGlueIdentityCenterConfigurationError, Self>
pub fn customize( self, ) -> CustomizableOperation<GetGlueIdentityCenterConfigurationOutput, GetGlueIdentityCenterConfigurationError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.