#[non_exhaustive]pub struct GetGlueIdentityCenterConfigurationOutput {
pub application_arn: Option<String>,
pub instance_arn: Option<String>,
pub scopes: Option<Vec<String>>,
pub user_background_sessions_enabled: Option<bool>,
/* private fields */
}Expand description
Response containing the Glue Identity Center configuration details.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.application_arn: Option<String>The Amazon Resource Name (ARN) of the Identity Center application associated with the Glue configuration.
instance_arn: Option<String>The Amazon Resource Name (ARN) of the Identity Center instance associated with the Glue configuration.
scopes: Option<Vec<String>>A list of Identity Center scopes that define the permissions and access levels for the Glue configuration.
user_background_sessions_enabled: Option<bool>Indicates whether users can run background sessions when using Identity Center authentication with Glue services.
Implementations
Sourceimpl GetGlueIdentityCenterConfigurationOutput
impl GetGlueIdentityCenterConfigurationOutput
Sourcepub fn application_arn(&self) -> Option<&str>
pub fn application_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the Identity Center application associated with the Glue configuration.
Sourcepub fn instance_arn(&self) -> Option<&str>
pub fn instance_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the Identity Center instance associated with the Glue configuration.
Sourcepub fn scopes(&self) -> &[String]
pub fn scopes(&self) -> &[String]
A list of Identity Center scopes that define the permissions and access levels for the Glue configuration.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .scopes.is_none().
Sourcepub fn user_background_sessions_enabled(&self) -> Option<bool>
pub fn user_background_sessions_enabled(&self) -> Option<bool>
Indicates whether users can run background sessions when using Identity Center authentication with Glue services.
Sourceimpl GetGlueIdentityCenterConfigurationOutput
impl GetGlueIdentityCenterConfigurationOutput
Sourcepub fn builder() -> GetGlueIdentityCenterConfigurationOutputBuilder
pub fn builder() -> GetGlueIdentityCenterConfigurationOutputBuilder
Creates a new builder-style object to manufacture GetGlueIdentityCenterConfigurationOutput.