pub struct GetIntegrationResourcePropertyFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to GetIntegrationResourceProperty.
This API is used for fetching the ResourceProperty of the Glue connection (for the source) or Glue database ARN (for the target)
Implementations
Sourceimpl GetIntegrationResourcePropertyFluentBuilder
impl GetIntegrationResourcePropertyFluentBuilder
Sourcepub fn as_input(&self) -> &GetIntegrationResourcePropertyInputBuilder
pub fn as_input(&self) -> &GetIntegrationResourcePropertyInputBuilder
Access the GetIntegrationResourceProperty as a reference.
Sourcepub async fn send(
self,
) -> Result<GetIntegrationResourcePropertyOutput, SdkError<GetIntegrationResourcePropertyError, HttpResponse>>
pub async fn send( self, ) -> Result<GetIntegrationResourcePropertyOutput, SdkError<GetIntegrationResourcePropertyError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<GetIntegrationResourcePropertyOutput, GetIntegrationResourcePropertyError, Self>
pub fn customize( self, ) -> CustomizableOperation<GetIntegrationResourcePropertyOutput, GetIntegrationResourcePropertyError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn resource_arn(self, input: impl Into<String>) -> Self
pub fn resource_arn(self, input: impl Into<String>) -> Self
The connection ARN of the source, or the database ARN of the target.
Sourcepub fn set_resource_arn(self, input: Option<String>) -> Self
pub fn set_resource_arn(self, input: Option<String>) -> Self
The connection ARN of the source, or the database ARN of the target.
Sourcepub fn get_resource_arn(&self) -> &Option<String>
pub fn get_resource_arn(&self) -> &Option<String>
The connection ARN of the source, or the database ARN of the target.