GetIntegrationTablePropertiesFluentBuilder

Struct GetIntegrationTablePropertiesFluentBuilder 

pub struct GetIntegrationTablePropertiesFluentBuilder { /* private fields */ }
Fluent builder constructing a request to GetIntegrationTableProperties.

This API is used to retrieve optional override properties for the tables that need to be replicated. These properties can include properties for filtering and partition for source and target tables.

Implementations

Source

impl GetIntegrationTablePropertiesFluentBuilder

pub fn as_input(&self) -> &GetIntegrationTablePropertiesInputBuilder

Access the GetIntegrationTableProperties as a reference.

pub async fn send( self, ) -> Result<GetIntegrationTablePropertiesOutput, SdkError<GetIntegrationTablePropertiesError, HttpResponse>>

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

pub fn customize( self, ) -> CustomizableOperation<GetIntegrationTablePropertiesOutput, GetIntegrationTablePropertiesError, Self>

Consumes this builder, creating a customizable operation that can be modified before being sent.

pub fn resource_arn(self, input: impl Into<String>) -> Self

The Amazon Resource Name (ARN) of the target table for which to retrieve integration table properties. Currently, this API only supports retrieving properties for target tables, and the provided ARN should be the ARN of the target table in the Glue Data Catalog. Support for retrieving integration table properties for source connections (using the connection ARN) is not yet implemented and will be added in a future release.

pub fn set_resource_arn(self, input: Option<String>) -> Self

The Amazon Resource Name (ARN) of the target table for which to retrieve integration table properties. Currently, this API only supports retrieving properties for target tables, and the provided ARN should be the ARN of the target table in the Glue Data Catalog. Support for retrieving integration table properties for source connections (using the connection ARN) is not yet implemented and will be added in a future release.

pub fn get_resource_arn(&self) -> &Option<String>

The Amazon Resource Name (ARN) of the target table for which to retrieve integration table properties. Currently, this API only supports retrieving properties for target tables, and the provided ARN should be the ARN of the target table in the Glue Data Catalog. Support for retrieving integration table properties for source connections (using the connection ARN) is not yet implemented and will be added in a future release.

pub fn table_name(self, input: impl Into<String>) -> Self

The name of the table to be replicated.

pub fn set_table_name(self, input: Option<String>) -> Self

The name of the table to be replicated.

pub fn get_table_name(&self) -> &Option<String>

The name of the table to be replicated.