#[non_exhaustive]pub struct GetIntegrationTablePropertiesOutputBuilder { /* private fields */ }Expand description
A builder for GetIntegrationTablePropertiesOutput.
Implementations
Sourceimpl GetIntegrationTablePropertiesOutputBuilder
impl GetIntegrationTablePropertiesOutputBuilder
Sourcepub fn resource_arn(self, input: impl Into<String>) -> Self
pub fn resource_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the target table for which to retrieve integration table properties. Currently, this API only supports retrieving properties for target tables, and the provided ARN should be the ARN of the target table in the Glue Data Catalog. Support for retrieving integration table properties for source connections (using the connection ARN) is not yet implemented and will be added in a future release.
Sourcepub fn set_resource_arn(self, input: Option<String>) -> Self
pub fn set_resource_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the target table for which to retrieve integration table properties. Currently, this API only supports retrieving properties for target tables, and the provided ARN should be the ARN of the target table in the Glue Data Catalog. Support for retrieving integration table properties for source connections (using the connection ARN) is not yet implemented and will be added in a future release.
Sourcepub fn get_resource_arn(&self) -> &Option<String>
pub fn get_resource_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the target table for which to retrieve integration table properties. Currently, this API only supports retrieving properties for target tables, and the provided ARN should be the ARN of the target table in the Glue Data Catalog. Support for retrieving integration table properties for source connections (using the connection ARN) is not yet implemented and will be added in a future release.
Sourcepub fn table_name(self, input: impl Into<String>) -> Self
pub fn table_name(self, input: impl Into<String>) -> Self
The name of the table to be replicated.
Sourcepub fn set_table_name(self, input: Option<String>) -> Self
pub fn set_table_name(self, input: Option<String>) -> Self
The name of the table to be replicated.
Sourcepub fn get_table_name(&self) -> &Option<String>
pub fn get_table_name(&self) -> &Option<String>
The name of the table to be replicated.
Sourcepub fn source_table_config(self, input: SourceTableConfig) -> Self
pub fn source_table_config(self, input: SourceTableConfig) -> Self
A structure for the source table configuration.
Sourcepub fn set_source_table_config(self, input: Option<SourceTableConfig>) -> Self
pub fn set_source_table_config(self, input: Option<SourceTableConfig>) -> Self
A structure for the source table configuration.
Sourcepub fn get_source_table_config(&self) -> &Option<SourceTableConfig>
pub fn get_source_table_config(&self) -> &Option<SourceTableConfig>
A structure for the source table configuration.
Sourcepub fn target_table_config(self, input: TargetTableConfig) -> Self
pub fn target_table_config(self, input: TargetTableConfig) -> Self
A structure for the target table configuration.
Sourcepub fn set_target_table_config(self, input: Option<TargetTableConfig>) -> Self
pub fn set_target_table_config(self, input: Option<TargetTableConfig>) -> Self
A structure for the target table configuration.
Sourcepub fn get_target_table_config(&self) -> &Option<TargetTableConfig>
pub fn get_target_table_config(&self) -> &Option<TargetTableConfig>
A structure for the target table configuration.
Sourcepub fn build(self) -> GetIntegrationTablePropertiesOutput
pub fn build(self) -> GetIntegrationTablePropertiesOutput
Consumes the builder and constructs a GetIntegrationTablePropertiesOutput.