#[non_exhaustive]pub struct GetJobBookmarkInputBuilder { /* private fields */ }Expand description
A builder for GetJobBookmarkInput.
Implementations
Sourceimpl GetJobBookmarkInputBuilder
impl GetJobBookmarkInputBuilder
Sourcepub fn job_name(self, input: impl Into<String>) -> Self
pub fn job_name(self, input: impl Into<String>) -> Self
The name of the job in question.
This field is required.Sourcepub fn set_job_name(self, input: Option<String>) -> Self
pub fn set_job_name(self, input: Option<String>) -> Self
The name of the job in question.
Sourcepub fn get_job_name(&self) -> &Option<String>
pub fn get_job_name(&self) -> &Option<String>
The name of the job in question.
Sourcepub fn run_id(self, input: impl Into<String>) -> Self
pub fn run_id(self, input: impl Into<String>) -> Self
The unique run identifier associated with this job run.
Sourcepub fn set_run_id(self, input: Option<String>) -> Self
pub fn set_run_id(self, input: Option<String>) -> Self
The unique run identifier associated with this job run.
Sourcepub fn get_run_id(&self) -> &Option<String>
pub fn get_run_id(&self) -> &Option<String>
The unique run identifier associated with this job run.
Sourcepub fn build(self) -> Result<GetJobBookmarkInput, BuildError>
pub fn build(self) -> Result<GetJobBookmarkInput, BuildError>
Consumes the builder and constructs a GetJobBookmarkInput.
Sourceimpl GetJobBookmarkInputBuilder
impl GetJobBookmarkInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<GetJobBookmarkOutput, SdkError<GetJobBookmarkError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<GetJobBookmarkOutput, SdkError<GetJobBookmarkError, HttpResponse>>
Sends a request with this input using the given client.