#[non_exhaustive]pub struct GetJobBookmarkOutputBuilder { /* private fields */ }Expand description
A builder for GetJobBookmarkOutput.
Implementations
Sourceimpl GetJobBookmarkOutputBuilder
impl GetJobBookmarkOutputBuilder
Sourcepub fn job_bookmark_entry(self, input: JobBookmarkEntry) -> Self
pub fn job_bookmark_entry(self, input: JobBookmarkEntry) -> Self
A structure that defines a point that a job can resume processing.
Sourcepub fn set_job_bookmark_entry(self, input: Option<JobBookmarkEntry>) -> Self
pub fn set_job_bookmark_entry(self, input: Option<JobBookmarkEntry>) -> Self
A structure that defines a point that a job can resume processing.
Sourcepub fn get_job_bookmark_entry(&self) -> &Option<JobBookmarkEntry>
pub fn get_job_bookmark_entry(&self) -> &Option<JobBookmarkEntry>
A structure that defines a point that a job can resume processing.
Sourcepub fn build(self) -> GetJobBookmarkOutput
pub fn build(self) -> GetJobBookmarkOutput
Consumes the builder and constructs a GetJobBookmarkOutput.