#[non_exhaustive]pub struct GetJobBookmarkOutput {
pub job_bookmark_entry: Option<JobBookmarkEntry>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.job_bookmark_entry: Option<JobBookmarkEntry>A structure that defines a point that a job can resume processing.
Implementations
Sourceimpl GetJobBookmarkOutput
impl GetJobBookmarkOutput
Sourcepub fn job_bookmark_entry(&self) -> Option<&JobBookmarkEntry>
pub fn job_bookmark_entry(&self) -> Option<&JobBookmarkEntry>
A structure that defines a point that a job can resume processing.
Sourceimpl GetJobBookmarkOutput
impl GetJobBookmarkOutput
Sourcepub fn builder() -> GetJobBookmarkOutputBuilder
pub fn builder() -> GetJobBookmarkOutputBuilder
Creates a new builder-style object to manufacture GetJobBookmarkOutput.