GetJobRunsFluentBuilder

Struct GetJobRunsFluentBuilder 

pub struct GetJobRunsFluentBuilder { /* private fields */ }
Fluent builder constructing a request to GetJobRuns.

Retrieves metadata for all runs of a given job definition.

GetJobRuns returns the job runs in chronological order, with the newest jobs returned first.

Implementations

Source

impl GetJobRunsFluentBuilder

pub fn as_input(&self) -> &GetJobRunsInputBuilder

Access the GetJobRuns as a reference.

pub async fn send( self, ) -> Result<GetJobRunsOutput, SdkError<GetJobRunsError, HttpResponse>>

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

pub fn customize( self, ) -> CustomizableOperation<GetJobRunsOutput, GetJobRunsError, Self>

Consumes this builder, creating a customizable operation that can be modified before being sent.

pub fn into_paginator(self) -> GetJobRunsPaginator

Create a paginator for this request

Paginators are used by calling send().await which returns a PaginationStream.

pub fn job_name(self, input: impl Into<String>) -> Self

The name of the job definition for which to retrieve all job runs.

pub fn set_job_name(self, input: Option<String>) -> Self

The name of the job definition for which to retrieve all job runs.

pub fn get_job_name(&self) -> &Option<String>

The name of the job definition for which to retrieve all job runs.

pub fn next_token(self, input: impl Into<String>) -> Self

A continuation token, if this is a continuation call.

pub fn set_next_token(self, input: Option<String>) -> Self

A continuation token, if this is a continuation call.

pub fn get_next_token(&self) -> &Option<String>

A continuation token, if this is a continuation call.

pub fn max_results(self, input: i32) -> Self

The maximum size of the response.

pub fn set_max_results(self, input: Option<i32>) -> Self

The maximum size of the response.

pub fn get_max_results(&self) -> &Option<i32>

The maximum size of the response.