#[non_exhaustive]pub struct GetJobRunsInputBuilder { /* private fields */ }Expand description
A builder for GetJobRunsInput.
Implementations
Sourceimpl GetJobRunsInputBuilder
impl GetJobRunsInputBuilder
Sourcepub fn job_name(self, input: impl Into<String>) -> Self
pub fn job_name(self, input: impl Into<String>) -> Self
The name of the job definition for which to retrieve all job runs.
This field is required.Sourcepub fn set_job_name(self, input: Option<String>) -> Self
pub fn set_job_name(self, input: Option<String>) -> Self
The name of the job definition for which to retrieve all job runs.
Sourcepub fn get_job_name(&self) -> &Option<String>
pub fn get_job_name(&self) -> &Option<String>
The name of the job definition for which to retrieve all job runs.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token, if this is a continuation call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token, if this is a continuation call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token, if this is a continuation call.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum size of the response.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum size of the response.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The maximum size of the response.
Sourcepub fn build(self) -> Result<GetJobRunsInput, BuildError>
pub fn build(self) -> Result<GetJobRunsInput, BuildError>
Consumes the builder and constructs a GetJobRunsInput.
Sourceimpl GetJobRunsInputBuilder
impl GetJobRunsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<GetJobRunsOutput, SdkError<GetJobRunsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<GetJobRunsOutput, SdkError<GetJobRunsError, HttpResponse>>
Sends a request with this input using the given client.