#[non_exhaustive]pub struct GetJobRunsInput {
pub job_name: Option<String>,
pub next_token: Option<String>,
pub max_results: Option<i32>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.job_name: Option<String>The name of the job definition for which to retrieve all job runs.
next_token: Option<String>A continuation token, if this is a continuation call.
max_results: Option<i32>The maximum size of the response.
Implementations
Sourceimpl GetJobRunsInput
impl GetJobRunsInput
Sourcepub fn builder() -> GetJobRunsInputBuilder
pub fn builder() -> GetJobRunsInputBuilder
Creates a new builder-style object to manufacture GetJobRunsInput.