pub struct GetJobsPaginator { /* private fields */ }Expand description
Paginator for GetJobs
Implementations
Sourceimpl GetJobsPaginator
impl GetJobsPaginator
Sourcepub fn page_size(self, limit: i32) -> Self
pub fn page_size(self, limit: i32) -> Self
Set the page size
Note: this method will override any previously set value for max_results
Sourcepub fn items(self) -> GetJobsPaginatorItems
pub fn items(self) -> GetJobsPaginatorItems
Create a flattened paginator
This paginator automatically flattens results using jobs. Queries to the underlying service
are dispatched lazily.
Sourcepub fn stop_on_duplicate_token(self, stop_on_duplicate_token: bool) -> Self
pub fn stop_on_duplicate_token(self, stop_on_duplicate_token: bool) -> Self
Stop paginating when the service returns the same pagination token twice in a row.
Defaults to true.
For certain operations, it may be useful to continue on duplicate token. For example,
if an operation is for tailing a log file in real-time, then continuing may be desired.
This option can be set to false to accommodate these use cases.
Sourcepub fn send(
self,
) -> PaginationStream<Result<GetJobsOutput, SdkError<GetJobsError, HttpResponse>>>
pub fn send( self, ) -> PaginationStream<Result<GetJobsOutput, SdkError<GetJobsError, HttpResponse>>>
Create the pagination stream
Note: No requests will be dispatched until the stream is used
(e.g. with the .next().await method).