#[non_exhaustive]pub struct GetJobsInput {
pub next_token: Option<String>,
pub max_results: Option<i32>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.next_token: Option<String>A continuation token, if this is a continuation call.
max_results: Option<i32>The maximum size of the response.
Implementations
Sourceimpl GetJobsInput
impl GetJobsInput
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A continuation token, if this is a continuation call.
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
The maximum size of the response.
Sourceimpl GetJobsInput
impl GetJobsInput
Sourcepub fn builder() -> GetJobsInputBuilder
pub fn builder() -> GetJobsInputBuilder
Creates a new builder-style object to manufacture GetJobsInput.