#[non_exhaustive]pub struct GetJobsOutput {
pub jobs: Option<Vec<Job>>,
pub next_token: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.jobs: Option<Vec<Job>>A list of job definitions.
next_token: Option<String>A continuation token, if not all job definitions have yet been returned.
Implementations
Sourceimpl GetJobsOutput
impl GetJobsOutput
Sourcepub fn jobs(&self) -> &[Job]
pub fn jobs(&self) -> &[Job]
A list of job definitions.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .jobs.is_none().
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A continuation token, if not all job definitions have yet been returned.
Sourceimpl GetJobsOutput
impl GetJobsOutput
Sourcepub fn builder() -> GetJobsOutputBuilder
pub fn builder() -> GetJobsOutputBuilder
Creates a new builder-style object to manufacture GetJobsOutput.