pub struct GetMaterializedViewRefreshTaskRunFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to GetMaterializedViewRefreshTaskRun.
Get the associated metadata/information for a task run, given a task run ID.
Implementations
Sourceimpl GetMaterializedViewRefreshTaskRunFluentBuilder
impl GetMaterializedViewRefreshTaskRunFluentBuilder
Sourcepub fn as_input(&self) -> &GetMaterializedViewRefreshTaskRunInputBuilder
pub fn as_input(&self) -> &GetMaterializedViewRefreshTaskRunInputBuilder
Access the GetMaterializedViewRefreshTaskRun as a reference.
Sourcepub async fn send(
self,
) -> Result<GetMaterializedViewRefreshTaskRunOutput, SdkError<GetMaterializedViewRefreshTaskRunError, HttpResponse>>
pub async fn send( self, ) -> Result<GetMaterializedViewRefreshTaskRunOutput, SdkError<GetMaterializedViewRefreshTaskRunError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<GetMaterializedViewRefreshTaskRunOutput, GetMaterializedViewRefreshTaskRunError, Self>
pub fn customize( self, ) -> CustomizableOperation<GetMaterializedViewRefreshTaskRunOutput, GetMaterializedViewRefreshTaskRunError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn catalog_id(self, input: impl Into<String>) -> Self
pub fn catalog_id(self, input: impl Into<String>) -> Self
The ID of the Data Catalog where the table resides. If none is supplied, the account ID is used by default.
Sourcepub fn set_catalog_id(self, input: Option<String>) -> Self
pub fn set_catalog_id(self, input: Option<String>) -> Self
The ID of the Data Catalog where the table resides. If none is supplied, the account ID is used by default.
Sourcepub fn get_catalog_id(&self) -> &Option<String>
pub fn get_catalog_id(&self) -> &Option<String>
The ID of the Data Catalog where the table resides. If none is supplied, the account ID is used by default.
Sourcepub fn materialized_view_refresh_task_run_id(
self,
input: impl Into<String>,
) -> Self
pub fn materialized_view_refresh_task_run_id( self, input: impl Into<String>, ) -> Self
The identifier for the particular materialized view refresh task run.
Sourcepub fn set_materialized_view_refresh_task_run_id(
self,
input: Option<String>,
) -> Self
pub fn set_materialized_view_refresh_task_run_id( self, input: Option<String>, ) -> Self
The identifier for the particular materialized view refresh task run.
Sourcepub fn get_materialized_view_refresh_task_run_id(&self) -> &Option<String>
pub fn get_materialized_view_refresh_task_run_id(&self) -> &Option<String>
The identifier for the particular materialized view refresh task run.