#[non_exhaustive]pub struct GetMaterializedViewRefreshTaskRunOutputBuilder { /* private fields */ }Expand description
A builder for GetMaterializedViewRefreshTaskRunOutput.
Implementations
Sourceimpl GetMaterializedViewRefreshTaskRunOutputBuilder
impl GetMaterializedViewRefreshTaskRunOutputBuilder
Sourcepub fn materialized_view_refresh_task_run(
self,
input: MaterializedViewRefreshTaskRun,
) -> Self
pub fn materialized_view_refresh_task_run( self, input: MaterializedViewRefreshTaskRun, ) -> Self
A MaterializedViewRefreshTaskRun object representing the details of the task run.
Sourcepub fn set_materialized_view_refresh_task_run(
self,
input: Option<MaterializedViewRefreshTaskRun>,
) -> Self
pub fn set_materialized_view_refresh_task_run( self, input: Option<MaterializedViewRefreshTaskRun>, ) -> Self
A MaterializedViewRefreshTaskRun object representing the details of the task run.
Sourcepub fn get_materialized_view_refresh_task_run(
&self,
) -> &Option<MaterializedViewRefreshTaskRun>
pub fn get_materialized_view_refresh_task_run( &self, ) -> &Option<MaterializedViewRefreshTaskRun>
A MaterializedViewRefreshTaskRun object representing the details of the task run.
Sourcepub fn build(self) -> GetMaterializedViewRefreshTaskRunOutput
pub fn build(self) -> GetMaterializedViewRefreshTaskRunOutput
Consumes the builder and constructs a GetMaterializedViewRefreshTaskRunOutput.