#[non_exhaustive]pub struct GetMaterializedViewRefreshTaskRunInput {
pub catalog_id: Option<String>,
pub materialized_view_refresh_task_run_id: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.catalog_id: Option<String>The ID of the Data Catalog where the table resides. If none is supplied, the account ID is used by default.
materialized_view_refresh_task_run_id: Option<String>The identifier for the particular materialized view refresh task run.
Implementations
Sourceimpl GetMaterializedViewRefreshTaskRunInput
impl GetMaterializedViewRefreshTaskRunInput
Sourcepub fn catalog_id(&self) -> Option<&str>
pub fn catalog_id(&self) -> Option<&str>
The ID of the Data Catalog where the table resides. If none is supplied, the account ID is used by default.
Sourcepub fn materialized_view_refresh_task_run_id(&self) -> Option<&str>
pub fn materialized_view_refresh_task_run_id(&self) -> Option<&str>
The identifier for the particular materialized view refresh task run.
Sourceimpl GetMaterializedViewRefreshTaskRunInput
impl GetMaterializedViewRefreshTaskRunInput
Sourcepub fn builder() -> GetMaterializedViewRefreshTaskRunInputBuilder
pub fn builder() -> GetMaterializedViewRefreshTaskRunInputBuilder
Creates a new builder-style object to manufacture GetMaterializedViewRefreshTaskRunInput.