#[non_exhaustive]pub struct GetMaterializedViewRefreshTaskRunOutput {
pub materialized_view_refresh_task_run: Option<MaterializedViewRefreshTaskRun>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.materialized_view_refresh_task_run: Option<MaterializedViewRefreshTaskRun>A MaterializedViewRefreshTaskRun object representing the details of the task run.
Implementations
Sourceimpl GetMaterializedViewRefreshTaskRunOutput
impl GetMaterializedViewRefreshTaskRunOutput
Sourcepub fn materialized_view_refresh_task_run(
&self,
) -> Option<&MaterializedViewRefreshTaskRun>
pub fn materialized_view_refresh_task_run( &self, ) -> Option<&MaterializedViewRefreshTaskRun>
A MaterializedViewRefreshTaskRun object representing the details of the task run.
Sourceimpl GetMaterializedViewRefreshTaskRunOutput
impl GetMaterializedViewRefreshTaskRunOutput
Sourcepub fn builder() -> GetMaterializedViewRefreshTaskRunOutputBuilder
pub fn builder() -> GetMaterializedViewRefreshTaskRunOutputBuilder
Creates a new builder-style object to manufacture GetMaterializedViewRefreshTaskRunOutput.