#[non_exhaustive]pub struct GetMlTaskRunsOutputBuilder { /* private fields */ }Expand description
A builder for GetMlTaskRunsOutput.
Implementations
Sourceimpl GetMlTaskRunsOutputBuilder
impl GetMlTaskRunsOutputBuilder
Sourcepub fn task_runs(self, input: TaskRun) -> Self
pub fn task_runs(self, input: TaskRun) -> Self
Appends an item to task_runs.
To override the contents of this collection use set_task_runs.
A list of task runs that are associated with the transform.
Sourcepub fn set_task_runs(self, input: Option<Vec<TaskRun>>) -> Self
pub fn set_task_runs(self, input: Option<Vec<TaskRun>>) -> Self
A list of task runs that are associated with the transform.
Sourcepub fn get_task_runs(&self) -> &Option<Vec<TaskRun>>
pub fn get_task_runs(&self) -> &Option<Vec<TaskRun>>
A list of task runs that are associated with the transform.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A pagination token, if more results are available.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A pagination token, if more results are available.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A pagination token, if more results are available.
Sourcepub fn build(self) -> GetMlTaskRunsOutput
pub fn build(self) -> GetMlTaskRunsOutput
Consumes the builder and constructs a GetMlTaskRunsOutput.