pub struct GetPartitionIndexesPaginatorItems(/* private fields */);Expand description
Flattened paginator for GetPartitionIndexesPaginator
This is created with .items()
Implementations
Sourceimpl GetPartitionIndexesPaginatorItems
impl GetPartitionIndexesPaginatorItems
Sourcepub fn send(
self,
) -> PaginationStream<Result<PartitionIndexDescriptor, SdkError<GetPartitionIndexesError, HttpResponse>>>
pub fn send( self, ) -> PaginationStream<Result<PartitionIndexDescriptor, SdkError<GetPartitionIndexesError, HttpResponse>>>
Create the pagination stream
Note: No requests will be dispatched until the stream is used
(e.g. with the .next().await method).
To read the entirety of the paginator, use .collect::<Result<Vec<_>, _>().