pub struct GetResourcePoliciesPaginatorItems(/* private fields */);Expand description
Flattened paginator for GetResourcePoliciesPaginator
This is created with .items()
Implementations
Sourceimpl GetResourcePoliciesPaginatorItems
impl GetResourcePoliciesPaginatorItems
Sourcepub fn send(
self,
) -> PaginationStream<Result<GluePolicy, SdkError<GetResourcePoliciesError, HttpResponse>>>
pub fn send( self, ) -> PaginationStream<Result<GluePolicy, SdkError<GetResourcePoliciesError, HttpResponse>>>
Create the pagination stream
Note: No requests will be dispatched until the stream is used
(e.g. with the .next().await method).
To read the entirety of the paginator, use .collect::<Result<Vec<_>, _>().