pub struct GetSchemaByDefinitionFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to GetSchemaByDefinition.
Retrieves a schema by the SchemaDefinition. The schema definition is sent to the Schema Registry, canonicalized, and hashed. If the hash is matched within the scope of the SchemaName or ARN (or the default registry, if none is supplied), that schema’s metadata is returned. Otherwise, a 404 or NotFound error is returned. Schema versions in Deleted statuses will not be included in the results.
Implementations
Sourceimpl GetSchemaByDefinitionFluentBuilder
impl GetSchemaByDefinitionFluentBuilder
Sourcepub fn as_input(&self) -> &GetSchemaByDefinitionInputBuilder
pub fn as_input(&self) -> &GetSchemaByDefinitionInputBuilder
Access the GetSchemaByDefinition as a reference.
Sourcepub async fn send(
self,
) -> Result<GetSchemaByDefinitionOutput, SdkError<GetSchemaByDefinitionError, HttpResponse>>
pub async fn send( self, ) -> Result<GetSchemaByDefinitionOutput, SdkError<GetSchemaByDefinitionError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<GetSchemaByDefinitionOutput, GetSchemaByDefinitionError, Self>
pub fn customize( self, ) -> CustomizableOperation<GetSchemaByDefinitionOutput, GetSchemaByDefinitionError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn schema_id(self, input: SchemaId) -> Self
pub fn schema_id(self, input: SchemaId) -> Self
This is a wrapper structure to contain schema identity fields. The structure contains:
-
SchemaId$SchemaArn: The Amazon Resource Name (ARN) of the schema. One of
SchemaArnorSchemaNamehas to be provided. -
SchemaId$SchemaName: The name of the schema. One of
SchemaArnorSchemaNamehas to be provided.
Sourcepub fn set_schema_id(self, input: Option<SchemaId>) -> Self
pub fn set_schema_id(self, input: Option<SchemaId>) -> Self
This is a wrapper structure to contain schema identity fields. The structure contains:
-
SchemaId$SchemaArn: The Amazon Resource Name (ARN) of the schema. One of
SchemaArnorSchemaNamehas to be provided. -
SchemaId$SchemaName: The name of the schema. One of
SchemaArnorSchemaNamehas to be provided.
Sourcepub fn get_schema_id(&self) -> &Option<SchemaId>
pub fn get_schema_id(&self) -> &Option<SchemaId>
This is a wrapper structure to contain schema identity fields. The structure contains:
-
SchemaId$SchemaArn: The Amazon Resource Name (ARN) of the schema. One of
SchemaArnorSchemaNamehas to be provided. -
SchemaId$SchemaName: The name of the schema. One of
SchemaArnorSchemaNamehas to be provided.
Sourcepub fn schema_definition(self, input: impl Into<String>) -> Self
pub fn schema_definition(self, input: impl Into<String>) -> Self
The definition of the schema for which schema details are required.
Sourcepub fn set_schema_definition(self, input: Option<String>) -> Self
pub fn set_schema_definition(self, input: Option<String>) -> Self
The definition of the schema for which schema details are required.
Sourcepub fn get_schema_definition(&self) -> &Option<String>
pub fn get_schema_definition(&self) -> &Option<String>
The definition of the schema for which schema details are required.