#[non_exhaustive]pub struct GetSchemaByDefinitionInputBuilder { /* private fields */ }Expand description
A builder for GetSchemaByDefinitionInput.
Implementations
Sourceimpl GetSchemaByDefinitionInputBuilder
impl GetSchemaByDefinitionInputBuilder
Sourcepub fn schema_id(self, input: SchemaId) -> Self
pub fn schema_id(self, input: SchemaId) -> Self
This is a wrapper structure to contain schema identity fields. The structure contains:
-
SchemaId$SchemaArn: The Amazon Resource Name (ARN) of the schema. One of
SchemaArnorSchemaNamehas to be provided. -
SchemaId$SchemaName: The name of the schema. One of
SchemaArnorSchemaNamehas to be provided.
Sourcepub fn set_schema_id(self, input: Option<SchemaId>) -> Self
pub fn set_schema_id(self, input: Option<SchemaId>) -> Self
This is a wrapper structure to contain schema identity fields. The structure contains:
-
SchemaId$SchemaArn: The Amazon Resource Name (ARN) of the schema. One of
SchemaArnorSchemaNamehas to be provided. -
SchemaId$SchemaName: The name of the schema. One of
SchemaArnorSchemaNamehas to be provided.
Sourcepub fn get_schema_id(&self) -> &Option<SchemaId>
pub fn get_schema_id(&self) -> &Option<SchemaId>
This is a wrapper structure to contain schema identity fields. The structure contains:
-
SchemaId$SchemaArn: The Amazon Resource Name (ARN) of the schema. One of
SchemaArnorSchemaNamehas to be provided. -
SchemaId$SchemaName: The name of the schema. One of
SchemaArnorSchemaNamehas to be provided.
Sourcepub fn schema_definition(self, input: impl Into<String>) -> Self
pub fn schema_definition(self, input: impl Into<String>) -> Self
The definition of the schema for which schema details are required.
This field is required.Sourcepub fn set_schema_definition(self, input: Option<String>) -> Self
pub fn set_schema_definition(self, input: Option<String>) -> Self
The definition of the schema for which schema details are required.
Sourcepub fn get_schema_definition(&self) -> &Option<String>
pub fn get_schema_definition(&self) -> &Option<String>
The definition of the schema for which schema details are required.
Sourcepub fn build(self) -> Result<GetSchemaByDefinitionInput, BuildError>
pub fn build(self) -> Result<GetSchemaByDefinitionInput, BuildError>
Consumes the builder and constructs a GetSchemaByDefinitionInput.
Sourceimpl GetSchemaByDefinitionInputBuilder
impl GetSchemaByDefinitionInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<GetSchemaByDefinitionOutput, SdkError<GetSchemaByDefinitionError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<GetSchemaByDefinitionOutput, SdkError<GetSchemaByDefinitionError, HttpResponse>>
Sends a request with this input using the given client.