pub struct GetSecurityConfigurationsPaginatorItems(/* private fields */);Expand description
Flattened paginator for GetSecurityConfigurationsPaginator
This is created with .items()
Implementations
Sourceimpl GetSecurityConfigurationsPaginatorItems
impl GetSecurityConfigurationsPaginatorItems
Sourcepub fn send(
self,
) -> PaginationStream<Result<SecurityConfiguration, SdkError<GetSecurityConfigurationsError, HttpResponse>>>
pub fn send( self, ) -> PaginationStream<Result<SecurityConfiguration, SdkError<GetSecurityConfigurationsError, HttpResponse>>>
Create the pagination stream
Note: No requests will be dispatched until the stream is used
(e.g. with the .next().await method).
To read the entirety of the paginator, use .collect::<Result<Vec<_>, _>().