GetTablesFluentBuilder

Struct GetTablesFluentBuilder 

pub struct GetTablesFluentBuilder { /* private fields */ }
Fluent builder constructing a request to GetTables.

Retrieves the definitions of some or all of the tables in a given Database.

Implementations

Source

impl GetTablesFluentBuilder

pub fn as_input(&self) -> &GetTablesInputBuilder

Access the GetTables as a reference.

pub async fn send( self, ) -> Result<GetTablesOutput, SdkError<GetTablesError, HttpResponse>>

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

pub fn customize( self, ) -> CustomizableOperation<GetTablesOutput, GetTablesError, Self>

Consumes this builder, creating a customizable operation that can be modified before being sent.

pub fn into_paginator(self) -> GetTablesPaginator

Create a paginator for this request

Paginators are used by calling send().await which returns a PaginationStream.

pub fn catalog_id(self, input: impl Into<String>) -> Self

The ID of the Data Catalog where the tables reside. If none is provided, the Amazon Web Services account ID is used by default.

pub fn set_catalog_id(self, input: Option<String>) -> Self

The ID of the Data Catalog where the tables reside. If none is provided, the Amazon Web Services account ID is used by default.

pub fn get_catalog_id(&self) -> &Option<String>

The ID of the Data Catalog where the tables reside. If none is provided, the Amazon Web Services account ID is used by default.

pub fn database_name(self, input: impl Into<String>) -> Self

The database in the catalog whose tables to list. For Hive compatibility, this name is entirely lowercase.

pub fn set_database_name(self, input: Option<String>) -> Self

The database in the catalog whose tables to list. For Hive compatibility, this name is entirely lowercase.

pub fn get_database_name(&self) -> &Option<String>

The database in the catalog whose tables to list. For Hive compatibility, this name is entirely lowercase.

pub fn expression(self, input: impl Into<String>) -> Self

A regular expression pattern. If present, only those tables whose names match the pattern are returned.

pub fn set_expression(self, input: Option<String>) -> Self

A regular expression pattern. If present, only those tables whose names match the pattern are returned.

pub fn get_expression(&self) -> &Option<String>

A regular expression pattern. If present, only those tables whose names match the pattern are returned.

pub fn next_token(self, input: impl Into<String>) -> Self

A continuation token, included if this is a continuation call.

pub fn set_next_token(self, input: Option<String>) -> Self

A continuation token, included if this is a continuation call.

pub fn get_next_token(&self) -> &Option<String>

A continuation token, included if this is a continuation call.

pub fn max_results(self, input: i32) -> Self

The maximum number of tables to return in a single response.

pub fn set_max_results(self, input: Option<i32>) -> Self

The maximum number of tables to return in a single response.

pub fn get_max_results(&self) -> &Option<i32>

The maximum number of tables to return in a single response.

pub fn transaction_id(self, input: impl Into<String>) -> Self

The transaction ID at which to read the table contents.

pub fn set_transaction_id(self, input: Option<String>) -> Self

The transaction ID at which to read the table contents.

pub fn get_transaction_id(&self) -> &Option<String>

The transaction ID at which to read the table contents.

pub fn query_as_of_time(self, input: DateTime) -> Self

The time as of when to read the table contents. If not set, the most recent transaction commit time will be used. Cannot be specified along with TransactionId.

pub fn set_query_as_of_time(self, input: Option<DateTime>) -> Self

The time as of when to read the table contents. If not set, the most recent transaction commit time will be used. Cannot be specified along with TransactionId.

pub fn get_query_as_of_time(&self) -> &Option<DateTime>

The time as of when to read the table contents. If not set, the most recent transaction commit time will be used. Cannot be specified along with TransactionId.

pub fn audit_context(self, input: AuditContext) -> Self

A structure containing the Lake Formation audit context.

pub fn set_audit_context(self, input: Option<AuditContext>) -> Self

A structure containing the Lake Formation audit context.

pub fn get_audit_context(&self) -> &Option<AuditContext>

A structure containing the Lake Formation audit context.

pub fn include_status_details(self, input: bool) -> Self

Specifies whether to include status details related to a request to create or update an Glue Data Catalog view.

pub fn set_include_status_details(self, input: Option<bool>) -> Self

Specifies whether to include status details related to a request to create or update an Glue Data Catalog view.

pub fn get_include_status_details(&self) -> &Option<bool>

Specifies whether to include status details related to a request to create or update an Glue Data Catalog view.

pub fn attributes_to_get(self, input: TableAttributes) -> Self

Appends an item to AttributesToGet.

To override the contents of this collection use set_attributes_to_get.

Specifies the table fields returned by the GetTables call. This parameter doesn’t accept an empty list. The request must include NAME.

The following are the valid combinations of values:

  • NAME - Names of all tables in the database.

  • NAME, TABLE_TYPE - Names of all tables and the table types.

pub fn set_attributes_to_get(self, input: Option<Vec<TableAttributes>>) -> Self

Specifies the table fields returned by the GetTables call. This parameter doesn’t accept an empty list. The request must include NAME.

The following are the valid combinations of values:

  • NAME - Names of all tables in the database.

  • NAME, TABLE_TYPE - Names of all tables and the table types.

pub fn get_attributes_to_get(&self) -> &Option<Vec<TableAttributes>>

Specifies the table fields returned by the GetTables call. This parameter doesn’t accept an empty list. The request must include NAME.

The following are the valid combinations of values:

  • NAME - Names of all tables in the database.

  • NAME, TABLE_TYPE - Names of all tables and the table types.