pub struct GetTriggersPaginatorItems(/* private fields */);Expand description
Flattened paginator for GetTriggersPaginator
This is created with .items()
Implementations
Sourceimpl GetTriggersPaginatorItems
impl GetTriggersPaginatorItems
Sourcepub fn send(
self,
) -> PaginationStream<Result<Trigger, SdkError<GetTriggersError, HttpResponse>>>
pub fn send( self, ) -> PaginationStream<Result<Trigger, SdkError<GetTriggersError, HttpResponse>>>
Create the pagination stream
Note: No requests will be dispatched until the stream is used
(e.g. with the .next().await method).
To read the entirety of the paginator, use .collect::<Result<Vec<_>, _>().