#[non_exhaustive]pub struct ListBlueprintsInputBuilder { /* private fields */ }Expand description
A builder for ListBlueprintsInput.
Implementations
Sourceimpl ListBlueprintsInputBuilder
impl ListBlueprintsInputBuilder
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token, if this is a continuation request.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token, if this is a continuation request.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token, if this is a continuation request.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum size of a list to return.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum size of a list to return.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The maximum size of a list to return.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
Filters the list by an Amazon Web Services resource tag.
Filters the list by an Amazon Web Services resource tag.
Filters the list by an Amazon Web Services resource tag.
Sourcepub fn build(self) -> Result<ListBlueprintsInput, BuildError>
pub fn build(self) -> Result<ListBlueprintsInput, BuildError>
Consumes the builder and constructs a ListBlueprintsInput.
Sourceimpl ListBlueprintsInputBuilder
impl ListBlueprintsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<ListBlueprintsOutput, SdkError<ListBlueprintsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<ListBlueprintsOutput, SdkError<ListBlueprintsError, HttpResponse>>
Sends a request with this input using the given client.