pub struct ListBlueprintsPaginatorItems(/* private fields */);Expand description
Flattened paginator for ListBlueprintsPaginator
This is created with .items()
Implementations
Sourceimpl ListBlueprintsPaginatorItems
impl ListBlueprintsPaginatorItems
Sourcepub fn send(
self,
) -> PaginationStream<Result<String, SdkError<ListBlueprintsError, HttpResponse>>>
pub fn send( self, ) -> PaginationStream<Result<String, SdkError<ListBlueprintsError, HttpResponse>>>
Create the pagination stream
Note: No requests will be dispatched until the stream is used
(e.g. with the .next().await method).
To read the entirety of the paginator, use .collect::<Result<Vec<_>, _>().