#[non_exhaustive]pub struct ListColumnStatisticsTaskRunsInput {
pub max_results: Option<i32>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.max_results: Option<i32>The maximum size of the response.
next_token: Option<String>A continuation token, if this is a continuation call.
Implementations
Sourceimpl ListColumnStatisticsTaskRunsInput
impl ListColumnStatisticsTaskRunsInput
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
The maximum size of the response.
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A continuation token, if this is a continuation call.
Sourceimpl ListColumnStatisticsTaskRunsInput
impl ListColumnStatisticsTaskRunsInput
Sourcepub fn builder() -> ListColumnStatisticsTaskRunsInputBuilder
pub fn builder() -> ListColumnStatisticsTaskRunsInputBuilder
Creates a new builder-style object to manufacture ListColumnStatisticsTaskRunsInput.