#[non_exhaustive]pub struct ListCrawlersOutputBuilder { /* private fields */ }Expand description
A builder for ListCrawlersOutput.
Implementations
Sourceimpl ListCrawlersOutputBuilder
impl ListCrawlersOutputBuilder
Sourcepub fn crawler_names(self, input: impl Into<String>) -> Self
pub fn crawler_names(self, input: impl Into<String>) -> Self
Appends an item to crawler_names.
To override the contents of this collection use set_crawler_names.
The names of all crawlers in the account, or the crawlers with the specified tags.
Sourcepub fn set_crawler_names(self, input: Option<Vec<String>>) -> Self
pub fn set_crawler_names(self, input: Option<Vec<String>>) -> Self
The names of all crawlers in the account, or the crawlers with the specified tags.
Sourcepub fn get_crawler_names(&self) -> &Option<Vec<String>>
pub fn get_crawler_names(&self) -> &Option<Vec<String>>
The names of all crawlers in the account, or the crawlers with the specified tags.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token, if the returned list does not contain the last metric available.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token, if the returned list does not contain the last metric available.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token, if the returned list does not contain the last metric available.
Sourcepub fn build(self) -> ListCrawlersOutput
pub fn build(self) -> ListCrawlersOutput
Consumes the builder and constructs a ListCrawlersOutput.