#[non_exhaustive]pub struct ListCrawlsOutputBuilder { /* private fields */ }Expand description
A builder for ListCrawlsOutput.
Implementations
Sourceimpl ListCrawlsOutputBuilder
impl ListCrawlsOutputBuilder
Sourcepub fn crawls(self, input: CrawlerHistory) -> Self
pub fn crawls(self, input: CrawlerHistory) -> Self
Appends an item to crawls.
To override the contents of this collection use set_crawls.
A list of CrawlerHistory objects representing the crawl runs that meet your criteria.
Sourcepub fn set_crawls(self, input: Option<Vec<CrawlerHistory>>) -> Self
pub fn set_crawls(self, input: Option<Vec<CrawlerHistory>>) -> Self
A list of CrawlerHistory objects representing the crawl runs that meet your criteria.
Sourcepub fn get_crawls(&self) -> &Option<Vec<CrawlerHistory>>
pub fn get_crawls(&self) -> &Option<Vec<CrawlerHistory>>
A list of CrawlerHistory objects representing the crawl runs that meet your criteria.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token for paginating the returned list of tokens, returned if the current segment of the list is not the last.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token for paginating the returned list of tokens, returned if the current segment of the list is not the last.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token for paginating the returned list of tokens, returned if the current segment of the list is not the last.
Sourcepub fn build(self) -> ListCrawlsOutput
pub fn build(self) -> ListCrawlsOutput
Consumes the builder and constructs a ListCrawlsOutput.