#[non_exhaustive]pub struct ListCrawlsInput {
pub crawler_name: Option<String>,
pub max_results: Option<i32>,
pub filters: Option<Vec<CrawlsFilter>>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.crawler_name: Option<String>The name of the crawler whose runs you want to retrieve.
max_results: Option<i32>The maximum number of results to return. The default is 20, and maximum is 100.
filters: Option<Vec<CrawlsFilter>>Filters the crawls by the criteria you specify in a list of CrawlsFilter objects.
next_token: Option<String>A continuation token, if this is a continuation call.
Implementations
Sourceimpl ListCrawlsInput
impl ListCrawlsInput
Sourcepub fn crawler_name(&self) -> Option<&str>
pub fn crawler_name(&self) -> Option<&str>
The name of the crawler whose runs you want to retrieve.
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
The maximum number of results to return. The default is 20, and maximum is 100.
Sourcepub fn filters(&self) -> &[CrawlsFilter]
pub fn filters(&self) -> &[CrawlsFilter]
Filters the crawls by the criteria you specify in a list of CrawlsFilter objects.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .filters.is_none().
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A continuation token, if this is a continuation call.
Sourceimpl ListCrawlsInput
impl ListCrawlsInput
Sourcepub fn builder() -> ListCrawlsInputBuilder
pub fn builder() -> ListCrawlsInputBuilder
Creates a new builder-style object to manufacture ListCrawlsInput.