#[non_exhaustive]pub struct ListCrawlsOutput {
pub crawls: Option<Vec<CrawlerHistory>>,
pub next_token: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.crawls: Option<Vec<CrawlerHistory>>A list of CrawlerHistory objects representing the crawl runs that meet your criteria.
next_token: Option<String>A continuation token for paginating the returned list of tokens, returned if the current segment of the list is not the last.
Implementations
Sourceimpl ListCrawlsOutput
impl ListCrawlsOutput
Sourcepub fn crawls(&self) -> &[CrawlerHistory]
pub fn crawls(&self) -> &[CrawlerHistory]
A list of CrawlerHistory objects representing the crawl runs that meet your criteria.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .crawls.is_none().
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A continuation token for paginating the returned list of tokens, returned if the current segment of the list is not the last.
Sourceimpl ListCrawlsOutput
impl ListCrawlsOutput
Sourcepub fn builder() -> ListCrawlsOutputBuilder
pub fn builder() -> ListCrawlsOutputBuilder
Creates a new builder-style object to manufacture ListCrawlsOutput.