pub struct ListDataQualityResultsFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to ListDataQualityResults.
Returns all data quality execution results for your account.
Implementations
Sourceimpl ListDataQualityResultsFluentBuilder
impl ListDataQualityResultsFluentBuilder
Sourcepub fn as_input(&self) -> &ListDataQualityResultsInputBuilder
pub fn as_input(&self) -> &ListDataQualityResultsInputBuilder
Access the ListDataQualityResults as a reference.
Sourcepub async fn send(
self,
) -> Result<ListDataQualityResultsOutput, SdkError<ListDataQualityResultsError, HttpResponse>>
pub async fn send( self, ) -> Result<ListDataQualityResultsOutput, SdkError<ListDataQualityResultsError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<ListDataQualityResultsOutput, ListDataQualityResultsError, Self>
pub fn customize( self, ) -> CustomizableOperation<ListDataQualityResultsOutput, ListDataQualityResultsError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn into_paginator(self) -> ListDataQualityResultsPaginator
pub fn into_paginator(self) -> ListDataQualityResultsPaginator
Create a paginator for this request
Paginators are used by calling send().await which returns a PaginationStream.
Sourcepub fn filter(self, input: DataQualityResultFilterCriteria) -> Self
pub fn filter(self, input: DataQualityResultFilterCriteria) -> Self
The filter criteria.
Sourcepub fn set_filter(self, input: Option<DataQualityResultFilterCriteria>) -> Self
pub fn set_filter(self, input: Option<DataQualityResultFilterCriteria>) -> Self
The filter criteria.
Sourcepub fn get_filter(&self) -> &Option<DataQualityResultFilterCriteria>
pub fn get_filter(&self) -> &Option<DataQualityResultFilterCriteria>
The filter criteria.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A paginated token to offset the results.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A paginated token to offset the results.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A paginated token to offset the results.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum number of results to return.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum number of results to return.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The maximum number of results to return.