#[non_exhaustive]pub struct ListDataQualityResultsOutputBuilder { /* private fields */ }Expand description
A builder for ListDataQualityResultsOutput.
Implementations
Sourceimpl ListDataQualityResultsOutputBuilder
impl ListDataQualityResultsOutputBuilder
Sourcepub fn results(self, input: DataQualityResultDescription) -> Self
pub fn results(self, input: DataQualityResultDescription) -> Self
Appends an item to results.
To override the contents of this collection use set_results.
A list of DataQualityResultDescription objects.
Sourcepub fn set_results(
self,
input: Option<Vec<DataQualityResultDescription>>,
) -> Self
pub fn set_results( self, input: Option<Vec<DataQualityResultDescription>>, ) -> Self
A list of DataQualityResultDescription objects.
Sourcepub fn get_results(&self) -> &Option<Vec<DataQualityResultDescription>>
pub fn get_results(&self) -> &Option<Vec<DataQualityResultDescription>>
A list of DataQualityResultDescription objects.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A pagination token, if more results are available.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A pagination token, if more results are available.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A pagination token, if more results are available.
Sourcepub fn build(self) -> Result<ListDataQualityResultsOutput, BuildError>
pub fn build(self) -> Result<ListDataQualityResultsOutput, BuildError>
Consumes the builder and constructs a ListDataQualityResultsOutput.
This method will fail if any of the following fields are not set: