#[non_exhaustive]pub struct ListDataQualityStatisticAnnotationsInput {
pub statistic_id: Option<String>,
pub profile_id: Option<String>,
pub timestamp_filter: Option<TimestampFilter>,
pub max_results: Option<i32>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.statistic_id: Option<String>The Statistic ID.
profile_id: Option<String>The Profile ID.
timestamp_filter: Option<TimestampFilter>A timestamp filter.
max_results: Option<i32>The maximum number of results to return in this request.
next_token: Option<String>A pagination token to retrieve the next set of results.
Implementations
Sourceimpl ListDataQualityStatisticAnnotationsInput
impl ListDataQualityStatisticAnnotationsInput
Sourcepub fn statistic_id(&self) -> Option<&str>
pub fn statistic_id(&self) -> Option<&str>
The Statistic ID.
Sourcepub fn profile_id(&self) -> Option<&str>
pub fn profile_id(&self) -> Option<&str>
The Profile ID.
Sourcepub fn timestamp_filter(&self) -> Option<&TimestampFilter>
pub fn timestamp_filter(&self) -> Option<&TimestampFilter>
A timestamp filter.
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
The maximum number of results to return in this request.
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A pagination token to retrieve the next set of results.
Sourceimpl ListDataQualityStatisticAnnotationsInput
impl ListDataQualityStatisticAnnotationsInput
Sourcepub fn builder() -> ListDataQualityStatisticAnnotationsInputBuilder
pub fn builder() -> ListDataQualityStatisticAnnotationsInputBuilder
Creates a new builder-style object to manufacture ListDataQualityStatisticAnnotationsInput.