#[non_exhaustive]pub struct ListDataQualityStatisticAnnotationsOutput {
pub annotations: Option<Vec<StatisticAnnotation>>,
pub next_token: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.annotations: Option<Vec<StatisticAnnotation>>A list of StatisticAnnotation applied to the Statistic
next_token: Option<String>A pagination token to retrieve the next set of results.
Implementations
Sourceimpl ListDataQualityStatisticAnnotationsOutput
impl ListDataQualityStatisticAnnotationsOutput
Sourcepub fn annotations(&self) -> &[StatisticAnnotation]
pub fn annotations(&self) -> &[StatisticAnnotation]
A list of StatisticAnnotation applied to the Statistic
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .annotations.is_none().
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A pagination token to retrieve the next set of results.
Sourceimpl ListDataQualityStatisticAnnotationsOutput
impl ListDataQualityStatisticAnnotationsOutput
Sourcepub fn builder() -> ListDataQualityStatisticAnnotationsOutputBuilder
pub fn builder() -> ListDataQualityStatisticAnnotationsOutputBuilder
Creates a new builder-style object to manufacture ListDataQualityStatisticAnnotationsOutput.