pub struct ListDataQualityStatisticsFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to ListDataQualityStatistics.
Retrieves a list of data quality statistics.
Implementations
Sourceimpl ListDataQualityStatisticsFluentBuilder
impl ListDataQualityStatisticsFluentBuilder
Sourcepub fn as_input(&self) -> &ListDataQualityStatisticsInputBuilder
pub fn as_input(&self) -> &ListDataQualityStatisticsInputBuilder
Access the ListDataQualityStatistics as a reference.
Sourcepub async fn send(
self,
) -> Result<ListDataQualityStatisticsOutput, SdkError<ListDataQualityStatisticsError, HttpResponse>>
pub async fn send( self, ) -> Result<ListDataQualityStatisticsOutput, SdkError<ListDataQualityStatisticsError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<ListDataQualityStatisticsOutput, ListDataQualityStatisticsError, Self>
pub fn customize( self, ) -> CustomizableOperation<ListDataQualityStatisticsOutput, ListDataQualityStatisticsError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn statistic_id(self, input: impl Into<String>) -> Self
pub fn statistic_id(self, input: impl Into<String>) -> Self
The Statistic ID.
Sourcepub fn set_statistic_id(self, input: Option<String>) -> Self
pub fn set_statistic_id(self, input: Option<String>) -> Self
The Statistic ID.
Sourcepub fn get_statistic_id(&self) -> &Option<String>
pub fn get_statistic_id(&self) -> &Option<String>
The Statistic ID.
Sourcepub fn profile_id(self, input: impl Into<String>) -> Self
pub fn profile_id(self, input: impl Into<String>) -> Self
The Profile ID.
Sourcepub fn set_profile_id(self, input: Option<String>) -> Self
pub fn set_profile_id(self, input: Option<String>) -> Self
The Profile ID.
Sourcepub fn get_profile_id(&self) -> &Option<String>
pub fn get_profile_id(&self) -> &Option<String>
The Profile ID.
Sourcepub fn timestamp_filter(self, input: TimestampFilter) -> Self
pub fn timestamp_filter(self, input: TimestampFilter) -> Self
A timestamp filter.
Sourcepub fn set_timestamp_filter(self, input: Option<TimestampFilter>) -> Self
pub fn set_timestamp_filter(self, input: Option<TimestampFilter>) -> Self
A timestamp filter.
Sourcepub fn get_timestamp_filter(&self) -> &Option<TimestampFilter>
pub fn get_timestamp_filter(&self) -> &Option<TimestampFilter>
A timestamp filter.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum number of results to return in this request.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum number of results to return in this request.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The maximum number of results to return in this request.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A pagination token to request the next page of results.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A pagination token to request the next page of results.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A pagination token to request the next page of results.