#[non_exhaustive]pub struct ListDataQualityStatisticsInputBuilder { /* private fields */ }Expand description
A builder for ListDataQualityStatisticsInput.
Implementations
Sourceimpl ListDataQualityStatisticsInputBuilder
impl ListDataQualityStatisticsInputBuilder
Sourcepub fn statistic_id(self, input: impl Into<String>) -> Self
pub fn statistic_id(self, input: impl Into<String>) -> Self
The Statistic ID.
Sourcepub fn set_statistic_id(self, input: Option<String>) -> Self
pub fn set_statistic_id(self, input: Option<String>) -> Self
The Statistic ID.
Sourcepub fn get_statistic_id(&self) -> &Option<String>
pub fn get_statistic_id(&self) -> &Option<String>
The Statistic ID.
Sourcepub fn profile_id(self, input: impl Into<String>) -> Self
pub fn profile_id(self, input: impl Into<String>) -> Self
The Profile ID.
Sourcepub fn set_profile_id(self, input: Option<String>) -> Self
pub fn set_profile_id(self, input: Option<String>) -> Self
The Profile ID.
Sourcepub fn get_profile_id(&self) -> &Option<String>
pub fn get_profile_id(&self) -> &Option<String>
The Profile ID.
Sourcepub fn timestamp_filter(self, input: TimestampFilter) -> Self
pub fn timestamp_filter(self, input: TimestampFilter) -> Self
A timestamp filter.
Sourcepub fn set_timestamp_filter(self, input: Option<TimestampFilter>) -> Self
pub fn set_timestamp_filter(self, input: Option<TimestampFilter>) -> Self
A timestamp filter.
Sourcepub fn get_timestamp_filter(&self) -> &Option<TimestampFilter>
pub fn get_timestamp_filter(&self) -> &Option<TimestampFilter>
A timestamp filter.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum number of results to return in this request.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum number of results to return in this request.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The maximum number of results to return in this request.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A pagination token to request the next page of results.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A pagination token to request the next page of results.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A pagination token to request the next page of results.
Sourcepub fn build(self) -> Result<ListDataQualityStatisticsInput, BuildError>
pub fn build(self) -> Result<ListDataQualityStatisticsInput, BuildError>
Consumes the builder and constructs a ListDataQualityStatisticsInput.
Sourceimpl ListDataQualityStatisticsInputBuilder
impl ListDataQualityStatisticsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<ListDataQualityStatisticsOutput, SdkError<ListDataQualityStatisticsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<ListDataQualityStatisticsOutput, SdkError<ListDataQualityStatisticsError, HttpResponse>>
Sends a request with this input using the given client.