#[non_exhaustive]pub struct ListDataQualityStatisticsOutputBuilder { /* private fields */ }Expand description
A builder for ListDataQualityStatisticsOutput.
Implementations
Sourceimpl ListDataQualityStatisticsOutputBuilder
impl ListDataQualityStatisticsOutputBuilder
Sourcepub fn statistics(self, input: StatisticSummary) -> Self
pub fn statistics(self, input: StatisticSummary) -> Self
Appends an item to statistics.
To override the contents of this collection use set_statistics.
A StatisticSummaryList.
Sourcepub fn set_statistics(self, input: Option<Vec<StatisticSummary>>) -> Self
pub fn set_statistics(self, input: Option<Vec<StatisticSummary>>) -> Self
A StatisticSummaryList.
Sourcepub fn get_statistics(&self) -> &Option<Vec<StatisticSummary>>
pub fn get_statistics(&self) -> &Option<Vec<StatisticSummary>>
A StatisticSummaryList.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A pagination token to request the next page of results.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A pagination token to request the next page of results.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A pagination token to request the next page of results.
Sourcepub fn build(self) -> ListDataQualityStatisticsOutput
pub fn build(self) -> ListDataQualityStatisticsOutput
Consumes the builder and constructs a ListDataQualityStatisticsOutput.