#[non_exhaustive]pub struct ListDataQualityStatisticsOutput {
pub statistics: Option<Vec<StatisticSummary>>,
pub next_token: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.statistics: Option<Vec<StatisticSummary>>A StatisticSummaryList.
next_token: Option<String>A pagination token to request the next page of results.
Implementations
Sourceimpl ListDataQualityStatisticsOutput
impl ListDataQualityStatisticsOutput
Sourcepub fn statistics(&self) -> &[StatisticSummary]
pub fn statistics(&self) -> &[StatisticSummary]
A StatisticSummaryList.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .statistics.is_none().
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A pagination token to request the next page of results.
Sourceimpl ListDataQualityStatisticsOutput
impl ListDataQualityStatisticsOutput
Sourcepub fn builder() -> ListDataQualityStatisticsOutputBuilder
pub fn builder() -> ListDataQualityStatisticsOutputBuilder
Creates a new builder-style object to manufacture ListDataQualityStatisticsOutput.