pub struct ListGlossariesFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to ListGlossaries.
Lists business glossaries in Glue Data Catalog.
Implementations
Sourceimpl ListGlossariesFluentBuilder
impl ListGlossariesFluentBuilder
Sourcepub fn as_input(&self) -> &ListGlossariesInputBuilder
pub fn as_input(&self) -> &ListGlossariesInputBuilder
Access the ListGlossaries as a reference.
Sourcepub async fn send(
self,
) -> Result<ListGlossariesOutput, SdkError<ListGlossariesError, HttpResponse>>
pub async fn send( self, ) -> Result<ListGlossariesOutput, SdkError<ListGlossariesError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<ListGlossariesOutput, ListGlossariesError, Self>
pub fn customize( self, ) -> CustomizableOperation<ListGlossariesOutput, ListGlossariesError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn into_paginator(self) -> ListGlossariesPaginator
pub fn into_paginator(self) -> ListGlossariesPaginator
Create a paginator for this request
Paginators are used by calling send().await which returns a PaginationStream.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum number of results to return in the response.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum number of results to return in the response.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The maximum number of results to return in the response.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token, if this is a continuation call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token, if this is a continuation call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token, if this is a continuation call.