#[non_exhaustive]pub struct ListGlossariesInputBuilder { /* private fields */ }Expand description
A builder for ListGlossariesInput.
Implementations
Sourceimpl ListGlossariesInputBuilder
impl ListGlossariesInputBuilder
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum number of results to return in the response.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum number of results to return in the response.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The maximum number of results to return in the response.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token, if this is a continuation call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token, if this is a continuation call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token, if this is a continuation call.
Sourcepub fn build(self) -> Result<ListGlossariesInput, BuildError>
pub fn build(self) -> Result<ListGlossariesInput, BuildError>
Consumes the builder and constructs a ListGlossariesInput.
Sourceimpl ListGlossariesInputBuilder
impl ListGlossariesInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<ListGlossariesOutput, SdkError<ListGlossariesError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<ListGlossariesOutput, SdkError<ListGlossariesError, HttpResponse>>
Sends a request with this input using the given client.