#[non_exhaustive]pub struct ListGlossariesOutputBuilder { /* private fields */ }Expand description
A builder for ListGlossariesOutput.
Implementations
Sourceimpl ListGlossariesOutputBuilder
impl ListGlossariesOutputBuilder
Sourcepub fn items(self, input: GlossaryItem) -> Self
pub fn items(self, input: GlossaryItem) -> Self
Appends an item to items.
To override the contents of this collection use set_items.
The list of glossary items.
Sourcepub fn set_items(self, input: Option<Vec<GlossaryItem>>) -> Self
pub fn set_items(self, input: Option<Vec<GlossaryItem>>) -> Self
The list of glossary items.
Sourcepub fn get_items(&self) -> &Option<Vec<GlossaryItem>>
pub fn get_items(&self) -> &Option<Vec<GlossaryItem>>
The list of glossary items.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token, present if the current segment is not the last.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token, present if the current segment is not the last.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token, present if the current segment is not the last.
Sourcepub fn build(self) -> ListGlossariesOutput
pub fn build(self) -> ListGlossariesOutput
Consumes the builder and constructs a ListGlossariesOutput.