pub struct ListGlossariesPaginatorItems(/* private fields */);Expand description
Flattened paginator for ListGlossariesPaginator
This is created with .items()
Implementations
Sourceimpl ListGlossariesPaginatorItems
impl ListGlossariesPaginatorItems
Sourcepub fn send(
self,
) -> PaginationStream<Result<GlossaryItem, SdkError<ListGlossariesError, HttpResponse>>>
pub fn send( self, ) -> PaginationStream<Result<GlossaryItem, SdkError<ListGlossariesError, HttpResponse>>>
Create the pagination stream
Note: No requests will be dispatched until the stream is used
(e.g. with the .next().await method).
To read the entirety of the paginator, use .collect::<Result<Vec<_>, _>().