pub struct ListGlossaryTermsFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to ListGlossaryTerms.
Lists glossary terms within a business glossary in Glue Data Catalog.
Implementations
Sourceimpl ListGlossaryTermsFluentBuilder
impl ListGlossaryTermsFluentBuilder
Sourcepub fn as_input(&self) -> &ListGlossaryTermsInputBuilder
pub fn as_input(&self) -> &ListGlossaryTermsInputBuilder
Access the ListGlossaryTerms as a reference.
Sourcepub async fn send(
self,
) -> Result<ListGlossaryTermsOutput, SdkError<ListGlossaryTermsError, HttpResponse>>
pub async fn send( self, ) -> Result<ListGlossaryTermsOutput, SdkError<ListGlossaryTermsError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<ListGlossaryTermsOutput, ListGlossaryTermsError, Self>
pub fn customize( self, ) -> CustomizableOperation<ListGlossaryTermsOutput, ListGlossaryTermsError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn into_paginator(self) -> ListGlossaryTermsPaginator
pub fn into_paginator(self) -> ListGlossaryTermsPaginator
Create a paginator for this request
Paginators are used by calling send().await which returns a PaginationStream.
Sourcepub fn glossary_identifier(self, input: impl Into<String>) -> Self
pub fn glossary_identifier(self, input: impl Into<String>) -> Self
The unique identifier of the glossary whose terms to list.
Sourcepub fn set_glossary_identifier(self, input: Option<String>) -> Self
pub fn set_glossary_identifier(self, input: Option<String>) -> Self
The unique identifier of the glossary whose terms to list.
Sourcepub fn get_glossary_identifier(&self) -> &Option<String>
pub fn get_glossary_identifier(&self) -> &Option<String>
The unique identifier of the glossary whose terms to list.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum number of results to return in the response.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum number of results to return in the response.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The maximum number of results to return in the response.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token, if this is a continuation call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token, if this is a continuation call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token, if this is a continuation call.