#[non_exhaustive]pub struct ListGlossaryTermsInputBuilder { /* private fields */ }Expand description
A builder for ListGlossaryTermsInput.
Implementations
Sourceimpl ListGlossaryTermsInputBuilder
impl ListGlossaryTermsInputBuilder
Sourcepub fn glossary_identifier(self, input: impl Into<String>) -> Self
pub fn glossary_identifier(self, input: impl Into<String>) -> Self
The unique identifier of the glossary whose terms to list.
This field is required.Sourcepub fn set_glossary_identifier(self, input: Option<String>) -> Self
pub fn set_glossary_identifier(self, input: Option<String>) -> Self
The unique identifier of the glossary whose terms to list.
Sourcepub fn get_glossary_identifier(&self) -> &Option<String>
pub fn get_glossary_identifier(&self) -> &Option<String>
The unique identifier of the glossary whose terms to list.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum number of results to return in the response.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum number of results to return in the response.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The maximum number of results to return in the response.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token, if this is a continuation call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token, if this is a continuation call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token, if this is a continuation call.
Sourcepub fn build(self) -> Result<ListGlossaryTermsInput, BuildError>
pub fn build(self) -> Result<ListGlossaryTermsInput, BuildError>
Consumes the builder and constructs a ListGlossaryTermsInput.
Sourceimpl ListGlossaryTermsInputBuilder
impl ListGlossaryTermsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<ListGlossaryTermsOutput, SdkError<ListGlossaryTermsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<ListGlossaryTermsOutput, SdkError<ListGlossaryTermsError, HttpResponse>>
Sends a request with this input using the given client.