#[non_exhaustive]pub struct ListGlossaryTermsOutputBuilder { /* private fields */ }Expand description
A builder for ListGlossaryTermsOutput.
Implementations
Sourceimpl ListGlossaryTermsOutputBuilder
impl ListGlossaryTermsOutputBuilder
Sourcepub fn items(self, input: GlossaryTermItem) -> Self
pub fn items(self, input: GlossaryTermItem) -> Self
Appends an item to items.
To override the contents of this collection use set_items.
The list of glossary term items.
Sourcepub fn set_items(self, input: Option<Vec<GlossaryTermItem>>) -> Self
pub fn set_items(self, input: Option<Vec<GlossaryTermItem>>) -> Self
The list of glossary term items.
Sourcepub fn get_items(&self) -> &Option<Vec<GlossaryTermItem>>
pub fn get_items(&self) -> &Option<Vec<GlossaryTermItem>>
The list of glossary term items.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token, present if the current segment is not the last.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token, present if the current segment is not the last.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token, present if the current segment is not the last.
Sourcepub fn build(self) -> ListGlossaryTermsOutput
pub fn build(self) -> ListGlossaryTermsOutput
Consumes the builder and constructs a ListGlossaryTermsOutput.