#[non_exhaustive]pub struct ListGlossaryTermsInput {
pub glossary_identifier: Option<String>,
pub max_results: Option<i32>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.glossary_identifier: Option<String>The unique identifier of the glossary whose terms to list.
max_results: Option<i32>The maximum number of results to return in the response.
next_token: Option<String>A continuation token, if this is a continuation call.
Implementations
Sourceimpl ListGlossaryTermsInput
impl ListGlossaryTermsInput
Sourcepub fn glossary_identifier(&self) -> Option<&str>
pub fn glossary_identifier(&self) -> Option<&str>
The unique identifier of the glossary whose terms to list.
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
The maximum number of results to return in the response.
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A continuation token, if this is a continuation call.
Sourceimpl ListGlossaryTermsInput
impl ListGlossaryTermsInput
Sourcepub fn builder() -> ListGlossaryTermsInputBuilder
pub fn builder() -> ListGlossaryTermsInputBuilder
Creates a new builder-style object to manufacture ListGlossaryTermsInput.