#[non_exhaustive]pub struct ListGlossaryTermsOutput {
pub items: Option<Vec<GlossaryTermItem>>,
pub next_token: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.items: Option<Vec<GlossaryTermItem>>The list of glossary term items.
next_token: Option<String>A continuation token, present if the current segment is not the last.
Implementations
Sourceimpl ListGlossaryTermsOutput
impl ListGlossaryTermsOutput
Sourcepub fn items(&self) -> &[GlossaryTermItem]
pub fn items(&self) -> &[GlossaryTermItem]
The list of glossary term items.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .items.is_none().
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A continuation token, present if the current segment is not the last.
Sourceimpl ListGlossaryTermsOutput
impl ListGlossaryTermsOutput
Sourcepub fn builder() -> ListGlossaryTermsOutputBuilder
pub fn builder() -> ListGlossaryTermsOutputBuilder
Creates a new builder-style object to manufacture ListGlossaryTermsOutput.