#[non_exhaustive]pub struct ListIntegrationResourcePropertiesInputBuilder { /* private fields */ }Expand description
A builder for ListIntegrationResourcePropertiesInput.
Implementations
Sourceimpl ListIntegrationResourcePropertiesInputBuilder
impl ListIntegrationResourcePropertiesInputBuilder
Sourcepub fn marker(self, input: impl Into<String>) -> Self
pub fn marker(self, input: impl Into<String>) -> Self
This is the pagination token for next page, initial value is null.
Sourcepub fn set_marker(self, input: Option<String>) -> Self
pub fn set_marker(self, input: Option<String>) -> Self
This is the pagination token for next page, initial value is null.
Sourcepub fn get_marker(&self) -> &Option<String>
pub fn get_marker(&self) -> &Option<String>
This is the pagination token for next page, initial value is null.
Sourcepub fn filters(self, input: IntegrationResourcePropertyFilter) -> Self
pub fn filters(self, input: IntegrationResourcePropertyFilter) -> Self
Appends an item to filters.
To override the contents of this collection use set_filters.
A list of filters, supported filter Key is SourceArn and TargetArn.
Sourcepub fn set_filters(
self,
input: Option<Vec<IntegrationResourcePropertyFilter>>,
) -> Self
pub fn set_filters( self, input: Option<Vec<IntegrationResourcePropertyFilter>>, ) -> Self
A list of filters, supported filter Key is SourceArn and TargetArn.
Sourcepub fn get_filters(&self) -> &Option<Vec<IntegrationResourcePropertyFilter>>
pub fn get_filters(&self) -> &Option<Vec<IntegrationResourcePropertyFilter>>
A list of filters, supported filter Key is SourceArn and TargetArn.
Sourcepub fn max_records(self, input: i32) -> Self
pub fn max_records(self, input: i32) -> Self
This is total number of items to be evaluated.
Sourcepub fn set_max_records(self, input: Option<i32>) -> Self
pub fn set_max_records(self, input: Option<i32>) -> Self
This is total number of items to be evaluated.
Sourcepub fn get_max_records(&self) -> &Option<i32>
pub fn get_max_records(&self) -> &Option<i32>
This is total number of items to be evaluated.
Sourcepub fn build(self) -> Result<ListIntegrationResourcePropertiesInput, BuildError>
pub fn build(self) -> Result<ListIntegrationResourcePropertiesInput, BuildError>
Consumes the builder and constructs a ListIntegrationResourcePropertiesInput.
Sourceimpl ListIntegrationResourcePropertiesInputBuilder
impl ListIntegrationResourcePropertiesInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<ListIntegrationResourcePropertiesOutput, SdkError<ListIntegrationResourcePropertiesError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<ListIntegrationResourcePropertiesOutput, SdkError<ListIntegrationResourcePropertiesError, HttpResponse>>
Sends a request with this input using the given client.