#[non_exhaustive]pub struct ListIntegrationResourcePropertiesOutputBuilder { /* private fields */ }Expand description
A builder for ListIntegrationResourcePropertiesOutput.
Implementations
Sourceimpl ListIntegrationResourcePropertiesOutputBuilder
impl ListIntegrationResourcePropertiesOutputBuilder
Sourcepub fn integration_resource_property_list(
self,
input: IntegrationResourceProperty,
) -> Self
pub fn integration_resource_property_list( self, input: IntegrationResourceProperty, ) -> Self
Appends an item to integration_resource_property_list.
To override the contents of this collection use set_integration_resource_property_list.
A list of integration resource property meeting the filter criteria.
Sourcepub fn set_integration_resource_property_list(
self,
input: Option<Vec<IntegrationResourceProperty>>,
) -> Self
pub fn set_integration_resource_property_list( self, input: Option<Vec<IntegrationResourceProperty>>, ) -> Self
A list of integration resource property meeting the filter criteria.
Sourcepub fn get_integration_resource_property_list(
&self,
) -> &Option<Vec<IntegrationResourceProperty>>
pub fn get_integration_resource_property_list( &self, ) -> &Option<Vec<IntegrationResourceProperty>>
A list of integration resource property meeting the filter criteria.
Sourcepub fn marker(self, input: impl Into<String>) -> Self
pub fn marker(self, input: impl Into<String>) -> Self
This is the pagination token for the next page.
Sourcepub fn set_marker(self, input: Option<String>) -> Self
pub fn set_marker(self, input: Option<String>) -> Self
This is the pagination token for the next page.
Sourcepub fn get_marker(&self) -> &Option<String>
pub fn get_marker(&self) -> &Option<String>
This is the pagination token for the next page.
Sourcepub fn build(self) -> ListIntegrationResourcePropertiesOutput
pub fn build(self) -> ListIntegrationResourcePropertiesOutput
Consumes the builder and constructs a ListIntegrationResourcePropertiesOutput.