#[non_exhaustive]pub struct ListIntegrationResourcePropertiesInput {
pub marker: Option<String>,
pub filters: Option<Vec<IntegrationResourcePropertyFilter>>,
pub max_records: Option<i32>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.marker: Option<String>This is the pagination token for next page, initial value is null.
filters: Option<Vec<IntegrationResourcePropertyFilter>>A list of filters, supported filter Key is SourceArn and TargetArn.
max_records: Option<i32>This is total number of items to be evaluated.
Implementations
Sourceimpl ListIntegrationResourcePropertiesInput
impl ListIntegrationResourcePropertiesInput
Sourcepub fn marker(&self) -> Option<&str>
pub fn marker(&self) -> Option<&str>
This is the pagination token for next page, initial value is null.
Sourcepub fn filters(&self) -> &[IntegrationResourcePropertyFilter]
pub fn filters(&self) -> &[IntegrationResourcePropertyFilter]
A list of filters, supported filter Key is SourceArn and TargetArn.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .filters.is_none().
Sourcepub fn max_records(&self) -> Option<i32>
pub fn max_records(&self) -> Option<i32>
This is total number of items to be evaluated.
Sourceimpl ListIntegrationResourcePropertiesInput
impl ListIntegrationResourcePropertiesInput
Sourcepub fn builder() -> ListIntegrationResourcePropertiesInputBuilder
pub fn builder() -> ListIntegrationResourcePropertiesInputBuilder
Creates a new builder-style object to manufacture ListIntegrationResourcePropertiesInput.