#[non_exhaustive]pub struct ListIntegrationResourcePropertiesOutput {
pub integration_resource_property_list: Option<Vec<IntegrationResourceProperty>>,
pub marker: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.integration_resource_property_list: Option<Vec<IntegrationResourceProperty>>A list of integration resource property meeting the filter criteria.
marker: Option<String>This is the pagination token for the next page.
Implementations
Sourceimpl ListIntegrationResourcePropertiesOutput
impl ListIntegrationResourcePropertiesOutput
Sourcepub fn integration_resource_property_list(
&self,
) -> &[IntegrationResourceProperty]
pub fn integration_resource_property_list( &self, ) -> &[IntegrationResourceProperty]
A list of integration resource property meeting the filter criteria.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .integration_resource_property_list.is_none().
Sourceimpl ListIntegrationResourcePropertiesOutput
impl ListIntegrationResourcePropertiesOutput
Sourcepub fn builder() -> ListIntegrationResourcePropertiesOutputBuilder
pub fn builder() -> ListIntegrationResourcePropertiesOutputBuilder
Creates a new builder-style object to manufacture ListIntegrationResourcePropertiesOutput.