pub struct ListIntegrationTablePropertiesFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to ListIntegrationTableProperties.
Lists the integration table properties in your account. This operation supports filtering and pagination.
Implementations
Sourceimpl ListIntegrationTablePropertiesFluentBuilder
impl ListIntegrationTablePropertiesFluentBuilder
Sourcepub fn as_input(&self) -> &ListIntegrationTablePropertiesInputBuilder
pub fn as_input(&self) -> &ListIntegrationTablePropertiesInputBuilder
Access the ListIntegrationTableProperties as a reference.
Sourcepub async fn send(
self,
) -> Result<ListIntegrationTablePropertiesOutput, SdkError<ListIntegrationTablePropertiesError, HttpResponse>>
pub async fn send( self, ) -> Result<ListIntegrationTablePropertiesOutput, SdkError<ListIntegrationTablePropertiesError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<ListIntegrationTablePropertiesOutput, ListIntegrationTablePropertiesError, Self>
pub fn customize( self, ) -> CustomizableOperation<ListIntegrationTablePropertiesOutput, ListIntegrationTablePropertiesError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn marker(self, input: impl Into<String>) -> Self
pub fn marker(self, input: impl Into<String>) -> Self
The pagination token for the next page of results. The initial value is null.
Sourcepub fn set_marker(self, input: Option<String>) -> Self
pub fn set_marker(self, input: Option<String>) -> Self
The pagination token for the next page of results. The initial value is null.
Sourcepub fn get_marker(&self) -> &Option<String>
pub fn get_marker(&self) -> &Option<String>
The pagination token for the next page of results. The initial value is null.
Sourcepub fn filters(self, input: IntegrationTablePropertiesFilter) -> Self
pub fn filters(self, input: IntegrationTablePropertiesFilter) -> Self
Appends an item to Filters.
To override the contents of this collection use set_filters.
A list of filters. Supported filter keys are SourceArn, TargetArn, SourceTableName, and TargetTableName.
Sourcepub fn set_filters(
self,
input: Option<Vec<IntegrationTablePropertiesFilter>>,
) -> Self
pub fn set_filters( self, input: Option<Vec<IntegrationTablePropertiesFilter>>, ) -> Self
A list of filters. Supported filter keys are SourceArn, TargetArn, SourceTableName, and TargetTableName.
Sourcepub fn get_filters(&self) -> &Option<Vec<IntegrationTablePropertiesFilter>>
pub fn get_filters(&self) -> &Option<Vec<IntegrationTablePropertiesFilter>>
A list of filters. Supported filter keys are SourceArn, TargetArn, SourceTableName, and TargetTableName.
Sourcepub fn max_records(self, input: i32) -> Self
pub fn max_records(self, input: i32) -> Self
The maximum number of records to return in the response.
Sourcepub fn set_max_records(self, input: Option<i32>) -> Self
pub fn set_max_records(self, input: Option<i32>) -> Self
The maximum number of records to return in the response.
Sourcepub fn get_max_records(&self) -> &Option<i32>
pub fn get_max_records(&self) -> &Option<i32>
The maximum number of records to return in the response.