#[non_exhaustive]pub struct ListIntegrationTablePropertiesInputBuilder { /* private fields */ }Expand description
A builder for ListIntegrationTablePropertiesInput.
Implementations
Sourceimpl ListIntegrationTablePropertiesInputBuilder
impl ListIntegrationTablePropertiesInputBuilder
Sourcepub fn marker(self, input: impl Into<String>) -> Self
pub fn marker(self, input: impl Into<String>) -> Self
The pagination token for the next page of results. The initial value is null.
Sourcepub fn set_marker(self, input: Option<String>) -> Self
pub fn set_marker(self, input: Option<String>) -> Self
The pagination token for the next page of results. The initial value is null.
Sourcepub fn get_marker(&self) -> &Option<String>
pub fn get_marker(&self) -> &Option<String>
The pagination token for the next page of results. The initial value is null.
Sourcepub fn filters(self, input: IntegrationTablePropertiesFilter) -> Self
pub fn filters(self, input: IntegrationTablePropertiesFilter) -> Self
Appends an item to filters.
To override the contents of this collection use set_filters.
A list of filters. Supported filter keys are SourceArn, TargetArn, SourceTableName, and TargetTableName.
Sourcepub fn set_filters(
self,
input: Option<Vec<IntegrationTablePropertiesFilter>>,
) -> Self
pub fn set_filters( self, input: Option<Vec<IntegrationTablePropertiesFilter>>, ) -> Self
A list of filters. Supported filter keys are SourceArn, TargetArn, SourceTableName, and TargetTableName.
Sourcepub fn get_filters(&self) -> &Option<Vec<IntegrationTablePropertiesFilter>>
pub fn get_filters(&self) -> &Option<Vec<IntegrationTablePropertiesFilter>>
A list of filters. Supported filter keys are SourceArn, TargetArn, SourceTableName, and TargetTableName.
Sourcepub fn max_records(self, input: i32) -> Self
pub fn max_records(self, input: i32) -> Self
The maximum number of records to return in the response.
Sourcepub fn set_max_records(self, input: Option<i32>) -> Self
pub fn set_max_records(self, input: Option<i32>) -> Self
The maximum number of records to return in the response.
Sourcepub fn get_max_records(&self) -> &Option<i32>
pub fn get_max_records(&self) -> &Option<i32>
The maximum number of records to return in the response.
Sourcepub fn build(self) -> Result<ListIntegrationTablePropertiesInput, BuildError>
pub fn build(self) -> Result<ListIntegrationTablePropertiesInput, BuildError>
Consumes the builder and constructs a ListIntegrationTablePropertiesInput.
Sourceimpl ListIntegrationTablePropertiesInputBuilder
impl ListIntegrationTablePropertiesInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<ListIntegrationTablePropertiesOutput, SdkError<ListIntegrationTablePropertiesError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<ListIntegrationTablePropertiesOutput, SdkError<ListIntegrationTablePropertiesError, HttpResponse>>
Sends a request with this input using the given client.