#[non_exhaustive]pub struct ListIntegrationTablePropertiesOutputBuilder { /* private fields */ }Expand description
A builder for ListIntegrationTablePropertiesOutput.
Implementations
Sourceimpl ListIntegrationTablePropertiesOutputBuilder
impl ListIntegrationTablePropertiesOutputBuilder
Sourcepub fn integration_table_properties_list(
self,
input: IntegrationTableProperties,
) -> Self
pub fn integration_table_properties_list( self, input: IntegrationTableProperties, ) -> Self
Appends an item to integration_table_properties_list.
To override the contents of this collection use set_integration_table_properties_list.
A list of integration table properties meeting the filter criteria.
Sourcepub fn set_integration_table_properties_list(
self,
input: Option<Vec<IntegrationTableProperties>>,
) -> Self
pub fn set_integration_table_properties_list( self, input: Option<Vec<IntegrationTableProperties>>, ) -> Self
A list of integration table properties meeting the filter criteria.
Sourcepub fn get_integration_table_properties_list(
&self,
) -> &Option<Vec<IntegrationTableProperties>>
pub fn get_integration_table_properties_list( &self, ) -> &Option<Vec<IntegrationTableProperties>>
A list of integration table properties meeting the filter criteria.
Sourcepub fn marker(self, input: impl Into<String>) -> Self
pub fn marker(self, input: impl Into<String>) -> Self
The pagination token for the next page. Returns null if there are no more results.
Sourcepub fn set_marker(self, input: Option<String>) -> Self
pub fn set_marker(self, input: Option<String>) -> Self
The pagination token for the next page. Returns null if there are no more results.
Sourcepub fn get_marker(&self) -> &Option<String>
pub fn get_marker(&self) -> &Option<String>
The pagination token for the next page. Returns null if there are no more results.
Sourcepub fn build(self) -> ListIntegrationTablePropertiesOutput
pub fn build(self) -> ListIntegrationTablePropertiesOutput
Consumes the builder and constructs a ListIntegrationTablePropertiesOutput.