#[non_exhaustive]pub struct ListIntegrationTablePropertiesInput {
pub marker: Option<String>,
pub filters: Option<Vec<IntegrationTablePropertiesFilter>>,
pub max_records: Option<i32>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.marker: Option<String>The pagination token for the next page of results. The initial value is null.
filters: Option<Vec<IntegrationTablePropertiesFilter>>A list of filters. Supported filter keys are SourceArn, TargetArn, SourceTableName, and TargetTableName.
max_records: Option<i32>The maximum number of records to return in the response.
Implementations
Sourceimpl ListIntegrationTablePropertiesInput
impl ListIntegrationTablePropertiesInput
Sourcepub fn marker(&self) -> Option<&str>
pub fn marker(&self) -> Option<&str>
The pagination token for the next page of results. The initial value is null.
Sourcepub fn filters(&self) -> &[IntegrationTablePropertiesFilter]
pub fn filters(&self) -> &[IntegrationTablePropertiesFilter]
A list of filters. Supported filter keys are SourceArn, TargetArn, SourceTableName, and TargetTableName.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .filters.is_none().
Sourcepub fn max_records(&self) -> Option<i32>
pub fn max_records(&self) -> Option<i32>
The maximum number of records to return in the response.
Sourceimpl ListIntegrationTablePropertiesInput
impl ListIntegrationTablePropertiesInput
Sourcepub fn builder() -> ListIntegrationTablePropertiesInputBuilder
pub fn builder() -> ListIntegrationTablePropertiesInputBuilder
Creates a new builder-style object to manufacture ListIntegrationTablePropertiesInput.