#[non_exhaustive]pub struct ListIntegrationTablePropertiesOutput {
pub integration_table_properties_list: Option<Vec<IntegrationTableProperties>>,
pub marker: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.integration_table_properties_list: Option<Vec<IntegrationTableProperties>>A list of integration table properties meeting the filter criteria.
marker: Option<String>The pagination token for the next page. Returns null if there are no more results.
Implementations
Sourceimpl ListIntegrationTablePropertiesOutput
impl ListIntegrationTablePropertiesOutput
Sourcepub fn integration_table_properties_list(&self) -> &[IntegrationTableProperties]
pub fn integration_table_properties_list(&self) -> &[IntegrationTableProperties]
A list of integration table properties meeting the filter criteria.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .integration_table_properties_list.is_none().
Sourceimpl ListIntegrationTablePropertiesOutput
impl ListIntegrationTablePropertiesOutput
Sourcepub fn builder() -> ListIntegrationTablePropertiesOutputBuilder
pub fn builder() -> ListIntegrationTablePropertiesOutputBuilder
Creates a new builder-style object to manufacture ListIntegrationTablePropertiesOutput.