#[non_exhaustive]pub struct ListIterableFormsInput {
pub asset_identifier: Option<String>,
pub iterable_form_name: Option<String>,
pub max_results: Option<i32>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.asset_identifier: Option<String>The unique identifier of the asset.
iterable_form_name: Option<String>The name of the iterable form to list items from.
max_results: Option<i32>The maximum number of results to return in the response.
next_token: Option<String>A continuation token, if this is a continuation call.
Implementations
Sourceimpl ListIterableFormsInput
impl ListIterableFormsInput
Sourcepub fn asset_identifier(&self) -> Option<&str>
pub fn asset_identifier(&self) -> Option<&str>
The unique identifier of the asset.
Sourcepub fn iterable_form_name(&self) -> Option<&str>
pub fn iterable_form_name(&self) -> Option<&str>
The name of the iterable form to list items from.
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
The maximum number of results to return in the response.
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A continuation token, if this is a continuation call.
Sourceimpl ListIterableFormsInput
impl ListIterableFormsInput
Sourcepub fn builder() -> ListIterableFormsInputBuilder
pub fn builder() -> ListIterableFormsInputBuilder
Creates a new builder-style object to manufacture ListIterableFormsInput.