pub struct ListJobsFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to ListJobs.
Retrieves the names of all job resources in this Amazon Web Services account, or the resources with the specified tag. This operation allows you to see which resources are available in your account, and their names.
This operation takes the optional Tags field, which you can use as a filter on the response so that tagged resources can be retrieved as a group. If you choose to use tags filtering, only resources with the tag are retrieved.
Implementations
Sourceimpl ListJobsFluentBuilder
impl ListJobsFluentBuilder
Sourcepub fn as_input(&self) -> &ListJobsInputBuilder
pub fn as_input(&self) -> &ListJobsInputBuilder
Access the ListJobs as a reference.
Sourcepub async fn send(
self,
) -> Result<ListJobsOutput, SdkError<ListJobsError, HttpResponse>>
pub async fn send( self, ) -> Result<ListJobsOutput, SdkError<ListJobsError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<ListJobsOutput, ListJobsError, Self>
pub fn customize( self, ) -> CustomizableOperation<ListJobsOutput, ListJobsError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn into_paginator(self) -> ListJobsPaginator
pub fn into_paginator(self) -> ListJobsPaginator
Create a paginator for this request
Paginators are used by calling send().await which returns a PaginationStream.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token, if this is a continuation request.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token, if this is a continuation request.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token, if this is a continuation request.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum size of a list to return.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum size of a list to return.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The maximum size of a list to return.
Adds a key-value pair to Tags.
To override the contents of this collection use set_tags.
Specifies to return only these tagged resources.
Specifies to return only these tagged resources.
Specifies to return only these tagged resources.