#[non_exhaustive]pub struct ListJobsOutputBuilder { /* private fields */ }Expand description
A builder for ListJobsOutput.
Implementations
Sourceimpl ListJobsOutputBuilder
impl ListJobsOutputBuilder
Sourcepub fn job_names(self, input: impl Into<String>) -> Self
pub fn job_names(self, input: impl Into<String>) -> Self
Appends an item to job_names.
To override the contents of this collection use set_job_names.
The names of all jobs in the account, or the jobs with the specified tags.
Sourcepub fn set_job_names(self, input: Option<Vec<String>>) -> Self
pub fn set_job_names(self, input: Option<Vec<String>>) -> Self
The names of all jobs in the account, or the jobs with the specified tags.
Sourcepub fn get_job_names(&self) -> &Option<Vec<String>>
pub fn get_job_names(&self) -> &Option<Vec<String>>
The names of all jobs in the account, or the jobs with the specified tags.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token, if the returned list does not contain the last metric available.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token, if the returned list does not contain the last metric available.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token, if the returned list does not contain the last metric available.
Sourcepub fn build(self) -> ListJobsOutput
pub fn build(self) -> ListJobsOutput
Consumes the builder and constructs a ListJobsOutput.