pub struct ListJobsPaginatorItems(/* private fields */);Expand description
Flattened paginator for ListJobsPaginator
This is created with .items()
Implementations
Sourceimpl ListJobsPaginatorItems
impl ListJobsPaginatorItems
Sourcepub fn send(
self,
) -> PaginationStream<Result<String, SdkError<ListJobsError, HttpResponse>>>
pub fn send( self, ) -> PaginationStream<Result<String, SdkError<ListJobsError, HttpResponse>>>
Create the pagination stream
Note: No requests will be dispatched until the stream is used
(e.g. with the .next().await method).
To read the entirety of the paginator, use .collect::<Result<Vec<_>, _>().