pub struct ListRegistriesFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to ListRegistries.
Returns a list of registries that you have created, with minimal registry information. Registries in the Deleting status will not be included in the results. Empty results will be returned if there are no registries available.
Implementations
Sourceimpl ListRegistriesFluentBuilder
impl ListRegistriesFluentBuilder
Sourcepub fn as_input(&self) -> &ListRegistriesInputBuilder
pub fn as_input(&self) -> &ListRegistriesInputBuilder
Access the ListRegistries as a reference.
Sourcepub async fn send(
self,
) -> Result<ListRegistriesOutput, SdkError<ListRegistriesError, HttpResponse>>
pub async fn send( self, ) -> Result<ListRegistriesOutput, SdkError<ListRegistriesError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<ListRegistriesOutput, ListRegistriesError, Self>
pub fn customize( self, ) -> CustomizableOperation<ListRegistriesOutput, ListRegistriesError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn into_paginator(self) -> ListRegistriesPaginator
pub fn into_paginator(self) -> ListRegistriesPaginator
Create a paginator for this request
Paginators are used by calling send().await which returns a PaginationStream.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
Maximum number of results required per page. If the value is not supplied, this will be defaulted to 25 per page.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
Maximum number of results required per page. If the value is not supplied, this will be defaulted to 25 per page.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
Maximum number of results required per page. If the value is not supplied, this will be defaulted to 25 per page.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token, if this is a continuation call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token, if this is a continuation call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token, if this is a continuation call.