#[non_exhaustive]pub struct ListRegistriesOutputBuilder { /* private fields */ }Expand description
A builder for ListRegistriesOutput.
Implementations
Sourceimpl ListRegistriesOutputBuilder
impl ListRegistriesOutputBuilder
Sourcepub fn registries(self, input: RegistryListItem) -> Self
pub fn registries(self, input: RegistryListItem) -> Self
Appends an item to registries.
To override the contents of this collection use set_registries.
An array of RegistryDetailedListItem objects containing minimal details of each registry.
Sourcepub fn set_registries(self, input: Option<Vec<RegistryListItem>>) -> Self
pub fn set_registries(self, input: Option<Vec<RegistryListItem>>) -> Self
An array of RegistryDetailedListItem objects containing minimal details of each registry.
Sourcepub fn get_registries(&self) -> &Option<Vec<RegistryListItem>>
pub fn get_registries(&self) -> &Option<Vec<RegistryListItem>>
An array of RegistryDetailedListItem objects containing minimal details of each registry.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token for paginating the returned list of tokens, returned if the current segment of the list is not the last.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token for paginating the returned list of tokens, returned if the current segment of the list is not the last.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token for paginating the returned list of tokens, returned if the current segment of the list is not the last.
Sourcepub fn build(self) -> ListRegistriesOutput
pub fn build(self) -> ListRegistriesOutput
Consumes the builder and constructs a ListRegistriesOutput.