#[non_exhaustive]pub struct ListSchemaVersionsOutputBuilder { /* private fields */ }Expand description
A builder for ListSchemaVersionsOutput.
Implementations
Sourceimpl ListSchemaVersionsOutputBuilder
impl ListSchemaVersionsOutputBuilder
Sourcepub fn schemas(self, input: SchemaVersionListItem) -> Self
pub fn schemas(self, input: SchemaVersionListItem) -> Self
Appends an item to schemas.
To override the contents of this collection use set_schemas.
An array of SchemaVersionList objects containing details of each schema version.
Sourcepub fn set_schemas(self, input: Option<Vec<SchemaVersionListItem>>) -> Self
pub fn set_schemas(self, input: Option<Vec<SchemaVersionListItem>>) -> Self
An array of SchemaVersionList objects containing details of each schema version.
Sourcepub fn get_schemas(&self) -> &Option<Vec<SchemaVersionListItem>>
pub fn get_schemas(&self) -> &Option<Vec<SchemaVersionListItem>>
An array of SchemaVersionList objects containing details of each schema version.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token for paginating the returned list of tokens, returned if the current segment of the list is not the last.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token for paginating the returned list of tokens, returned if the current segment of the list is not the last.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token for paginating the returned list of tokens, returned if the current segment of the list is not the last.
Sourcepub fn build(self) -> ListSchemaVersionsOutput
pub fn build(self) -> ListSchemaVersionsOutput
Consumes the builder and constructs a ListSchemaVersionsOutput.