#[non_exhaustive]pub struct ListSchemaVersionsInput {
pub schema_id: Option<SchemaId>,
pub max_results: Option<i32>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.schema_id: Option<SchemaId>This is a wrapper structure to contain schema identity fields. The structure contains:
-
SchemaId$SchemaArn: The Amazon Resource Name (ARN) of the schema. Either
SchemaArnorSchemaNameandRegistryNamehas to be provided. -
SchemaId$SchemaName: The name of the schema. Either
SchemaArnorSchemaNameandRegistryNamehas to be provided.
max_results: Option<i32>Maximum number of results required per page. If the value is not supplied, this will be defaulted to 25 per page.
next_token: Option<String>A continuation token, if this is a continuation call.
Implementations
Sourceimpl ListSchemaVersionsInput
impl ListSchemaVersionsInput
Sourcepub fn schema_id(&self) -> Option<&SchemaId>
pub fn schema_id(&self) -> Option<&SchemaId>
This is a wrapper structure to contain schema identity fields. The structure contains:
-
SchemaId$SchemaArn: The Amazon Resource Name (ARN) of the schema. Either
SchemaArnorSchemaNameandRegistryNamehas to be provided. -
SchemaId$SchemaName: The name of the schema. Either
SchemaArnorSchemaNameandRegistryNamehas to be provided.
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
Maximum number of results required per page. If the value is not supplied, this will be defaulted to 25 per page.
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A continuation token, if this is a continuation call.
Sourceimpl ListSchemaVersionsInput
impl ListSchemaVersionsInput
Sourcepub fn builder() -> ListSchemaVersionsInputBuilder
pub fn builder() -> ListSchemaVersionsInputBuilder
Creates a new builder-style object to manufacture ListSchemaVersionsInput.