#[non_exhaustive]pub struct ListSchemasInputBuilder { /* private fields */ }Expand description
A builder for ListSchemasInput.
Implementations
Sourceimpl ListSchemasInputBuilder
impl ListSchemasInputBuilder
Sourcepub fn registry_id(self, input: RegistryId) -> Self
pub fn registry_id(self, input: RegistryId) -> Self
A wrapper structure that may contain the registry name and Amazon Resource Name (ARN).
Sourcepub fn set_registry_id(self, input: Option<RegistryId>) -> Self
pub fn set_registry_id(self, input: Option<RegistryId>) -> Self
A wrapper structure that may contain the registry name and Amazon Resource Name (ARN).
Sourcepub fn get_registry_id(&self) -> &Option<RegistryId>
pub fn get_registry_id(&self) -> &Option<RegistryId>
A wrapper structure that may contain the registry name and Amazon Resource Name (ARN).
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
Maximum number of results required per page. If the value is not supplied, this will be defaulted to 25 per page.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
Maximum number of results required per page. If the value is not supplied, this will be defaulted to 25 per page.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
Maximum number of results required per page. If the value is not supplied, this will be defaulted to 25 per page.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token, if this is a continuation call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token, if this is a continuation call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token, if this is a continuation call.
Sourcepub fn build(self) -> Result<ListSchemasInput, BuildError>
pub fn build(self) -> Result<ListSchemasInput, BuildError>
Consumes the builder and constructs a ListSchemasInput.
Sourceimpl ListSchemasInputBuilder
impl ListSchemasInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<ListSchemasOutput, SdkError<ListSchemasError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<ListSchemasOutput, SdkError<ListSchemasError, HttpResponse>>
Sends a request with this input using the given client.