#[non_exhaustive]pub struct ListSchemasOutputBuilder { /* private fields */ }Expand description
A builder for ListSchemasOutput.
Implementations
Sourceimpl ListSchemasOutputBuilder
impl ListSchemasOutputBuilder
Sourcepub fn schemas(self, input: SchemaListItem) -> Self
pub fn schemas(self, input: SchemaListItem) -> Self
Appends an item to schemas.
To override the contents of this collection use set_schemas.
An array of SchemaListItem objects containing details of each schema.
Sourcepub fn set_schemas(self, input: Option<Vec<SchemaListItem>>) -> Self
pub fn set_schemas(self, input: Option<Vec<SchemaListItem>>) -> Self
An array of SchemaListItem objects containing details of each schema.
Sourcepub fn get_schemas(&self) -> &Option<Vec<SchemaListItem>>
pub fn get_schemas(&self) -> &Option<Vec<SchemaListItem>>
An array of SchemaListItem objects containing details of each schema.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token for paginating the returned list of tokens, returned if the current segment of the list is not the last.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token for paginating the returned list of tokens, returned if the current segment of the list is not the last.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token for paginating the returned list of tokens, returned if the current segment of the list is not the last.
Sourcepub fn build(self) -> ListSchemasOutput
pub fn build(self) -> ListSchemasOutput
Consumes the builder and constructs a ListSchemasOutput.