pub struct ListSchemasPaginatorItems(/* private fields */);Expand description
Flattened paginator for ListSchemasPaginator
This is created with .items()
Implementations
Sourceimpl ListSchemasPaginatorItems
impl ListSchemasPaginatorItems
Sourcepub fn send(
self,
) -> PaginationStream<Result<SchemaListItem, SdkError<ListSchemasError, HttpResponse>>>
pub fn send( self, ) -> PaginationStream<Result<SchemaListItem, SdkError<ListSchemasError, HttpResponse>>>
Create the pagination stream
Note: No requests will be dispatched until the stream is used
(e.g. with the .next().await method).
To read the entirety of the paginator, use .collect::<Result<Vec<_>, _>().