#[non_exhaustive]pub struct ListSessionsOutputBuilder { /* private fields */ }Expand description
A builder for ListSessionsOutput.
Implementations
Sourceimpl ListSessionsOutputBuilder
impl ListSessionsOutputBuilder
Sourcepub fn ids(self, input: impl Into<String>) -> Self
pub fn ids(self, input: impl Into<String>) -> Self
Appends an item to ids.
To override the contents of this collection use set_ids.
Returns the ID of the session.
Sourcepub fn sessions(self, input: Session) -> Self
pub fn sessions(self, input: Session) -> Self
Appends an item to sessions.
To override the contents of this collection use set_sessions.
Returns the session object.
Sourcepub fn set_sessions(self, input: Option<Vec<Session>>) -> Self
pub fn set_sessions(self, input: Option<Vec<Session>>) -> Self
Returns the session object.
Sourcepub fn get_sessions(&self) -> &Option<Vec<Session>>
pub fn get_sessions(&self) -> &Option<Vec<Session>>
Returns the session object.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
The token for the next set of results, or null if there are no more result.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
The token for the next set of results, or null if there are no more result.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
The token for the next set of results, or null if there are no more result.
Sourcepub fn build(self) -> ListSessionsOutput
pub fn build(self) -> ListSessionsOutput
Consumes the builder and constructs a ListSessionsOutput.