#[non_exhaustive]pub struct ListSessionsInput {
pub next_token: Option<String>,
pub max_results: Option<i32>,
pub tags: Option<HashMap<String, String>>,
pub request_origin: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.next_token: Option<String>The token for the next set of results, or null if there are no more result.
max_results: Option<i32>The maximum number of results.
Tags belonging to the session.
request_origin: Option<String>The origin of the request.
Implementations
Sourceimpl ListSessionsInput
impl ListSessionsInput
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
The token for the next set of results, or null if there are no more result.
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
The maximum number of results.
Tags belonging to the session.
Sourcepub fn request_origin(&self) -> Option<&str>
pub fn request_origin(&self) -> Option<&str>
The origin of the request.
Sourceimpl ListSessionsInput
impl ListSessionsInput
Sourcepub fn builder() -> ListSessionsInputBuilder
pub fn builder() -> ListSessionsInputBuilder
Creates a new builder-style object to manufacture ListSessionsInput.