#[non_exhaustive]pub struct ListSessionsOutput {
pub ids: Option<Vec<String>>,
pub sessions: Option<Vec<Session>>,
pub next_token: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.ids: Option<Vec<String>>Returns the ID of the session.
sessions: Option<Vec<Session>>Returns the session object.
next_token: Option<String>The token for the next set of results, or null if there are no more result.
Implementations
Sourceimpl ListSessionsOutput
impl ListSessionsOutput
Sourcepub fn ids(&self) -> &[String]
pub fn ids(&self) -> &[String]
Returns the ID of the session.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .ids.is_none().
Sourcepub fn sessions(&self) -> &[Session]
pub fn sessions(&self) -> &[Session]
Returns the session object.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .sessions.is_none().
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
The token for the next set of results, or null if there are no more result.
Sourceimpl ListSessionsOutput
impl ListSessionsOutput
Sourcepub fn builder() -> ListSessionsOutputBuilder
pub fn builder() -> ListSessionsOutputBuilder
Creates a new builder-style object to manufacture ListSessionsOutput.