pub struct ListStatementsFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to ListStatements.
Lists statements for the session.
Implementations
Sourceimpl ListStatementsFluentBuilder
impl ListStatementsFluentBuilder
Sourcepub fn as_input(&self) -> &ListStatementsInputBuilder
pub fn as_input(&self) -> &ListStatementsInputBuilder
Access the ListStatements as a reference.
Sourcepub async fn send(
self,
) -> Result<ListStatementsOutput, SdkError<ListStatementsError, HttpResponse>>
pub async fn send( self, ) -> Result<ListStatementsOutput, SdkError<ListStatementsError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<ListStatementsOutput, ListStatementsError, Self>
pub fn customize( self, ) -> CustomizableOperation<ListStatementsOutput, ListStatementsError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn session_id(self, input: impl Into<String>) -> Self
pub fn session_id(self, input: impl Into<String>) -> Self
The Session ID of the statements.
Sourcepub fn set_session_id(self, input: Option<String>) -> Self
pub fn set_session_id(self, input: Option<String>) -> Self
The Session ID of the statements.
Sourcepub fn get_session_id(&self) -> &Option<String>
pub fn get_session_id(&self) -> &Option<String>
The Session ID of the statements.
Sourcepub fn request_origin(self, input: impl Into<String>) -> Self
pub fn request_origin(self, input: impl Into<String>) -> Self
The origin of the request to list statements.
Sourcepub fn set_request_origin(self, input: Option<String>) -> Self
pub fn set_request_origin(self, input: Option<String>) -> Self
The origin of the request to list statements.
Sourcepub fn get_request_origin(&self) -> &Option<String>
pub fn get_request_origin(&self) -> &Option<String>
The origin of the request to list statements.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token, if this is a continuation call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token, if this is a continuation call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token, if this is a continuation call.