#[non_exhaustive]pub struct ListStatementsInput {
pub session_id: Option<String>,
pub request_origin: Option<String>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.session_id: Option<String>The Session ID of the statements.
request_origin: Option<String>The origin of the request to list statements.
next_token: Option<String>A continuation token, if this is a continuation call.
Implementations
Sourceimpl ListStatementsInput
impl ListStatementsInput
Sourcepub fn session_id(&self) -> Option<&str>
pub fn session_id(&self) -> Option<&str>
The Session ID of the statements.
Sourcepub fn request_origin(&self) -> Option<&str>
pub fn request_origin(&self) -> Option<&str>
The origin of the request to list statements.
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A continuation token, if this is a continuation call.
Sourceimpl ListStatementsInput
impl ListStatementsInput
Sourcepub fn builder() -> ListStatementsInputBuilder
pub fn builder() -> ListStatementsInputBuilder
Creates a new builder-style object to manufacture ListStatementsInput.