#[non_exhaustive]pub struct ListTableOptimizerRunsInputBuilder { /* private fields */ }Expand description
A builder for ListTableOptimizerRunsInput.
Implementations
Sourceimpl ListTableOptimizerRunsInputBuilder
impl ListTableOptimizerRunsInputBuilder
Sourcepub fn catalog_id(self, input: impl Into<String>) -> Self
pub fn catalog_id(self, input: impl Into<String>) -> Self
The Catalog ID of the table.
This field is required.Sourcepub fn set_catalog_id(self, input: Option<String>) -> Self
pub fn set_catalog_id(self, input: Option<String>) -> Self
The Catalog ID of the table.
Sourcepub fn get_catalog_id(&self) -> &Option<String>
pub fn get_catalog_id(&self) -> &Option<String>
The Catalog ID of the table.
Sourcepub fn database_name(self, input: impl Into<String>) -> Self
pub fn database_name(self, input: impl Into<String>) -> Self
The name of the database in the catalog in which the table resides.
This field is required.Sourcepub fn set_database_name(self, input: Option<String>) -> Self
pub fn set_database_name(self, input: Option<String>) -> Self
The name of the database in the catalog in which the table resides.
Sourcepub fn get_database_name(&self) -> &Option<String>
pub fn get_database_name(&self) -> &Option<String>
The name of the database in the catalog in which the table resides.
Sourcepub fn table_name(self, input: impl Into<String>) -> Self
pub fn table_name(self, input: impl Into<String>) -> Self
The name of the table.
This field is required.Sourcepub fn set_table_name(self, input: Option<String>) -> Self
pub fn set_table_name(self, input: Option<String>) -> Self
The name of the table.
Sourcepub fn get_table_name(&self) -> &Option<String>
pub fn get_table_name(&self) -> &Option<String>
The name of the table.
Sourcepub fn type(self, input: TableOptimizerType) -> Self
pub fn type(self, input: TableOptimizerType) -> Self
The type of table optimizer.
This field is required.Sourcepub fn set_type(self, input: Option<TableOptimizerType>) -> Self
pub fn set_type(self, input: Option<TableOptimizerType>) -> Self
The type of table optimizer.
Sourcepub fn get_type(&self) -> &Option<TableOptimizerType>
pub fn get_type(&self) -> &Option<TableOptimizerType>
The type of table optimizer.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum number of optimizer runs to return on each call.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum number of optimizer runs to return on each call.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The maximum number of optimizer runs to return on each call.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token, if this is a continuation call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token, if this is a continuation call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token, if this is a continuation call.
Sourcepub fn build(self) -> Result<ListTableOptimizerRunsInput, BuildError>
pub fn build(self) -> Result<ListTableOptimizerRunsInput, BuildError>
Consumes the builder and constructs a ListTableOptimizerRunsInput.
Sourceimpl ListTableOptimizerRunsInputBuilder
impl ListTableOptimizerRunsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<ListTableOptimizerRunsOutput, SdkError<ListTableOptimizerRunsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<ListTableOptimizerRunsOutput, SdkError<ListTableOptimizerRunsError, HttpResponse>>
Sends a request with this input using the given client.