#[non_exhaustive]pub struct ListTriggersOutputBuilder { /* private fields */ }Expand description
A builder for ListTriggersOutput.
Implementations
Sourceimpl ListTriggersOutputBuilder
impl ListTriggersOutputBuilder
Sourcepub fn trigger_names(self, input: impl Into<String>) -> Self
pub fn trigger_names(self, input: impl Into<String>) -> Self
Appends an item to trigger_names.
To override the contents of this collection use set_trigger_names.
The names of all triggers in the account, or the triggers with the specified tags.
Sourcepub fn set_trigger_names(self, input: Option<Vec<String>>) -> Self
pub fn set_trigger_names(self, input: Option<Vec<String>>) -> Self
The names of all triggers in the account, or the triggers with the specified tags.
Sourcepub fn get_trigger_names(&self) -> &Option<Vec<String>>
pub fn get_trigger_names(&self) -> &Option<Vec<String>>
The names of all triggers in the account, or the triggers with the specified tags.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token, if the returned list does not contain the last metric available.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token, if the returned list does not contain the last metric available.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token, if the returned list does not contain the last metric available.
Sourcepub fn build(self) -> ListTriggersOutput
pub fn build(self) -> ListTriggersOutput
Consumes the builder and constructs a ListTriggersOutput.