pub struct ListTriggersPaginatorItems(/* private fields */);Expand description
Flattened paginator for ListTriggersPaginator
This is created with .items()
Implementations
Sourceimpl ListTriggersPaginatorItems
impl ListTriggersPaginatorItems
Sourcepub fn send(
self,
) -> PaginationStream<Result<String, SdkError<ListTriggersError, HttpResponse>>>
pub fn send( self, ) -> PaginationStream<Result<String, SdkError<ListTriggersError, HttpResponse>>>
Create the pagination stream
Note: No requests will be dispatched until the stream is used
(e.g. with the .next().await method).
To read the entirety of the paginator, use .collect::<Result<Vec<_>, _>().