pub struct ListUsageProfilesFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to ListUsageProfiles.
List all the Glue usage profiles.
Implementations
Sourceimpl ListUsageProfilesFluentBuilder
impl ListUsageProfilesFluentBuilder
Sourcepub fn as_input(&self) -> &ListUsageProfilesInputBuilder
pub fn as_input(&self) -> &ListUsageProfilesInputBuilder
Access the ListUsageProfiles as a reference.
Sourcepub async fn send(
self,
) -> Result<ListUsageProfilesOutput, SdkError<ListUsageProfilesError, HttpResponse>>
pub async fn send( self, ) -> Result<ListUsageProfilesOutput, SdkError<ListUsageProfilesError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<ListUsageProfilesOutput, ListUsageProfilesError, Self>
pub fn customize( self, ) -> CustomizableOperation<ListUsageProfilesOutput, ListUsageProfilesError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn into_paginator(self) -> ListUsageProfilesPaginator
pub fn into_paginator(self) -> ListUsageProfilesPaginator
Create a paginator for this request
Paginators are used by calling send().await which returns a PaginationStream.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token, included if this is a continuation call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token, included if this is a continuation call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token, included if this is a continuation call.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum number of usage profiles to return in a single response.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum number of usage profiles to return in a single response.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The maximum number of usage profiles to return in a single response.