#[non_exhaustive]pub struct ListUsageProfilesInputBuilder { /* private fields */ }Expand description
A builder for ListUsageProfilesInput.
Implementations
Sourceimpl ListUsageProfilesInputBuilder
impl ListUsageProfilesInputBuilder
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token, included if this is a continuation call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token, included if this is a continuation call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token, included if this is a continuation call.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum number of usage profiles to return in a single response.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum number of usage profiles to return in a single response.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The maximum number of usage profiles to return in a single response.
Sourcepub fn build(self) -> Result<ListUsageProfilesInput, BuildError>
pub fn build(self) -> Result<ListUsageProfilesInput, BuildError>
Consumes the builder and constructs a ListUsageProfilesInput.
Sourceimpl ListUsageProfilesInputBuilder
impl ListUsageProfilesInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<ListUsageProfilesOutput, SdkError<ListUsageProfilesError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<ListUsageProfilesOutput, SdkError<ListUsageProfilesError, HttpResponse>>
Sends a request with this input using the given client.