#[non_exhaustive]pub struct ListUsageProfilesOutputBuilder { /* private fields */ }Expand description
A builder for ListUsageProfilesOutput.
Implementations
Sourceimpl ListUsageProfilesOutputBuilder
impl ListUsageProfilesOutputBuilder
Sourcepub fn profiles(self, input: UsageProfileDefinition) -> Self
pub fn profiles(self, input: UsageProfileDefinition) -> Self
Appends an item to profiles.
To override the contents of this collection use set_profiles.
A list of usage profile (UsageProfileDefinition) objects.
Sourcepub fn set_profiles(self, input: Option<Vec<UsageProfileDefinition>>) -> Self
pub fn set_profiles(self, input: Option<Vec<UsageProfileDefinition>>) -> Self
A list of usage profile (UsageProfileDefinition) objects.
Sourcepub fn get_profiles(&self) -> &Option<Vec<UsageProfileDefinition>>
pub fn get_profiles(&self) -> &Option<Vec<UsageProfileDefinition>>
A list of usage profile (UsageProfileDefinition) objects.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token, present if the current list segment is not the last.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token, present if the current list segment is not the last.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token, present if the current list segment is not the last.
Sourcepub fn build(self) -> ListUsageProfilesOutput
pub fn build(self) -> ListUsageProfilesOutput
Consumes the builder and constructs a ListUsageProfilesOutput.