#[non_exhaustive]pub struct ListUsageProfilesOutput {
pub profiles: Option<Vec<UsageProfileDefinition>>,
pub next_token: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.profiles: Option<Vec<UsageProfileDefinition>>A list of usage profile (UsageProfileDefinition) objects.
next_token: Option<String>A continuation token, present if the current list segment is not the last.
Implementations
Sourceimpl ListUsageProfilesOutput
impl ListUsageProfilesOutput
Sourcepub fn profiles(&self) -> &[UsageProfileDefinition]
pub fn profiles(&self) -> &[UsageProfileDefinition]
A list of usage profile (UsageProfileDefinition) objects.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .profiles.is_none().
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A continuation token, present if the current list segment is not the last.
Sourceimpl ListUsageProfilesOutput
impl ListUsageProfilesOutput
Sourcepub fn builder() -> ListUsageProfilesOutputBuilder
pub fn builder() -> ListUsageProfilesOutputBuilder
Creates a new builder-style object to manufacture ListUsageProfilesOutput.