ModifyIntegrationFluentBuilder

Struct ModifyIntegrationFluentBuilder 

pub struct ModifyIntegrationFluentBuilder { /* private fields */ }
Fluent builder constructing a request to ModifyIntegration.

Modifies a Zero-ETL integration in the caller's account.

Implementations

Source

impl ModifyIntegrationFluentBuilder

pub fn as_input(&self) -> &ModifyIntegrationInputBuilder

Access the ModifyIntegration as a reference.

pub async fn send( self, ) -> Result<ModifyIntegrationOutput, SdkError<ModifyIntegrationError, HttpResponse>>

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

pub fn customize( self, ) -> CustomizableOperation<ModifyIntegrationOutput, ModifyIntegrationError, Self>

Consumes this builder, creating a customizable operation that can be modified before being sent.

pub fn integration_identifier(self, input: impl Into<String>) -> Self

The Amazon Resource Name (ARN) for the integration.

pub fn set_integration_identifier(self, input: Option<String>) -> Self

The Amazon Resource Name (ARN) for the integration.

pub fn get_integration_identifier(&self) -> &Option<String>

The Amazon Resource Name (ARN) for the integration.

pub fn description(self, input: impl Into<String>) -> Self

A description of the integration.

pub fn set_description(self, input: Option<String>) -> Self

A description of the integration.

pub fn get_description(&self) -> &Option<String>

A description of the integration.

pub fn data_filter(self, input: impl Into<String>) -> Self

Selects source tables for the integration using Maxwell filter syntax.

pub fn set_data_filter(self, input: Option<String>) -> Self

Selects source tables for the integration using Maxwell filter syntax.

pub fn get_data_filter(&self) -> &Option<String>

Selects source tables for the integration using Maxwell filter syntax.

pub fn integration_config(self, input: IntegrationConfig) -> Self

The configuration settings for the integration. Currently, only the RefreshInterval can be modified.

pub fn set_integration_config(self, input: Option<IntegrationConfig>) -> Self

The configuration settings for the integration. Currently, only the RefreshInterval can be modified.

pub fn get_integration_config(&self) -> &Option<IntegrationConfig>

The configuration settings for the integration. Currently, only the RefreshInterval can be modified.

pub fn integration_name(self, input: impl Into<String>) -> Self

A unique name for an integration in Glue.

pub fn set_integration_name(self, input: Option<String>) -> Self

A unique name for an integration in Glue.

pub fn get_integration_name(&self) -> &Option<String>

A unique name for an integration in Glue.