#[non_exhaustive]pub struct ModifyIntegrationInput {
pub integration_identifier: Option<String>,
pub description: Option<String>,
pub data_filter: Option<String>,
pub integration_config: Option<IntegrationConfig>,
pub integration_name: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.integration_identifier: Option<String>The Amazon Resource Name (ARN) for the integration.
description: Option<String>A description of the integration.
data_filter: Option<String>Selects source tables for the integration using Maxwell filter syntax.
integration_config: Option<IntegrationConfig>The configuration settings for the integration. Currently, only the RefreshInterval can be modified.
integration_name: Option<String>A unique name for an integration in Glue.
Implementations
Sourceimpl ModifyIntegrationInput
impl ModifyIntegrationInput
Sourcepub fn integration_identifier(&self) -> Option<&str>
pub fn integration_identifier(&self) -> Option<&str>
The Amazon Resource Name (ARN) for the integration.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A description of the integration.
Sourcepub fn data_filter(&self) -> Option<&str>
pub fn data_filter(&self) -> Option<&str>
Selects source tables for the integration using Maxwell filter syntax.
Sourcepub fn integration_config(&self) -> Option<&IntegrationConfig>
pub fn integration_config(&self) -> Option<&IntegrationConfig>
The configuration settings for the integration. Currently, only the RefreshInterval can be modified.
Sourcepub fn integration_name(&self) -> Option<&str>
pub fn integration_name(&self) -> Option<&str>
A unique name for an integration in Glue.
Sourceimpl ModifyIntegrationInput
impl ModifyIntegrationInput
Sourcepub fn builder() -> ModifyIntegrationInputBuilder
pub fn builder() -> ModifyIntegrationInputBuilder
Creates a new builder-style object to manufacture ModifyIntegrationInput.