#[non_exhaustive]pub struct ModifyIntegrationOutput {Show 13 fields
pub source_arn: String,
pub target_arn: String,
pub integration_name: String,
pub description: Option<String>,
pub integration_arn: String,
pub kms_key_id: Option<String>,
pub additional_encryption_context: Option<HashMap<String, String>>,
pub tags: Option<Vec<Tag>>,
pub status: IntegrationStatus,
pub create_time: DateTime,
pub errors: Option<Vec<IntegrationError>>,
pub data_filter: Option<String>,
pub integration_config: Option<IntegrationConfig>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source_arn: StringThe ARN of the source for the integration.
target_arn: StringThe ARN of the target for the integration.
integration_name: StringA unique name for an integration in Glue.
description: Option<String>A description of the integration.
integration_arn: StringThe Amazon Resource Name (ARN) for the integration.
kms_key_id: Option<String>The ARN of a KMS key used for encrypting the channel.
additional_encryption_context: Option<HashMap<String, String>>An optional set of non-secret key–value pairs that contains additional contextual information for encryption.
Metadata assigned to the resource consisting of a list of key-value pairs.
status: IntegrationStatusThe status of the integration being modified.
The possible statuses are:
-
CREATING: The integration is being created.
-
ACTIVE: The integration creation succeeds.
-
MODIFYING: The integration is being modified.
-
FAILED: The integration creation fails.
-
DELETING: The integration is deleted.
-
SYNCING: The integration is synchronizing.
-
NEEDS_ATTENTION: The integration needs attention, such as synchronization.
create_time: DateTimeThe time when the integration was created, in UTC.
errors: Option<Vec<IntegrationError>>A list of errors associated with the integration modification.
data_filter: Option<String>Selects source tables for the integration using Maxwell filter syntax.
integration_config: Option<IntegrationConfig>The updated configuration settings for the integration.
Implementations
Sourceimpl ModifyIntegrationOutput
impl ModifyIntegrationOutput
Sourcepub fn source_arn(&self) -> &str
pub fn source_arn(&self) -> &str
The ARN of the source for the integration.
Sourcepub fn target_arn(&self) -> &str
pub fn target_arn(&self) -> &str
The ARN of the target for the integration.
Sourcepub fn integration_name(&self) -> &str
pub fn integration_name(&self) -> &str
A unique name for an integration in Glue.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A description of the integration.
Sourcepub fn integration_arn(&self) -> &str
pub fn integration_arn(&self) -> &str
The Amazon Resource Name (ARN) for the integration.
Sourcepub fn kms_key_id(&self) -> Option<&str>
pub fn kms_key_id(&self) -> Option<&str>
The ARN of a KMS key used for encrypting the channel.
Sourcepub fn additional_encryption_context(&self) -> Option<&HashMap<String, String>>
pub fn additional_encryption_context(&self) -> Option<&HashMap<String, String>>
An optional set of non-secret key–value pairs that contains additional contextual information for encryption.
Metadata assigned to the resource consisting of a list of key-value pairs.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .tags.is_none().
Sourcepub fn status(&self) -> &IntegrationStatus
pub fn status(&self) -> &IntegrationStatus
The status of the integration being modified.
The possible statuses are:
-
CREATING: The integration is being created.
-
ACTIVE: The integration creation succeeds.
-
MODIFYING: The integration is being modified.
-
FAILED: The integration creation fails.
-
DELETING: The integration is deleted.
-
SYNCING: The integration is synchronizing.
-
NEEDS_ATTENTION: The integration needs attention, such as synchronization.
Sourcepub fn create_time(&self) -> &DateTime
pub fn create_time(&self) -> &DateTime
The time when the integration was created, in UTC.
Sourcepub fn errors(&self) -> &[IntegrationError]
pub fn errors(&self) -> &[IntegrationError]
A list of errors associated with the integration modification.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .errors.is_none().
Sourcepub fn data_filter(&self) -> Option<&str>
pub fn data_filter(&self) -> Option<&str>
Selects source tables for the integration using Maxwell filter syntax.
Sourcepub fn integration_config(&self) -> Option<&IntegrationConfig>
pub fn integration_config(&self) -> Option<&IntegrationConfig>
The updated configuration settings for the integration.
Sourceimpl ModifyIntegrationOutput
impl ModifyIntegrationOutput
Sourcepub fn builder() -> ModifyIntegrationOutputBuilder
pub fn builder() -> ModifyIntegrationOutputBuilder
Creates a new builder-style object to manufacture ModifyIntegrationOutput.