PutAssetFluentBuilder

Struct PutAssetFluentBuilder 

pub struct PutAssetFluentBuilder { /* private fields */ }
Fluent builder constructing a request to PutAsset.

Creates or updates an asset in Glue Data Catalog. If the asset already exists, this operation updates it; otherwise, a new asset is created.

Implementations

Source

impl PutAssetFluentBuilder

pub fn as_input(&self) -> &PutAssetInputBuilder

Access the PutAsset as a reference.

pub async fn send( self, ) -> Result<PutAssetOutput, SdkError<PutAssetError, HttpResponse>>

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

pub fn customize( self, ) -> CustomizableOperation<PutAssetOutput, PutAssetError, Self>

Consumes this builder, creating a customizable operation that can be modified before being sent.

pub fn asset_type_id(self, input: impl Into<String>) -> Self

The identifier of the asset type for the asset.

pub fn set_asset_type_id(self, input: Option<String>) -> Self

The identifier of the asset type for the asset.

pub fn get_asset_type_id(&self) -> &Option<String>

The identifier of the asset type for the asset.

pub fn identifier(self, input: impl Into<String>) -> Self

The unique identifier of the asset. If an asset with this identifier already exists, it is updated.

pub fn set_identifier(self, input: Option<String>) -> Self

The unique identifier of the asset. If an asset with this identifier already exists, it is updated.

pub fn get_identifier(&self) -> &Option<String>

The unique identifier of the asset. If an asset with this identifier already exists, it is updated.

pub fn name(self, input: impl Into<String>) -> Self

The name of the asset.

pub fn set_name(self, input: Option<String>) -> Self

The name of the asset.

pub fn get_name(&self) -> &Option<String>

The name of the asset.

pub fn description(self, input: impl Into<String>) -> Self

The description of the asset.

pub fn set_description(self, input: Option<String>) -> Self

The description of the asset.

pub fn get_description(&self) -> &Option<String>

The description of the asset.

pub fn forms(self, k: impl Into<String>, v: AssetFormEntry) -> Self

Adds a key-value pair to Forms.

To override the contents of this collection use set_forms.

The forms to set on the asset, keyed by form name. Each entry specifies the form type and its JSON content.

pub fn set_forms(self, input: Option<HashMap<String, AssetFormEntry>>) -> Self

The forms to set on the asset, keyed by form name. Each entry specifies the form type and its JSON content.

pub fn get_forms(&self) -> &Option<HashMap<String, AssetFormEntry>>

The forms to set on the asset, keyed by form name. Each entry specifies the form type and its JSON content.

pub fn client_token(self, input: impl Into<String>) -> Self

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

pub fn set_client_token(self, input: Option<String>) -> Self

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

pub fn get_client_token(&self) -> &Option<String>

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.