#[non_exhaustive]pub struct PutAssetInputBuilder { /* private fields */ }Expand description
A builder for PutAssetInput.
Implementations
Sourceimpl PutAssetInputBuilder
impl PutAssetInputBuilder
Sourcepub fn asset_type_id(self, input: impl Into<String>) -> Self
pub fn asset_type_id(self, input: impl Into<String>) -> Self
The identifier of the asset type for the asset.
This field is required.Sourcepub fn set_asset_type_id(self, input: Option<String>) -> Self
pub fn set_asset_type_id(self, input: Option<String>) -> Self
The identifier of the asset type for the asset.
Sourcepub fn get_asset_type_id(&self) -> &Option<String>
pub fn get_asset_type_id(&self) -> &Option<String>
The identifier of the asset type for the asset.
Sourcepub fn identifier(self, input: impl Into<String>) -> Self
pub fn identifier(self, input: impl Into<String>) -> Self
The unique identifier of the asset. If an asset with this identifier already exists, it is updated.
This field is required.Sourcepub fn set_identifier(self, input: Option<String>) -> Self
pub fn set_identifier(self, input: Option<String>) -> Self
The unique identifier of the asset. If an asset with this identifier already exists, it is updated.
Sourcepub fn get_identifier(&self) -> &Option<String>
pub fn get_identifier(&self) -> &Option<String>
The unique identifier of the asset. If an asset with this identifier already exists, it is updated.
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the asset.
This field is required.Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
The description of the asset.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
The description of the asset.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
The description of the asset.
Sourcepub fn forms(self, k: impl Into<String>, v: AssetFormEntry) -> Self
pub fn forms(self, k: impl Into<String>, v: AssetFormEntry) -> Self
Adds a key-value pair to forms.
To override the contents of this collection use set_forms.
The forms to set on the asset, keyed by form name. Each entry specifies the form type and its JSON content.
Sourcepub fn set_forms(self, input: Option<HashMap<String, AssetFormEntry>>) -> Self
pub fn set_forms(self, input: Option<HashMap<String, AssetFormEntry>>) -> Self
The forms to set on the asset, keyed by form name. Each entry specifies the form type and its JSON content.
Sourcepub fn get_forms(&self) -> &Option<HashMap<String, AssetFormEntry>>
pub fn get_forms(&self) -> &Option<HashMap<String, AssetFormEntry>>
The forms to set on the asset, keyed by form name. Each entry specifies the form type and its JSON content.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn build(self) -> Result<PutAssetInput, BuildError>
pub fn build(self) -> Result<PutAssetInput, BuildError>
Consumes the builder and constructs a PutAssetInput.
Sourceimpl PutAssetInputBuilder
impl PutAssetInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<PutAssetOutput, SdkError<PutAssetError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<PutAssetOutput, SdkError<PutAssetError, HttpResponse>>
Sends a request with this input using the given client.