#[non_exhaustive]pub struct PutAssetOutputBuilder { /* private fields */ }Expand description
A builder for PutAssetOutput.
Implementations
Sourceimpl PutAssetOutputBuilder
impl PutAssetOutputBuilder
Sourcepub fn id(self, input: impl Into<String>) -> Self
pub fn id(self, input: impl Into<String>) -> Self
The unique identifier of the asset.
This field is required.Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the asset.
This field is required.Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
The description of the asset.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
The description of the asset.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
The description of the asset.
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
The timestamp at which the asset was created.
Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
The timestamp at which the asset was created.
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
The timestamp at which the asset was created.
Sourcepub fn forms(self, k: impl Into<String>, v: AssetFormEntry) -> Self
pub fn forms(self, k: impl Into<String>, v: AssetFormEntry) -> Self
Adds a key-value pair to forms.
To override the contents of this collection use set_forms.
The forms attached to the asset, keyed by form name.
Sourcepub fn set_forms(self, input: Option<HashMap<String, AssetFormEntry>>) -> Self
pub fn set_forms(self, input: Option<HashMap<String, AssetFormEntry>>) -> Self
The forms attached to the asset, keyed by form name.
Sourcepub fn get_forms(&self) -> &Option<HashMap<String, AssetFormEntry>>
pub fn get_forms(&self) -> &Option<HashMap<String, AssetFormEntry>>
The forms attached to the asset, keyed by form name.
Sourcepub fn build(self) -> Result<PutAssetOutput, BuildError>
pub fn build(self) -> Result<PutAssetOutput, BuildError>
Consumes the builder and constructs a PutAssetOutput.
This method will fail if any of the following fields are not set: