#[non_exhaustive]pub enum PutAssetError {
AccessDeniedException(AccessDeniedException),
ConcurrentModificationException(ConcurrentModificationException),
EntityNotFoundException(EntityNotFoundException),
InternalServiceException(InternalServiceException),
InvalidInputException(InvalidInputException),
ThrottlingException(ThrottlingException),
Unhandled(Unhandled),
}Expand description
Error type for the PutAssetError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AccessDeniedException(AccessDeniedException)
Access to a resource was denied.
ConcurrentModificationException(ConcurrentModificationException)
Two processes are trying to modify a resource simultaneously.
EntityNotFoundException(EntityNotFoundException)
A specified entity does not exist
InternalServiceException(InternalServiceException)
An internal service error occurred.
InvalidInputException(InvalidInputException)
The input provided was not valid.
ThrottlingException(ThrottlingException)
The throttling threshhold was exceeded.
Unhandled(Unhandled)
Matching Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
Sourceimpl PutAssetError
impl PutAssetError
Sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the PutAssetError::Unhandled variant from any error type.
Sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the PutAssetError::Unhandled variant from an ErrorMetadata.
Sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
Sourcepub fn is_access_denied_exception(&self) -> bool
pub fn is_access_denied_exception(&self) -> bool
Returns true if the error kind is PutAssetError::AccessDeniedException.
Sourcepub fn is_concurrent_modification_exception(&self) -> bool
pub fn is_concurrent_modification_exception(&self) -> bool
Returns true if the error kind is PutAssetError::ConcurrentModificationException.
Sourcepub fn is_entity_not_found_exception(&self) -> bool
pub fn is_entity_not_found_exception(&self) -> bool
Returns true if the error kind is PutAssetError::EntityNotFoundException.
Sourcepub fn is_internal_service_exception(&self) -> bool
pub fn is_internal_service_exception(&self) -> bool
Returns true if the error kind is PutAssetError::InternalServiceException.
Sourcepub fn is_invalid_input_exception(&self) -> bool
pub fn is_invalid_input_exception(&self) -> bool
Returns true if the error kind is PutAssetError::InvalidInputException.
Sourcepub fn is_throttling_exception(&self) -> bool
pub fn is_throttling_exception(&self) -> bool
Returns true if the error kind is PutAssetError::ThrottlingException.