#[non_exhaustive]pub struct PutAssetInput {
pub asset_type_id: Option<String>,
pub identifier: Option<String>,
pub name: Option<String>,
pub description: Option<String>,
pub forms: Option<HashMap<String, AssetFormEntry>>,
pub client_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.asset_type_id: Option<String>The identifier of the asset type for the asset.
identifier: Option<String>The unique identifier of the asset. If an asset with this identifier already exists, it is updated.
name: Option<String>The name of the asset.
description: Option<String>The description of the asset.
forms: Option<HashMap<String, AssetFormEntry>>The forms to set on the asset, keyed by form name. Each entry specifies the form type and its JSON content.
client_token: Option<String>A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Implementations
Sourceimpl PutAssetInput
impl PutAssetInput
Sourcepub fn asset_type_id(&self) -> Option<&str>
pub fn asset_type_id(&self) -> Option<&str>
The identifier of the asset type for the asset.
Sourcepub fn identifier(&self) -> Option<&str>
pub fn identifier(&self) -> Option<&str>
The unique identifier of the asset. If an asset with this identifier already exists, it is updated.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The description of the asset.
Sourcepub fn forms(&self) -> Option<&HashMap<String, AssetFormEntry>>
pub fn forms(&self) -> Option<&HashMap<String, AssetFormEntry>>
The forms to set on the asset, keyed by form name. Each entry specifies the form type and its JSON content.
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourceimpl PutAssetInput
impl PutAssetInput
Sourcepub fn builder() -> PutAssetInputBuilder
pub fn builder() -> PutAssetInputBuilder
Creates a new builder-style object to manufacture PutAssetInput.