#[non_exhaustive]pub struct PutAttachmentOutputBuilder { /* private fields */ }Expand description
A builder for PutAttachmentOutput.
Implementations
Sourceimpl PutAttachmentOutputBuilder
impl PutAttachmentOutputBuilder
Sourcepub fn asset_identifier(self, input: impl Into<String>) -> Self
pub fn asset_identifier(self, input: impl Into<String>) -> Self
The unique identifier of the asset.
Sourcepub fn set_asset_identifier(self, input: Option<String>) -> Self
pub fn set_asset_identifier(self, input: Option<String>) -> Self
The unique identifier of the asset.
Sourcepub fn get_asset_identifier(&self) -> &Option<String>
pub fn get_asset_identifier(&self) -> &Option<String>
The unique identifier of the asset.
Sourcepub fn iterable_form_name(self, input: impl Into<String>) -> Self
pub fn iterable_form_name(self, input: impl Into<String>) -> Self
The name of the iterable form, if the attachment targets an item.
Sourcepub fn set_iterable_form_name(self, input: Option<String>) -> Self
pub fn set_iterable_form_name(self, input: Option<String>) -> Self
The name of the iterable form, if the attachment targets an item.
Sourcepub fn get_iterable_form_name(&self) -> &Option<String>
pub fn get_iterable_form_name(&self) -> &Option<String>
The name of the iterable form, if the attachment targets an item.
Sourcepub fn item_identifier(self, input: impl Into<String>) -> Self
pub fn item_identifier(self, input: impl Into<String>) -> Self
The identifier of the item within the iterable form, if applicable.
Sourcepub fn set_item_identifier(self, input: Option<String>) -> Self
pub fn set_item_identifier(self, input: Option<String>) -> Self
The identifier of the item within the iterable form, if applicable.
Sourcepub fn get_item_identifier(&self) -> &Option<String>
pub fn get_item_identifier(&self) -> &Option<String>
The identifier of the item within the iterable form, if applicable.
Sourcepub fn attachment_name(self, input: impl Into<String>) -> Self
pub fn attachment_name(self, input: impl Into<String>) -> Self
The name of the attachment.
Sourcepub fn set_attachment_name(self, input: Option<String>) -> Self
pub fn set_attachment_name(self, input: Option<String>) -> Self
The name of the attachment.
Sourcepub fn get_attachment_name(&self) -> &Option<String>
pub fn get_attachment_name(&self) -> &Option<String>
The name of the attachment.
Sourcepub fn form_type_id(self, input: impl Into<String>) -> Self
pub fn form_type_id(self, input: impl Into<String>) -> Self
The identifier of the form type for this attachment.
Sourcepub fn set_form_type_id(self, input: Option<String>) -> Self
pub fn set_form_type_id(self, input: Option<String>) -> Self
The identifier of the form type for this attachment.
Sourcepub fn get_form_type_id(&self) -> &Option<String>
pub fn get_form_type_id(&self) -> &Option<String>
The identifier of the form type for this attachment.
Sourcepub fn build(self) -> PutAttachmentOutput
pub fn build(self) -> PutAttachmentOutput
Consumes the builder and constructs a PutAttachmentOutput.