#[non_exhaustive]pub struct PutAttachmentInput {
pub asset_identifier: Option<String>,
pub iterable_form_name: Option<String>,
pub item_identifier: Option<String>,
pub attachment_name: Option<String>,
pub content: Option<String>,
pub form_type_id: Option<String>,
pub client_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.asset_identifier: Option<String>The unique identifier of the asset to attach the form to.
iterable_form_name: Option<String>The name of the iterable form. When specified along with itemIdentifier, the attachment targets an item within the iterable form rather than the asset itself.
item_identifier: Option<String>The identifier of the item within the iterable form. Required when iterableFormName is specified.
attachment_name: Option<String>The name of the attachment.
content: Option<String>The JSON content of the form, conforming to the schema of the specified form type.
form_type_id: Option<String>The identifier of the form type for this attachment.
client_token: Option<String>A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Implementations
Sourceimpl PutAttachmentInput
impl PutAttachmentInput
Sourcepub fn asset_identifier(&self) -> Option<&str>
pub fn asset_identifier(&self) -> Option<&str>
The unique identifier of the asset to attach the form to.
Sourcepub fn iterable_form_name(&self) -> Option<&str>
pub fn iterable_form_name(&self) -> Option<&str>
The name of the iterable form. When specified along with itemIdentifier, the attachment targets an item within the iterable form rather than the asset itself.
Sourcepub fn item_identifier(&self) -> Option<&str>
pub fn item_identifier(&self) -> Option<&str>
The identifier of the item within the iterable form. Required when iterableFormName is specified.
Sourcepub fn attachment_name(&self) -> Option<&str>
pub fn attachment_name(&self) -> Option<&str>
The name of the attachment.
Sourcepub fn content(&self) -> Option<&str>
pub fn content(&self) -> Option<&str>
The JSON content of the form, conforming to the schema of the specified form type.
Sourcepub fn form_type_id(&self) -> Option<&str>
pub fn form_type_id(&self) -> Option<&str>
The identifier of the form type for this attachment.
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourceimpl PutAttachmentInput
impl PutAttachmentInput
Sourcepub fn builder() -> PutAttachmentInputBuilder
pub fn builder() -> PutAttachmentInputBuilder
Creates a new builder-style object to manufacture PutAttachmentInput.