#[non_exhaustive]pub struct PutAttachmentOutput {
pub asset_identifier: Option<String>,
pub iterable_form_name: Option<String>,
pub item_identifier: Option<String>,
pub attachment_name: Option<String>,
pub form_type_id: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.asset_identifier: Option<String>The unique identifier of the asset.
iterable_form_name: Option<String>The name of the iterable form, if the attachment targets an item.
item_identifier: Option<String>The identifier of the item within the iterable form, if applicable.
attachment_name: Option<String>The name of the attachment.
form_type_id: Option<String>The identifier of the form type for this attachment.
Implementations
Sourceimpl PutAttachmentOutput
impl PutAttachmentOutput
Sourcepub fn asset_identifier(&self) -> Option<&str>
pub fn asset_identifier(&self) -> Option<&str>
The unique identifier of the asset.
Sourcepub fn iterable_form_name(&self) -> Option<&str>
pub fn iterable_form_name(&self) -> Option<&str>
The name of the iterable form, if the attachment targets an item.
Sourcepub fn item_identifier(&self) -> Option<&str>
pub fn item_identifier(&self) -> Option<&str>
The identifier of the item within the iterable form, if applicable.
Sourcepub fn attachment_name(&self) -> Option<&str>
pub fn attachment_name(&self) -> Option<&str>
The name of the attachment.
Sourcepub fn form_type_id(&self) -> Option<&str>
pub fn form_type_id(&self) -> Option<&str>
The identifier of the form type for this attachment.
Sourceimpl PutAttachmentOutput
impl PutAttachmentOutput
Sourcepub fn builder() -> PutAttachmentOutputBuilder
pub fn builder() -> PutAttachmentOutputBuilder
Creates a new builder-style object to manufacture PutAttachmentOutput.