#[non_exhaustive]pub struct PutDataQualityProfileAnnotationInput {
pub profile_id: Option<String>,
pub inclusion_annotation: Option<InclusionAnnotationValue>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.profile_id: Option<String>The ID of the data quality monitoring profile to annotate.
inclusion_annotation: Option<InclusionAnnotationValue>The inclusion annotation value to apply to the profile.
Implementations
Sourceimpl PutDataQualityProfileAnnotationInput
impl PutDataQualityProfileAnnotationInput
Sourcepub fn profile_id(&self) -> Option<&str>
pub fn profile_id(&self) -> Option<&str>
The ID of the data quality monitoring profile to annotate.
Sourcepub fn inclusion_annotation(&self) -> Option<&InclusionAnnotationValue>
pub fn inclusion_annotation(&self) -> Option<&InclusionAnnotationValue>
The inclusion annotation value to apply to the profile.
Sourceimpl PutDataQualityProfileAnnotationInput
impl PutDataQualityProfileAnnotationInput
Sourcepub fn builder() -> PutDataQualityProfileAnnotationInputBuilder
pub fn builder() -> PutDataQualityProfileAnnotationInputBuilder
Creates a new builder-style object to manufacture PutDataQualityProfileAnnotationInput.