#[non_exhaustive]pub struct PutResourcePolicyOutput {
pub policy_hash: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.policy_hash: Option<String>A hash of the policy that has just been set. This must be included in a subsequent call that overwrites or updates this policy.
Implementations
Sourceimpl PutResourcePolicyOutput
impl PutResourcePolicyOutput
Sourcepub fn policy_hash(&self) -> Option<&str>
pub fn policy_hash(&self) -> Option<&str>
A hash of the policy that has just been set. This must be included in a subsequent call that overwrites or updates this policy.
Sourceimpl PutResourcePolicyOutput
impl PutResourcePolicyOutput
Sourcepub fn builder() -> PutResourcePolicyOutputBuilder
pub fn builder() -> PutResourcePolicyOutputBuilder
Creates a new builder-style object to manufacture PutResourcePolicyOutput.