pub struct PutSchemaVersionMetadataFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to PutSchemaVersionMetadata.
Puts the metadata key value pair for a specified schema version ID. A maximum of 10 key value pairs will be allowed per schema version. They can be added over one or more calls.
Implementations
Sourceimpl PutSchemaVersionMetadataFluentBuilder
impl PutSchemaVersionMetadataFluentBuilder
Sourcepub fn as_input(&self) -> &PutSchemaVersionMetadataInputBuilder
pub fn as_input(&self) -> &PutSchemaVersionMetadataInputBuilder
Access the PutSchemaVersionMetadata as a reference.
Sourcepub async fn send(
self,
) -> Result<PutSchemaVersionMetadataOutput, SdkError<PutSchemaVersionMetadataError, HttpResponse>>
pub async fn send( self, ) -> Result<PutSchemaVersionMetadataOutput, SdkError<PutSchemaVersionMetadataError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<PutSchemaVersionMetadataOutput, PutSchemaVersionMetadataError, Self>
pub fn customize( self, ) -> CustomizableOperation<PutSchemaVersionMetadataOutput, PutSchemaVersionMetadataError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn set_schema_id(self, input: Option<SchemaId>) -> Self
pub fn set_schema_id(self, input: Option<SchemaId>) -> Self
The unique ID for the schema.
Sourcepub fn get_schema_id(&self) -> &Option<SchemaId>
pub fn get_schema_id(&self) -> &Option<SchemaId>
The unique ID for the schema.
Sourcepub fn schema_version_number(self, input: SchemaVersionNumber) -> Self
pub fn schema_version_number(self, input: SchemaVersionNumber) -> Self
The version number of the schema.
Sourcepub fn set_schema_version_number(
self,
input: Option<SchemaVersionNumber>,
) -> Self
pub fn set_schema_version_number( self, input: Option<SchemaVersionNumber>, ) -> Self
The version number of the schema.
Sourcepub fn get_schema_version_number(&self) -> &Option<SchemaVersionNumber>
pub fn get_schema_version_number(&self) -> &Option<SchemaVersionNumber>
The version number of the schema.
Sourcepub fn schema_version_id(self, input: impl Into<String>) -> Self
pub fn schema_version_id(self, input: impl Into<String>) -> Self
The unique version ID of the schema version.
Sourcepub fn set_schema_version_id(self, input: Option<String>) -> Self
pub fn set_schema_version_id(self, input: Option<String>) -> Self
The unique version ID of the schema version.
Sourcepub fn get_schema_version_id(&self) -> &Option<String>
pub fn get_schema_version_id(&self) -> &Option<String>
The unique version ID of the schema version.
Sourcepub fn metadata_key_value(self, input: MetadataKeyValuePair) -> Self
pub fn metadata_key_value(self, input: MetadataKeyValuePair) -> Self
The metadata key's corresponding value.
Sourcepub fn set_metadata_key_value(self, input: Option<MetadataKeyValuePair>) -> Self
pub fn set_metadata_key_value(self, input: Option<MetadataKeyValuePair>) -> Self
The metadata key's corresponding value.
Sourcepub fn get_metadata_key_value(&self) -> &Option<MetadataKeyValuePair>
pub fn get_metadata_key_value(&self) -> &Option<MetadataKeyValuePair>
The metadata key's corresponding value.