pub struct PutWorkflowRunPropertiesFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to PutWorkflowRunProperties.
Puts the specified workflow run properties for the given workflow run. If a property already exists for the specified run, then it overrides the value otherwise adds the property to existing properties.
Implementations
Sourceimpl PutWorkflowRunPropertiesFluentBuilder
impl PutWorkflowRunPropertiesFluentBuilder
Sourcepub fn as_input(&self) -> &PutWorkflowRunPropertiesInputBuilder
pub fn as_input(&self) -> &PutWorkflowRunPropertiesInputBuilder
Access the PutWorkflowRunProperties as a reference.
Sourcepub async fn send(
self,
) -> Result<PutWorkflowRunPropertiesOutput, SdkError<PutWorkflowRunPropertiesError, HttpResponse>>
pub async fn send( self, ) -> Result<PutWorkflowRunPropertiesOutput, SdkError<PutWorkflowRunPropertiesError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<PutWorkflowRunPropertiesOutput, PutWorkflowRunPropertiesError, Self>
pub fn customize( self, ) -> CustomizableOperation<PutWorkflowRunPropertiesOutput, PutWorkflowRunPropertiesError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn run_id(self, input: impl Into<String>) -> Self
pub fn run_id(self, input: impl Into<String>) -> Self
The ID of the workflow run for which the run properties should be updated.
Sourcepub fn set_run_id(self, input: Option<String>) -> Self
pub fn set_run_id(self, input: Option<String>) -> Self
The ID of the workflow run for which the run properties should be updated.
Sourcepub fn get_run_id(&self) -> &Option<String>
pub fn get_run_id(&self) -> &Option<String>
The ID of the workflow run for which the run properties should be updated.
Sourcepub fn run_properties(self, k: impl Into<String>, v: impl Into<String>) -> Self
pub fn run_properties(self, k: impl Into<String>, v: impl Into<String>) -> Self
Adds a key-value pair to RunProperties.
To override the contents of this collection use set_run_properties.
The properties to put for the specified run.
Run properties may be logged. Do not pass plaintext secrets as properties. Retrieve secrets from a Glue Connection, Amazon Web Services Secrets Manager or other secret management mechanism if you intend to use them within the workflow run.
Sourcepub fn set_run_properties(self, input: Option<HashMap<String, String>>) -> Self
pub fn set_run_properties(self, input: Option<HashMap<String, String>>) -> Self
The properties to put for the specified run.
Run properties may be logged. Do not pass plaintext secrets as properties. Retrieve secrets from a Glue Connection, Amazon Web Services Secrets Manager or other secret management mechanism if you intend to use them within the workflow run.
Sourcepub fn get_run_properties(&self) -> &Option<HashMap<String, String>>
pub fn get_run_properties(&self) -> &Option<HashMap<String, String>>
The properties to put for the specified run.
Run properties may be logged. Do not pass plaintext secrets as properties. Retrieve secrets from a Glue Connection, Amazon Web Services Secrets Manager or other secret management mechanism if you intend to use them within the workflow run.