#[non_exhaustive]pub struct PutWorkflowRunPropertiesInputBuilder { /* private fields */ }Expand description
A builder for PutWorkflowRunPropertiesInput.
Implementations
Sourceimpl PutWorkflowRunPropertiesInputBuilder
impl PutWorkflowRunPropertiesInputBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
Name of the workflow which was run.
This field is required.Sourcepub fn run_id(self, input: impl Into<String>) -> Self
pub fn run_id(self, input: impl Into<String>) -> Self
The ID of the workflow run for which the run properties should be updated.
This field is required.Sourcepub fn set_run_id(self, input: Option<String>) -> Self
pub fn set_run_id(self, input: Option<String>) -> Self
The ID of the workflow run for which the run properties should be updated.
Sourcepub fn get_run_id(&self) -> &Option<String>
pub fn get_run_id(&self) -> &Option<String>
The ID of the workflow run for which the run properties should be updated.
Sourcepub fn run_properties(self, k: impl Into<String>, v: impl Into<String>) -> Self
pub fn run_properties(self, k: impl Into<String>, v: impl Into<String>) -> Self
Adds a key-value pair to run_properties.
To override the contents of this collection use set_run_properties.
The properties to put for the specified run.
Run properties may be logged. Do not pass plaintext secrets as properties. Retrieve secrets from a Glue Connection, Amazon Web Services Secrets Manager or other secret management mechanism if you intend to use them within the workflow run.
Sourcepub fn set_run_properties(self, input: Option<HashMap<String, String>>) -> Self
pub fn set_run_properties(self, input: Option<HashMap<String, String>>) -> Self
The properties to put for the specified run.
Run properties may be logged. Do not pass plaintext secrets as properties. Retrieve secrets from a Glue Connection, Amazon Web Services Secrets Manager or other secret management mechanism if you intend to use them within the workflow run.
Sourcepub fn get_run_properties(&self) -> &Option<HashMap<String, String>>
pub fn get_run_properties(&self) -> &Option<HashMap<String, String>>
The properties to put for the specified run.
Run properties may be logged. Do not pass plaintext secrets as properties. Retrieve secrets from a Glue Connection, Amazon Web Services Secrets Manager or other secret management mechanism if you intend to use them within the workflow run.
Sourcepub fn build(self) -> Result<PutWorkflowRunPropertiesInput, BuildError>
pub fn build(self) -> Result<PutWorkflowRunPropertiesInput, BuildError>
Consumes the builder and constructs a PutWorkflowRunPropertiesInput.
Sourceimpl PutWorkflowRunPropertiesInputBuilder
impl PutWorkflowRunPropertiesInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<PutWorkflowRunPropertiesOutput, SdkError<PutWorkflowRunPropertiesError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<PutWorkflowRunPropertiesOutput, SdkError<PutWorkflowRunPropertiesError, HttpResponse>>
Sends a request with this input using the given client.