#[non_exhaustive]pub struct PutWorkflowRunPropertiesInput {
pub name: Option<String>,
pub run_id: Option<String>,
pub run_properties: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>Name of the workflow which was run.
run_id: Option<String>The ID of the workflow run for which the run properties should be updated.
run_properties: Option<HashMap<String, String>>The properties to put for the specified run.
Run properties may be logged. Do not pass plaintext secrets as properties. Retrieve secrets from a Glue Connection, Amazon Web Services Secrets Manager or other secret management mechanism if you intend to use them within the workflow run.
Implementations
Sourceimpl PutWorkflowRunPropertiesInput
impl PutWorkflowRunPropertiesInput
Sourcepub fn run_id(&self) -> Option<&str>
pub fn run_id(&self) -> Option<&str>
The ID of the workflow run for which the run properties should be updated.
Sourcepub fn run_properties(&self) -> Option<&HashMap<String, String>>
pub fn run_properties(&self) -> Option<&HashMap<String, String>>
The properties to put for the specified run.
Run properties may be logged. Do not pass plaintext secrets as properties. Retrieve secrets from a Glue Connection, Amazon Web Services Secrets Manager or other secret management mechanism if you intend to use them within the workflow run.
Sourceimpl PutWorkflowRunPropertiesInput
impl PutWorkflowRunPropertiesInput
Sourcepub fn builder() -> PutWorkflowRunPropertiesInputBuilder
pub fn builder() -> PutWorkflowRunPropertiesInputBuilder
Creates a new builder-style object to manufacture PutWorkflowRunPropertiesInput.