#[non_exhaustive]pub struct RegisterSchemaVersionInputBuilder { /* private fields */ }Expand description
A builder for RegisterSchemaVersionInput.
Implementations
Sourceimpl RegisterSchemaVersionInputBuilder
impl RegisterSchemaVersionInputBuilder
Sourcepub fn schema_id(self, input: SchemaId) -> Self
pub fn schema_id(self, input: SchemaId) -> Self
This is a wrapper structure to contain schema identity fields. The structure contains:
-
SchemaId$SchemaArn: The Amazon Resource Name (ARN) of the schema. Either
SchemaArnorSchemaNameandRegistryNamehas to be provided. -
SchemaId$SchemaName: The name of the schema. Either
SchemaArnorSchemaNameandRegistryNamehas to be provided.
Sourcepub fn set_schema_id(self, input: Option<SchemaId>) -> Self
pub fn set_schema_id(self, input: Option<SchemaId>) -> Self
This is a wrapper structure to contain schema identity fields. The structure contains:
-
SchemaId$SchemaArn: The Amazon Resource Name (ARN) of the schema. Either
SchemaArnorSchemaNameandRegistryNamehas to be provided. -
SchemaId$SchemaName: The name of the schema. Either
SchemaArnorSchemaNameandRegistryNamehas to be provided.
Sourcepub fn get_schema_id(&self) -> &Option<SchemaId>
pub fn get_schema_id(&self) -> &Option<SchemaId>
This is a wrapper structure to contain schema identity fields. The structure contains:
-
SchemaId$SchemaArn: The Amazon Resource Name (ARN) of the schema. Either
SchemaArnorSchemaNameandRegistryNamehas to be provided. -
SchemaId$SchemaName: The name of the schema. Either
SchemaArnorSchemaNameandRegistryNamehas to be provided.
Sourcepub fn schema_definition(self, input: impl Into<String>) -> Self
pub fn schema_definition(self, input: impl Into<String>) -> Self
The schema definition using the DataFormat setting for the SchemaName.
Sourcepub fn set_schema_definition(self, input: Option<String>) -> Self
pub fn set_schema_definition(self, input: Option<String>) -> Self
The schema definition using the DataFormat setting for the SchemaName.
Sourcepub fn get_schema_definition(&self) -> &Option<String>
pub fn get_schema_definition(&self) -> &Option<String>
The schema definition using the DataFormat setting for the SchemaName.
Sourcepub fn build(self) -> Result<RegisterSchemaVersionInput, BuildError>
pub fn build(self) -> Result<RegisterSchemaVersionInput, BuildError>
Consumes the builder and constructs a RegisterSchemaVersionInput.
Sourceimpl RegisterSchemaVersionInputBuilder
impl RegisterSchemaVersionInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<RegisterSchemaVersionOutput, SdkError<RegisterSchemaVersionError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<RegisterSchemaVersionOutput, SdkError<RegisterSchemaVersionError, HttpResponse>>
Sends a request with this input using the given client.