#[non_exhaustive]pub struct RegisterSchemaVersionOutputBuilder { /* private fields */ }Expand description
A builder for RegisterSchemaVersionOutput.
Implementations
Sourceimpl RegisterSchemaVersionOutputBuilder
impl RegisterSchemaVersionOutputBuilder
Sourcepub fn schema_version_id(self, input: impl Into<String>) -> Self
pub fn schema_version_id(self, input: impl Into<String>) -> Self
The unique ID that represents the version of this schema.
Sourcepub fn set_schema_version_id(self, input: Option<String>) -> Self
pub fn set_schema_version_id(self, input: Option<String>) -> Self
The unique ID that represents the version of this schema.
Sourcepub fn get_schema_version_id(&self) -> &Option<String>
pub fn get_schema_version_id(&self) -> &Option<String>
The unique ID that represents the version of this schema.
Sourcepub fn version_number(self, input: i64) -> Self
pub fn version_number(self, input: i64) -> Self
The version of this schema (for sync flow only, in case this is the first version).
Sourcepub fn set_version_number(self, input: Option<i64>) -> Self
pub fn set_version_number(self, input: Option<i64>) -> Self
The version of this schema (for sync flow only, in case this is the first version).
Sourcepub fn get_version_number(&self) -> &Option<i64>
pub fn get_version_number(&self) -> &Option<i64>
The version of this schema (for sync flow only, in case this is the first version).
Sourcepub fn status(self, input: SchemaVersionStatus) -> Self
pub fn status(self, input: SchemaVersionStatus) -> Self
The status of the schema version.
Sourcepub fn set_status(self, input: Option<SchemaVersionStatus>) -> Self
pub fn set_status(self, input: Option<SchemaVersionStatus>) -> Self
The status of the schema version.
Sourcepub fn get_status(&self) -> &Option<SchemaVersionStatus>
pub fn get_status(&self) -> &Option<SchemaVersionStatus>
The status of the schema version.
Sourcepub fn build(self) -> RegisterSchemaVersionOutput
pub fn build(self) -> RegisterSchemaVersionOutput
Consumes the builder and constructs a RegisterSchemaVersionOutput.