#[non_exhaustive]pub struct RegisterSchemaVersionInput {
pub schema_id: Option<SchemaId>,
pub schema_definition: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.schema_id: Option<SchemaId>This is a wrapper structure to contain schema identity fields. The structure contains:
-
SchemaId$SchemaArn: The Amazon Resource Name (ARN) of the schema. Either
SchemaArnorSchemaNameandRegistryNamehas to be provided. -
SchemaId$SchemaName: The name of the schema. Either
SchemaArnorSchemaNameandRegistryNamehas to be provided.
schema_definition: Option<String>The schema definition using the DataFormat setting for the SchemaName.
Implementations
Sourceimpl RegisterSchemaVersionInput
impl RegisterSchemaVersionInput
Sourcepub fn schema_id(&self) -> Option<&SchemaId>
pub fn schema_id(&self) -> Option<&SchemaId>
This is a wrapper structure to contain schema identity fields. The structure contains:
-
SchemaId$SchemaArn: The Amazon Resource Name (ARN) of the schema. Either
SchemaArnorSchemaNameandRegistryNamehas to be provided. -
SchemaId$SchemaName: The name of the schema. Either
SchemaArnorSchemaNameandRegistryNamehas to be provided.
Sourcepub fn schema_definition(&self) -> Option<&str>
pub fn schema_definition(&self) -> Option<&str>
The schema definition using the DataFormat setting for the SchemaName.
Sourceimpl RegisterSchemaVersionInput
impl RegisterSchemaVersionInput
Sourcepub fn builder() -> RegisterSchemaVersionInputBuilder
pub fn builder() -> RegisterSchemaVersionInputBuilder
Creates a new builder-style object to manufacture RegisterSchemaVersionInput.