#[non_exhaustive]pub struct SearchAssetsInputBuilder { /* private fields */ }Expand description
A builder for SearchAssetsInput.
Implementations
Sourceimpl SearchAssetsInputBuilder
impl SearchAssetsInputBuilder
Sourcepub fn search_text(self, input: impl Into<String>) -> Self
pub fn search_text(self, input: impl Into<String>) -> Self
The text to search for. At least one of searchText or filterClause must be provided.
Sourcepub fn set_search_text(self, input: Option<String>) -> Self
pub fn set_search_text(self, input: Option<String>) -> Self
The text to search for. At least one of searchText or filterClause must be provided.
Sourcepub fn get_search_text(&self) -> &Option<String>
pub fn get_search_text(&self) -> &Option<String>
The text to search for. At least one of searchText or filterClause must be provided.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum number of results to return in the response.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum number of results to return in the response.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The maximum number of results to return in the response.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token, if this is a continuation call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token, if this is a continuation call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token, if this is a continuation call.
Sourcepub fn sort(self, input: SearchSort) -> Self
pub fn sort(self, input: SearchSort) -> Self
The sort criteria for the search results.
Sourcepub fn set_sort(self, input: Option<SearchSort>) -> Self
pub fn set_sort(self, input: Option<SearchSort>) -> Self
The sort criteria for the search results.
Sourcepub fn get_sort(&self) -> &Option<SearchSort>
pub fn get_sort(&self) -> &Option<SearchSort>
The sort criteria for the search results.
Sourcepub fn filter_clause(self, input: SearchFilterClause) -> Self
pub fn filter_clause(self, input: SearchFilterClause) -> Self
The filter clause to apply to the search. Supports nested AND/OR logic with attribute-level and map-level filters.
Sourcepub fn set_filter_clause(self, input: Option<SearchFilterClause>) -> Self
pub fn set_filter_clause(self, input: Option<SearchFilterClause>) -> Self
The filter clause to apply to the search. Supports nested AND/OR logic with attribute-level and map-level filters.
Sourcepub fn get_filter_clause(&self) -> &Option<SearchFilterClause>
pub fn get_filter_clause(&self) -> &Option<SearchFilterClause>
The filter clause to apply to the search. Supports nested AND/OR logic with attribute-level and map-level filters.
Sourcepub fn build(self) -> Result<SearchAssetsInput, BuildError>
pub fn build(self) -> Result<SearchAssetsInput, BuildError>
Consumes the builder and constructs a SearchAssetsInput.
Sourceimpl SearchAssetsInputBuilder
impl SearchAssetsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<SearchAssetsOutput, SdkError<SearchAssetsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<SearchAssetsOutput, SdkError<SearchAssetsError, HttpResponse>>
Sends a request with this input using the given client.