#[non_exhaustive]pub struct SearchAssetsOutputBuilder { /* private fields */ }Expand description
A builder for SearchAssetsOutput.
Implementations
Sourceimpl SearchAssetsOutputBuilder
impl SearchAssetsOutputBuilder
Sourcepub fn items(self, input: SearchResultItem) -> Self
pub fn items(self, input: SearchResultItem) -> Self
Appends an item to items.
To override the contents of this collection use set_items.
The list of assets matching the search criteria.
Sourcepub fn set_items(self, input: Option<Vec<SearchResultItem>>) -> Self
pub fn set_items(self, input: Option<Vec<SearchResultItem>>) -> Self
The list of assets matching the search criteria.
Sourcepub fn get_items(&self) -> &Option<Vec<SearchResultItem>>
pub fn get_items(&self) -> &Option<Vec<SearchResultItem>>
The list of assets matching the search criteria.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token, present if the current segment is not the last.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token, present if the current segment is not the last.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token, present if the current segment is not the last.
Sourcepub fn build(self) -> SearchAssetsOutput
pub fn build(self) -> SearchAssetsOutput
Consumes the builder and constructs a SearchAssetsOutput.