pub struct SearchAssetsPaginatorItems(/* private fields */);Expand description
Flattened paginator for SearchAssetsPaginator
This is created with .items()
Implementations
Sourceimpl SearchAssetsPaginatorItems
impl SearchAssetsPaginatorItems
Sourcepub fn send(
self,
) -> PaginationStream<Result<SearchResultItem, SdkError<SearchAssetsError, HttpResponse>>>
pub fn send( self, ) -> PaginationStream<Result<SearchResultItem, SdkError<SearchAssetsError, HttpResponse>>>
Create the pagination stream
Note: No requests will be dispatched until the stream is used
(e.g. with the .next().await method).
To read the entirety of the paginator, use .collect::<Result<Vec<_>, _>().