#[non_exhaustive]pub struct SearchAssetsInput {
pub search_text: Option<String>,
pub max_results: Option<i32>,
pub next_token: Option<String>,
pub sort: Option<SearchSort>,
pub filter_clause: Option<SearchFilterClause>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.search_text: Option<String>The text to search for. At least one of searchText or filterClause must be provided.
max_results: Option<i32>The maximum number of results to return in the response.
next_token: Option<String>A continuation token, if this is a continuation call.
sort: Option<SearchSort>The sort criteria for the search results.
filter_clause: Option<SearchFilterClause>The filter clause to apply to the search. Supports nested AND/OR logic with attribute-level and map-level filters.
Implementations
Sourceimpl SearchAssetsInput
impl SearchAssetsInput
Sourcepub fn search_text(&self) -> Option<&str>
pub fn search_text(&self) -> Option<&str>
The text to search for. At least one of searchText or filterClause must be provided.
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
The maximum number of results to return in the response.
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A continuation token, if this is a continuation call.
Sourcepub fn sort(&self) -> Option<&SearchSort>
pub fn sort(&self) -> Option<&SearchSort>
The sort criteria for the search results.
Sourcepub fn filter_clause(&self) -> Option<&SearchFilterClause>
pub fn filter_clause(&self) -> Option<&SearchFilterClause>
The filter clause to apply to the search. Supports nested AND/OR logic with attribute-level and map-level filters.
Sourceimpl SearchAssetsInput
impl SearchAssetsInput
Sourcepub fn builder() -> SearchAssetsInputBuilder
pub fn builder() -> SearchAssetsInputBuilder
Creates a new builder-style object to manufacture SearchAssetsInput.