#[non_exhaustive]pub struct SearchAssetsOutput {
pub items: Option<Vec<SearchResultItem>>,
pub next_token: Option<String>,
/* private fields */
}Expand description
The search results returned by the SearchAssets operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.items: Option<Vec<SearchResultItem>>The list of assets matching the search criteria.
next_token: Option<String>A continuation token, present if the current segment is not the last.
Implementations
Sourceimpl SearchAssetsOutput
impl SearchAssetsOutput
Sourcepub fn items(&self) -> &[SearchResultItem]
pub fn items(&self) -> &[SearchResultItem]
The list of assets matching the search criteria.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .items.is_none().
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A continuation token, present if the current segment is not the last.
Sourceimpl SearchAssetsOutput
impl SearchAssetsOutput
Sourcepub fn builder() -> SearchAssetsOutputBuilder
pub fn builder() -> SearchAssetsOutputBuilder
Creates a new builder-style object to manufacture SearchAssetsOutput.