#[non_exhaustive]pub struct SearchTablesOutputBuilder { /* private fields */ }Expand description
A builder for SearchTablesOutput.
Implementations
Sourceimpl SearchTablesOutputBuilder
impl SearchTablesOutputBuilder
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token, present if the current list segment is not the last.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token, present if the current list segment is not the last.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token, present if the current list segment is not the last.
Sourcepub fn table_list(self, input: Table) -> Self
pub fn table_list(self, input: Table) -> Self
Appends an item to table_list.
To override the contents of this collection use set_table_list.
A list of the requested Table objects. The SearchTables response returns only the tables that you have access to.
Sourcepub fn set_table_list(self, input: Option<Vec<Table>>) -> Self
pub fn set_table_list(self, input: Option<Vec<Table>>) -> Self
A list of the requested Table objects. The SearchTables response returns only the tables that you have access to.
Sourcepub fn get_table_list(&self) -> &Option<Vec<Table>>
pub fn get_table_list(&self) -> &Option<Vec<Table>>
A list of the requested Table objects. The SearchTables response returns only the tables that you have access to.
Sourcepub fn build(self) -> SearchTablesOutput
pub fn build(self) -> SearchTablesOutput
Consumes the builder and constructs a SearchTablesOutput.