#[non_exhaustive]pub struct SearchTablesInput {
pub catalog_id: Option<String>,
pub next_token: Option<String>,
pub filters: Option<Vec<PropertyPredicate>>,
pub search_text: Option<String>,
pub sort_criteria: Option<Vec<SortCriterion>>,
pub max_results: Option<i32>,
pub resource_share_type: Option<ResourceShareType>,
pub include_status_details: Option<bool>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.catalog_id: Option<String>A unique identifier, consisting of account_id .
next_token: Option<String>A continuation token, included if this is a continuation call.
filters: Option<Vec<PropertyPredicate>>A list of key-value pairs, and a comparator used to filter the search results. Returns all entities matching the predicate.
The Comparator member of the PropertyPredicate struct is used only for time fields, and can be omitted for other field types. Also, when comparing string values, such as when Key=Name, a fuzzy match algorithm is used. The Key field (for example, the value of the Name field) is split on certain punctuation characters, for example, -, :, #, etc. into tokens. Then each token is exact-match compared with the Value member of PropertyPredicate. For example, if Key=Name and Value=link, tables named customer-link and xx-link-yy are returned, but xxlinkyy is not returned.
search_text: Option<String>A string used for a text search.
Specifying a value in quotes filters based on an exact match to the value.
sort_criteria: Option<Vec<SortCriterion>>A list of criteria for sorting the results by a field name, in an ascending or descending order.
max_results: Option<i32>The maximum number of tables to return in a single response.
Allows you to specify that you want to search the tables shared with your account. The allowable values are FOREIGN or ALL.
-
If set to
FOREIGN, will search the tables shared with your account. -
If set to
ALL, will search the tables shared with your account, as well as the tables in yor local account.
include_status_details: Option<bool>Specifies whether to include status details related to a request to create or update an Glue Data Catalog view.
Implementations
Sourceimpl SearchTablesInput
impl SearchTablesInput
Sourcepub fn catalog_id(&self) -> Option<&str>
pub fn catalog_id(&self) -> Option<&str>
A unique identifier, consisting of account_id .
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A continuation token, included if this is a continuation call.
Sourcepub fn filters(&self) -> &[PropertyPredicate]
pub fn filters(&self) -> &[PropertyPredicate]
A list of key-value pairs, and a comparator used to filter the search results. Returns all entities matching the predicate.
The Comparator member of the PropertyPredicate struct is used only for time fields, and can be omitted for other field types. Also, when comparing string values, such as when Key=Name, a fuzzy match algorithm is used. The Key field (for example, the value of the Name field) is split on certain punctuation characters, for example, -, :, #, etc. into tokens. Then each token is exact-match compared with the Value member of PropertyPredicate. For example, if Key=Name and Value=link, tables named customer-link and xx-link-yy are returned, but xxlinkyy is not returned.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .filters.is_none().
Sourcepub fn search_text(&self) -> Option<&str>
pub fn search_text(&self) -> Option<&str>
A string used for a text search.
Specifying a value in quotes filters based on an exact match to the value.
Sourcepub fn sort_criteria(&self) -> &[SortCriterion]
pub fn sort_criteria(&self) -> &[SortCriterion]
A list of criteria for sorting the results by a field name, in an ascending or descending order.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .sort_criteria.is_none().
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
The maximum number of tables to return in a single response.
Allows you to specify that you want to search the tables shared with your account. The allowable values are FOREIGN or ALL.
-
If set to
FOREIGN, will search the tables shared with your account. -
If set to
ALL, will search the tables shared with your account, as well as the tables in yor local account.
Sourcepub fn include_status_details(&self) -> Option<bool>
pub fn include_status_details(&self) -> Option<bool>
Specifies whether to include status details related to a request to create or update an Glue Data Catalog view.
Sourceimpl SearchTablesInput
impl SearchTablesInput
Sourcepub fn builder() -> SearchTablesInputBuilder
pub fn builder() -> SearchTablesInputBuilder
Creates a new builder-style object to manufacture SearchTablesInput.