StartBlueprintRunFluentBuilder

Struct StartBlueprintRunFluentBuilder 

pub struct StartBlueprintRunFluentBuilder { /* private fields */ }
Fluent builder constructing a request to StartBlueprintRun.

Starts a new run of the specified blueprint.

Implementations

Source

impl StartBlueprintRunFluentBuilder

pub fn as_input(&self) -> &StartBlueprintRunInputBuilder

Access the StartBlueprintRun as a reference.

pub async fn send( self, ) -> Result<StartBlueprintRunOutput, SdkError<StartBlueprintRunError, HttpResponse>>

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

pub fn customize( self, ) -> CustomizableOperation<StartBlueprintRunOutput, StartBlueprintRunError, Self>

Consumes this builder, creating a customizable operation that can be modified before being sent.

pub fn blueprint_name(self, input: impl Into<String>) -> Self

The name of the blueprint.

pub fn set_blueprint_name(self, input: Option<String>) -> Self

The name of the blueprint.

pub fn get_blueprint_name(&self) -> &Option<String>

The name of the blueprint.

pub fn parameters(self, input: impl Into<String>) -> Self

Specifies the parameters as a BlueprintParameters object.

pub fn set_parameters(self, input: Option<String>) -> Self

Specifies the parameters as a BlueprintParameters object.

pub fn get_parameters(&self) -> &Option<String>

Specifies the parameters as a BlueprintParameters object.

pub fn role_arn(self, input: impl Into<String>) -> Self

Specifies the IAM role used to create the workflow.

pub fn set_role_arn(self, input: Option<String>) -> Self

Specifies the IAM role used to create the workflow.

pub fn get_role_arn(&self) -> &Option<String>

Specifies the IAM role used to create the workflow.