#[non_exhaustive]pub struct StartColumnStatisticsTaskRunScheduleInputBuilder { /* private fields */ }Expand description
A builder for StartColumnStatisticsTaskRunScheduleInput.
Implementations
Sourceimpl StartColumnStatisticsTaskRunScheduleInputBuilder
impl StartColumnStatisticsTaskRunScheduleInputBuilder
Sourcepub fn database_name(self, input: impl Into<String>) -> Self
pub fn database_name(self, input: impl Into<String>) -> Self
The name of the database where the table resides.
This field is required.Sourcepub fn set_database_name(self, input: Option<String>) -> Self
pub fn set_database_name(self, input: Option<String>) -> Self
The name of the database where the table resides.
Sourcepub fn get_database_name(&self) -> &Option<String>
pub fn get_database_name(&self) -> &Option<String>
The name of the database where the table resides.
Sourcepub fn table_name(self, input: impl Into<String>) -> Self
pub fn table_name(self, input: impl Into<String>) -> Self
The name of the table for which to start a column statistic task run schedule.
This field is required.Sourcepub fn set_table_name(self, input: Option<String>) -> Self
pub fn set_table_name(self, input: Option<String>) -> Self
The name of the table for which to start a column statistic task run schedule.
Sourcepub fn get_table_name(&self) -> &Option<String>
pub fn get_table_name(&self) -> &Option<String>
The name of the table for which to start a column statistic task run schedule.
Sourcepub fn build(
self,
) -> Result<StartColumnStatisticsTaskRunScheduleInput, BuildError>
pub fn build( self, ) -> Result<StartColumnStatisticsTaskRunScheduleInput, BuildError>
Consumes the builder and constructs a StartColumnStatisticsTaskRunScheduleInput.
Sourceimpl StartColumnStatisticsTaskRunScheduleInputBuilder
impl StartColumnStatisticsTaskRunScheduleInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<StartColumnStatisticsTaskRunScheduleOutput, SdkError<StartColumnStatisticsTaskRunScheduleError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<StartColumnStatisticsTaskRunScheduleOutput, SdkError<StartColumnStatisticsTaskRunScheduleError, HttpResponse>>
Sends a request with this input using the given client.