pub struct StartCrawlerScheduleFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to StartCrawlerSchedule.
Changes the schedule state of the specified crawler to SCHEDULED, unless the crawler is already running or the schedule state is already SCHEDULED.
Implementations
Sourceimpl StartCrawlerScheduleFluentBuilder
impl StartCrawlerScheduleFluentBuilder
Sourcepub fn as_input(&self) -> &StartCrawlerScheduleInputBuilder
pub fn as_input(&self) -> &StartCrawlerScheduleInputBuilder
Access the StartCrawlerSchedule as a reference.
Sourcepub async fn send(
self,
) -> Result<StartCrawlerScheduleOutput, SdkError<StartCrawlerScheduleError, HttpResponse>>
pub async fn send( self, ) -> Result<StartCrawlerScheduleOutput, SdkError<StartCrawlerScheduleError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<StartCrawlerScheduleOutput, StartCrawlerScheduleError, Self>
pub fn customize( self, ) -> CustomizableOperation<StartCrawlerScheduleOutput, StartCrawlerScheduleError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn crawler_name(self, input: impl Into<String>) -> Self
pub fn crawler_name(self, input: impl Into<String>) -> Self
Name of the crawler to schedule.
Sourcepub fn set_crawler_name(self, input: Option<String>) -> Self
pub fn set_crawler_name(self, input: Option<String>) -> Self
Name of the crawler to schedule.
Sourcepub fn get_crawler_name(&self) -> &Option<String>
pub fn get_crawler_name(&self) -> &Option<String>
Name of the crawler to schedule.