StartDataQualityRuleRecommendationRunInputBuilder

Struct StartDataQualityRuleRecommendationRunInputBuilder 

#[non_exhaustive]
pub struct StartDataQualityRuleRecommendationRunInputBuilder { /* private fields */ }
Implementations

Source

impl StartDataQualityRuleRecommendationRunInputBuilder

pub fn data_source(self, input: DataSource) -> Self

The data source (Glue table) associated with this run.

This field is required.
pub fn set_data_source(self, input: Option<DataSource>) -> Self

The data source (Glue table) associated with this run.

pub fn get_data_source(&self) -> &Option<DataSource>

The data source (Glue table) associated with this run.

pub fn role(self, input: impl Into<String>) -> Self

The IAM role that Glue assumes to access resources for the run.

For more information, see Configure IAM permissions for Glue Data Quality.

This field is required.
pub fn set_role(self, input: Option<String>) -> Self

The IAM role that Glue assumes to access resources for the run.

For more information, see Configure IAM permissions for Glue Data Quality.

pub fn get_role(&self) -> &Option<String>

The IAM role that Glue assumes to access resources for the run.

For more information, see Configure IAM permissions for Glue Data Quality.

pub fn number_of_workers(self, input: i32) -> Self

The number of G.1X workers to be used in the run. The default is 5.

pub fn set_number_of_workers(self, input: Option<i32>) -> Self

The number of G.1X workers to be used in the run. The default is 5.

pub fn get_number_of_workers(&self) -> &Option<i32>

The number of G.1X workers to be used in the run. The default is 5.

pub fn timeout(self, input: i32) -> Self

The timeout for a run in minutes. This is the maximum time that a run can consume resources before it is terminated and enters TIMEOUT status. The default is 2,880 minutes (48 hours).

pub fn set_timeout(self, input: Option<i32>) -> Self

The timeout for a run in minutes. This is the maximum time that a run can consume resources before it is terminated and enters TIMEOUT status. The default is 2,880 minutes (48 hours).

pub fn get_timeout(&self) -> &Option<i32>

The timeout for a run in minutes. This is the maximum time that a run can consume resources before it is terminated and enters TIMEOUT status. The default is 2,880 minutes (48 hours).

pub fn created_ruleset_name(self, input: impl Into<String>) -> Self

A name for the ruleset.

pub fn set_created_ruleset_name(self, input: Option<String>) -> Self

A name for the ruleset.

pub fn get_created_ruleset_name(&self) -> &Option<String>

A name for the ruleset.

pub fn data_quality_security_configuration( self, input: impl Into<String>, ) -> Self

The name of the security configuration created with the data quality encryption option.

pub fn set_data_quality_security_configuration( self, input: Option<String>, ) -> Self

The name of the security configuration created with the data quality encryption option.

pub fn get_data_quality_security_configuration(&self) -> &Option<String>

The name of the security configuration created with the data quality encryption option.

pub fn client_token(self, input: impl Into<String>) -> Self

Used for idempotency and is recommended to be set to a random ID (such as a UUID) to avoid creating or starting multiple instances of the same resource.

pub fn set_client_token(self, input: Option<String>) -> Self

Used for idempotency and is recommended to be set to a random ID (such as a UUID) to avoid creating or starting multiple instances of the same resource.

pub fn get_client_token(&self) -> &Option<String>

Used for idempotency and is recommended to be set to a random ID (such as a UUID) to avoid creating or starting multiple instances of the same resource.

pub fn additional_run_options( self, input: DataQualityRuleRecommendationRunAdditionalRunOptions, ) -> Self

Additional run options you can specify for a recommendation run.

pub fn set_additional_run_options( self, input: Option<DataQualityRuleRecommendationRunAdditionalRunOptions>, ) -> Self

Additional run options you can specify for a recommendation run.

pub fn get_additional_run_options( &self, ) -> &Option<DataQualityRuleRecommendationRunAdditionalRunOptions>

Additional run options you can specify for a recommendation run.

pub fn recommendation_mode(self, input: RecommendationMode) -> Self

The mode that Glue Data Quality uses to recommend rules.

The default is BASIC.

pub fn set_recommendation_mode(self, input: Option<RecommendationMode>) -> Self

The mode that Glue Data Quality uses to recommend rules.

The default is BASIC.

pub fn get_recommendation_mode(&self) -> &Option<RecommendationMode>

The mode that Glue Data Quality uses to recommend rules.

The default is BASIC.

pub fn build( self, ) -> Result<StartDataQualityRuleRecommendationRunInput, BuildError>

Consumes the builder and constructs a StartDataQualityRuleRecommendationRunInput.

Source

impl StartDataQualityRuleRecommendationRunInputBuilder

pub async fn send_with( self, client: &Client, ) -> Result<StartDataQualityRuleRecommendationRunOutput, SdkError<StartDataQualityRuleRecommendationRunError, HttpResponse>>

Sends a request with this input using the given client.