#[non_exhaustive]pub struct StartDataQualityRuleRecommendationRunInput {
pub data_source: Option<DataSource>,
pub role: Option<String>,
pub number_of_workers: Option<i32>,
pub timeout: Option<i32>,
pub created_ruleset_name: Option<String>,
pub data_quality_security_configuration: Option<String>,
pub client_token: Option<String>,
pub additional_run_options: Option<DataQualityRuleRecommendationRunAdditionalRunOptions>,
pub recommendation_mode: Option<RecommendationMode>,
}Expand description
The request of the Data Quality rule recommendation request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.data_source: Option<DataSource>The data source (Glue table) associated with this run.
role: Option<String>The IAM role that Glue assumes to access resources for the run.
For more information, see Configure IAM permissions for Glue Data Quality.
number_of_workers: Option<i32>The number of G.1X workers to be used in the run. The default is 5.
timeout: Option<i32>The timeout for a run in minutes. This is the maximum time that a run can consume resources before it is terminated and enters TIMEOUT status. The default is 2,880 minutes (48 hours).
created_ruleset_name: Option<String>A name for the ruleset.
data_quality_security_configuration: Option<String>The name of the security configuration created with the data quality encryption option.
client_token: Option<String>Used for idempotency and is recommended to be set to a random ID (such as a UUID) to avoid creating or starting multiple instances of the same resource.
additional_run_options: Option<DataQualityRuleRecommendationRunAdditionalRunOptions>Additional run options you can specify for a recommendation run.
recommendation_mode: Option<RecommendationMode>The mode that Glue Data Quality uses to recommend rules.
The default is BASIC.
Implementations
Sourceimpl StartDataQualityRuleRecommendationRunInput
impl StartDataQualityRuleRecommendationRunInput
Sourcepub fn data_source(&self) -> Option<&DataSource>
pub fn data_source(&self) -> Option<&DataSource>
The data source (Glue table) associated with this run.
Sourcepub fn role(&self) -> Option<&str>
pub fn role(&self) -> Option<&str>
The IAM role that Glue assumes to access resources for the run.
For more information, see Configure IAM permissions for Glue Data Quality.
Sourcepub fn number_of_workers(&self) -> Option<i32>
pub fn number_of_workers(&self) -> Option<i32>
The number of G.1X workers to be used in the run. The default is 5.
Sourcepub fn timeout(&self) -> Option<i32>
pub fn timeout(&self) -> Option<i32>
The timeout for a run in minutes. This is the maximum time that a run can consume resources before it is terminated and enters TIMEOUT status. The default is 2,880 minutes (48 hours).
Sourcepub fn created_ruleset_name(&self) -> Option<&str>
pub fn created_ruleset_name(&self) -> Option<&str>
A name for the ruleset.
Sourcepub fn data_quality_security_configuration(&self) -> Option<&str>
pub fn data_quality_security_configuration(&self) -> Option<&str>
The name of the security configuration created with the data quality encryption option.
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
Used for idempotency and is recommended to be set to a random ID (such as a UUID) to avoid creating or starting multiple instances of the same resource.
Sourcepub fn additional_run_options(
&self,
) -> Option<&DataQualityRuleRecommendationRunAdditionalRunOptions>
pub fn additional_run_options( &self, ) -> Option<&DataQualityRuleRecommendationRunAdditionalRunOptions>
Additional run options you can specify for a recommendation run.
Sourcepub fn recommendation_mode(&self) -> Option<&RecommendationMode>
pub fn recommendation_mode(&self) -> Option<&RecommendationMode>
The mode that Glue Data Quality uses to recommend rules.
The default is BASIC.
Sourceimpl StartDataQualityRuleRecommendationRunInput
impl StartDataQualityRuleRecommendationRunInput
Sourcepub fn builder() -> StartDataQualityRuleRecommendationRunInputBuilder
pub fn builder() -> StartDataQualityRuleRecommendationRunInputBuilder
Creates a new builder-style object to manufacture StartDataQualityRuleRecommendationRunInput.