#[non_exhaustive]pub struct StartDataQualityRulesetEvaluationRunInputBuilder { /* private fields */ }Expand description
A builder for StartDataQualityRulesetEvaluationRunInput.
Implementations
Sourceimpl StartDataQualityRulesetEvaluationRunInputBuilder
impl StartDataQualityRulesetEvaluationRunInputBuilder
Sourcepub fn data_source(self, input: DataSource) -> Self
pub fn data_source(self, input: DataSource) -> Self
The data source (Glue table) associated with this run.
This field is required.Sourcepub fn set_data_source(self, input: Option<DataSource>) -> Self
pub fn set_data_source(self, input: Option<DataSource>) -> Self
The data source (Glue table) associated with this run.
Sourcepub fn get_data_source(&self) -> &Option<DataSource>
pub fn get_data_source(&self) -> &Option<DataSource>
The data source (Glue table) associated with this run.
Sourcepub fn role(self, input: impl Into<String>) -> Self
pub fn role(self, input: impl Into<String>) -> Self
An IAM role supplied to encrypt the results of the run.
This field is required.Sourcepub fn set_role(self, input: Option<String>) -> Self
pub fn set_role(self, input: Option<String>) -> Self
An IAM role supplied to encrypt the results of the run.
Sourcepub fn get_role(&self) -> &Option<String>
pub fn get_role(&self) -> &Option<String>
An IAM role supplied to encrypt the results of the run.
Sourcepub fn number_of_workers(self, input: i32) -> Self
pub fn number_of_workers(self, input: i32) -> Self
The number of G.1X workers to be used in the run. The default is 5.
Sourcepub fn set_number_of_workers(self, input: Option<i32>) -> Self
pub fn set_number_of_workers(self, input: Option<i32>) -> Self
The number of G.1X workers to be used in the run. The default is 5.
Sourcepub fn get_number_of_workers(&self) -> &Option<i32>
pub fn get_number_of_workers(&self) -> &Option<i32>
The number of G.1X workers to be used in the run. The default is 5.
Sourcepub fn timeout(self, input: i32) -> Self
pub fn timeout(self, input: i32) -> Self
The timeout for a run in minutes. This is the maximum time that a run can consume resources before it is terminated and enters TIMEOUT status. The default is 2,880 minutes (48 hours).
Sourcepub fn set_timeout(self, input: Option<i32>) -> Self
pub fn set_timeout(self, input: Option<i32>) -> Self
The timeout for a run in minutes. This is the maximum time that a run can consume resources before it is terminated and enters TIMEOUT status. The default is 2,880 minutes (48 hours).
Sourcepub fn get_timeout(&self) -> &Option<i32>
pub fn get_timeout(&self) -> &Option<i32>
The timeout for a run in minutes. This is the maximum time that a run can consume resources before it is terminated and enters TIMEOUT status. The default is 2,880 minutes (48 hours).
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
Used for idempotency and is recommended to be set to a random ID (such as a UUID) to avoid creating or starting multiple instances of the same resource.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
Used for idempotency and is recommended to be set to a random ID (such as a UUID) to avoid creating or starting multiple instances of the same resource.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
Used for idempotency and is recommended to be set to a random ID (such as a UUID) to avoid creating or starting multiple instances of the same resource.
Sourcepub fn additional_run_options(
self,
input: DataQualityEvaluationRunAdditionalRunOptions,
) -> Self
pub fn additional_run_options( self, input: DataQualityEvaluationRunAdditionalRunOptions, ) -> Self
Additional run options you can specify for an evaluation run.
Sourcepub fn set_additional_run_options(
self,
input: Option<DataQualityEvaluationRunAdditionalRunOptions>,
) -> Self
pub fn set_additional_run_options( self, input: Option<DataQualityEvaluationRunAdditionalRunOptions>, ) -> Self
Additional run options you can specify for an evaluation run.
Sourcepub fn get_additional_run_options(
&self,
) -> &Option<DataQualityEvaluationRunAdditionalRunOptions>
pub fn get_additional_run_options( &self, ) -> &Option<DataQualityEvaluationRunAdditionalRunOptions>
Additional run options you can specify for an evaluation run.
Sourcepub fn ruleset_names(self, input: impl Into<String>) -> Self
pub fn ruleset_names(self, input: impl Into<String>) -> Self
Appends an item to ruleset_names.
To override the contents of this collection use set_ruleset_names.
A list of ruleset names.
Sourcepub fn set_ruleset_names(self, input: Option<Vec<String>>) -> Self
pub fn set_ruleset_names(self, input: Option<Vec<String>>) -> Self
A list of ruleset names.
Sourcepub fn get_ruleset_names(&self) -> &Option<Vec<String>>
pub fn get_ruleset_names(&self) -> &Option<Vec<String>>
A list of ruleset names.
Sourcepub fn additional_data_sources(
self,
k: impl Into<String>,
v: DataSource,
) -> Self
pub fn additional_data_sources( self, k: impl Into<String>, v: DataSource, ) -> Self
Adds a key-value pair to additional_data_sources.
To override the contents of this collection use set_additional_data_sources.
A map of reference strings to additional data sources you can specify for an evaluation run.
Sourcepub fn set_additional_data_sources(
self,
input: Option<HashMap<String, DataSource>>,
) -> Self
pub fn set_additional_data_sources( self, input: Option<HashMap<String, DataSource>>, ) -> Self
A map of reference strings to additional data sources you can specify for an evaluation run.
Sourcepub fn get_additional_data_sources(
&self,
) -> &Option<HashMap<String, DataSource>>
pub fn get_additional_data_sources( &self, ) -> &Option<HashMap<String, DataSource>>
A map of reference strings to additional data sources you can specify for an evaluation run.
Sourcepub fn build(
self,
) -> Result<StartDataQualityRulesetEvaluationRunInput, BuildError>
pub fn build( self, ) -> Result<StartDataQualityRulesetEvaluationRunInput, BuildError>
Consumes the builder and constructs a StartDataQualityRulesetEvaluationRunInput.
Sourceimpl StartDataQualityRulesetEvaluationRunInputBuilder
impl StartDataQualityRulesetEvaluationRunInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<StartDataQualityRulesetEvaluationRunOutput, SdkError<StartDataQualityRulesetEvaluationRunError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<StartDataQualityRulesetEvaluationRunOutput, SdkError<StartDataQualityRulesetEvaluationRunError, HttpResponse>>
Sends a request with this input using the given client.