pub struct StartMaterializedViewRefreshTaskRunFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to StartMaterializedViewRefreshTaskRun.
Starts a materialized view refresh task run, for a specified table and columns.
Implementations
Sourceimpl StartMaterializedViewRefreshTaskRunFluentBuilder
impl StartMaterializedViewRefreshTaskRunFluentBuilder
Sourcepub fn as_input(&self) -> &StartMaterializedViewRefreshTaskRunInputBuilder
pub fn as_input(&self) -> &StartMaterializedViewRefreshTaskRunInputBuilder
Access the StartMaterializedViewRefreshTaskRun as a reference.
Sourcepub async fn send(
self,
) -> Result<StartMaterializedViewRefreshTaskRunOutput, SdkError<StartMaterializedViewRefreshTaskRunError, HttpResponse>>
pub async fn send( self, ) -> Result<StartMaterializedViewRefreshTaskRunOutput, SdkError<StartMaterializedViewRefreshTaskRunError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<StartMaterializedViewRefreshTaskRunOutput, StartMaterializedViewRefreshTaskRunError, Self>
pub fn customize( self, ) -> CustomizableOperation<StartMaterializedViewRefreshTaskRunOutput, StartMaterializedViewRefreshTaskRunError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn catalog_id(self, input: impl Into<String>) -> Self
pub fn catalog_id(self, input: impl Into<String>) -> Self
The ID of the Data Catalog where the table reside. If none is supplied, the account ID is used by default.
Sourcepub fn set_catalog_id(self, input: Option<String>) -> Self
pub fn set_catalog_id(self, input: Option<String>) -> Self
The ID of the Data Catalog where the table reside. If none is supplied, the account ID is used by default.
Sourcepub fn get_catalog_id(&self) -> &Option<String>
pub fn get_catalog_id(&self) -> &Option<String>
The ID of the Data Catalog where the table reside. If none is supplied, the account ID is used by default.
Sourcepub fn database_name(self, input: impl Into<String>) -> Self
pub fn database_name(self, input: impl Into<String>) -> Self
The name of the database where the table resides.
Sourcepub fn set_database_name(self, input: Option<String>) -> Self
pub fn set_database_name(self, input: Option<String>) -> Self
The name of the database where the table resides.
Sourcepub fn get_database_name(&self) -> &Option<String>
pub fn get_database_name(&self) -> &Option<String>
The name of the database where the table resides.
Sourcepub fn table_name(self, input: impl Into<String>) -> Self
pub fn table_name(self, input: impl Into<String>) -> Self
The name of the table to generate run the materialized view refresh task.
Sourcepub fn set_table_name(self, input: Option<String>) -> Self
pub fn set_table_name(self, input: Option<String>) -> Self
The name of the table to generate run the materialized view refresh task.
Sourcepub fn get_table_name(&self) -> &Option<String>
pub fn get_table_name(&self) -> &Option<String>
The name of the table to generate run the materialized view refresh task.
Sourcepub fn full_refresh(self, input: bool) -> Self
pub fn full_refresh(self, input: bool) -> Self
Specifies whether this is a full refresh of the task run.
Sourcepub fn set_full_refresh(self, input: Option<bool>) -> Self
pub fn set_full_refresh(self, input: Option<bool>) -> Self
Specifies whether this is a full refresh of the task run.
Sourcepub fn get_full_refresh(&self) -> &Option<bool>
pub fn get_full_refresh(&self) -> &Option<bool>
Specifies whether this is a full refresh of the task run.