#[non_exhaustive]pub struct StartMaterializedViewRefreshTaskRunInputBuilder { /* private fields */ }Expand description
A builder for StartMaterializedViewRefreshTaskRunInput.
Implementations
Sourceimpl StartMaterializedViewRefreshTaskRunInputBuilder
impl StartMaterializedViewRefreshTaskRunInputBuilder
Sourcepub fn catalog_id(self, input: impl Into<String>) -> Self
pub fn catalog_id(self, input: impl Into<String>) -> Self
The ID of the Data Catalog where the table reside. If none is supplied, the account ID is used by default.
This field is required.Sourcepub fn set_catalog_id(self, input: Option<String>) -> Self
pub fn set_catalog_id(self, input: Option<String>) -> Self
The ID of the Data Catalog where the table reside. If none is supplied, the account ID is used by default.
Sourcepub fn get_catalog_id(&self) -> &Option<String>
pub fn get_catalog_id(&self) -> &Option<String>
The ID of the Data Catalog where the table reside. If none is supplied, the account ID is used by default.
Sourcepub fn database_name(self, input: impl Into<String>) -> Self
pub fn database_name(self, input: impl Into<String>) -> Self
The name of the database where the table resides.
This field is required.Sourcepub fn set_database_name(self, input: Option<String>) -> Self
pub fn set_database_name(self, input: Option<String>) -> Self
The name of the database where the table resides.
Sourcepub fn get_database_name(&self) -> &Option<String>
pub fn get_database_name(&self) -> &Option<String>
The name of the database where the table resides.
Sourcepub fn table_name(self, input: impl Into<String>) -> Self
pub fn table_name(self, input: impl Into<String>) -> Self
The name of the table to generate run the materialized view refresh task.
This field is required.Sourcepub fn set_table_name(self, input: Option<String>) -> Self
pub fn set_table_name(self, input: Option<String>) -> Self
The name of the table to generate run the materialized view refresh task.
Sourcepub fn get_table_name(&self) -> &Option<String>
pub fn get_table_name(&self) -> &Option<String>
The name of the table to generate run the materialized view refresh task.
Sourcepub fn full_refresh(self, input: bool) -> Self
pub fn full_refresh(self, input: bool) -> Self
Specifies whether this is a full refresh of the task run.
Sourcepub fn set_full_refresh(self, input: Option<bool>) -> Self
pub fn set_full_refresh(self, input: Option<bool>) -> Self
Specifies whether this is a full refresh of the task run.
Sourcepub fn get_full_refresh(&self) -> &Option<bool>
pub fn get_full_refresh(&self) -> &Option<bool>
Specifies whether this is a full refresh of the task run.
Sourcepub fn build(
self,
) -> Result<StartMaterializedViewRefreshTaskRunInput, BuildError>
pub fn build( self, ) -> Result<StartMaterializedViewRefreshTaskRunInput, BuildError>
Consumes the builder and constructs a StartMaterializedViewRefreshTaskRunInput.
Sourceimpl StartMaterializedViewRefreshTaskRunInputBuilder
impl StartMaterializedViewRefreshTaskRunInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<StartMaterializedViewRefreshTaskRunOutput, SdkError<StartMaterializedViewRefreshTaskRunError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<StartMaterializedViewRefreshTaskRunOutput, SdkError<StartMaterializedViewRefreshTaskRunError, HttpResponse>>
Sends a request with this input using the given client.