#[non_exhaustive]pub struct StartMaterializedViewRefreshTaskRunOutputBuilder { /* private fields */ }Expand description
A builder for StartMaterializedViewRefreshTaskRunOutput.
Implementations
Sourceimpl StartMaterializedViewRefreshTaskRunOutputBuilder
impl StartMaterializedViewRefreshTaskRunOutputBuilder
Sourcepub fn materialized_view_refresh_task_run_id(
self,
input: impl Into<String>,
) -> Self
pub fn materialized_view_refresh_task_run_id( self, input: impl Into<String>, ) -> Self
The identifier for the materialized view refresh task run.
Sourcepub fn set_materialized_view_refresh_task_run_id(
self,
input: Option<String>,
) -> Self
pub fn set_materialized_view_refresh_task_run_id( self, input: Option<String>, ) -> Self
The identifier for the materialized view refresh task run.
Sourcepub fn get_materialized_view_refresh_task_run_id(&self) -> &Option<String>
pub fn get_materialized_view_refresh_task_run_id(&self) -> &Option<String>
The identifier for the materialized view refresh task run.
Sourcepub fn build(self) -> StartMaterializedViewRefreshTaskRunOutput
pub fn build(self) -> StartMaterializedViewRefreshTaskRunOutput
Consumes the builder and constructs a StartMaterializedViewRefreshTaskRunOutput.