#[non_exhaustive]pub struct StartMaterializedViewRefreshTaskRunOutput {
pub materialized_view_refresh_task_run_id: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.materialized_view_refresh_task_run_id: Option<String>The identifier for the materialized view refresh task run.
Implementations
Sourceimpl StartMaterializedViewRefreshTaskRunOutput
impl StartMaterializedViewRefreshTaskRunOutput
Sourcepub fn materialized_view_refresh_task_run_id(&self) -> Option<&str>
pub fn materialized_view_refresh_task_run_id(&self) -> Option<&str>
The identifier for the materialized view refresh task run.
Sourceimpl StartMaterializedViewRefreshTaskRunOutput
impl StartMaterializedViewRefreshTaskRunOutput
Sourcepub fn builder() -> StartMaterializedViewRefreshTaskRunOutputBuilder
pub fn builder() -> StartMaterializedViewRefreshTaskRunOutputBuilder
Creates a new builder-style object to manufacture StartMaterializedViewRefreshTaskRunOutput.