pub struct StartMLEvaluationTaskRunFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to StartMLEvaluationTaskRun.
Starts a task to estimate the quality of the transform.
When you provide label sets as examples of truth, Glue machine learning uses some of those examples to learn from them. The rest of the labels are used as a test to estimate quality.
Returns a unique identifier for the run. You can call GetMLTaskRun to get more information about the stats of the EvaluationTaskRun.
Implementations
Sourceimpl StartMLEvaluationTaskRunFluentBuilder
impl StartMLEvaluationTaskRunFluentBuilder
Sourcepub fn as_input(&self) -> &StartMlEvaluationTaskRunInputBuilder
pub fn as_input(&self) -> &StartMlEvaluationTaskRunInputBuilder
Access the StartMLEvaluationTaskRun as a reference.
Sourcepub async fn send(
self,
) -> Result<StartMlEvaluationTaskRunOutput, SdkError<StartMLEvaluationTaskRunError, HttpResponse>>
pub async fn send( self, ) -> Result<StartMlEvaluationTaskRunOutput, SdkError<StartMLEvaluationTaskRunError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<StartMlEvaluationTaskRunOutput, StartMLEvaluationTaskRunError, Self>
pub fn customize( self, ) -> CustomizableOperation<StartMlEvaluationTaskRunOutput, StartMLEvaluationTaskRunError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn transform_id(self, input: impl Into<String>) -> Self
pub fn transform_id(self, input: impl Into<String>) -> Self
The unique identifier of the machine learning transform.
Sourcepub fn set_transform_id(self, input: Option<String>) -> Self
pub fn set_transform_id(self, input: Option<String>) -> Self
The unique identifier of the machine learning transform.
Sourcepub fn get_transform_id(&self) -> &Option<String>
pub fn get_transform_id(&self) -> &Option<String>
The unique identifier of the machine learning transform.