pub struct StartWorkflowRunFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to StartWorkflowRun.
Starts a new run of the specified workflow.
Implementations
Sourceimpl StartWorkflowRunFluentBuilder
impl StartWorkflowRunFluentBuilder
Sourcepub fn as_input(&self) -> &StartWorkflowRunInputBuilder
pub fn as_input(&self) -> &StartWorkflowRunInputBuilder
Access the StartWorkflowRun as a reference.
Sourcepub async fn send(
self,
) -> Result<StartWorkflowRunOutput, SdkError<StartWorkflowRunError, HttpResponse>>
pub async fn send( self, ) -> Result<StartWorkflowRunOutput, SdkError<StartWorkflowRunError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<StartWorkflowRunOutput, StartWorkflowRunError, Self>
pub fn customize( self, ) -> CustomizableOperation<StartWorkflowRunOutput, StartWorkflowRunError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn run_properties(self, k: impl Into<String>, v: impl Into<String>) -> Self
pub fn run_properties(self, k: impl Into<String>, v: impl Into<String>) -> Self
Adds a key-value pair to RunProperties.
To override the contents of this collection use set_run_properties.
The workflow run properties for the new workflow run.
Run properties may be logged. Do not pass plaintext secrets as properties. Retrieve secrets from a Glue Connection, Amazon Web Services Secrets Manager or other secret management mechanism if you intend to use them within the workflow run.
Sourcepub fn set_run_properties(self, input: Option<HashMap<String, String>>) -> Self
pub fn set_run_properties(self, input: Option<HashMap<String, String>>) -> Self
The workflow run properties for the new workflow run.
Run properties may be logged. Do not pass plaintext secrets as properties. Retrieve secrets from a Glue Connection, Amazon Web Services Secrets Manager or other secret management mechanism if you intend to use them within the workflow run.
Sourcepub fn get_run_properties(&self) -> &Option<HashMap<String, String>>
pub fn get_run_properties(&self) -> &Option<HashMap<String, String>>
The workflow run properties for the new workflow run.
Run properties may be logged. Do not pass plaintext secrets as properties. Retrieve secrets from a Glue Connection, Amazon Web Services Secrets Manager or other secret management mechanism if you intend to use them within the workflow run.