#[non_exhaustive]pub struct StartWorkflowRunInputBuilder { /* private fields */ }Expand description
A builder for StartWorkflowRunInput.
Implementations
Sourceimpl StartWorkflowRunInputBuilder
impl StartWorkflowRunInputBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the workflow to start.
This field is required.Sourcepub fn run_properties(self, k: impl Into<String>, v: impl Into<String>) -> Self
pub fn run_properties(self, k: impl Into<String>, v: impl Into<String>) -> Self
Adds a key-value pair to run_properties.
To override the contents of this collection use set_run_properties.
The workflow run properties for the new workflow run.
Run properties may be logged. Do not pass plaintext secrets as properties. Retrieve secrets from a Glue Connection, Amazon Web Services Secrets Manager or other secret management mechanism if you intend to use them within the workflow run.
Sourcepub fn set_run_properties(self, input: Option<HashMap<String, String>>) -> Self
pub fn set_run_properties(self, input: Option<HashMap<String, String>>) -> Self
The workflow run properties for the new workflow run.
Run properties may be logged. Do not pass plaintext secrets as properties. Retrieve secrets from a Glue Connection, Amazon Web Services Secrets Manager or other secret management mechanism if you intend to use them within the workflow run.
Sourcepub fn get_run_properties(&self) -> &Option<HashMap<String, String>>
pub fn get_run_properties(&self) -> &Option<HashMap<String, String>>
The workflow run properties for the new workflow run.
Run properties may be logged. Do not pass plaintext secrets as properties. Retrieve secrets from a Glue Connection, Amazon Web Services Secrets Manager or other secret management mechanism if you intend to use them within the workflow run.
Sourcepub fn build(self) -> Result<StartWorkflowRunInput, BuildError>
pub fn build(self) -> Result<StartWorkflowRunInput, BuildError>
Consumes the builder and constructs a StartWorkflowRunInput.
Sourceimpl StartWorkflowRunInputBuilder
impl StartWorkflowRunInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<StartWorkflowRunOutput, SdkError<StartWorkflowRunError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<StartWorkflowRunOutput, SdkError<StartWorkflowRunError, HttpResponse>>
Sends a request with this input using the given client.