pub struct StopColumnStatisticsTaskRunScheduleFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to StopColumnStatisticsTaskRunSchedule.
Stops a column statistics task run schedule.
Implementations
Sourceimpl StopColumnStatisticsTaskRunScheduleFluentBuilder
impl StopColumnStatisticsTaskRunScheduleFluentBuilder
Sourcepub fn as_input(&self) -> &StopColumnStatisticsTaskRunScheduleInputBuilder
pub fn as_input(&self) -> &StopColumnStatisticsTaskRunScheduleInputBuilder
Access the StopColumnStatisticsTaskRunSchedule as a reference.
Sourcepub async fn send(
self,
) -> Result<StopColumnStatisticsTaskRunScheduleOutput, SdkError<StopColumnStatisticsTaskRunScheduleError, HttpResponse>>
pub async fn send( self, ) -> Result<StopColumnStatisticsTaskRunScheduleOutput, SdkError<StopColumnStatisticsTaskRunScheduleError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<StopColumnStatisticsTaskRunScheduleOutput, StopColumnStatisticsTaskRunScheduleError, Self>
pub fn customize( self, ) -> CustomizableOperation<StopColumnStatisticsTaskRunScheduleOutput, StopColumnStatisticsTaskRunScheduleError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn database_name(self, input: impl Into<String>) -> Self
pub fn database_name(self, input: impl Into<String>) -> Self
The name of the database where the table resides.
Sourcepub fn set_database_name(self, input: Option<String>) -> Self
pub fn set_database_name(self, input: Option<String>) -> Self
The name of the database where the table resides.
Sourcepub fn get_database_name(&self) -> &Option<String>
pub fn get_database_name(&self) -> &Option<String>
The name of the database where the table resides.
Sourcepub fn table_name(self, input: impl Into<String>) -> Self
pub fn table_name(self, input: impl Into<String>) -> Self
The name of the table for which to stop a column statistic task run schedule.
Sourcepub fn set_table_name(self, input: Option<String>) -> Self
pub fn set_table_name(self, input: Option<String>) -> Self
The name of the table for which to stop a column statistic task run schedule.
Sourcepub fn get_table_name(&self) -> &Option<String>
pub fn get_table_name(&self) -> &Option<String>
The name of the table for which to stop a column statistic task run schedule.