#[non_exhaustive]pub struct StopColumnStatisticsTaskRunScheduleInputBuilder { /* private fields */ }Expand description
A builder for StopColumnStatisticsTaskRunScheduleInput.
Implementations
Sourceimpl StopColumnStatisticsTaskRunScheduleInputBuilder
impl StopColumnStatisticsTaskRunScheduleInputBuilder
Sourcepub fn database_name(self, input: impl Into<String>) -> Self
pub fn database_name(self, input: impl Into<String>) -> Self
The name of the database where the table resides.
This field is required.Sourcepub fn set_database_name(self, input: Option<String>) -> Self
pub fn set_database_name(self, input: Option<String>) -> Self
The name of the database where the table resides.
Sourcepub fn get_database_name(&self) -> &Option<String>
pub fn get_database_name(&self) -> &Option<String>
The name of the database where the table resides.
Sourcepub fn table_name(self, input: impl Into<String>) -> Self
pub fn table_name(self, input: impl Into<String>) -> Self
The name of the table for which to stop a column statistic task run schedule.
This field is required.Sourcepub fn set_table_name(self, input: Option<String>) -> Self
pub fn set_table_name(self, input: Option<String>) -> Self
The name of the table for which to stop a column statistic task run schedule.
Sourcepub fn get_table_name(&self) -> &Option<String>
pub fn get_table_name(&self) -> &Option<String>
The name of the table for which to stop a column statistic task run schedule.
Sourcepub fn build(
self,
) -> Result<StopColumnStatisticsTaskRunScheduleInput, BuildError>
pub fn build( self, ) -> Result<StopColumnStatisticsTaskRunScheduleInput, BuildError>
Consumes the builder and constructs a StopColumnStatisticsTaskRunScheduleInput.
Sourceimpl StopColumnStatisticsTaskRunScheduleInputBuilder
impl StopColumnStatisticsTaskRunScheduleInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<StopColumnStatisticsTaskRunScheduleOutput, SdkError<StopColumnStatisticsTaskRunScheduleError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<StopColumnStatisticsTaskRunScheduleOutput, SdkError<StopColumnStatisticsTaskRunScheduleError, HttpResponse>>
Sends a request with this input using the given client.