#[non_exhaustive]pub struct StopColumnStatisticsTaskRunScheduleInput {
pub database_name: Option<String>,
pub table_name: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.database_name: Option<String>The name of the database where the table resides.
table_name: Option<String>The name of the table for which to stop a column statistic task run schedule.
Implementations
Sourceimpl StopColumnStatisticsTaskRunScheduleInput
impl StopColumnStatisticsTaskRunScheduleInput
Sourcepub fn database_name(&self) -> Option<&str>
pub fn database_name(&self) -> Option<&str>
The name of the database where the table resides.
Sourcepub fn table_name(&self) -> Option<&str>
pub fn table_name(&self) -> Option<&str>
The name of the table for which to stop a column statistic task run schedule.
Sourceimpl StopColumnStatisticsTaskRunScheduleInput
impl StopColumnStatisticsTaskRunScheduleInput
Sourcepub fn builder() -> StopColumnStatisticsTaskRunScheduleInputBuilder
pub fn builder() -> StopColumnStatisticsTaskRunScheduleInputBuilder
Creates a new builder-style object to manufacture StopColumnStatisticsTaskRunScheduleInput.