pub struct StopCrawlerFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to StopCrawler.
If the specified crawler is running, stops the crawl.
Implementations
Sourceimpl StopCrawlerFluentBuilder
impl StopCrawlerFluentBuilder
Sourcepub fn as_input(&self) -> &StopCrawlerInputBuilder
pub fn as_input(&self) -> &StopCrawlerInputBuilder
Access the StopCrawler as a reference.
Sourcepub async fn send(
self,
) -> Result<StopCrawlerOutput, SdkError<StopCrawlerError, HttpResponse>>
pub async fn send( self, ) -> Result<StopCrawlerOutput, SdkError<StopCrawlerError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<StopCrawlerOutput, StopCrawlerError, Self>
pub fn customize( self, ) -> CustomizableOperation<StopCrawlerOutput, StopCrawlerError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.