pub struct StopCrawlerScheduleFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to StopCrawlerSchedule.
Sets the schedule state of the specified crawler to NOT_SCHEDULED, but does not stop the crawler if it is already running.
Implementations
Sourceimpl StopCrawlerScheduleFluentBuilder
impl StopCrawlerScheduleFluentBuilder
Sourcepub fn as_input(&self) -> &StopCrawlerScheduleInputBuilder
pub fn as_input(&self) -> &StopCrawlerScheduleInputBuilder
Access the StopCrawlerSchedule as a reference.
Sourcepub async fn send(
self,
) -> Result<StopCrawlerScheduleOutput, SdkError<StopCrawlerScheduleError, HttpResponse>>
pub async fn send( self, ) -> Result<StopCrawlerScheduleOutput, SdkError<StopCrawlerScheduleError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<StopCrawlerScheduleOutput, StopCrawlerScheduleError, Self>
pub fn customize( self, ) -> CustomizableOperation<StopCrawlerScheduleOutput, StopCrawlerScheduleError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn crawler_name(self, input: impl Into<String>) -> Self
pub fn crawler_name(self, input: impl Into<String>) -> Self
Name of the crawler whose schedule state to set.
Sourcepub fn set_crawler_name(self, input: Option<String>) -> Self
pub fn set_crawler_name(self, input: Option<String>) -> Self
Name of the crawler whose schedule state to set.
Sourcepub fn get_crawler_name(&self) -> &Option<String>
pub fn get_crawler_name(&self) -> &Option<String>
Name of the crawler whose schedule state to set.