#[non_exhaustive]pub struct StopCrawlerScheduleInputBuilder { /* private fields */ }Expand description
A builder for StopCrawlerScheduleInput.
Implementations
Sourceimpl StopCrawlerScheduleInputBuilder
impl StopCrawlerScheduleInputBuilder
Sourcepub fn crawler_name(self, input: impl Into<String>) -> Self
pub fn crawler_name(self, input: impl Into<String>) -> Self
Name of the crawler whose schedule state to set.
This field is required.Sourcepub fn set_crawler_name(self, input: Option<String>) -> Self
pub fn set_crawler_name(self, input: Option<String>) -> Self
Name of the crawler whose schedule state to set.
Sourcepub fn get_crawler_name(&self) -> &Option<String>
pub fn get_crawler_name(&self) -> &Option<String>
Name of the crawler whose schedule state to set.
Sourcepub fn build(self) -> Result<StopCrawlerScheduleInput, BuildError>
pub fn build(self) -> Result<StopCrawlerScheduleInput, BuildError>
Consumes the builder and constructs a StopCrawlerScheduleInput.
Sourceimpl StopCrawlerScheduleInputBuilder
impl StopCrawlerScheduleInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<StopCrawlerScheduleOutput, SdkError<StopCrawlerScheduleError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<StopCrawlerScheduleOutput, SdkError<StopCrawlerScheduleError, HttpResponse>>
Sends a request with this input using the given client.