#[non_exhaustive]pub enum StopCrawlerScheduleError {
EntityNotFoundException(EntityNotFoundException),
OperationTimeoutException(OperationTimeoutException),
SchedulerNotRunningException(SchedulerNotRunningException),
SchedulerTransitioningException(SchedulerTransitioningException),
Unhandled(Unhandled),
}Expand description
Error type for the StopCrawlerScheduleError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
EntityNotFoundException(EntityNotFoundException)
A specified entity does not exist
OperationTimeoutException(OperationTimeoutException)
The operation timed out.
SchedulerNotRunningException(SchedulerNotRunningException)
The specified scheduler is not running.
SchedulerTransitioningException(SchedulerTransitioningException)
The specified scheduler is transitioning.
Unhandled(Unhandled)
Matching Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
Sourceimpl StopCrawlerScheduleError
impl StopCrawlerScheduleError
Sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the StopCrawlerScheduleError::Unhandled variant from any error type.
Sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the StopCrawlerScheduleError::Unhandled variant from an ErrorMetadata.
Sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
Sourcepub fn is_entity_not_found_exception(&self) -> bool
pub fn is_entity_not_found_exception(&self) -> bool
Returns true if the error kind is StopCrawlerScheduleError::EntityNotFoundException.
Sourcepub fn is_operation_timeout_exception(&self) -> bool
pub fn is_operation_timeout_exception(&self) -> bool
Returns true if the error kind is StopCrawlerScheduleError::OperationTimeoutException.
Sourcepub fn is_scheduler_not_running_exception(&self) -> bool
pub fn is_scheduler_not_running_exception(&self) -> bool
Returns true if the error kind is StopCrawlerScheduleError::SchedulerNotRunningException.
Sourcepub fn is_scheduler_transitioning_exception(&self) -> bool
pub fn is_scheduler_transitioning_exception(&self) -> bool
Returns true if the error kind is StopCrawlerScheduleError::SchedulerTransitioningException.