#[non_exhaustive]pub struct StopCrawlerScheduleInput {
pub crawler_name: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.crawler_name: Option<String>Name of the crawler whose schedule state to set.
Implementations
Sourceimpl StopCrawlerScheduleInput
impl StopCrawlerScheduleInput
Sourcepub fn crawler_name(&self) -> Option<&str>
pub fn crawler_name(&self) -> Option<&str>
Name of the crawler whose schedule state to set.
Sourceimpl StopCrawlerScheduleInput
impl StopCrawlerScheduleInput
Sourcepub fn builder() -> StopCrawlerScheduleInputBuilder
pub fn builder() -> StopCrawlerScheduleInputBuilder
Creates a new builder-style object to manufacture StopCrawlerScheduleInput.