#[non_exhaustive]pub struct StopMaterializedViewRefreshTaskRunInputBuilder { /* private fields */ }Expand description
A builder for StopMaterializedViewRefreshTaskRunInput.
Implementations
Sourceimpl StopMaterializedViewRefreshTaskRunInputBuilder
impl StopMaterializedViewRefreshTaskRunInputBuilder
Sourcepub fn catalog_id(self, input: impl Into<String>) -> Self
pub fn catalog_id(self, input: impl Into<String>) -> Self
The ID of the Data Catalog where the table reside. If none is supplied, the account ID is used by default.
This field is required.Sourcepub fn set_catalog_id(self, input: Option<String>) -> Self
pub fn set_catalog_id(self, input: Option<String>) -> Self
The ID of the Data Catalog where the table reside. If none is supplied, the account ID is used by default.
Sourcepub fn get_catalog_id(&self) -> &Option<String>
pub fn get_catalog_id(&self) -> &Option<String>
The ID of the Data Catalog where the table reside. If none is supplied, the account ID is used by default.
Sourcepub fn database_name(self, input: impl Into<String>) -> Self
pub fn database_name(self, input: impl Into<String>) -> Self
The name of the database where the table resides.
This field is required.Sourcepub fn set_database_name(self, input: Option<String>) -> Self
pub fn set_database_name(self, input: Option<String>) -> Self
The name of the database where the table resides.
Sourcepub fn get_database_name(&self) -> &Option<String>
pub fn get_database_name(&self) -> &Option<String>
The name of the database where the table resides.
Sourcepub fn table_name(self, input: impl Into<String>) -> Self
pub fn table_name(self, input: impl Into<String>) -> Self
The name of the table to generate statistics.
This field is required.Sourcepub fn set_table_name(self, input: Option<String>) -> Self
pub fn set_table_name(self, input: Option<String>) -> Self
The name of the table to generate statistics.
Sourcepub fn get_table_name(&self) -> &Option<String>
pub fn get_table_name(&self) -> &Option<String>
The name of the table to generate statistics.
Sourcepub fn build(
self,
) -> Result<StopMaterializedViewRefreshTaskRunInput, BuildError>
pub fn build( self, ) -> Result<StopMaterializedViewRefreshTaskRunInput, BuildError>
Consumes the builder and constructs a StopMaterializedViewRefreshTaskRunInput.
Sourceimpl StopMaterializedViewRefreshTaskRunInputBuilder
impl StopMaterializedViewRefreshTaskRunInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<StopMaterializedViewRefreshTaskRunOutput, SdkError<StopMaterializedViewRefreshTaskRunError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<StopMaterializedViewRefreshTaskRunOutput, SdkError<StopMaterializedViewRefreshTaskRunError, HttpResponse>>
Sends a request with this input using the given client.