#[non_exhaustive]pub enum StopMaterializedViewRefreshTaskRunError {
AccessDeniedException(AccessDeniedException),
InvalidInputException(InvalidInputException),
MaterializedViewRefreshTaskNotRunningException(MaterializedViewRefreshTaskNotRunningException),
MaterializedViewRefreshTaskStoppingException(MaterializedViewRefreshTaskStoppingException),
OperationTimeoutException(OperationTimeoutException),
Unhandled(Unhandled),
}Expand description
Error type for the StopMaterializedViewRefreshTaskRunError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AccessDeniedException(AccessDeniedException)
Access to a resource was denied.
InvalidInputException(InvalidInputException)
The input provided was not valid.
MaterializedViewRefreshTaskNotRunningException(MaterializedViewRefreshTaskNotRunningException)
Exception thrown when stopping a task that is not in running state.
MaterializedViewRefreshTaskStoppingException(MaterializedViewRefreshTaskStoppingException)
Exception thrown when a task is already in stopping state.
OperationTimeoutException(OperationTimeoutException)
The operation timed out.
Unhandled(Unhandled)
Matching Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
Sourceimpl StopMaterializedViewRefreshTaskRunError
impl StopMaterializedViewRefreshTaskRunError
Sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the StopMaterializedViewRefreshTaskRunError::Unhandled variant from any error type.
Sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the StopMaterializedViewRefreshTaskRunError::Unhandled variant from an ErrorMetadata.
Sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
Sourcepub fn is_access_denied_exception(&self) -> bool
pub fn is_access_denied_exception(&self) -> bool
Returns true if the error kind is StopMaterializedViewRefreshTaskRunError::AccessDeniedException.
Sourcepub fn is_invalid_input_exception(&self) -> bool
pub fn is_invalid_input_exception(&self) -> bool
Returns true if the error kind is StopMaterializedViewRefreshTaskRunError::InvalidInputException.
Sourcepub fn is_materialized_view_refresh_task_not_running_exception(&self) -> bool
pub fn is_materialized_view_refresh_task_not_running_exception(&self) -> bool
Returns true if the error kind is StopMaterializedViewRefreshTaskRunError::MaterializedViewRefreshTaskNotRunningException.
Sourcepub fn is_materialized_view_refresh_task_stopping_exception(&self) -> bool
pub fn is_materialized_view_refresh_task_stopping_exception(&self) -> bool
Returns true if the error kind is StopMaterializedViewRefreshTaskRunError::MaterializedViewRefreshTaskStoppingException.
Sourcepub fn is_operation_timeout_exception(&self) -> bool
pub fn is_operation_timeout_exception(&self) -> bool
Returns true if the error kind is StopMaterializedViewRefreshTaskRunError::OperationTimeoutException.