#[non_exhaustive]pub struct StopMaterializedViewRefreshTaskRunInput {
pub catalog_id: Option<String>,
pub database_name: Option<String>,
pub table_name: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.catalog_id: Option<String>The ID of the Data Catalog where the table reside. If none is supplied, the account ID is used by default.
database_name: Option<String>The name of the database where the table resides.
table_name: Option<String>The name of the table to generate statistics.
Implementations
Sourceimpl StopMaterializedViewRefreshTaskRunInput
impl StopMaterializedViewRefreshTaskRunInput
Sourcepub fn catalog_id(&self) -> Option<&str>
pub fn catalog_id(&self) -> Option<&str>
The ID of the Data Catalog where the table reside. If none is supplied, the account ID is used by default.
Sourcepub fn database_name(&self) -> Option<&str>
pub fn database_name(&self) -> Option<&str>
The name of the database where the table resides.
Sourcepub fn table_name(&self) -> Option<&str>
pub fn table_name(&self) -> Option<&str>
The name of the table to generate statistics.
Sourceimpl StopMaterializedViewRefreshTaskRunInput
impl StopMaterializedViewRefreshTaskRunInput
Sourcepub fn builder() -> StopMaterializedViewRefreshTaskRunInputBuilder
pub fn builder() -> StopMaterializedViewRefreshTaskRunInputBuilder
Creates a new builder-style object to manufacture StopMaterializedViewRefreshTaskRunInput.