pub struct TestConnectionFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to TestConnection.
Tests a connection to a service to validate the service credentials that you provide.
You can either provide an existing connection name or a TestConnectionInput for testing a non-existing connection input. Providing both at the same time will cause an error.
If the action is successful, the service sends back an HTTP 200 response.
Implementations
Sourceimpl TestConnectionFluentBuilder
impl TestConnectionFluentBuilder
Sourcepub fn as_input(&self) -> &TestConnectionInputBuilder
pub fn as_input(&self) -> &TestConnectionInputBuilder
Access the TestConnection as a reference.
Sourcepub async fn send(
self,
) -> Result<TestConnectionOutput, SdkError<TestConnectionError, HttpResponse>>
pub async fn send( self, ) -> Result<TestConnectionOutput, SdkError<TestConnectionError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<TestConnectionOutput, TestConnectionError, Self>
pub fn customize( self, ) -> CustomizableOperation<TestConnectionOutput, TestConnectionError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn connection_name(self, input: impl Into<String>) -> Self
pub fn connection_name(self, input: impl Into<String>) -> Self
Optional. The name of the connection to test. If only name is provided, the operation will get the connection and use that for testing.
Sourcepub fn set_connection_name(self, input: Option<String>) -> Self
pub fn set_connection_name(self, input: Option<String>) -> Self
Optional. The name of the connection to test. If only name is provided, the operation will get the connection and use that for testing.
Sourcepub fn get_connection_name(&self) -> &Option<String>
pub fn get_connection_name(&self) -> &Option<String>
Optional. The name of the connection to test. If only name is provided, the operation will get the connection and use that for testing.
Sourcepub fn catalog_id(self, input: impl Into<String>) -> Self
pub fn catalog_id(self, input: impl Into<String>) -> Self
The catalog ID where the connection resides.
Sourcepub fn set_catalog_id(self, input: Option<String>) -> Self
pub fn set_catalog_id(self, input: Option<String>) -> Self
The catalog ID where the connection resides.
Sourcepub fn get_catalog_id(&self) -> &Option<String>
pub fn get_catalog_id(&self) -> &Option<String>
The catalog ID where the connection resides.
Sourcepub fn test_connection_input(self, input: TestConnectionInput) -> Self
pub fn test_connection_input(self, input: TestConnectionInput) -> Self
A structure that is used to specify testing a connection to a service.
Sourcepub fn set_test_connection_input(
self,
input: Option<TestConnectionInput>,
) -> Self
pub fn set_test_connection_input( self, input: Option<TestConnectionInput>, ) -> Self
A structure that is used to specify testing a connection to a service.
Sourcepub fn get_test_connection_input(&self) -> &Option<TestConnectionInput>
pub fn get_test_connection_input(&self) -> &Option<TestConnectionInput>
A structure that is used to specify testing a connection to a service.