#[non_exhaustive]pub struct TestConnectionInputBuilder { /* private fields */ }Expand description
A builder for TestConnectionInput.
Implementations
Sourceimpl TestConnectionInputBuilder
impl TestConnectionInputBuilder
Sourcepub fn connection_name(self, input: impl Into<String>) -> Self
pub fn connection_name(self, input: impl Into<String>) -> Self
Optional. The name of the connection to test. If only name is provided, the operation will get the connection and use that for testing.
Sourcepub fn set_connection_name(self, input: Option<String>) -> Self
pub fn set_connection_name(self, input: Option<String>) -> Self
Optional. The name of the connection to test. If only name is provided, the operation will get the connection and use that for testing.
Sourcepub fn get_connection_name(&self) -> &Option<String>
pub fn get_connection_name(&self) -> &Option<String>
Optional. The name of the connection to test. If only name is provided, the operation will get the connection and use that for testing.
Sourcepub fn catalog_id(self, input: impl Into<String>) -> Self
pub fn catalog_id(self, input: impl Into<String>) -> Self
The catalog ID where the connection resides.
Sourcepub fn set_catalog_id(self, input: Option<String>) -> Self
pub fn set_catalog_id(self, input: Option<String>) -> Self
The catalog ID where the connection resides.
Sourcepub fn get_catalog_id(&self) -> &Option<String>
pub fn get_catalog_id(&self) -> &Option<String>
The catalog ID where the connection resides.
Sourcepub fn test_connection_input(self, input: TestConnectionInput) -> Self
pub fn test_connection_input(self, input: TestConnectionInput) -> Self
A structure that is used to specify testing a connection to a service.
Sourcepub fn set_test_connection_input(
self,
input: Option<TestConnectionInput>,
) -> Self
pub fn set_test_connection_input( self, input: Option<TestConnectionInput>, ) -> Self
A structure that is used to specify testing a connection to a service.
Sourcepub fn get_test_connection_input(&self) -> &Option<TestConnectionInput>
pub fn get_test_connection_input(&self) -> &Option<TestConnectionInput>
A structure that is used to specify testing a connection to a service.
Sourcepub fn build(self) -> Result<TestConnectionInput, BuildError>
pub fn build(self) -> Result<TestConnectionInput, BuildError>
Consumes the builder and constructs a TestConnectionInput.
Sourceimpl TestConnectionInputBuilder
impl TestConnectionInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<TestConnectionOutput, SdkError<TestConnectionError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<TestConnectionOutput, SdkError<TestConnectionError, HttpResponse>>
Sends a request with this input using the given client.