#[non_exhaustive]pub struct TestConnectionInput {
pub connection_name: Option<String>,
pub catalog_id: Option<String>,
pub test_connection_input: Option<TestConnectionInput>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.connection_name: Option<String>Optional. The name of the connection to test. If only name is provided, the operation will get the connection and use that for testing.
catalog_id: Option<String>The catalog ID where the connection resides.
test_connection_input: Option<TestConnectionInput>A structure that is used to specify testing a connection to a service.
Implementations
Sourceimpl TestConnectionInput
impl TestConnectionInput
Sourcepub fn connection_name(&self) -> Option<&str>
pub fn connection_name(&self) -> Option<&str>
Optional. The name of the connection to test. If only name is provided, the operation will get the connection and use that for testing.
Sourcepub fn catalog_id(&self) -> Option<&str>
pub fn catalog_id(&self) -> Option<&str>
The catalog ID where the connection resides.
Sourcepub fn test_connection_input(&self) -> Option<&TestConnectionInput>
pub fn test_connection_input(&self) -> Option<&TestConnectionInput>
A structure that is used to specify testing a connection to a service.
Sourceimpl TestConnectionInput
impl TestConnectionInput
Sourcepub fn builder() -> TestConnectionInputBuilder
pub fn builder() -> TestConnectionInputBuilder
Creates a new builder-style object to manufacture TestConnectionInput.