pub struct UpdateAssetFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to UpdateAsset.
Updates the name and description of an existing asset in Glue Data Catalog. Only the fields that you provide are updated.
Implementations
Sourceimpl UpdateAssetFluentBuilder
impl UpdateAssetFluentBuilder
Sourcepub fn as_input(&self) -> &UpdateAssetInputBuilder
pub fn as_input(&self) -> &UpdateAssetInputBuilder
Access the UpdateAsset as a reference.
Sourcepub async fn send(
self,
) -> Result<UpdateAssetOutput, SdkError<UpdateAssetError, HttpResponse>>
pub async fn send( self, ) -> Result<UpdateAssetOutput, SdkError<UpdateAssetError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<UpdateAssetOutput, UpdateAssetError, Self>
pub fn customize( self, ) -> CustomizableOperation<UpdateAssetOutput, UpdateAssetError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn identifier(self, input: impl Into<String>) -> Self
pub fn identifier(self, input: impl Into<String>) -> Self
The unique identifier of the asset to update.
Sourcepub fn set_identifier(self, input: Option<String>) -> Self
pub fn set_identifier(self, input: Option<String>) -> Self
The unique identifier of the asset to update.
Sourcepub fn get_identifier(&self) -> &Option<String>
pub fn get_identifier(&self) -> &Option<String>
The unique identifier of the asset to update.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
The new description of the asset.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
The new description of the asset.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
The new description of the asset.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.