#[non_exhaustive]pub struct UpdateAssetInputBuilder { /* private fields */ }Expand description
A builder for UpdateAssetInput.
Implementations
Sourceimpl UpdateAssetInputBuilder
impl UpdateAssetInputBuilder
Sourcepub fn identifier(self, input: impl Into<String>) -> Self
pub fn identifier(self, input: impl Into<String>) -> Self
The unique identifier of the asset to update.
This field is required.Sourcepub fn set_identifier(self, input: Option<String>) -> Self
pub fn set_identifier(self, input: Option<String>) -> Self
The unique identifier of the asset to update.
Sourcepub fn get_identifier(&self) -> &Option<String>
pub fn get_identifier(&self) -> &Option<String>
The unique identifier of the asset to update.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
The new description of the asset.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
The new description of the asset.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
The new description of the asset.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn build(self) -> Result<UpdateAssetInput, BuildError>
pub fn build(self) -> Result<UpdateAssetInput, BuildError>
Consumes the builder and constructs a UpdateAssetInput.
Sourceimpl UpdateAssetInputBuilder
impl UpdateAssetInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<UpdateAssetOutput, SdkError<UpdateAssetError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<UpdateAssetOutput, SdkError<UpdateAssetError, HttpResponse>>
Sends a request with this input using the given client.