#[non_exhaustive]pub struct UpdateAssetOutputBuilder { /* private fields */ }Expand description
A builder for UpdateAssetOutput.
Implementations
Sourceimpl UpdateAssetOutputBuilder
impl UpdateAssetOutputBuilder
Sourcepub fn id(self, input: impl Into<String>) -> Self
pub fn id(self, input: impl Into<String>) -> Self
The unique identifier of the asset.
This field is required.Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
The description of the asset.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
The description of the asset.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
The description of the asset.
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
The timestamp at which the asset was last updated.
Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
The timestamp at which the asset was last updated.
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
The timestamp at which the asset was last updated.
Sourcepub fn build(self) -> Result<UpdateAssetOutput, BuildError>
pub fn build(self) -> Result<UpdateAssetOutput, BuildError>
Consumes the builder and constructs a UpdateAssetOutput.
This method will fail if any of the following fields are not set: