#[non_exhaustive]pub struct UpdateAssetOutput {
pub id: String,
pub name: Option<String>,
pub description: Option<String>,
pub updated_at: Option<DateTime>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: StringThe unique identifier of the asset.
name: Option<String>The name of the asset.
description: Option<String>The description of the asset.
updated_at: Option<DateTime>The timestamp at which the asset was last updated.
Implementations
Sourceimpl UpdateAssetOutput
impl UpdateAssetOutput
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The description of the asset.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The timestamp at which the asset was last updated.
Sourceimpl UpdateAssetOutput
impl UpdateAssetOutput
Sourcepub fn builder() -> UpdateAssetOutputBuilder
pub fn builder() -> UpdateAssetOutputBuilder
Creates a new builder-style object to manufacture UpdateAssetOutput.