#[non_exhaustive]pub struct UpdateBlueprintOutputBuilder { /* private fields */ }Expand description
A builder for UpdateBlueprintOutput.
Implementations
Sourceimpl UpdateBlueprintOutputBuilder
impl UpdateBlueprintOutputBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
Returns the name of the blueprint that was updated.
Sourcepub fn set_name(self, input: Option<String>) -> Self
pub fn set_name(self, input: Option<String>) -> Self
Returns the name of the blueprint that was updated.
Sourcepub fn build(self) -> UpdateBlueprintOutput
pub fn build(self) -> UpdateBlueprintOutput
Consumes the builder and constructs a UpdateBlueprintOutput.