#[non_exhaustive]pub struct UpdateCatalogInputBuilder { /* private fields */ }Expand description
A builder for UpdateCatalogInput.
Implementations
Sourceimpl UpdateCatalogInputBuilder
impl UpdateCatalogInputBuilder
Sourcepub fn catalog_id(self, input: impl Into<String>) -> Self
pub fn catalog_id(self, input: impl Into<String>) -> Self
The ID of the catalog.
This field is required.Sourcepub fn set_catalog_id(self, input: Option<String>) -> Self
pub fn set_catalog_id(self, input: Option<String>) -> Self
The ID of the catalog.
Sourcepub fn get_catalog_id(&self) -> &Option<String>
pub fn get_catalog_id(&self) -> &Option<String>
The ID of the catalog.
Sourcepub fn catalog_input(self, input: CatalogInput) -> Self
pub fn catalog_input(self, input: CatalogInput) -> Self
A CatalogInput object specifying the new properties of an existing catalog.
Sourcepub fn set_catalog_input(self, input: Option<CatalogInput>) -> Self
pub fn set_catalog_input(self, input: Option<CatalogInput>) -> Self
A CatalogInput object specifying the new properties of an existing catalog.
Sourcepub fn get_catalog_input(&self) -> &Option<CatalogInput>
pub fn get_catalog_input(&self) -> &Option<CatalogInput>
A CatalogInput object specifying the new properties of an existing catalog.
Sourcepub fn build(self) -> Result<UpdateCatalogInput, BuildError>
pub fn build(self) -> Result<UpdateCatalogInput, BuildError>
Consumes the builder and constructs a UpdateCatalogInput.
Sourceimpl UpdateCatalogInputBuilder
impl UpdateCatalogInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<UpdateCatalogOutput, SdkError<UpdateCatalogError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<UpdateCatalogOutput, SdkError<UpdateCatalogError, HttpResponse>>
Sends a request with this input using the given client.