#[non_exhaustive]pub enum UpdateCatalogError {
AccessDeniedException(AccessDeniedException),
ConcurrentModificationException(ConcurrentModificationException),
EntityNotFoundException(EntityNotFoundException),
FederationSourceException(FederationSourceException),
GlueEncryptionException(GlueEncryptionException),
InternalServiceException(InternalServiceException),
InvalidInputException(InvalidInputException),
OperationTimeoutException(OperationTimeoutException),
Unhandled(Unhandled),
}Expand description
Error type for the UpdateCatalogError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AccessDeniedException(AccessDeniedException)
Access to a resource was denied.
ConcurrentModificationException(ConcurrentModificationException)
Two processes are trying to modify a resource simultaneously.
EntityNotFoundException(EntityNotFoundException)
A specified entity does not exist
FederationSourceException(FederationSourceException)
A federation source failed.
GlueEncryptionException(GlueEncryptionException)
An encryption operation failed.
InternalServiceException(InternalServiceException)
An internal service error occurred.
InvalidInputException(InvalidInputException)
The input provided was not valid.
OperationTimeoutException(OperationTimeoutException)
The operation timed out.
Unhandled(Unhandled)
Matching Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
Sourceimpl UpdateCatalogError
impl UpdateCatalogError
Sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the UpdateCatalogError::Unhandled variant from any error type.
Sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the UpdateCatalogError::Unhandled variant from an ErrorMetadata.
Sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
Sourcepub fn is_access_denied_exception(&self) -> bool
pub fn is_access_denied_exception(&self) -> bool
Returns true if the error kind is UpdateCatalogError::AccessDeniedException.
Sourcepub fn is_concurrent_modification_exception(&self) -> bool
pub fn is_concurrent_modification_exception(&self) -> bool
Returns true if the error kind is UpdateCatalogError::ConcurrentModificationException.
Sourcepub fn is_entity_not_found_exception(&self) -> bool
pub fn is_entity_not_found_exception(&self) -> bool
Returns true if the error kind is UpdateCatalogError::EntityNotFoundException.
Sourcepub fn is_federation_source_exception(&self) -> bool
pub fn is_federation_source_exception(&self) -> bool
Returns true if the error kind is UpdateCatalogError::FederationSourceException.
Sourcepub fn is_glue_encryption_exception(&self) -> bool
pub fn is_glue_encryption_exception(&self) -> bool
Returns true if the error kind is UpdateCatalogError::GlueEncryptionException.
Sourcepub fn is_internal_service_exception(&self) -> bool
pub fn is_internal_service_exception(&self) -> bool
Returns true if the error kind is UpdateCatalogError::InternalServiceException.
Sourcepub fn is_invalid_input_exception(&self) -> bool
pub fn is_invalid_input_exception(&self) -> bool
Returns true if the error kind is UpdateCatalogError::InvalidInputException.
Sourcepub fn is_operation_timeout_exception(&self) -> bool
pub fn is_operation_timeout_exception(&self) -> bool
Returns true if the error kind is UpdateCatalogError::OperationTimeoutException.