#[non_exhaustive]pub struct UpdateCatalogInput {
pub catalog_id: Option<String>,
pub catalog_input: Option<CatalogInput>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.catalog_id: Option<String>The ID of the catalog.
catalog_input: Option<CatalogInput>A CatalogInput object specifying the new properties of an existing catalog.
Implementations
Sourceimpl UpdateCatalogInput
impl UpdateCatalogInput
Sourcepub fn catalog_id(&self) -> Option<&str>
pub fn catalog_id(&self) -> Option<&str>
The ID of the catalog.
Sourcepub fn catalog_input(&self) -> Option<&CatalogInput>
pub fn catalog_input(&self) -> Option<&CatalogInput>
A CatalogInput object specifying the new properties of an existing catalog.
Sourceimpl UpdateCatalogInput
impl UpdateCatalogInput
Sourcepub fn builder() -> UpdateCatalogInputBuilder
pub fn builder() -> UpdateCatalogInputBuilder
Creates a new builder-style object to manufacture UpdateCatalogInput.