#[non_exhaustive]pub struct UpdateGlossaryInputBuilder { /* private fields */ }Expand description
A builder for UpdateGlossaryInput.
Implementations
Sourceimpl UpdateGlossaryInputBuilder
impl UpdateGlossaryInputBuilder
Sourcepub fn identifier(self, input: impl Into<String>) -> Self
pub fn identifier(self, input: impl Into<String>) -> Self
The unique identifier of the glossary to update.
This field is required.Sourcepub fn set_identifier(self, input: Option<String>) -> Self
pub fn set_identifier(self, input: Option<String>) -> Self
The unique identifier of the glossary to update.
Sourcepub fn get_identifier(&self) -> &Option<String>
pub fn get_identifier(&self) -> &Option<String>
The unique identifier of the glossary to update.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
The updated description of the glossary.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
The updated description of the glossary.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
The updated description of the glossary.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn build(self) -> Result<UpdateGlossaryInput, BuildError>
pub fn build(self) -> Result<UpdateGlossaryInput, BuildError>
Consumes the builder and constructs a UpdateGlossaryInput.
Sourceimpl UpdateGlossaryInputBuilder
impl UpdateGlossaryInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<UpdateGlossaryOutput, SdkError<UpdateGlossaryError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<UpdateGlossaryOutput, SdkError<UpdateGlossaryError, HttpResponse>>
Sends a request with this input using the given client.