#[non_exhaustive]pub struct UpdateGlossaryInput {
pub identifier: Option<String>,
pub name: Option<String>,
pub description: Option<String>,
pub client_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.identifier: Option<String>The unique identifier of the glossary to update.
name: Option<String>The updated name of the glossary.
description: Option<String>The updated description of the glossary.
client_token: Option<String>A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Implementations
Sourceimpl UpdateGlossaryInput
impl UpdateGlossaryInput
Sourcepub fn identifier(&self) -> Option<&str>
pub fn identifier(&self) -> Option<&str>
The unique identifier of the glossary to update.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The updated description of the glossary.
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourceimpl UpdateGlossaryInput
impl UpdateGlossaryInput
Sourcepub fn builder() -> UpdateGlossaryInputBuilder
pub fn builder() -> UpdateGlossaryInputBuilder
Creates a new builder-style object to manufacture UpdateGlossaryInput.