pub struct UpdateGlossaryTermFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to UpdateGlossaryTerm.
Updates a glossary term in Glue Data Catalog.
Implementations
Sourceimpl UpdateGlossaryTermFluentBuilder
impl UpdateGlossaryTermFluentBuilder
Sourcepub fn as_input(&self) -> &UpdateGlossaryTermInputBuilder
pub fn as_input(&self) -> &UpdateGlossaryTermInputBuilder
Access the UpdateGlossaryTerm as a reference.
Sourcepub async fn send(
self,
) -> Result<UpdateGlossaryTermOutput, SdkError<UpdateGlossaryTermError, HttpResponse>>
pub async fn send( self, ) -> Result<UpdateGlossaryTermOutput, SdkError<UpdateGlossaryTermError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<UpdateGlossaryTermOutput, UpdateGlossaryTermError, Self>
pub fn customize( self, ) -> CustomizableOperation<UpdateGlossaryTermOutput, UpdateGlossaryTermError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn identifier(self, input: impl Into<String>) -> Self
pub fn identifier(self, input: impl Into<String>) -> Self
The unique identifier of the glossary term to update.
Sourcepub fn set_identifier(self, input: Option<String>) -> Self
pub fn set_identifier(self, input: Option<String>) -> Self
The unique identifier of the glossary term to update.
Sourcepub fn get_identifier(&self) -> &Option<String>
pub fn get_identifier(&self) -> &Option<String>
The unique identifier of the glossary term to update.
Sourcepub fn short_description(self, input: impl Into<String>) -> Self
pub fn short_description(self, input: impl Into<String>) -> Self
The updated short description of the glossary term.
Sourcepub fn set_short_description(self, input: Option<String>) -> Self
pub fn set_short_description(self, input: Option<String>) -> Self
The updated short description of the glossary term.
Sourcepub fn get_short_description(&self) -> &Option<String>
pub fn get_short_description(&self) -> &Option<String>
The updated short description of the glossary term.
Sourcepub fn long_description(self, input: impl Into<String>) -> Self
pub fn long_description(self, input: impl Into<String>) -> Self
The updated long description of the glossary term.
Sourcepub fn set_long_description(self, input: Option<String>) -> Self
pub fn set_long_description(self, input: Option<String>) -> Self
The updated long description of the glossary term.
Sourcepub fn get_long_description(&self) -> &Option<String>
pub fn get_long_description(&self) -> &Option<String>
The updated long description of the glossary term.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.