#[non_exhaustive]pub struct UpdateGlossaryTermInputBuilder { /* private fields */ }Expand description
A builder for UpdateGlossaryTermInput.
Implementations
Sourceimpl UpdateGlossaryTermInputBuilder
impl UpdateGlossaryTermInputBuilder
Sourcepub fn identifier(self, input: impl Into<String>) -> Self
pub fn identifier(self, input: impl Into<String>) -> Self
The unique identifier of the glossary term to update.
This field is required.Sourcepub fn set_identifier(self, input: Option<String>) -> Self
pub fn set_identifier(self, input: Option<String>) -> Self
The unique identifier of the glossary term to update.
Sourcepub fn get_identifier(&self) -> &Option<String>
pub fn get_identifier(&self) -> &Option<String>
The unique identifier of the glossary term to update.
Sourcepub fn short_description(self, input: impl Into<String>) -> Self
pub fn short_description(self, input: impl Into<String>) -> Self
The updated short description of the glossary term.
Sourcepub fn set_short_description(self, input: Option<String>) -> Self
pub fn set_short_description(self, input: Option<String>) -> Self
The updated short description of the glossary term.
Sourcepub fn get_short_description(&self) -> &Option<String>
pub fn get_short_description(&self) -> &Option<String>
The updated short description of the glossary term.
Sourcepub fn long_description(self, input: impl Into<String>) -> Self
pub fn long_description(self, input: impl Into<String>) -> Self
The updated long description of the glossary term.
Sourcepub fn set_long_description(self, input: Option<String>) -> Self
pub fn set_long_description(self, input: Option<String>) -> Self
The updated long description of the glossary term.
Sourcepub fn get_long_description(&self) -> &Option<String>
pub fn get_long_description(&self) -> &Option<String>
The updated long description of the glossary term.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn build(self) -> Result<UpdateGlossaryTermInput, BuildError>
pub fn build(self) -> Result<UpdateGlossaryTermInput, BuildError>
Consumes the builder and constructs a UpdateGlossaryTermInput.
Sourceimpl UpdateGlossaryTermInputBuilder
impl UpdateGlossaryTermInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<UpdateGlossaryTermOutput, SdkError<UpdateGlossaryTermError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<UpdateGlossaryTermOutput, SdkError<UpdateGlossaryTermError, HttpResponse>>
Sends a request with this input using the given client.