#[non_exhaustive]pub struct UpdateGlossaryTermInput {
pub identifier: Option<String>,
pub name: Option<String>,
pub short_description: Option<String>,
pub long_description: Option<String>,
pub client_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.identifier: Option<String>The unique identifier of the glossary term to update.
name: Option<String>The updated name of the glossary term.
short_description: Option<String>The updated short description of the glossary term.
long_description: Option<String>The updated long description of the glossary term.
client_token: Option<String>A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Implementations
Sourceimpl UpdateGlossaryTermInput
impl UpdateGlossaryTermInput
Sourcepub fn identifier(&self) -> Option<&str>
pub fn identifier(&self) -> Option<&str>
The unique identifier of the glossary term to update.
Sourcepub fn short_description(&self) -> Option<&str>
pub fn short_description(&self) -> Option<&str>
The updated short description of the glossary term.
Sourcepub fn long_description(&self) -> Option<&str>
pub fn long_description(&self) -> Option<&str>
The updated long description of the glossary term.
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourceimpl UpdateGlossaryTermInput
impl UpdateGlossaryTermInput
Sourcepub fn builder() -> UpdateGlossaryTermInputBuilder
pub fn builder() -> UpdateGlossaryTermInputBuilder
Creates a new builder-style object to manufacture UpdateGlossaryTermInput.