#[non_exhaustive]pub struct UpdateGlueIdentityCenterConfigurationInputBuilder { /* private fields */ }Expand description
A builder for UpdateGlueIdentityCenterConfigurationInput.
Implementations
Sourceimpl UpdateGlueIdentityCenterConfigurationInputBuilder
impl UpdateGlueIdentityCenterConfigurationInputBuilder
Sourcepub fn scopes(self, input: impl Into<String>) -> Self
pub fn scopes(self, input: impl Into<String>) -> Self
Appends an item to scopes.
To override the contents of this collection use set_scopes.
A list of Identity Center scopes that define the updated permissions and access levels for the Glue configuration.
Sourcepub fn set_scopes(self, input: Option<Vec<String>>) -> Self
pub fn set_scopes(self, input: Option<Vec<String>>) -> Self
A list of Identity Center scopes that define the updated permissions and access levels for the Glue configuration.
Sourcepub fn get_scopes(&self) -> &Option<Vec<String>>
pub fn get_scopes(&self) -> &Option<Vec<String>>
A list of Identity Center scopes that define the updated permissions and access levels for the Glue configuration.
Sourcepub fn user_background_sessions_enabled(self, input: bool) -> Self
pub fn user_background_sessions_enabled(self, input: bool) -> Self
Specifies whether users can run background sessions when using Identity Center authentication with Glue services.
Sourcepub fn set_user_background_sessions_enabled(self, input: Option<bool>) -> Self
pub fn set_user_background_sessions_enabled(self, input: Option<bool>) -> Self
Specifies whether users can run background sessions when using Identity Center authentication with Glue services.
Sourcepub fn get_user_background_sessions_enabled(&self) -> &Option<bool>
pub fn get_user_background_sessions_enabled(&self) -> &Option<bool>
Specifies whether users can run background sessions when using Identity Center authentication with Glue services.
Sourcepub fn build(
self,
) -> Result<UpdateGlueIdentityCenterConfigurationInput, BuildError>
pub fn build( self, ) -> Result<UpdateGlueIdentityCenterConfigurationInput, BuildError>
Consumes the builder and constructs a UpdateGlueIdentityCenterConfigurationInput.
Sourceimpl UpdateGlueIdentityCenterConfigurationInputBuilder
impl UpdateGlueIdentityCenterConfigurationInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<UpdateGlueIdentityCenterConfigurationOutput, SdkError<UpdateGlueIdentityCenterConfigurationError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<UpdateGlueIdentityCenterConfigurationOutput, SdkError<UpdateGlueIdentityCenterConfigurationError, HttpResponse>>
Sends a request with this input using the given client.