pub struct UpdateIntegrationResourcePropertyFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to UpdateIntegrationResourceProperty.
This API can be used for updating the ResourceProperty of the Glue connection (for the source) or Glue database ARN (for the target). These properties can include the role to access the connection or database. Since the same resource can be used across multiple integrations, updating resource properties will impact all the integrations using it.
Implementations
Sourceimpl UpdateIntegrationResourcePropertyFluentBuilder
impl UpdateIntegrationResourcePropertyFluentBuilder
Sourcepub fn as_input(&self) -> &UpdateIntegrationResourcePropertyInputBuilder
pub fn as_input(&self) -> &UpdateIntegrationResourcePropertyInputBuilder
Access the UpdateIntegrationResourceProperty as a reference.
Sourcepub async fn send(
self,
) -> Result<UpdateIntegrationResourcePropertyOutput, SdkError<UpdateIntegrationResourcePropertyError, HttpResponse>>
pub async fn send( self, ) -> Result<UpdateIntegrationResourcePropertyOutput, SdkError<UpdateIntegrationResourcePropertyError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<UpdateIntegrationResourcePropertyOutput, UpdateIntegrationResourcePropertyError, Self>
pub fn customize( self, ) -> CustomizableOperation<UpdateIntegrationResourcePropertyOutput, UpdateIntegrationResourcePropertyError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn resource_arn(self, input: impl Into<String>) -> Self
pub fn resource_arn(self, input: impl Into<String>) -> Self
The connection ARN of the source, or the database ARN of the target.
Sourcepub fn set_resource_arn(self, input: Option<String>) -> Self
pub fn set_resource_arn(self, input: Option<String>) -> Self
The connection ARN of the source, or the database ARN of the target.
Sourcepub fn get_resource_arn(&self) -> &Option<String>
pub fn get_resource_arn(&self) -> &Option<String>
The connection ARN of the source, or the database ARN of the target.
Sourcepub fn source_processing_properties(
self,
input: SourceProcessingProperties,
) -> Self
pub fn source_processing_properties( self, input: SourceProcessingProperties, ) -> Self
The resource properties associated with the integration source.
Sourcepub fn set_source_processing_properties(
self,
input: Option<SourceProcessingProperties>,
) -> Self
pub fn set_source_processing_properties( self, input: Option<SourceProcessingProperties>, ) -> Self
The resource properties associated with the integration source.
Sourcepub fn get_source_processing_properties(
&self,
) -> &Option<SourceProcessingProperties>
pub fn get_source_processing_properties( &self, ) -> &Option<SourceProcessingProperties>
The resource properties associated with the integration source.
Sourcepub fn target_processing_properties(
self,
input: TargetProcessingProperties,
) -> Self
pub fn target_processing_properties( self, input: TargetProcessingProperties, ) -> Self
The resource properties associated with the integration target.
Sourcepub fn set_target_processing_properties(
self,
input: Option<TargetProcessingProperties>,
) -> Self
pub fn set_target_processing_properties( self, input: Option<TargetProcessingProperties>, ) -> Self
The resource properties associated with the integration target.
Sourcepub fn get_target_processing_properties(
&self,
) -> &Option<TargetProcessingProperties>
pub fn get_target_processing_properties( &self, ) -> &Option<TargetProcessingProperties>
The resource properties associated with the integration target.