pub struct UpdateIntegrationTablePropertiesFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to UpdateIntegrationTableProperties.
This API is used to provide optional override properties for the tables that need to be replicated. These properties can include properties for filtering and partitioning for the source and target tables. To set both source and target properties the same API need to be invoked with the Glue connection ARN as ResourceArn with SourceTableConfig, and the Glue database ARN as ResourceArn with TargetTableConfig respectively.
The override will be reflected across all the integrations using same ResourceArn and source table.
Implementations
Sourceimpl UpdateIntegrationTablePropertiesFluentBuilder
impl UpdateIntegrationTablePropertiesFluentBuilder
Sourcepub fn as_input(&self) -> &UpdateIntegrationTablePropertiesInputBuilder
pub fn as_input(&self) -> &UpdateIntegrationTablePropertiesInputBuilder
Access the UpdateIntegrationTableProperties as a reference.
Sourcepub async fn send(
self,
) -> Result<UpdateIntegrationTablePropertiesOutput, SdkError<UpdateIntegrationTablePropertiesError, HttpResponse>>
pub async fn send( self, ) -> Result<UpdateIntegrationTablePropertiesOutput, SdkError<UpdateIntegrationTablePropertiesError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<UpdateIntegrationTablePropertiesOutput, UpdateIntegrationTablePropertiesError, Self>
pub fn customize( self, ) -> CustomizableOperation<UpdateIntegrationTablePropertiesOutput, UpdateIntegrationTablePropertiesError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn resource_arn(self, input: impl Into<String>) -> Self
pub fn resource_arn(self, input: impl Into<String>) -> Self
The connection ARN of the source, or the database ARN of the target.
Sourcepub fn set_resource_arn(self, input: Option<String>) -> Self
pub fn set_resource_arn(self, input: Option<String>) -> Self
The connection ARN of the source, or the database ARN of the target.
Sourcepub fn get_resource_arn(&self) -> &Option<String>
pub fn get_resource_arn(&self) -> &Option<String>
The connection ARN of the source, or the database ARN of the target.
Sourcepub fn table_name(self, input: impl Into<String>) -> Self
pub fn table_name(self, input: impl Into<String>) -> Self
The name of the table to be replicated.
Sourcepub fn set_table_name(self, input: Option<String>) -> Self
pub fn set_table_name(self, input: Option<String>) -> Self
The name of the table to be replicated.
Sourcepub fn get_table_name(&self) -> &Option<String>
pub fn get_table_name(&self) -> &Option<String>
The name of the table to be replicated.
Sourcepub fn source_table_config(self, input: SourceTableConfig) -> Self
pub fn source_table_config(self, input: SourceTableConfig) -> Self
A structure for the source table configuration.
Sourcepub fn set_source_table_config(self, input: Option<SourceTableConfig>) -> Self
pub fn set_source_table_config(self, input: Option<SourceTableConfig>) -> Self
A structure for the source table configuration.
Sourcepub fn get_source_table_config(&self) -> &Option<SourceTableConfig>
pub fn get_source_table_config(&self) -> &Option<SourceTableConfig>
A structure for the source table configuration.
Sourcepub fn target_table_config(self, input: TargetTableConfig) -> Self
pub fn target_table_config(self, input: TargetTableConfig) -> Self
A structure for the target table configuration.
Sourcepub fn set_target_table_config(self, input: Option<TargetTableConfig>) -> Self
pub fn set_target_table_config(self, input: Option<TargetTableConfig>) -> Self
A structure for the target table configuration.
Sourcepub fn get_target_table_config(&self) -> &Option<TargetTableConfig>
pub fn get_target_table_config(&self) -> &Option<TargetTableConfig>
A structure for the target table configuration.