pub struct UpdateTriggerFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to UpdateTrigger.
Updates a trigger definition.
Job arguments may be logged. Do not pass plaintext secrets as arguments. Retrieve secrets from a Glue Connection, Amazon Web Services Secrets Manager or other secret management mechanism if you intend to keep them within the Job.
Implementations
Sourceimpl UpdateTriggerFluentBuilder
impl UpdateTriggerFluentBuilder
Sourcepub fn as_input(&self) -> &UpdateTriggerInputBuilder
pub fn as_input(&self) -> &UpdateTriggerInputBuilder
Access the UpdateTrigger as a reference.
Sourcepub async fn send(
self,
) -> Result<UpdateTriggerOutput, SdkError<UpdateTriggerError, HttpResponse>>
pub async fn send( self, ) -> Result<UpdateTriggerOutput, SdkError<UpdateTriggerError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<UpdateTriggerOutput, UpdateTriggerError, Self>
pub fn customize( self, ) -> CustomizableOperation<UpdateTriggerOutput, UpdateTriggerError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn trigger_update(self, input: TriggerUpdate) -> Self
pub fn trigger_update(self, input: TriggerUpdate) -> Self
The new values with which to update the trigger.
Sourcepub fn set_trigger_update(self, input: Option<TriggerUpdate>) -> Self
pub fn set_trigger_update(self, input: Option<TriggerUpdate>) -> Self
The new values with which to update the trigger.
Sourcepub fn get_trigger_update(&self) -> &Option<TriggerUpdate>
pub fn get_trigger_update(&self) -> &Option<TriggerUpdate>
The new values with which to update the trigger.