#[non_exhaustive]pub struct AuthConfigurationBuilder { /* private fields */ }Expand description
A builder for AuthConfiguration.
Implementations
Sourceimpl AuthConfigurationBuilder
impl AuthConfigurationBuilder
Sourcepub fn authentication_type(self, input: Property) -> Self
pub fn authentication_type(self, input: Property) -> Self
The type of authentication for a connection.
This field is required.Sourcepub fn set_authentication_type(self, input: Option<Property>) -> Self
pub fn set_authentication_type(self, input: Option<Property>) -> Self
The type of authentication for a connection.
Sourcepub fn get_authentication_type(&self) -> &Option<Property>
pub fn get_authentication_type(&self) -> &Option<Property>
The type of authentication for a connection.
Sourcepub fn secret_arn(self, input: Property) -> Self
pub fn secret_arn(self, input: Property) -> Self
The Amazon Resource Name (ARN) for the Secrets Manager.
Sourcepub fn set_secret_arn(self, input: Option<Property>) -> Self
pub fn set_secret_arn(self, input: Option<Property>) -> Self
The Amazon Resource Name (ARN) for the Secrets Manager.
Sourcepub fn get_secret_arn(&self) -> &Option<Property>
pub fn get_secret_arn(&self) -> &Option<Property>
The Amazon Resource Name (ARN) for the Secrets Manager.
Sourcepub fn o_auth2_properties(self, k: impl Into<String>, v: Property) -> Self
pub fn o_auth2_properties(self, k: impl Into<String>, v: Property) -> Self
Adds a key-value pair to o_auth2_properties.
To override the contents of this collection use set_o_auth2_properties.
A map of key-value pairs for the OAuth2 properties. Each value is a a Property object.
Sourcepub fn set_o_auth2_properties(
self,
input: Option<HashMap<String, Property>>,
) -> Self
pub fn set_o_auth2_properties( self, input: Option<HashMap<String, Property>>, ) -> Self
A map of key-value pairs for the OAuth2 properties. Each value is a a Property object.
Sourcepub fn get_o_auth2_properties(&self) -> &Option<HashMap<String, Property>>
pub fn get_o_auth2_properties(&self) -> &Option<HashMap<String, Property>>
A map of key-value pairs for the OAuth2 properties. Each value is a a Property object.
Sourcepub fn basic_authentication_properties(
self,
k: impl Into<String>,
v: Property,
) -> Self
pub fn basic_authentication_properties( self, k: impl Into<String>, v: Property, ) -> Self
Adds a key-value pair to basic_authentication_properties.
To override the contents of this collection use set_basic_authentication_properties.
A map of key-value pairs for the OAuth2 properties. Each value is a a Property object.
Sourcepub fn set_basic_authentication_properties(
self,
input: Option<HashMap<String, Property>>,
) -> Self
pub fn set_basic_authentication_properties( self, input: Option<HashMap<String, Property>>, ) -> Self
A map of key-value pairs for the OAuth2 properties. Each value is a a Property object.
Sourcepub fn get_basic_authentication_properties(
&self,
) -> &Option<HashMap<String, Property>>
pub fn get_basic_authentication_properties( &self, ) -> &Option<HashMap<String, Property>>
A map of key-value pairs for the OAuth2 properties. Each value is a a Property object.
Sourcepub fn custom_authentication_properties(
self,
k: impl Into<String>,
v: Property,
) -> Self
pub fn custom_authentication_properties( self, k: impl Into<String>, v: Property, ) -> Self
Adds a key-value pair to custom_authentication_properties.
To override the contents of this collection use set_custom_authentication_properties.
A map of key-value pairs for the custom authentication properties. Each value is a a Property object.
Sourcepub fn set_custom_authentication_properties(
self,
input: Option<HashMap<String, Property>>,
) -> Self
pub fn set_custom_authentication_properties( self, input: Option<HashMap<String, Property>>, ) -> Self
A map of key-value pairs for the custom authentication properties. Each value is a a Property object.
Sourcepub fn get_custom_authentication_properties(
&self,
) -> &Option<HashMap<String, Property>>
pub fn get_custom_authentication_properties( &self, ) -> &Option<HashMap<String, Property>>
A map of key-value pairs for the custom authentication properties. Each value is a a Property object.
Sourcepub fn build(self) -> AuthConfiguration
pub fn build(self) -> AuthConfiguration
Consumes the builder and constructs a AuthConfiguration.