AuthenticationConfigurationBuilder

Struct AuthenticationConfigurationBuilder 

#[non_exhaustive]
pub struct AuthenticationConfigurationBuilder { /* private fields */ }
Implementations

Source

impl AuthenticationConfigurationBuilder

pub fn authentication_type(self, input: AuthenticationType) -> Self

A structure containing the authentication configuration.

pub fn set_authentication_type(self, input: Option<AuthenticationType>) -> Self

A structure containing the authentication configuration.

pub fn get_authentication_type(&self) -> &Option<AuthenticationType>

A structure containing the authentication configuration.

pub fn secret_arn(self, input: impl Into<String>) -> Self

The secret manager ARN to store credentials.

pub fn set_secret_arn(self, input: Option<String>) -> Self

The secret manager ARN to store credentials.

pub fn get_secret_arn(&self) -> &Option<String>

The secret manager ARN to store credentials.

pub fn kms_key_arn(self, input: impl Into<String>) -> Self

The Amazon Resource Name (ARN) of the KMS key used to encrypt sensitive authentication information. This key is used to protect credentials and other sensitive data stored within the authentication configuration.

pub fn set_kms_key_arn(self, input: Option<String>) -> Self

The Amazon Resource Name (ARN) of the KMS key used to encrypt sensitive authentication information. This key is used to protect credentials and other sensitive data stored within the authentication configuration.

pub fn get_kms_key_arn(&self) -> &Option<String>

The Amazon Resource Name (ARN) of the KMS key used to encrypt sensitive authentication information. This key is used to protect credentials and other sensitive data stored within the authentication configuration.

pub fn o_auth2_properties(self, input: OAuth2Properties) -> Self

The properties for OAuth2 authentication.

pub fn set_o_auth2_properties(self, input: Option<OAuth2Properties>) -> Self

The properties for OAuth2 authentication.

pub fn get_o_auth2_properties(&self) -> &Option<OAuth2Properties>

The properties for OAuth2 authentication.

pub fn build(self) -> AuthenticationConfiguration

Consumes the builder and constructs a AuthenticationConfiguration.