AuthenticationConfigurationInputBuilder

Struct AuthenticationConfigurationInputBuilder 

#[non_exhaustive]
pub struct AuthenticationConfigurationInputBuilder { /* private fields */ }
Implementations

Source

impl AuthenticationConfigurationInputBuilder

pub fn authentication_type(self, input: AuthenticationType) -> Self

A structure containing the authentication configuration in the CreateConnection request.

pub fn set_authentication_type(self, input: Option<AuthenticationType>) -> Self

A structure containing the authentication configuration in the CreateConnection request.

pub fn get_authentication_type(&self) -> &Option<AuthenticationType>

A structure containing the authentication configuration in the CreateConnection request.

pub fn o_auth2_properties(self, input: OAuth2PropertiesInput) -> Self

The properties for OAuth2 authentication in the CreateConnection request.

pub fn set_o_auth2_properties( self, input: Option<OAuth2PropertiesInput>, ) -> Self

The properties for OAuth2 authentication in the CreateConnection request.

pub fn get_o_auth2_properties(&self) -> &Option<OAuth2PropertiesInput>

The properties for OAuth2 authentication in the CreateConnection request.

pub fn secret_arn(self, input: impl Into<String>) -> Self

The secret manager ARN to store credentials in the CreateConnection request.

pub fn set_secret_arn(self, input: Option<String>) -> Self

The secret manager ARN to store credentials in the CreateConnection request.

pub fn get_secret_arn(&self) -> &Option<String>

The secret manager ARN to store credentials in the CreateConnection request.

pub fn kms_key_arn(self, input: impl Into<String>) -> Self

The ARN of the KMS key used to encrypt the connection. Only taken an as input in the request and stored in the Secret Manager.

pub fn set_kms_key_arn(self, input: Option<String>) -> Self

The ARN of the KMS key used to encrypt the connection. Only taken an as input in the request and stored in the Secret Manager.

pub fn get_kms_key_arn(&self) -> &Option<String>

The ARN of the KMS key used to encrypt the connection. Only taken an as input in the request and stored in the Secret Manager.

pub fn basic_authentication_credentials( self, input: BasicAuthenticationCredentials, ) -> Self

The credentials used when the authentication type is basic authentication.

pub fn set_basic_authentication_credentials( self, input: Option<BasicAuthenticationCredentials>, ) -> Self

The credentials used when the authentication type is basic authentication.

pub fn get_basic_authentication_credentials( &self, ) -> &Option<BasicAuthenticationCredentials>

The credentials used when the authentication type is basic authentication.

pub fn custom_authentication_credentials( self, k: impl Into<String>, v: impl Into<String>, ) -> Self

Adds a key-value pair to custom_authentication_credentials.

To override the contents of this collection use set_custom_authentication_credentials.

The credentials used when the authentication type is custom authentication.

pub fn set_custom_authentication_credentials( self, input: Option<HashMap<String, String>>, ) -> Self

The credentials used when the authentication type is custom authentication.

pub fn get_custom_authentication_credentials( &self, ) -> &Option<HashMap<String, String>>

The credentials used when the authentication type is custom authentication.

pub fn build(self) -> AuthenticationConfigurationInput

Consumes the builder and constructs a AuthenticationConfigurationInput.