#[non_exhaustive]pub struct AutoDataQualityBuilder { /* private fields */ }Expand description
A builder for AutoDataQuality.
Implementations
Sourceimpl AutoDataQualityBuilder
impl AutoDataQualityBuilder
Sourcepub fn is_enabled(self, input: bool) -> Self
pub fn is_enabled(self, input: bool) -> Self
Specifies whether automatic data quality evaluation is enabled. When set to true, data quality checks are performed automatically.
Sourcepub fn set_is_enabled(self, input: Option<bool>) -> Self
pub fn set_is_enabled(self, input: Option<bool>) -> Self
Specifies whether automatic data quality evaluation is enabled. When set to true, data quality checks are performed automatically.
Sourcepub fn get_is_enabled(&self) -> &Option<bool>
pub fn get_is_enabled(&self) -> &Option<bool>
Specifies whether automatic data quality evaluation is enabled. When set to true, data quality checks are performed automatically.
Sourcepub fn evaluation_context(self, input: impl Into<String>) -> Self
pub fn evaluation_context(self, input: impl Into<String>) -> Self
The evaluation context for the automatic data quality checks. This defines the scope and parameters for the data quality evaluation.
Sourcepub fn set_evaluation_context(self, input: Option<String>) -> Self
pub fn set_evaluation_context(self, input: Option<String>) -> Self
The evaluation context for the automatic data quality checks. This defines the scope and parameters for the data quality evaluation.
Sourcepub fn get_evaluation_context(&self) -> &Option<String>
pub fn get_evaluation_context(&self) -> &Option<String>
The evaluation context for the automatic data quality checks. This defines the scope and parameters for the data quality evaluation.
Sourcepub fn build(self) -> AutoDataQuality
pub fn build(self) -> AutoDataQuality
Consumes the builder and constructs a AutoDataQuality.