#[non_exhaustive]pub struct BasicAuthenticationPropertiesBuilder { /* private fields */ }Expand description
A builder for BasicAuthenticationProperties.
Implementations
Sourceimpl BasicAuthenticationPropertiesBuilder
impl BasicAuthenticationPropertiesBuilder
Sourcepub fn username(self, input: ConnectorProperty) -> Self
pub fn username(self, input: ConnectorProperty) -> Self
The username property name to use for Basic authentication credentials.
Sourcepub fn set_username(self, input: Option<ConnectorProperty>) -> Self
pub fn set_username(self, input: Option<ConnectorProperty>) -> Self
The username property name to use for Basic authentication credentials.
Sourcepub fn get_username(&self) -> &Option<ConnectorProperty>
pub fn get_username(&self) -> &Option<ConnectorProperty>
The username property name to use for Basic authentication credentials.
Sourcepub fn password(self, input: ConnectorProperty) -> Self
pub fn password(self, input: ConnectorProperty) -> Self
The password property name to use for Basic authentication credentials.
Sourcepub fn set_password(self, input: Option<ConnectorProperty>) -> Self
pub fn set_password(self, input: Option<ConnectorProperty>) -> Self
The password property name to use for Basic authentication credentials.
Sourcepub fn get_password(&self) -> &Option<ConnectorProperty>
pub fn get_password(&self) -> &Option<ConnectorProperty>
The password property name to use for Basic authentication credentials.
Sourcepub fn build(self) -> BasicAuthenticationProperties
pub fn build(self) -> BasicAuthenticationProperties
Consumes the builder and constructs a BasicAuthenticationProperties.