#[non_exhaustive]pub struct BetweenConfigurationBuilder { /* private fields */ }Expand description
A builder for BetweenConfiguration.
Implementations
Sourceimpl BetweenConfigurationBuilder
impl BetweenConfigurationBuilder
Sourcepub fn low_bound_key(self, input: impl Into<String>) -> Self
pub fn low_bound_key(self, input: impl Into<String>) -> Self
The parameter name used for the lower bound value in a BETWEEN filter operation.
Sourcepub fn set_low_bound_key(self, input: Option<String>) -> Self
pub fn set_low_bound_key(self, input: Option<String>) -> Self
The parameter name used for the lower bound value in a BETWEEN filter operation.
Sourcepub fn get_low_bound_key(&self) -> &Option<String>
pub fn get_low_bound_key(&self) -> &Option<String>
The parameter name used for the lower bound value in a BETWEEN filter operation.
Sourcepub fn high_bound_key(self, input: impl Into<String>) -> Self
pub fn high_bound_key(self, input: impl Into<String>) -> Self
The parameter name used for the upper bound value in a BETWEEN filter operation.
Sourcepub fn set_high_bound_key(self, input: Option<String>) -> Self
pub fn set_high_bound_key(self, input: Option<String>) -> Self
The parameter name used for the upper bound value in a BETWEEN filter operation.
Sourcepub fn get_high_bound_key(&self) -> &Option<String>
pub fn get_high_bound_key(&self) -> &Option<String>
The parameter name used for the upper bound value in a BETWEEN filter operation.
Sourcepub fn template(self, input: impl Into<String>) -> Self
pub fn template(self, input: impl Into<String>) -> Self
A template string for constructing the BETWEEN filter expression.
Sourcepub fn set_template(self, input: Option<String>) -> Self
pub fn set_template(self, input: Option<String>) -> Self
A template string for constructing the BETWEEN filter expression.
Sourcepub fn get_template(&self) -> &Option<String>
pub fn get_template(&self) -> &Option<String>
A template string for constructing the BETWEEN filter expression.
Sourcepub fn build(self) -> BetweenConfiguration
pub fn build(self) -> BetweenConfiguration
Consumes the builder and constructs a BetweenConfiguration.