#[non_exhaustive]pub struct CapabilitiesBuilder { /* private fields */ }Expand description
A builder for Capabilities.
Implementations
Sourceimpl CapabilitiesBuilder
impl CapabilitiesBuilder
Sourcepub fn supported_authentication_types(self, input: AuthenticationType) -> Self
pub fn supported_authentication_types(self, input: AuthenticationType) -> Self
Appends an item to supported_authentication_types.
To override the contents of this collection use set_supported_authentication_types.
A list of supported authentication types.
Sourcepub fn set_supported_authentication_types(
self,
input: Option<Vec<AuthenticationType>>,
) -> Self
pub fn set_supported_authentication_types( self, input: Option<Vec<AuthenticationType>>, ) -> Self
A list of supported authentication types.
Sourcepub fn get_supported_authentication_types(
&self,
) -> &Option<Vec<AuthenticationType>>
pub fn get_supported_authentication_types( &self, ) -> &Option<Vec<AuthenticationType>>
A list of supported authentication types.
Sourcepub fn supported_data_operations(self, input: DataOperation) -> Self
pub fn supported_data_operations(self, input: DataOperation) -> Self
Appends an item to supported_data_operations.
To override the contents of this collection use set_supported_data_operations.
A list of supported data operations.
Sourcepub fn set_supported_data_operations(
self,
input: Option<Vec<DataOperation>>,
) -> Self
pub fn set_supported_data_operations( self, input: Option<Vec<DataOperation>>, ) -> Self
A list of supported data operations.
Sourcepub fn get_supported_data_operations(&self) -> &Option<Vec<DataOperation>>
pub fn get_supported_data_operations(&self) -> &Option<Vec<DataOperation>>
A list of supported data operations.
Sourcepub fn supported_compute_environments(self, input: ComputeEnvironment) -> Self
pub fn supported_compute_environments(self, input: ComputeEnvironment) -> Self
Appends an item to supported_compute_environments.
To override the contents of this collection use set_supported_compute_environments.
A list of supported compute environments.
Sourcepub fn set_supported_compute_environments(
self,
input: Option<Vec<ComputeEnvironment>>,
) -> Self
pub fn set_supported_compute_environments( self, input: Option<Vec<ComputeEnvironment>>, ) -> Self
A list of supported compute environments.
Sourcepub fn get_supported_compute_environments(
&self,
) -> &Option<Vec<ComputeEnvironment>>
pub fn get_supported_compute_environments( &self, ) -> &Option<Vec<ComputeEnvironment>>
A list of supported compute environments.
Sourcepub fn build(self) -> Result<Capabilities, BuildError>
pub fn build(self) -> Result<Capabilities, BuildError>
Consumes the builder and constructs a Capabilities.
This method will fail if any of the following fields are not set: