#[non_exhaustive]pub struct ClientCredentialsPropertiesBuilder { /* private fields */ }Expand description
A builder for ClientCredentialsProperties.
Implementations
Sourceimpl ClientCredentialsPropertiesBuilder
impl ClientCredentialsPropertiesBuilder
Sourcepub fn token_url(self, input: ConnectorProperty) -> Self
pub fn token_url(self, input: ConnectorProperty) -> Self
The token endpoint URL where the client will request access tokens using client credentials.
Sourcepub fn set_token_url(self, input: Option<ConnectorProperty>) -> Self
pub fn set_token_url(self, input: Option<ConnectorProperty>) -> Self
The token endpoint URL where the client will request access tokens using client credentials.
Sourcepub fn get_token_url(&self) -> &Option<ConnectorProperty>
pub fn get_token_url(&self) -> &Option<ConnectorProperty>
The token endpoint URL where the client will request access tokens using client credentials.
Sourcepub fn request_method(self, input: HttpMethod) -> Self
pub fn request_method(self, input: HttpMethod) -> Self
The HTTP method to use when making token requests, typically POST.
Sourcepub fn set_request_method(self, input: Option<HttpMethod>) -> Self
pub fn set_request_method(self, input: Option<HttpMethod>) -> Self
The HTTP method to use when making token requests, typically POST.
Sourcepub fn get_request_method(&self) -> &Option<HttpMethod>
pub fn get_request_method(&self) -> &Option<HttpMethod>
The HTTP method to use when making token requests, typically POST.
Sourcepub fn content_type(self, input: ContentType) -> Self
pub fn content_type(self, input: ContentType) -> Self
The content type to use for token requests, such as application/x-www-form-urlencoded or application/json.
Sourcepub fn set_content_type(self, input: Option<ContentType>) -> Self
pub fn set_content_type(self, input: Option<ContentType>) -> Self
The content type to use for token requests, such as application/x-www-form-urlencoded or application/json.
Sourcepub fn get_content_type(&self) -> &Option<ContentType>
pub fn get_content_type(&self) -> &Option<ContentType>
The content type to use for token requests, such as application/x-www-form-urlencoded or application/json.
Sourcepub fn client_id(self, input: ConnectorProperty) -> Self
pub fn client_id(self, input: ConnectorProperty) -> Self
The OAuth2 client identifier provided by the authorization server.
Sourcepub fn set_client_id(self, input: Option<ConnectorProperty>) -> Self
pub fn set_client_id(self, input: Option<ConnectorProperty>) -> Self
The OAuth2 client identifier provided by the authorization server.
Sourcepub fn get_client_id(&self) -> &Option<ConnectorProperty>
pub fn get_client_id(&self) -> &Option<ConnectorProperty>
The OAuth2 client identifier provided by the authorization server.
Sourcepub fn client_secret(self, input: ConnectorProperty) -> Self
pub fn client_secret(self, input: ConnectorProperty) -> Self
The OAuth2 client secret provided by the authorization server.
Sourcepub fn set_client_secret(self, input: Option<ConnectorProperty>) -> Self
pub fn set_client_secret(self, input: Option<ConnectorProperty>) -> Self
The OAuth2 client secret provided by the authorization server.
Sourcepub fn get_client_secret(&self) -> &Option<ConnectorProperty>
pub fn get_client_secret(&self) -> &Option<ConnectorProperty>
The OAuth2 client secret provided by the authorization server.
Sourcepub fn scope(self, input: ConnectorProperty) -> Self
pub fn scope(self, input: ConnectorProperty) -> Self
The OAuth2 scope that defines the level of access requested for the client credentials flow.
Sourcepub fn set_scope(self, input: Option<ConnectorProperty>) -> Self
pub fn set_scope(self, input: Option<ConnectorProperty>) -> Self
The OAuth2 scope that defines the level of access requested for the client credentials flow.
Sourcepub fn get_scope(&self) -> &Option<ConnectorProperty>
pub fn get_scope(&self) -> &Option<ConnectorProperty>
The OAuth2 scope that defines the level of access requested for the client credentials flow.
Sourcepub fn token_url_parameters(self, input: ConnectorProperty) -> Self
pub fn token_url_parameters(self, input: ConnectorProperty) -> Self
Appends an item to token_url_parameters.
To override the contents of this collection use set_token_url_parameters.
Additional parameters to include in token URL requests as key-value pairs.
Sourcepub fn set_token_url_parameters(
self,
input: Option<Vec<ConnectorProperty>>,
) -> Self
pub fn set_token_url_parameters( self, input: Option<Vec<ConnectorProperty>>, ) -> Self
Additional parameters to include in token URL requests as key-value pairs.
Sourcepub fn get_token_url_parameters(&self) -> &Option<Vec<ConnectorProperty>>
pub fn get_token_url_parameters(&self) -> &Option<Vec<ConnectorProperty>>
Additional parameters to include in token URL requests as key-value pairs.
Sourcepub fn build(self) -> ClientCredentialsProperties
pub fn build(self) -> ClientCredentialsProperties
Consumes the builder and constructs a ClientCredentialsProperties.