#[non_exhaustive]pub struct CompactionMetricsBuilder { /* private fields */ }Expand description
A builder for CompactionMetrics.
Implementations
Sourceimpl CompactionMetricsBuilder
impl CompactionMetricsBuilder
Sourcepub fn iceberg_metrics(self, input: IcebergCompactionMetrics) -> Self
pub fn iceberg_metrics(self, input: IcebergCompactionMetrics) -> Self
A structure containing the Iceberg compaction metrics for the optimizer run.
Sourcepub fn set_iceberg_metrics(
self,
input: Option<IcebergCompactionMetrics>,
) -> Self
pub fn set_iceberg_metrics( self, input: Option<IcebergCompactionMetrics>, ) -> Self
A structure containing the Iceberg compaction metrics for the optimizer run.
Sourcepub fn get_iceberg_metrics(&self) -> &Option<IcebergCompactionMetrics>
pub fn get_iceberg_metrics(&self) -> &Option<IcebergCompactionMetrics>
A structure containing the Iceberg compaction metrics for the optimizer run.
Sourcepub fn build(self) -> CompactionMetrics
pub fn build(self) -> CompactionMetrics
Consumes the builder and constructs a CompactionMetrics.