#[non_exhaustive]pub struct ComputeEnvironmentConfigurationBuilder { /* private fields */ }Expand description
A builder for ComputeEnvironmentConfiguration.
Implementations
Sourceimpl ComputeEnvironmentConfigurationBuilder
impl ComputeEnvironmentConfigurationBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
A name for the compute environment configuration.
This field is required.Sourcepub fn set_name(self, input: Option<String>) -> Self
pub fn set_name(self, input: Option<String>) -> Self
A name for the compute environment configuration.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
A description of the compute environment.
This field is required.Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
A description of the compute environment.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
A description of the compute environment.
Sourcepub fn compute_environment(self, input: ComputeEnvironment) -> Self
pub fn compute_environment(self, input: ComputeEnvironment) -> Self
The type of compute environment.
This field is required.Sourcepub fn set_compute_environment(self, input: Option<ComputeEnvironment>) -> Self
pub fn set_compute_environment(self, input: Option<ComputeEnvironment>) -> Self
The type of compute environment.
Sourcepub fn get_compute_environment(&self) -> &Option<ComputeEnvironment>
pub fn get_compute_environment(&self) -> &Option<ComputeEnvironment>
The type of compute environment.
Sourcepub fn supported_authentication_types(self, input: AuthenticationType) -> Self
pub fn supported_authentication_types(self, input: AuthenticationType) -> Self
Appends an item to supported_authentication_types.
To override the contents of this collection use set_supported_authentication_types.
The supported authentication types for the compute environment.
Sourcepub fn set_supported_authentication_types(
self,
input: Option<Vec<AuthenticationType>>,
) -> Self
pub fn set_supported_authentication_types( self, input: Option<Vec<AuthenticationType>>, ) -> Self
The supported authentication types for the compute environment.
Sourcepub fn get_supported_authentication_types(
&self,
) -> &Option<Vec<AuthenticationType>>
pub fn get_supported_authentication_types( &self, ) -> &Option<Vec<AuthenticationType>>
The supported authentication types for the compute environment.
Sourcepub fn connection_options(self, k: impl Into<String>, v: Property) -> Self
pub fn connection_options(self, k: impl Into<String>, v: Property) -> Self
Adds a key-value pair to connection_options.
To override the contents of this collection use set_connection_options.
The parameters used as connection options for the compute environment.
Sourcepub fn set_connection_options(
self,
input: Option<HashMap<String, Property>>,
) -> Self
pub fn set_connection_options( self, input: Option<HashMap<String, Property>>, ) -> Self
The parameters used as connection options for the compute environment.
Sourcepub fn get_connection_options(&self) -> &Option<HashMap<String, Property>>
pub fn get_connection_options(&self) -> &Option<HashMap<String, Property>>
The parameters used as connection options for the compute environment.
Sourcepub fn connection_property_name_overrides(
self,
k: impl Into<String>,
v: impl Into<String>,
) -> Self
pub fn connection_property_name_overrides( self, k: impl Into<String>, v: impl Into<String>, ) -> Self
Adds a key-value pair to connection_property_name_overrides.
To override the contents of this collection use set_connection_property_name_overrides.
The connection property name overrides for the compute environment.
Sourcepub fn set_connection_property_name_overrides(
self,
input: Option<HashMap<String, String>>,
) -> Self
pub fn set_connection_property_name_overrides( self, input: Option<HashMap<String, String>>, ) -> Self
The connection property name overrides for the compute environment.
Sourcepub fn get_connection_property_name_overrides(
&self,
) -> &Option<HashMap<String, String>>
pub fn get_connection_property_name_overrides( &self, ) -> &Option<HashMap<String, String>>
The connection property name overrides for the compute environment.
Sourcepub fn connection_option_name_overrides(
self,
k: impl Into<String>,
v: impl Into<String>,
) -> Self
pub fn connection_option_name_overrides( self, k: impl Into<String>, v: impl Into<String>, ) -> Self
Adds a key-value pair to connection_option_name_overrides.
To override the contents of this collection use set_connection_option_name_overrides.
The connection option name overrides for the compute environment.
Sourcepub fn set_connection_option_name_overrides(
self,
input: Option<HashMap<String, String>>,
) -> Self
pub fn set_connection_option_name_overrides( self, input: Option<HashMap<String, String>>, ) -> Self
The connection option name overrides for the compute environment.
Sourcepub fn get_connection_option_name_overrides(
&self,
) -> &Option<HashMap<String, String>>
pub fn get_connection_option_name_overrides( &self, ) -> &Option<HashMap<String, String>>
The connection option name overrides for the compute environment.
Sourcepub fn connection_properties_required_overrides(
self,
input: impl Into<String>,
) -> Self
pub fn connection_properties_required_overrides( self, input: impl Into<String>, ) -> Self
Appends an item to connection_properties_required_overrides.
To override the contents of this collection use set_connection_properties_required_overrides.
The connection properties that are required as overrides for the compute environment.
Sourcepub fn set_connection_properties_required_overrides(
self,
input: Option<Vec<String>>,
) -> Self
pub fn set_connection_properties_required_overrides( self, input: Option<Vec<String>>, ) -> Self
The connection properties that are required as overrides for the compute environment.
Sourcepub fn get_connection_properties_required_overrides(
&self,
) -> &Option<Vec<String>>
pub fn get_connection_properties_required_overrides( &self, ) -> &Option<Vec<String>>
The connection properties that are required as overrides for the compute environment.
Sourcepub fn physical_connection_properties_required(self, input: bool) -> Self
pub fn physical_connection_properties_required(self, input: bool) -> Self
Indicates whether PhysicalConnectionProperties are required for the compute environment.
Sourcepub fn set_physical_connection_properties_required(
self,
input: Option<bool>,
) -> Self
pub fn set_physical_connection_properties_required( self, input: Option<bool>, ) -> Self
Indicates whether PhysicalConnectionProperties are required for the compute environment.
Sourcepub fn get_physical_connection_properties_required(&self) -> &Option<bool>
pub fn get_physical_connection_properties_required(&self) -> &Option<bool>
Indicates whether PhysicalConnectionProperties are required for the compute environment.
Sourcepub fn build(self) -> Result<ComputeEnvironmentConfiguration, BuildError>
pub fn build(self) -> Result<ComputeEnvironmentConfiguration, BuildError>
Consumes the builder and constructs a ComputeEnvironmentConfiguration.
This method will fail if any of the following fields are not set: