#[non_exhaustive]pub struct ConnectionPropertiesConfigurationBuilder { /* private fields */ }Expand description
A builder for ConnectionPropertiesConfiguration.
Implementations
Sourceimpl ConnectionPropertiesConfigurationBuilder
impl ConnectionPropertiesConfigurationBuilder
Sourcepub fn url(self, input: ConnectorProperty) -> Self
pub fn url(self, input: ConnectorProperty) -> Self
The base instance URL for the endpoint that this connection type will connect to.
Sourcepub fn set_url(self, input: Option<ConnectorProperty>) -> Self
pub fn set_url(self, input: Option<ConnectorProperty>) -> Self
The base instance URL for the endpoint that this connection type will connect to.
Sourcepub fn get_url(&self) -> &Option<ConnectorProperty>
pub fn get_url(&self) -> &Option<ConnectorProperty>
The base instance URL for the endpoint that this connection type will connect to.
Sourcepub fn additional_request_parameters(self, input: ConnectorProperty) -> Self
pub fn additional_request_parameters(self, input: ConnectorProperty) -> Self
Appends an item to additional_request_parameters.
To override the contents of this collection use set_additional_request_parameters.
Key-value pairs of additional request parameters that may be needed during connection creation, such as API versions or service-specific configuration options.
Sourcepub fn set_additional_request_parameters(
self,
input: Option<Vec<ConnectorProperty>>,
) -> Self
pub fn set_additional_request_parameters( self, input: Option<Vec<ConnectorProperty>>, ) -> Self
Key-value pairs of additional request parameters that may be needed during connection creation, such as API versions or service-specific configuration options.
Sourcepub fn get_additional_request_parameters(
&self,
) -> &Option<Vec<ConnectorProperty>>
pub fn get_additional_request_parameters( &self, ) -> &Option<Vec<ConnectorProperty>>
Key-value pairs of additional request parameters that may be needed during connection creation, such as API versions or service-specific configuration options.
Sourcepub fn build(self) -> ConnectionPropertiesConfiguration
pub fn build(self) -> ConnectionPropertiesConfiguration
Consumes the builder and constructs a ConnectionPropertiesConfiguration.