#[non_exhaustive]pub struct ConnectionTypeVariantBuilder { /* private fields */ }Expand description
A builder for ConnectionTypeVariant.
Implementations
Sourceimpl ConnectionTypeVariantBuilder
impl ConnectionTypeVariantBuilder
Sourcepub fn connection_type_variant_name(self, input: impl Into<String>) -> Self
pub fn connection_type_variant_name(self, input: impl Into<String>) -> Self
The unique identifier for the connection type variant. This name is used internally to identify the specific variant of a connection type.
Sourcepub fn set_connection_type_variant_name(self, input: Option<String>) -> Self
pub fn set_connection_type_variant_name(self, input: Option<String>) -> Self
The unique identifier for the connection type variant. This name is used internally to identify the specific variant of a connection type.
Sourcepub fn get_connection_type_variant_name(&self) -> &Option<String>
pub fn get_connection_type_variant_name(&self) -> &Option<String>
The unique identifier for the connection type variant. This name is used internally to identify the specific variant of a connection type.
Sourcepub fn display_name(self, input: impl Into<String>) -> Self
pub fn display_name(self, input: impl Into<String>) -> Self
The human-readable name for the connection type variant that is displayed in the Glue console.
Sourcepub fn set_display_name(self, input: Option<String>) -> Self
pub fn set_display_name(self, input: Option<String>) -> Self
The human-readable name for the connection type variant that is displayed in the Glue console.
Sourcepub fn get_display_name(&self) -> &Option<String>
pub fn get_display_name(&self) -> &Option<String>
The human-readable name for the connection type variant that is displayed in the Glue console.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
A detailed description of the connection type variant, including its purpose, use cases, and any specific configuration requirements.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
A detailed description of the connection type variant, including its purpose, use cases, and any specific configuration requirements.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
A detailed description of the connection type variant, including its purpose, use cases, and any specific configuration requirements.
Sourcepub fn logo_url(self, input: impl Into<String>) -> Self
pub fn logo_url(self, input: impl Into<String>) -> Self
The URL of the logo associated with a connection type variant.
Sourcepub fn set_logo_url(self, input: Option<String>) -> Self
pub fn set_logo_url(self, input: Option<String>) -> Self
The URL of the logo associated with a connection type variant.
Sourcepub fn get_logo_url(&self) -> &Option<String>
pub fn get_logo_url(&self) -> &Option<String>
The URL of the logo associated with a connection type variant.
Sourcepub fn build(self) -> ConnectionTypeVariant
pub fn build(self) -> ConnectionTypeVariant
Consumes the builder and constructs a ConnectionTypeVariant.