CreateIcebergTableInputBuilder

Struct CreateIcebergTableInputBuilder 

#[non_exhaustive]
pub struct CreateIcebergTableInputBuilder { /* private fields */ }
A builder for CreateIcebergTableInput.

Implementations

Source

impl CreateIcebergTableInputBuilder

pub fn location(self, input: impl Into<String>) -> Self

The S3 location where the Iceberg table data will be stored.

This field is required.
pub fn set_location(self, input: Option<String>) -> Self

The S3 location where the Iceberg table data will be stored.

pub fn get_location(&self) -> &Option<String>

The S3 location where the Iceberg table data will be stored.

pub fn schema(self, input: IcebergSchema) -> Self

The schema definition that specifies the structure, field types, and metadata for the Iceberg table.

This field is required.
pub fn set_schema(self, input: Option<IcebergSchema>) -> Self

The schema definition that specifies the structure, field types, and metadata for the Iceberg table.

pub fn get_schema(&self) -> &Option<IcebergSchema>

The schema definition that specifies the structure, field types, and metadata for the Iceberg table.

pub fn partition_spec(self, input: IcebergPartitionSpec) -> Self

The partitioning specification that defines how the Iceberg table data will be organized and partitioned for optimal query performance.

pub fn set_partition_spec(self, input: Option<IcebergPartitionSpec>) -> Self

The partitioning specification that defines how the Iceberg table data will be organized and partitioned for optimal query performance.

pub fn get_partition_spec(&self) -> &Option<IcebergPartitionSpec>

The partitioning specification that defines how the Iceberg table data will be organized and partitioned for optimal query performance.

pub fn write_order(self, input: IcebergSortOrder) -> Self

The sort order specification that defines how data should be ordered within each partition to optimize query performance.

pub fn set_write_order(self, input: Option<IcebergSortOrder>) -> Self

The sort order specification that defines how data should be ordered within each partition to optimize query performance.

pub fn get_write_order(&self) -> &Option<IcebergSortOrder>

The sort order specification that defines how data should be ordered within each partition to optimize query performance.

pub fn properties(self, k: impl Into<String>, v: impl Into<String>) -> Self

Adds a key-value pair to properties.

To override the contents of this collection use set_properties.

Key-value pairs of additional table properties and configuration settings for the Iceberg table.

pub fn set_properties(self, input: Option<HashMap<String, String>>) -> Self

Key-value pairs of additional table properties and configuration settings for the Iceberg table.

pub fn get_properties(&self) -> &Option<HashMap<String, String>>

Key-value pairs of additional table properties and configuration settings for the Iceberg table.

pub fn build(self) -> Result<CreateIcebergTableInput, BuildError>

Consumes the builder and constructs a CreateIcebergTableInput. This method will fail if any of the following fields are not set: