#[non_exhaustive]pub struct CustomAuthenticationPropertiesBuilder { /* private fields */ }Expand description
A builder for CustomAuthenticationProperties.
Implementations
Sourceimpl CustomAuthenticationPropertiesBuilder
impl CustomAuthenticationPropertiesBuilder
Sourcepub fn authentication_parameters(self, input: ConnectorProperty) -> Self
pub fn authentication_parameters(self, input: ConnectorProperty) -> Self
Appends an item to authentication_parameters.
To override the contents of this collection use set_authentication_parameters.
A map of custom authentication parameters that define the specific authentication mechanism and required properties.
Sourcepub fn set_authentication_parameters(
self,
input: Option<Vec<ConnectorProperty>>,
) -> Self
pub fn set_authentication_parameters( self, input: Option<Vec<ConnectorProperty>>, ) -> Self
A map of custom authentication parameters that define the specific authentication mechanism and required properties.
Sourcepub fn get_authentication_parameters(&self) -> &Option<Vec<ConnectorProperty>>
pub fn get_authentication_parameters(&self) -> &Option<Vec<ConnectorProperty>>
A map of custom authentication parameters that define the specific authentication mechanism and required properties.
Sourcepub fn build(self) -> Result<CustomAuthenticationProperties, BuildError>
pub fn build(self) -> Result<CustomAuthenticationProperties, BuildError>
Consumes the builder and constructs a CustomAuthenticationProperties.
This method will fail if any of the following fields are not set: