#[non_exhaustive]pub struct DataLakeAccessPropertiesBuilder { /* private fields */ }Expand description
A builder for DataLakeAccessProperties.
Implementations
Sourceimpl DataLakeAccessPropertiesBuilder
impl DataLakeAccessPropertiesBuilder
Sourcepub fn data_lake_access(self, input: bool) -> Self
pub fn data_lake_access(self, input: bool) -> Self
Turns on or off data lake access for Apache Spark applications that access Amazon Redshift databases in the Data Catalog from any non-Redshift engine, such as Amazon Athena, Amazon EMR, or Glue ETL.
Sourcepub fn set_data_lake_access(self, input: Option<bool>) -> Self
pub fn set_data_lake_access(self, input: Option<bool>) -> Self
Turns on or off data lake access for Apache Spark applications that access Amazon Redshift databases in the Data Catalog from any non-Redshift engine, such as Amazon Athena, Amazon EMR, or Glue ETL.
Sourcepub fn get_data_lake_access(&self) -> &Option<bool>
pub fn get_data_lake_access(&self) -> &Option<bool>
Turns on or off data lake access for Apache Spark applications that access Amazon Redshift databases in the Data Catalog from any non-Redshift engine, such as Amazon Athena, Amazon EMR, or Glue ETL.
Sourcepub fn data_transfer_role(self, input: impl Into<String>) -> Self
pub fn data_transfer_role(self, input: impl Into<String>) -> Self
A role that will be assumed by Glue for transferring data into/out of the staging bucket during a query.
Sourcepub fn set_data_transfer_role(self, input: Option<String>) -> Self
pub fn set_data_transfer_role(self, input: Option<String>) -> Self
A role that will be assumed by Glue for transferring data into/out of the staging bucket during a query.
Sourcepub fn get_data_transfer_role(&self) -> &Option<String>
pub fn get_data_transfer_role(&self) -> &Option<String>
A role that will be assumed by Glue for transferring data into/out of the staging bucket during a query.
Sourcepub fn kms_key(self, input: impl Into<String>) -> Self
pub fn kms_key(self, input: impl Into<String>) -> Self
An encryption key that will be used for the staging bucket that will be created along with the catalog.
Sourcepub fn set_kms_key(self, input: Option<String>) -> Self
pub fn set_kms_key(self, input: Option<String>) -> Self
An encryption key that will be used for the staging bucket that will be created along with the catalog.
Sourcepub fn get_kms_key(&self) -> &Option<String>
pub fn get_kms_key(&self) -> &Option<String>
An encryption key that will be used for the staging bucket that will be created along with the catalog.
Sourcepub fn catalog_type(self, input: impl Into<String>) -> Self
pub fn catalog_type(self, input: impl Into<String>) -> Self
Specifies a federated catalog type for the native catalog resource. The currently supported type is aws:redshift.
Sourcepub fn set_catalog_type(self, input: Option<String>) -> Self
pub fn set_catalog_type(self, input: Option<String>) -> Self
Specifies a federated catalog type for the native catalog resource. The currently supported type is aws:redshift.
Sourcepub fn get_catalog_type(&self) -> &Option<String>
pub fn get_catalog_type(&self) -> &Option<String>
Specifies a federated catalog type for the native catalog resource. The currently supported type is aws:redshift.
Sourcepub fn build(self) -> DataLakeAccessProperties
pub fn build(self) -> DataLakeAccessProperties
Consumes the builder and constructs a DataLakeAccessProperties.