#[non_exhaustive]pub struct DataLakeAccessPropertiesOutputBuilder { /* private fields */ }Expand description
A builder for DataLakeAccessPropertiesOutput.
Implementations
Sourceimpl DataLakeAccessPropertiesOutputBuilder
impl DataLakeAccessPropertiesOutputBuilder
Sourcepub fn data_lake_access(self, input: bool) -> Self
pub fn data_lake_access(self, input: bool) -> Self
Turns on or off data lake access for Apache Spark applications that access Amazon Redshift databases in the Data Catalog.
Sourcepub fn set_data_lake_access(self, input: Option<bool>) -> Self
pub fn set_data_lake_access(self, input: Option<bool>) -> Self
Turns on or off data lake access for Apache Spark applications that access Amazon Redshift databases in the Data Catalog.
Sourcepub fn get_data_lake_access(&self) -> &Option<bool>
pub fn get_data_lake_access(&self) -> &Option<bool>
Turns on or off data lake access for Apache Spark applications that access Amazon Redshift databases in the Data Catalog.
Sourcepub fn data_transfer_role(self, input: impl Into<String>) -> Self
pub fn data_transfer_role(self, input: impl Into<String>) -> Self
A role that will be assumed by Glue for transferring data into/out of the staging bucket during a query.
Sourcepub fn set_data_transfer_role(self, input: Option<String>) -> Self
pub fn set_data_transfer_role(self, input: Option<String>) -> Self
A role that will be assumed by Glue for transferring data into/out of the staging bucket during a query.
Sourcepub fn get_data_transfer_role(&self) -> &Option<String>
pub fn get_data_transfer_role(&self) -> &Option<String>
A role that will be assumed by Glue for transferring data into/out of the staging bucket during a query.
Sourcepub fn kms_key(self, input: impl Into<String>) -> Self
pub fn kms_key(self, input: impl Into<String>) -> Self
An encryption key that will be used for the staging bucket that will be created along with the catalog.
Sourcepub fn set_kms_key(self, input: Option<String>) -> Self
pub fn set_kms_key(self, input: Option<String>) -> Self
An encryption key that will be used for the staging bucket that will be created along with the catalog.
Sourcepub fn get_kms_key(&self) -> &Option<String>
pub fn get_kms_key(&self) -> &Option<String>
An encryption key that will be used for the staging bucket that will be created along with the catalog.
Sourcepub fn managed_workgroup_name(self, input: impl Into<String>) -> Self
pub fn managed_workgroup_name(self, input: impl Into<String>) -> Self
The managed Redshift Serverless compute name that is created for your catalog resource.
Sourcepub fn set_managed_workgroup_name(self, input: Option<String>) -> Self
pub fn set_managed_workgroup_name(self, input: Option<String>) -> Self
The managed Redshift Serverless compute name that is created for your catalog resource.
Sourcepub fn get_managed_workgroup_name(&self) -> &Option<String>
pub fn get_managed_workgroup_name(&self) -> &Option<String>
The managed Redshift Serverless compute name that is created for your catalog resource.
Sourcepub fn managed_workgroup_status(self, input: impl Into<String>) -> Self
pub fn managed_workgroup_status(self, input: impl Into<String>) -> Self
The managed Redshift Serverless compute status.
Sourcepub fn set_managed_workgroup_status(self, input: Option<String>) -> Self
pub fn set_managed_workgroup_status(self, input: Option<String>) -> Self
The managed Redshift Serverless compute status.
Sourcepub fn get_managed_workgroup_status(&self) -> &Option<String>
pub fn get_managed_workgroup_status(&self) -> &Option<String>
The managed Redshift Serverless compute status.
Sourcepub fn redshift_database_name(self, input: impl Into<String>) -> Self
pub fn redshift_database_name(self, input: impl Into<String>) -> Self
The default Redshift database resource name in the managed compute.
Sourcepub fn set_redshift_database_name(self, input: Option<String>) -> Self
pub fn set_redshift_database_name(self, input: Option<String>) -> Self
The default Redshift database resource name in the managed compute.
Sourcepub fn get_redshift_database_name(&self) -> &Option<String>
pub fn get_redshift_database_name(&self) -> &Option<String>
The default Redshift database resource name in the managed compute.
Sourcepub fn status_message(self, input: impl Into<String>) -> Self
pub fn status_message(self, input: impl Into<String>) -> Self
A message that gives more detailed information about the managed workgroup status.
Sourcepub fn set_status_message(self, input: Option<String>) -> Self
pub fn set_status_message(self, input: Option<String>) -> Self
A message that gives more detailed information about the managed workgroup status.
Sourcepub fn get_status_message(&self) -> &Option<String>
pub fn get_status_message(&self) -> &Option<String>
A message that gives more detailed information about the managed workgroup status.
Sourcepub fn catalog_type(self, input: impl Into<String>) -> Self
pub fn catalog_type(self, input: impl Into<String>) -> Self
Specifies a federated catalog type for the native catalog resource. The currently supported type is aws:redshift.
Sourcepub fn set_catalog_type(self, input: Option<String>) -> Self
pub fn set_catalog_type(self, input: Option<String>) -> Self
Specifies a federated catalog type for the native catalog resource. The currently supported type is aws:redshift.
Sourcepub fn get_catalog_type(&self) -> &Option<String>
pub fn get_catalog_type(&self) -> &Option<String>
Specifies a federated catalog type for the native catalog resource. The currently supported type is aws:redshift.
Sourcepub fn build(self) -> DataLakeAccessPropertiesOutput
pub fn build(self) -> DataLakeAccessPropertiesOutput
Consumes the builder and constructs a DataLakeAccessPropertiesOutput.