#[non_exhaustive]pub struct DataQualityAggregatedMetricsBuilder { /* private fields */ }Expand description
A builder for DataQualityAggregatedMetrics.
Implementations
Sourceimpl DataQualityAggregatedMetricsBuilder
impl DataQualityAggregatedMetricsBuilder
Sourcepub fn total_rows_processed(self, input: f64) -> Self
pub fn total_rows_processed(self, input: f64) -> Self
The total number of rows that were processed during the data quality evaluation.
Sourcepub fn set_total_rows_processed(self, input: Option<f64>) -> Self
pub fn set_total_rows_processed(self, input: Option<f64>) -> Self
The total number of rows that were processed during the data quality evaluation.
Sourcepub fn get_total_rows_processed(&self) -> &Option<f64>
pub fn get_total_rows_processed(&self) -> &Option<f64>
The total number of rows that were processed during the data quality evaluation.
Sourcepub fn total_rows_passed(self, input: f64) -> Self
pub fn total_rows_passed(self, input: f64) -> Self
The total number of rows that passed all applicable data quality rules.
Sourcepub fn set_total_rows_passed(self, input: Option<f64>) -> Self
pub fn set_total_rows_passed(self, input: Option<f64>) -> Self
The total number of rows that passed all applicable data quality rules.
Sourcepub fn get_total_rows_passed(&self) -> &Option<f64>
pub fn get_total_rows_passed(&self) -> &Option<f64>
The total number of rows that passed all applicable data quality rules.
Sourcepub fn total_rows_failed(self, input: f64) -> Self
pub fn total_rows_failed(self, input: f64) -> Self
The total number of rows that failed one or more data quality rules.
Sourcepub fn set_total_rows_failed(self, input: Option<f64>) -> Self
pub fn set_total_rows_failed(self, input: Option<f64>) -> Self
The total number of rows that failed one or more data quality rules.
Sourcepub fn get_total_rows_failed(&self) -> &Option<f64>
pub fn get_total_rows_failed(&self) -> &Option<f64>
The total number of rows that failed one or more data quality rules.
Sourcepub fn total_rules_processed(self, input: f64) -> Self
pub fn total_rules_processed(self, input: f64) -> Self
The total number of data quality rules that were evaluated.
Sourcepub fn set_total_rules_processed(self, input: Option<f64>) -> Self
pub fn set_total_rules_processed(self, input: Option<f64>) -> Self
The total number of data quality rules that were evaluated.
Sourcepub fn get_total_rules_processed(&self) -> &Option<f64>
pub fn get_total_rules_processed(&self) -> &Option<f64>
The total number of data quality rules that were evaluated.
Sourcepub fn total_rules_passed(self, input: f64) -> Self
pub fn total_rules_passed(self, input: f64) -> Self
The total number of data quality rules that passed their evaluation criteria.
Sourcepub fn set_total_rules_passed(self, input: Option<f64>) -> Self
pub fn set_total_rules_passed(self, input: Option<f64>) -> Self
The total number of data quality rules that passed their evaluation criteria.
Sourcepub fn get_total_rules_passed(&self) -> &Option<f64>
pub fn get_total_rules_passed(&self) -> &Option<f64>
The total number of data quality rules that passed their evaluation criteria.
Sourcepub fn total_rules_failed(self, input: f64) -> Self
pub fn total_rules_failed(self, input: f64) -> Self
The total number of data quality rules that failed their evaluation criteria.
Sourcepub fn set_total_rules_failed(self, input: Option<f64>) -> Self
pub fn set_total_rules_failed(self, input: Option<f64>) -> Self
The total number of data quality rules that failed their evaluation criteria.
Sourcepub fn get_total_rules_failed(&self) -> &Option<f64>
pub fn get_total_rules_failed(&self) -> &Option<f64>
The total number of data quality rules that failed their evaluation criteria.
Sourcepub fn build(self) -> DataQualityAggregatedMetrics
pub fn build(self) -> DataQualityAggregatedMetrics
Consumes the builder and constructs a DataQualityAggregatedMetrics.