DataQualityEncryptionBuilder

Struct DataQualityEncryptionBuilder 

#[non_exhaustive]
pub struct DataQualityEncryptionBuilder { /* private fields */ }
A builder for DataQualityEncryption.

Implementations

Source

impl DataQualityEncryptionBuilder

pub fn data_quality_encryption_mode( self, input: DataQualityEncryptionMode, ) -> Self

The encryption mode to use for encrypting Data Quality assets. These assets include data quality rulesets, results, statistics, anomaly detection models and observations.

Valid values are SSEKMS for encryption using a customer-managed KMS key, or DISABLED.

pub fn set_data_quality_encryption_mode( self, input: Option<DataQualityEncryptionMode>, ) -> Self

The encryption mode to use for encrypting Data Quality assets. These assets include data quality rulesets, results, statistics, anomaly detection models and observations.

Valid values are SSEKMS for encryption using a customer-managed KMS key, or DISABLED.

pub fn get_data_quality_encryption_mode( &self, ) -> &Option<DataQualityEncryptionMode>

The encryption mode to use for encrypting Data Quality assets. These assets include data quality rulesets, results, statistics, anomaly detection models and observations.

Valid values are SSEKMS for encryption using a customer-managed KMS key, or DISABLED.

pub fn kms_key_arn(self, input: impl Into<String>) -> Self

The Amazon Resource Name (ARN) of the KMS key to be used to encrypt the data.

pub fn set_kms_key_arn(self, input: Option<String>) -> Self

The Amazon Resource Name (ARN) of the KMS key to be used to encrypt the data.

pub fn get_kms_key_arn(&self) -> &Option<String>

The Amazon Resource Name (ARN) of the KMS key to be used to encrypt the data.

pub fn build(self) -> DataQualityEncryption

Consumes the builder and constructs a DataQualityEncryption.