DataQualityEvaluationRunAdditionalRunOptionsBuilder

Struct DataQualityEvaluationRunAdditionalRunOptionsBuilder 

#[non_exhaustive]
pub struct DataQualityEvaluationRunAdditionalRunOptionsBuilder { /* private fields */ }
Implementations

Source

impl DataQualityEvaluationRunAdditionalRunOptionsBuilder

pub fn cloud_watch_metrics_enabled(self, input: bool) -> Self

Whether or not to enable CloudWatch metrics.

pub fn set_cloud_watch_metrics_enabled(self, input: Option<bool>) -> Self

Whether or not to enable CloudWatch metrics.

pub fn get_cloud_watch_metrics_enabled(&self) -> &Option<bool>

Whether or not to enable CloudWatch metrics.

pub fn results_s3_prefix(self, input: impl Into<String>) -> Self

Prefix for Amazon S3 to store results.

pub fn set_results_s3_prefix(self, input: Option<String>) -> Self

Prefix for Amazon S3 to store results.

pub fn get_results_s3_prefix(&self) -> &Option<String>

Prefix for Amazon S3 to store results.

pub fn composite_rule_evaluation_method( self, input: DqCompositeRuleEvaluationMethod, ) -> Self

Set the evaluation method for composite rules in the ruleset to ROW/COLUMN

pub fn set_composite_rule_evaluation_method( self, input: Option<DqCompositeRuleEvaluationMethod>, ) -> Self

Set the evaluation method for composite rules in the ruleset to ROW/COLUMN

pub fn get_composite_rule_evaluation_method( &self, ) -> &Option<DqCompositeRuleEvaluationMethod>

Set the evaluation method for composite rules in the ruleset to ROW/COLUMN

pub fn custom_log_group_prefix(self, input: impl Into<String>) -> Self

A custom prefix for the CloudWatch log group names. When specified, evaluation run logs are written to /error and /output instead of the default /aws-glue/data-quality/error and /aws-glue/data-quality/output log groups.

pub fn set_custom_log_group_prefix(self, input: Option<String>) -> Self

A custom prefix for the CloudWatch log group names. When specified, evaluation run logs are written to /error and /output instead of the default /aws-glue/data-quality/error and /aws-glue/data-quality/output log groups.

pub fn get_custom_log_group_prefix(&self) -> &Option<String>

A custom prefix for the CloudWatch log group names. When specified, evaluation run logs are written to /error and /output instead of the default /aws-glue/data-quality/error and /aws-glue/data-quality/output log groups.

pub fn row_level_results(self, input: RowLevelResultsOptions) -> Self

The configuration for writing row-level evaluation results to a Glue Data Catalog table.

pub fn set_row_level_results( self, input: Option<RowLevelResultsOptions>, ) -> Self

The configuration for writing row-level evaluation results to a Glue Data Catalog table.

pub fn get_row_level_results(&self) -> &Option<RowLevelResultsOptions>

The configuration for writing row-level evaluation results to a Glue Data Catalog table.

pub fn profiling_results(self, input: ProfilingResultsOptions) -> Self

The configuration for writing profiling results to a Glue Data Catalog table.

pub fn set_profiling_results( self, input: Option<ProfilingResultsOptions>, ) -> Self

The configuration for writing profiling results to a Glue Data Catalog table.

pub fn get_profiling_results(&self) -> &Option<ProfilingResultsOptions>

The configuration for writing profiling results to a Glue Data Catalog table.

pub fn observation_scope(self, input: ObservationConfiguration) -> Self

The scope of the observation for the evaluation run. Specifies whether anomaly detection is enabled or disabled.

pub fn set_observation_scope( self, input: Option<ObservationConfiguration>, ) -> Self

The scope of the observation for the evaluation run. Specifies whether anomaly detection is enabled or disabled.

pub fn get_observation_scope(&self) -> &Option<ObservationConfiguration>

The scope of the observation for the evaluation run. Specifies whether anomaly detection is enabled or disabled.

pub fn observation_mode(self, input: ObservationMode) -> Self

The observation mode for the evaluation run. Specifies how anomaly detection bounds are calculated.

pub fn set_observation_mode(self, input: Option<ObservationMode>) -> Self

The observation mode for the evaluation run. Specifies how anomaly detection bounds are calculated.

pub fn get_observation_mode(&self) -> &Option<ObservationMode>

The observation mode for the evaluation run. Specifies how anomaly detection bounds are calculated.

pub fn data_quality_rule_results( self, input: DataQualityRuleResultsOptions, ) -> Self

The configuration for writing rule results to a Glue Data Catalog table.

pub fn set_data_quality_rule_results( self, input: Option<DataQualityRuleResultsOptions>, ) -> Self

The configuration for writing rule results to a Glue Data Catalog table.

pub fn get_data_quality_rule_results( &self, ) -> &Option<DataQualityRuleResultsOptions>

The configuration for writing rule results to a Glue Data Catalog table.

pub fn observation_results(self, input: ObservationResultsOptions) -> Self

The configuration for writing observation results to a Glue Data Catalog table.

pub fn set_observation_results( self, input: Option<ObservationResultsOptions>, ) -> Self

The configuration for writing observation results to a Glue Data Catalog table.

pub fn get_observation_results(&self) -> &Option<ObservationResultsOptions>

The configuration for writing observation results to a Glue Data Catalog table.

pub fn build(self) -> DataQualityEvaluationRunAdditionalRunOptions

Consumes the builder and constructs a DataQualityEvaluationRunAdditionalRunOptions.