#[non_exhaustive]pub struct DataQualityRuleRecommendationRunDescriptionBuilder { /* private fields */ }Expand description
A builder for DataQualityRuleRecommendationRunDescription.
Implementations
Sourceimpl DataQualityRuleRecommendationRunDescriptionBuilder
impl DataQualityRuleRecommendationRunDescriptionBuilder
Sourcepub fn run_id(self, input: impl Into<String>) -> Self
pub fn run_id(self, input: impl Into<String>) -> Self
The unique run identifier associated with this run.
Sourcepub fn set_run_id(self, input: Option<String>) -> Self
pub fn set_run_id(self, input: Option<String>) -> Self
The unique run identifier associated with this run.
Sourcepub fn get_run_id(&self) -> &Option<String>
pub fn get_run_id(&self) -> &Option<String>
The unique run identifier associated with this run.
Sourcepub fn status(self, input: TaskStatusType) -> Self
pub fn status(self, input: TaskStatusType) -> Self
The status for this run.
Sourcepub fn set_status(self, input: Option<TaskStatusType>) -> Self
pub fn set_status(self, input: Option<TaskStatusType>) -> Self
The status for this run.
Sourcepub fn get_status(&self) -> &Option<TaskStatusType>
pub fn get_status(&self) -> &Option<TaskStatusType>
The status for this run.
Sourcepub fn started_on(self, input: DateTime) -> Self
pub fn started_on(self, input: DateTime) -> Self
The date and time when this run started.
Sourcepub fn set_started_on(self, input: Option<DateTime>) -> Self
pub fn set_started_on(self, input: Option<DateTime>) -> Self
The date and time when this run started.
Sourcepub fn get_started_on(&self) -> &Option<DateTime>
pub fn get_started_on(&self) -> &Option<DateTime>
The date and time when this run started.
Sourcepub fn data_source(self, input: DataSource) -> Self
pub fn data_source(self, input: DataSource) -> Self
The data source (Glue table) associated with the recommendation run.
Sourcepub fn set_data_source(self, input: Option<DataSource>) -> Self
pub fn set_data_source(self, input: Option<DataSource>) -> Self
The data source (Glue table) associated with the recommendation run.
Sourcepub fn get_data_source(&self) -> &Option<DataSource>
pub fn get_data_source(&self) -> &Option<DataSource>
The data source (Glue table) associated with the recommendation run.
Sourcepub fn created_ruleset_name(self, input: impl Into<String>) -> Self
pub fn created_ruleset_name(self, input: impl Into<String>) -> Self
The name of the ruleset that was created by the recommendation run.
Sourcepub fn set_created_ruleset_name(self, input: Option<String>) -> Self
pub fn set_created_ruleset_name(self, input: Option<String>) -> Self
The name of the ruleset that was created by the recommendation run.
Sourcepub fn get_created_ruleset_name(&self) -> &Option<String>
pub fn get_created_ruleset_name(&self) -> &Option<String>
The name of the ruleset that was created by the recommendation run.
Sourcepub fn recommendation_mode(self, input: RecommendationMode) -> Self
pub fn recommendation_mode(self, input: RecommendationMode) -> Self
The mode that Glue Data Quality uses to recommend rules.
The default is BASIC.
Sourcepub fn set_recommendation_mode(self, input: Option<RecommendationMode>) -> Self
pub fn set_recommendation_mode(self, input: Option<RecommendationMode>) -> Self
The mode that Glue Data Quality uses to recommend rules.
The default is BASIC.
Sourcepub fn get_recommendation_mode(&self) -> &Option<RecommendationMode>
pub fn get_recommendation_mode(&self) -> &Option<RecommendationMode>
The mode that Glue Data Quality uses to recommend rules.
The default is BASIC.
Sourcepub fn build(self) -> DataQualityRuleRecommendationRunDescription
pub fn build(self) -> DataQualityRuleRecommendationRunDescription
Consumes the builder and constructs a DataQualityRuleRecommendationRunDescription.