#[non_exhaustive]pub struct DataQualityRuleResultBuilder { /* private fields */ }Expand description
A builder for DataQualityRuleResult.
Implementations
Sourceimpl DataQualityRuleResultBuilder
impl DataQualityRuleResultBuilder
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
A description of the data quality rule.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
A description of the data quality rule.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
A description of the data quality rule.
Sourcepub fn evaluation_message(self, input: impl Into<String>) -> Self
pub fn evaluation_message(self, input: impl Into<String>) -> Self
An evaluation message.
Sourcepub fn set_evaluation_message(self, input: Option<String>) -> Self
pub fn set_evaluation_message(self, input: Option<String>) -> Self
An evaluation message.
Sourcepub fn get_evaluation_message(&self) -> &Option<String>
pub fn get_evaluation_message(&self) -> &Option<String>
An evaluation message.
Sourcepub fn result(self, input: DataQualityRuleResultStatus) -> Self
pub fn result(self, input: DataQualityRuleResultStatus) -> Self
A pass or fail status for the rule.
Sourcepub fn set_result(self, input: Option<DataQualityRuleResultStatus>) -> Self
pub fn set_result(self, input: Option<DataQualityRuleResultStatus>) -> Self
A pass or fail status for the rule.
Sourcepub fn get_result(&self) -> &Option<DataQualityRuleResultStatus>
pub fn get_result(&self) -> &Option<DataQualityRuleResultStatus>
A pass or fail status for the rule.
Sourcepub fn evaluated_metrics(self, k: impl Into<String>, v: f64) -> Self
pub fn evaluated_metrics(self, k: impl Into<String>, v: f64) -> Self
Adds a key-value pair to evaluated_metrics.
To override the contents of this collection use set_evaluated_metrics.
A map of metrics associated with the evaluation of the rule.
Sourcepub fn set_evaluated_metrics(self, input: Option<HashMap<String, f64>>) -> Self
pub fn set_evaluated_metrics(self, input: Option<HashMap<String, f64>>) -> Self
A map of metrics associated with the evaluation of the rule.
Sourcepub fn get_evaluated_metrics(&self) -> &Option<HashMap<String, f64>>
pub fn get_evaluated_metrics(&self) -> &Option<HashMap<String, f64>>
A map of metrics associated with the evaluation of the rule.
Sourcepub fn evaluated_rule(self, input: impl Into<String>) -> Self
pub fn evaluated_rule(self, input: impl Into<String>) -> Self
The evaluated rule.
Sourcepub fn set_evaluated_rule(self, input: Option<String>) -> Self
pub fn set_evaluated_rule(self, input: Option<String>) -> Self
The evaluated rule.
Sourcepub fn get_evaluated_rule(&self) -> &Option<String>
pub fn get_evaluated_rule(&self) -> &Option<String>
The evaluated rule.
Sourcepub fn rule_metrics(self, k: impl Into<String>, v: f64) -> Self
pub fn rule_metrics(self, k: impl Into<String>, v: f64) -> Self
Adds a key-value pair to rule_metrics.
To override the contents of this collection use set_rule_metrics.
A map containing metrics associated with the evaluation of the rule based on row-level results.
Sourcepub fn set_rule_metrics(self, input: Option<HashMap<String, f64>>) -> Self
pub fn set_rule_metrics(self, input: Option<HashMap<String, f64>>) -> Self
A map containing metrics associated with the evaluation of the rule based on row-level results.
Sourcepub fn get_rule_metrics(&self) -> &Option<HashMap<String, f64>>
pub fn get_rule_metrics(&self) -> &Option<HashMap<String, f64>>
A map containing metrics associated with the evaluation of the rule based on row-level results.
Sourcepub fn labels(self, k: impl Into<String>, v: impl Into<String>) -> Self
pub fn labels(self, k: impl Into<String>, v: impl Into<String>) -> Self
Adds a key-value pair to labels.
To override the contents of this collection use set_labels.
A map containing labels assigned to the data quality rule.
Sourcepub fn set_labels(self, input: Option<HashMap<String, String>>) -> Self
pub fn set_labels(self, input: Option<HashMap<String, String>>) -> Self
A map containing labels assigned to the data quality rule.
Sourcepub fn get_labels(&self) -> &Option<HashMap<String, String>>
pub fn get_labels(&self) -> &Option<HashMap<String, String>>
A map containing labels assigned to the data quality rule.
Sourcepub fn build(self) -> DataQualityRuleResult
pub fn build(self) -> DataQualityRuleResult
Consumes the builder and constructs a DataQualityRuleResult.