#[non_exhaustive]pub struct DataQualityRuleResultsOptionsBuilder { /* private fields */ }Expand description
A builder for DataQualityRuleResultsOptions.
Implementations
Sourceimpl DataQualityRuleResultsOptionsBuilder
impl DataQualityRuleResultsOptionsBuilder
Sourcepub fn write_data_quality_rule_results_enabled(self, input: bool) -> Self
pub fn write_data_quality_rule_results_enabled(self, input: bool) -> Self
Set to true to write data quality rule results.
Sourcepub fn set_write_data_quality_rule_results_enabled(
self,
input: Option<bool>,
) -> Self
pub fn set_write_data_quality_rule_results_enabled( self, input: Option<bool>, ) -> Self
Set to true to write data quality rule results.
Sourcepub fn get_write_data_quality_rule_results_enabled(&self) -> &Option<bool>
pub fn get_write_data_quality_rule_results_enabled(&self) -> &Option<bool>
Set to true to write data quality rule results.
Sourcepub fn catalog_table_config(self, input: CatalogTableConfigOptions) -> Self
pub fn catalog_table_config(self, input: CatalogTableConfigOptions) -> Self
The Glue Data Catalog table configuration for storing the rule results.
Sourcepub fn set_catalog_table_config(
self,
input: Option<CatalogTableConfigOptions>,
) -> Self
pub fn set_catalog_table_config( self, input: Option<CatalogTableConfigOptions>, ) -> Self
The Glue Data Catalog table configuration for storing the rule results.
Sourcepub fn get_catalog_table_config(&self) -> &Option<CatalogTableConfigOptions>
pub fn get_catalog_table_config(&self) -> &Option<CatalogTableConfigOptions>
The Glue Data Catalog table configuration for storing the rule results.
Sourcepub fn build(self) -> DataQualityRuleResultsOptions
pub fn build(self) -> DataQualityRuleResultsOptions
Consumes the builder and constructs a DataQualityRuleResultsOptions.