#[non_exhaustive]pub struct DataQualityRulesetEvaluationRunBuilder { /* private fields */ }Expand description
A builder for DataQualityRulesetEvaluationRun.
Implementations
Sourceimpl DataQualityRulesetEvaluationRunBuilder
impl DataQualityRulesetEvaluationRunBuilder
Sourcepub fn run_id(self, input: impl Into<String>) -> Self
pub fn run_id(self, input: impl Into<String>) -> Self
The unique run identifier associated with this run.
Sourcepub fn set_run_id(self, input: Option<String>) -> Self
pub fn set_run_id(self, input: Option<String>) -> Self
The unique run identifier associated with this run.
Sourcepub fn get_run_id(&self) -> &Option<String>
pub fn get_run_id(&self) -> &Option<String>
The unique run identifier associated with this run.
Sourcepub fn data_source(self, input: DataSource) -> Self
pub fn data_source(self, input: DataSource) -> Self
A data source (an Glue table) for which you want data quality results.
Sourcepub fn set_data_source(self, input: Option<DataSource>) -> Self
pub fn set_data_source(self, input: Option<DataSource>) -> Self
A data source (an Glue table) for which you want data quality results.
Sourcepub fn get_data_source(&self) -> &Option<DataSource>
pub fn get_data_source(&self) -> &Option<DataSource>
A data source (an Glue table) for which you want data quality results.
Sourcepub fn role(self, input: impl Into<String>) -> Self
pub fn role(self, input: impl Into<String>) -> Self
An IAM role supplied to encrypt the results of the run.
Sourcepub fn set_role(self, input: Option<String>) -> Self
pub fn set_role(self, input: Option<String>) -> Self
An IAM role supplied to encrypt the results of the run.
Sourcepub fn get_role(&self) -> &Option<String>
pub fn get_role(&self) -> &Option<String>
An IAM role supplied to encrypt the results of the run.
Sourcepub fn number_of_workers(self, input: i32) -> Self
pub fn number_of_workers(self, input: i32) -> Self
The number of G.1X workers to be used in the run. The default is 5.
Sourcepub fn set_number_of_workers(self, input: Option<i32>) -> Self
pub fn set_number_of_workers(self, input: Option<i32>) -> Self
The number of G.1X workers to be used in the run. The default is 5.
Sourcepub fn get_number_of_workers(&self) -> &Option<i32>
pub fn get_number_of_workers(&self) -> &Option<i32>
The number of G.1X workers to be used in the run. The default is 5.
Sourcepub fn timeout(self, input: i32) -> Self
pub fn timeout(self, input: i32) -> Self
The timeout for a run in minutes. This is the maximum time that a run can consume resources before it is terminated and enters TIMEOUT status. The default is 2,880 minutes (48 hours).
Sourcepub fn set_timeout(self, input: Option<i32>) -> Self
pub fn set_timeout(self, input: Option<i32>) -> Self
The timeout for a run in minutes. This is the maximum time that a run can consume resources before it is terminated and enters TIMEOUT status. The default is 2,880 minutes (48 hours).
Sourcepub fn get_timeout(&self) -> &Option<i32>
pub fn get_timeout(&self) -> &Option<i32>
The timeout for a run in minutes. This is the maximum time that a run can consume resources before it is terminated and enters TIMEOUT status. The default is 2,880 minutes (48 hours).
Sourcepub fn additional_run_options(
self,
input: DataQualityEvaluationRunAdditionalRunOptions,
) -> Self
pub fn additional_run_options( self, input: DataQualityEvaluationRunAdditionalRunOptions, ) -> Self
Additional run options you can specify for an evaluation run.
Sourcepub fn set_additional_run_options(
self,
input: Option<DataQualityEvaluationRunAdditionalRunOptions>,
) -> Self
pub fn set_additional_run_options( self, input: Option<DataQualityEvaluationRunAdditionalRunOptions>, ) -> Self
Additional run options you can specify for an evaluation run.
Sourcepub fn get_additional_run_options(
&self,
) -> &Option<DataQualityEvaluationRunAdditionalRunOptions>
pub fn get_additional_run_options( &self, ) -> &Option<DataQualityEvaluationRunAdditionalRunOptions>
Additional run options you can specify for an evaluation run.
Sourcepub fn status(self, input: TaskStatusType) -> Self
pub fn status(self, input: TaskStatusType) -> Self
The status for this run.
Sourcepub fn set_status(self, input: Option<TaskStatusType>) -> Self
pub fn set_status(self, input: Option<TaskStatusType>) -> Self
The status for this run.
Sourcepub fn get_status(&self) -> &Option<TaskStatusType>
pub fn get_status(&self) -> &Option<TaskStatusType>
The status for this run.
Sourcepub fn error_string(self, input: impl Into<String>) -> Self
pub fn error_string(self, input: impl Into<String>) -> Self
The error strings that are associated with the run.
Sourcepub fn set_error_string(self, input: Option<String>) -> Self
pub fn set_error_string(self, input: Option<String>) -> Self
The error strings that are associated with the run.
Sourcepub fn get_error_string(&self) -> &Option<String>
pub fn get_error_string(&self) -> &Option<String>
The error strings that are associated with the run.
Sourcepub fn started_on(self, input: DateTime) -> Self
pub fn started_on(self, input: DateTime) -> Self
The date and time when this run started.
Sourcepub fn set_started_on(self, input: Option<DateTime>) -> Self
pub fn set_started_on(self, input: Option<DateTime>) -> Self
The date and time when this run started.
Sourcepub fn get_started_on(&self) -> &Option<DateTime>
pub fn get_started_on(&self) -> &Option<DateTime>
The date and time when this run started.
Sourcepub fn last_modified_on(self, input: DateTime) -> Self
pub fn last_modified_on(self, input: DateTime) -> Self
A timestamp. The last point in time when this run was modified.
Sourcepub fn set_last_modified_on(self, input: Option<DateTime>) -> Self
pub fn set_last_modified_on(self, input: Option<DateTime>) -> Self
A timestamp. The last point in time when this run was modified.
Sourcepub fn get_last_modified_on(&self) -> &Option<DateTime>
pub fn get_last_modified_on(&self) -> &Option<DateTime>
A timestamp. The last point in time when this run was modified.
Sourcepub fn completed_on(self, input: DateTime) -> Self
pub fn completed_on(self, input: DateTime) -> Self
The date and time when this run was completed.
Sourcepub fn set_completed_on(self, input: Option<DateTime>) -> Self
pub fn set_completed_on(self, input: Option<DateTime>) -> Self
The date and time when this run was completed.
Sourcepub fn get_completed_on(&self) -> &Option<DateTime>
pub fn get_completed_on(&self) -> &Option<DateTime>
The date and time when this run was completed.
Sourcepub fn execution_time(self, input: i32) -> Self
pub fn execution_time(self, input: i32) -> Self
The amount of time (in seconds) that the run consumed resources.
Sourcepub fn set_execution_time(self, input: Option<i32>) -> Self
pub fn set_execution_time(self, input: Option<i32>) -> Self
The amount of time (in seconds) that the run consumed resources.
Sourcepub fn get_execution_time(&self) -> &Option<i32>
pub fn get_execution_time(&self) -> &Option<i32>
The amount of time (in seconds) that the run consumed resources.
Sourcepub fn ruleset_names(self, input: impl Into<String>) -> Self
pub fn ruleset_names(self, input: impl Into<String>) -> Self
Appends an item to ruleset_names.
To override the contents of this collection use set_ruleset_names.
A list of ruleset names for the run.
Sourcepub fn set_ruleset_names(self, input: Option<Vec<String>>) -> Self
pub fn set_ruleset_names(self, input: Option<Vec<String>>) -> Self
A list of ruleset names for the run.
Sourcepub fn get_ruleset_names(&self) -> &Option<Vec<String>>
pub fn get_ruleset_names(&self) -> &Option<Vec<String>>
A list of ruleset names for the run.
Sourcepub fn result_ids(self, input: impl Into<String>) -> Self
pub fn result_ids(self, input: impl Into<String>) -> Self
Appends an item to result_ids.
To override the contents of this collection use set_result_ids.
A list of result IDs for the data quality results for the run.
Sourcepub fn set_result_ids(self, input: Option<Vec<String>>) -> Self
pub fn set_result_ids(self, input: Option<Vec<String>>) -> Self
A list of result IDs for the data quality results for the run.
Sourcepub fn get_result_ids(&self) -> &Option<Vec<String>>
pub fn get_result_ids(&self) -> &Option<Vec<String>>
A list of result IDs for the data quality results for the run.
Sourcepub fn additional_data_sources(
self,
k: impl Into<String>,
v: DataSource,
) -> Self
pub fn additional_data_sources( self, k: impl Into<String>, v: DataSource, ) -> Self
Adds a key-value pair to additional_data_sources.
To override the contents of this collection use set_additional_data_sources.
A map of reference strings to additional data sources you can specify for an evaluation run.
Sourcepub fn set_additional_data_sources(
self,
input: Option<HashMap<String, DataSource>>,
) -> Self
pub fn set_additional_data_sources( self, input: Option<HashMap<String, DataSource>>, ) -> Self
A map of reference strings to additional data sources you can specify for an evaluation run.
Sourcepub fn get_additional_data_sources(
&self,
) -> &Option<HashMap<String, DataSource>>
pub fn get_additional_data_sources( &self, ) -> &Option<HashMap<String, DataSource>>
A map of reference strings to additional data sources you can specify for an evaluation run.
Sourcepub fn build(self) -> DataQualityRulesetEvaluationRun
pub fn build(self) -> DataQualityRulesetEvaluationRun
Consumes the builder and constructs a DataQualityRulesetEvaluationRun.