#[non_exhaustive]pub struct DistributionDataBuilder { /* private fields */ }Expand description
A builder for DistributionData.
Implementations
Sourceimpl DistributionDataBuilder
impl DistributionDataBuilder
Sourcepub fn bin_edges(self, input: impl Into<String>) -> Self
pub fn bin_edges(self, input: impl Into<String>) -> Self
Appends an item to bin_edges.
To override the contents of this collection use set_bin_edges.
The bin edge values for the distribution.
Sourcepub fn set_bin_edges(self, input: Option<Vec<String>>) -> Self
pub fn set_bin_edges(self, input: Option<Vec<String>>) -> Self
The bin edge values for the distribution.
Sourcepub fn get_bin_edges(&self) -> &Option<Vec<String>>
pub fn get_bin_edges(&self) -> &Option<Vec<String>>
The bin edge values for the distribution.
Sourcepub fn count(self, input: i32) -> Self
pub fn count(self, input: i32) -> Self
Appends an item to count.
To override the contents of this collection use set_count.
The frequency count for each bin in the distribution.
Sourcepub fn set_count(self, input: Option<Vec<i32>>) -> Self
pub fn set_count(self, input: Option<Vec<i32>>) -> Self
The frequency count for each bin in the distribution.
Sourcepub fn get_count(&self) -> &Option<Vec<i32>>
pub fn get_count(&self) -> &Option<Vec<i32>>
The frequency count for each bin in the distribution.
Sourcepub fn data_type(self, input: impl Into<String>) -> Self
pub fn data_type(self, input: impl Into<String>) -> Self
The data type of the column for the distribution.
Sourcepub fn set_data_type(self, input: Option<String>) -> Self
pub fn set_data_type(self, input: Option<String>) -> Self
The data type of the column for the distribution.
Sourcepub fn get_data_type(&self) -> &Option<String>
pub fn get_data_type(&self) -> &Option<String>
The data type of the column for the distribution.
Sourcepub fn build(self) -> DistributionData
pub fn build(self) -> DistributionData
Consumes the builder and constructs a DistributionData.