#[non_exhaustive]pub struct DistributionResultsOptionsBuilder { /* private fields */ }Expand description
A builder for DistributionResultsOptions.
Implementations
Sourceimpl DistributionResultsOptionsBuilder
impl DistributionResultsOptionsBuilder
Sourcepub fn write_distribution_results_enabled(self, input: bool) -> Self
pub fn write_distribution_results_enabled(self, input: bool) -> Self
Set to true to write distribution results.
Sourcepub fn set_write_distribution_results_enabled(self, input: Option<bool>) -> Self
pub fn set_write_distribution_results_enabled(self, input: Option<bool>) -> Self
Set to true to write distribution results.
Sourcepub fn get_write_distribution_results_enabled(&self) -> &Option<bool>
pub fn get_write_distribution_results_enabled(&self) -> &Option<bool>
Set to true to write distribution results.
Sourcepub fn catalog_table_config(self, input: CatalogTableConfigOptions) -> Self
pub fn catalog_table_config(self, input: CatalogTableConfigOptions) -> Self
The Glue Data Catalog table configuration for storing the distribution results.
Sourcepub fn set_catalog_table_config(
self,
input: Option<CatalogTableConfigOptions>,
) -> Self
pub fn set_catalog_table_config( self, input: Option<CatalogTableConfigOptions>, ) -> Self
The Glue Data Catalog table configuration for storing the distribution results.
Sourcepub fn get_catalog_table_config(&self) -> &Option<CatalogTableConfigOptions>
pub fn get_catalog_table_config(&self) -> &Option<CatalogTableConfigOptions>
The Glue Data Catalog table configuration for storing the distribution results.
Sourcepub fn build(self) -> DistributionResultsOptions
pub fn build(self) -> DistributionResultsOptions
Consumes the builder and constructs a DistributionResultsOptions.