#[non_exhaustive]pub struct EncryptionAtRestBuilder { /* private fields */ }Expand description
A builder for EncryptionAtRest.
Implementations
Sourceimpl EncryptionAtRestBuilder
impl EncryptionAtRestBuilder
Sourcepub fn catalog_encryption_mode(self, input: CatalogEncryptionMode) -> Self
pub fn catalog_encryption_mode(self, input: CatalogEncryptionMode) -> Self
The encryption-at-rest mode for encrypting Data Catalog data.
This field is required.Sourcepub fn set_catalog_encryption_mode(
self,
input: Option<CatalogEncryptionMode>,
) -> Self
pub fn set_catalog_encryption_mode( self, input: Option<CatalogEncryptionMode>, ) -> Self
The encryption-at-rest mode for encrypting Data Catalog data.
Sourcepub fn get_catalog_encryption_mode(&self) -> &Option<CatalogEncryptionMode>
pub fn get_catalog_encryption_mode(&self) -> &Option<CatalogEncryptionMode>
The encryption-at-rest mode for encrypting Data Catalog data.
Sourcepub fn sse_aws_kms_key_id(self, input: impl Into<String>) -> Self
pub fn sse_aws_kms_key_id(self, input: impl Into<String>) -> Self
The ID of the KMS key to use for encryption at rest.
Sourcepub fn set_sse_aws_kms_key_id(self, input: Option<String>) -> Self
pub fn set_sse_aws_kms_key_id(self, input: Option<String>) -> Self
The ID of the KMS key to use for encryption at rest.
Sourcepub fn get_sse_aws_kms_key_id(&self) -> &Option<String>
pub fn get_sse_aws_kms_key_id(&self) -> &Option<String>
The ID of the KMS key to use for encryption at rest.
Sourcepub fn catalog_encryption_service_role(self, input: impl Into<String>) -> Self
pub fn catalog_encryption_service_role(self, input: impl Into<String>) -> Self
The role that Glue assumes to encrypt and decrypt the Data Catalog objects on the caller's behalf.
Sourcepub fn set_catalog_encryption_service_role(self, input: Option<String>) -> Self
pub fn set_catalog_encryption_service_role(self, input: Option<String>) -> Self
The role that Glue assumes to encrypt and decrypt the Data Catalog objects on the caller's behalf.
Sourcepub fn get_catalog_encryption_service_role(&self) -> &Option<String>
pub fn get_catalog_encryption_service_role(&self) -> &Option<String>
The role that Glue assumes to encrypt and decrypt the Data Catalog objects on the caller's behalf.
Sourcepub fn build(self) -> Result<EncryptionAtRest, BuildError>
pub fn build(self) -> Result<EncryptionAtRest, BuildError>
Consumes the builder and constructs a EncryptionAtRest.
This method will fail if any of the following fields are not set: