EntityBuilder

Struct EntityBuilder 

#[non_exhaustive]
pub struct EntityBuilder { /* private fields */ }
A builder for Entity.

Implementations

Source

impl EntityBuilder

pub fn entity_name(self, input: impl Into<String>) -> Self

The name of the entity.

pub fn set_entity_name(self, input: Option<String>) -> Self

The name of the entity.

pub fn get_entity_name(&self) -> &Option<String>

The name of the entity.

pub fn label(self, input: impl Into<String>) -> Self

Label used for the entity.

pub fn set_label(self, input: Option<String>) -> Self

Label used for the entity.

pub fn get_label(&self) -> &Option<String>

Label used for the entity.

pub fn is_parent_entity(self, input: bool) -> Self

A Boolean value which helps to determine whether there are sub objects that can be listed.

pub fn set_is_parent_entity(self, input: Option<bool>) -> Self

A Boolean value which helps to determine whether there are sub objects that can be listed.

pub fn get_is_parent_entity(&self) -> &Option<bool>

A Boolean value which helps to determine whether there are sub objects that can be listed.

pub fn description(self, input: impl Into<String>) -> Self

A description of the entity.

pub fn set_description(self, input: Option<String>) -> Self

A description of the entity.

pub fn get_description(&self) -> &Option<String>

A description of the entity.

pub fn category(self, input: impl Into<String>) -> Self

The type of entities that are present in the response. This value depends on the source connection. For example this is SObjects for Salesforce and databases or schemas or tables for sources like Amazon Redshift.

pub fn set_category(self, input: Option<String>) -> Self

The type of entities that are present in the response. This value depends on the source connection. For example this is SObjects for Salesforce and databases or schemas or tables for sources like Amazon Redshift.

pub fn get_category(&self) -> &Option<String>

The type of entities that are present in the response. This value depends on the source connection. For example this is SObjects for Salesforce and databases or schemas or tables for sources like Amazon Redshift.

pub fn custom_properties( self, k: impl Into<String>, v: impl Into<String>, ) -> Self

Adds a key-value pair to custom_properties.

To override the contents of this collection use set_custom_properties.

An optional map of keys which may be returned for an entity by a connector.

pub fn set_custom_properties( self, input: Option<HashMap<String, String>>, ) -> Self

An optional map of keys which may be returned for an entity by a connector.

pub fn get_custom_properties(&self) -> &Option<HashMap<String, String>>

An optional map of keys which may be returned for an entity by a connector.

pub fn build(self) -> Entity

Consumes the builder and constructs a Entity.