#[non_exhaustive]pub struct EntityConfigurationBuilder { /* private fields */ }Expand description
A builder for EntityConfiguration.
Implementations
Sourceimpl EntityConfigurationBuilder
impl EntityConfigurationBuilder
Sourcepub fn source_configuration(self, input: SourceConfiguration) -> Self
pub fn source_configuration(self, input: SourceConfiguration) -> Self
The source configuration that defines how to make requests to access this entity's data through the REST API.
Sourcepub fn set_source_configuration(
self,
input: Option<SourceConfiguration>,
) -> Self
pub fn set_source_configuration( self, input: Option<SourceConfiguration>, ) -> Self
The source configuration that defines how to make requests to access this entity's data through the REST API.
Sourcepub fn get_source_configuration(&self) -> &Option<SourceConfiguration>
pub fn get_source_configuration(&self) -> &Option<SourceConfiguration>
The source configuration that defines how to make requests to access this entity's data through the REST API.
Sourcepub fn schema(self, k: impl Into<String>, v: FieldDefinition) -> Self
pub fn schema(self, k: impl Into<String>, v: FieldDefinition) -> Self
Adds a key-value pair to schema.
To override the contents of this collection use set_schema.
The schema definition for this entity, including field names, types, and other metadata that describes the structure of the data.
Sourcepub fn set_schema(self, input: Option<HashMap<String, FieldDefinition>>) -> Self
pub fn set_schema(self, input: Option<HashMap<String, FieldDefinition>>) -> Self
The schema definition for this entity, including field names, types, and other metadata that describes the structure of the data.
Sourcepub fn get_schema(&self) -> &Option<HashMap<String, FieldDefinition>>
pub fn get_schema(&self) -> &Option<HashMap<String, FieldDefinition>>
The schema definition for this entity, including field names, types, and other metadata that describes the structure of the data.
Sourcepub fn build(self) -> EntityConfiguration
pub fn build(self) -> EntityConfiguration
Consumes the builder and constructs a EntityConfiguration.