#[non_exhaustive]pub struct ExecutionAttemptBuilder { /* private fields */ }Expand description
A builder for ExecutionAttempt.
Implementations
Sourceimpl ExecutionAttemptBuilder
impl ExecutionAttemptBuilder
Sourcepub fn status(self, input: ExecutionStatus) -> Self
pub fn status(self, input: ExecutionStatus) -> Self
The status of the last column statistics task run.
Sourcepub fn set_status(self, input: Option<ExecutionStatus>) -> Self
pub fn set_status(self, input: Option<ExecutionStatus>) -> Self
The status of the last column statistics task run.
Sourcepub fn get_status(&self) -> &Option<ExecutionStatus>
pub fn get_status(&self) -> &Option<ExecutionStatus>
The status of the last column statistics task run.
Sourcepub fn column_statistics_task_run_id(self, input: impl Into<String>) -> Self
pub fn column_statistics_task_run_id(self, input: impl Into<String>) -> Self
A task run ID for the last column statistics task run.
Sourcepub fn set_column_statistics_task_run_id(self, input: Option<String>) -> Self
pub fn set_column_statistics_task_run_id(self, input: Option<String>) -> Self
A task run ID for the last column statistics task run.
Sourcepub fn get_column_statistics_task_run_id(&self) -> &Option<String>
pub fn get_column_statistics_task_run_id(&self) -> &Option<String>
A task run ID for the last column statistics task run.
Sourcepub fn execution_timestamp(self, input: DateTime) -> Self
pub fn execution_timestamp(self, input: DateTime) -> Self
A timestamp when the last column statistics task run occurred.
Sourcepub fn set_execution_timestamp(self, input: Option<DateTime>) -> Self
pub fn set_execution_timestamp(self, input: Option<DateTime>) -> Self
A timestamp when the last column statistics task run occurred.
Sourcepub fn get_execution_timestamp(&self) -> &Option<DateTime>
pub fn get_execution_timestamp(&self) -> &Option<DateTime>
A timestamp when the last column statistics task run occurred.
Sourcepub fn error_message(self, input: impl Into<String>) -> Self
pub fn error_message(self, input: impl Into<String>) -> Self
An error message associated with the last column statistics task run.
Sourcepub fn set_error_message(self, input: Option<String>) -> Self
pub fn set_error_message(self, input: Option<String>) -> Self
An error message associated with the last column statistics task run.
Sourcepub fn get_error_message(&self) -> &Option<String>
pub fn get_error_message(&self) -> &Option<String>
An error message associated with the last column statistics task run.
Sourcepub fn build(self) -> ExecutionAttempt
pub fn build(self) -> ExecutionAttempt
Consumes the builder and constructs a ExecutionAttempt.