#[non_exhaustive]pub struct ExtractedParameterBuilder { /* private fields */ }Expand description
A builder for ExtractedParameter.
Implementations
Sourceimpl ExtractedParameterBuilder
impl ExtractedParameterBuilder
Sourcepub fn key(self, input: impl Into<String>) -> Self
pub fn key(self, input: impl Into<String>) -> Self
The parameter key name that will be used in subsequent requests.
Sourcepub fn set_key(self, input: Option<String>) -> Self
pub fn set_key(self, input: Option<String>) -> Self
The parameter key name that will be used in subsequent requests.
Sourcepub fn get_key(&self) -> &Option<String>
pub fn get_key(&self) -> &Option<String>
The parameter key name that will be used in subsequent requests.
Sourcepub fn default_value(self, input: impl Into<String>) -> Self
pub fn default_value(self, input: impl Into<String>) -> Self
The default value to use if the parameter cannot be extracted from the response.
Sourcepub fn set_default_value(self, input: Option<String>) -> Self
pub fn set_default_value(self, input: Option<String>) -> Self
The default value to use if the parameter cannot be extracted from the response.
Sourcepub fn get_default_value(&self) -> &Option<String>
pub fn get_default_value(&self) -> &Option<String>
The default value to use if the parameter cannot be extracted from the response.
Sourcepub fn property_location(self, input: PropertyLocation) -> Self
pub fn property_location(self, input: PropertyLocation) -> Self
Specifies where this extracted parameter should be placed in subsequent requests, such as in headers, query parameters, or request body.
Sourcepub fn set_property_location(self, input: Option<PropertyLocation>) -> Self
pub fn set_property_location(self, input: Option<PropertyLocation>) -> Self
Specifies where this extracted parameter should be placed in subsequent requests, such as in headers, query parameters, or request body.
Sourcepub fn get_property_location(&self) -> &Option<PropertyLocation>
pub fn get_property_location(&self) -> &Option<PropertyLocation>
Specifies where this extracted parameter should be placed in subsequent requests, such as in headers, query parameters, or request body.
Sourcepub fn value(self, input: ResponseExtractionMapping) -> Self
pub fn value(self, input: ResponseExtractionMapping) -> Self
The JSON path or extraction mapping that defines how to extract the parameter value from API responses.
Sourcepub fn set_value(self, input: Option<ResponseExtractionMapping>) -> Self
pub fn set_value(self, input: Option<ResponseExtractionMapping>) -> Self
The JSON path or extraction mapping that defines how to extract the parameter value from API responses.
Sourcepub fn get_value(&self) -> &Option<ResponseExtractionMapping>
pub fn get_value(&self) -> &Option<ResponseExtractionMapping>
The JSON path or extraction mapping that defines how to extract the parameter value from API responses.
Sourcepub fn build(self) -> ExtractedParameter
pub fn build(self) -> ExtractedParameter
Consumes the builder and constructs a ExtractedParameter.