#[non_exhaustive]pub struct FederatedDatabaseBuilder { /* private fields */ }Expand description
A builder for FederatedDatabase.
Implementations
Sourceimpl FederatedDatabaseBuilder
impl FederatedDatabaseBuilder
Sourcepub fn identifier(self, input: impl Into<String>) -> Self
pub fn identifier(self, input: impl Into<String>) -> Self
A unique identifier for the federated database.
Sourcepub fn set_identifier(self, input: Option<String>) -> Self
pub fn set_identifier(self, input: Option<String>) -> Self
A unique identifier for the federated database.
Sourcepub fn get_identifier(&self) -> &Option<String>
pub fn get_identifier(&self) -> &Option<String>
A unique identifier for the federated database.
Sourcepub fn connection_name(self, input: impl Into<String>) -> Self
pub fn connection_name(self, input: impl Into<String>) -> Self
The name of the connection to the external metastore.
Sourcepub fn set_connection_name(self, input: Option<String>) -> Self
pub fn set_connection_name(self, input: Option<String>) -> Self
The name of the connection to the external metastore.
Sourcepub fn get_connection_name(&self) -> &Option<String>
pub fn get_connection_name(&self) -> &Option<String>
The name of the connection to the external metastore.
Sourcepub fn connection_type(self, input: impl Into<String>) -> Self
pub fn connection_type(self, input: impl Into<String>) -> Self
The type of connection used to access the federated database, such as JDBC, ODBC, or other supported connection protocols.
Sourcepub fn set_connection_type(self, input: Option<String>) -> Self
pub fn set_connection_type(self, input: Option<String>) -> Self
The type of connection used to access the federated database, such as JDBC, ODBC, or other supported connection protocols.
Sourcepub fn get_connection_type(&self) -> &Option<String>
pub fn get_connection_type(&self) -> &Option<String>
The type of connection used to access the federated database, such as JDBC, ODBC, or other supported connection protocols.
Sourcepub fn build(self) -> FederatedDatabase
pub fn build(self) -> FederatedDatabase
Consumes the builder and constructs a FederatedDatabase.