#[non_exhaustive]pub struct FederatedTableBuilder { /* private fields */ }Expand description
A builder for FederatedTable.
Implementations
Sourceimpl FederatedTableBuilder
impl FederatedTableBuilder
Sourcepub fn identifier(self, input: impl Into<String>) -> Self
pub fn identifier(self, input: impl Into<String>) -> Self
A unique identifier for the federated table.
Sourcepub fn set_identifier(self, input: Option<String>) -> Self
pub fn set_identifier(self, input: Option<String>) -> Self
A unique identifier for the federated table.
Sourcepub fn get_identifier(&self) -> &Option<String>
pub fn get_identifier(&self) -> &Option<String>
A unique identifier for the federated table.
Sourcepub fn database_identifier(self, input: impl Into<String>) -> Self
pub fn database_identifier(self, input: impl Into<String>) -> Self
A unique identifier for the federated database.
Sourcepub fn set_database_identifier(self, input: Option<String>) -> Self
pub fn set_database_identifier(self, input: Option<String>) -> Self
A unique identifier for the federated database.
Sourcepub fn get_database_identifier(&self) -> &Option<String>
pub fn get_database_identifier(&self) -> &Option<String>
A unique identifier for the federated database.
Sourcepub fn connection_name(self, input: impl Into<String>) -> Self
pub fn connection_name(self, input: impl Into<String>) -> Self
The name of the connection to the external metastore.
Sourcepub fn set_connection_name(self, input: Option<String>) -> Self
pub fn set_connection_name(self, input: Option<String>) -> Self
The name of the connection to the external metastore.
Sourcepub fn get_connection_name(&self) -> &Option<String>
pub fn get_connection_name(&self) -> &Option<String>
The name of the connection to the external metastore.
Sourcepub fn connection_type(self, input: impl Into<String>) -> Self
pub fn connection_type(self, input: impl Into<String>) -> Self
The type of connection used to access the federated table, specifying the protocol or method for connecting to the external data source.
Sourcepub fn set_connection_type(self, input: Option<String>) -> Self
pub fn set_connection_type(self, input: Option<String>) -> Self
The type of connection used to access the federated table, specifying the protocol or method for connecting to the external data source.
Sourcepub fn get_connection_type(&self) -> &Option<String>
pub fn get_connection_type(&self) -> &Option<String>
The type of connection used to access the federated table, specifying the protocol or method for connecting to the external data source.
Sourcepub fn build(self) -> FederatedTable
pub fn build(self) -> FederatedTable
Consumes the builder and constructs a FederatedTable.