FieldBuilder

Struct FieldBuilder 

#[non_exhaustive]
pub struct FieldBuilder { /* private fields */ }
A builder for Field.

Implementations

Source

impl FieldBuilder

pub fn field_name(self, input: impl Into<String>) -> Self

A unique identifier for the field.

pub fn set_field_name(self, input: Option<String>) -> Self

A unique identifier for the field.

pub fn get_field_name(&self) -> &Option<String>

A unique identifier for the field.

pub fn label(self, input: impl Into<String>) -> Self

A readable label used for the field.

pub fn set_label(self, input: Option<String>) -> Self

A readable label used for the field.

pub fn get_label(&self) -> &Option<String>

A readable label used for the field.

pub fn description(self, input: impl Into<String>) -> Self

A description of the field.

pub fn set_description(self, input: Option<String>) -> Self

A description of the field.

pub fn get_description(&self) -> &Option<String>

A description of the field.

pub fn field_type(self, input: FieldDataType) -> Self

The type of data in the field.

pub fn set_field_type(self, input: Option<FieldDataType>) -> Self

The type of data in the field.

pub fn get_field_type(&self) -> &Option<FieldDataType>

The type of data in the field.

pub fn is_primary_key(self, input: bool) -> Self

Indicates whether this field can used as a primary key for the given entity.

pub fn set_is_primary_key(self, input: Option<bool>) -> Self

Indicates whether this field can used as a primary key for the given entity.

pub fn get_is_primary_key(&self) -> &Option<bool>

Indicates whether this field can used as a primary key for the given entity.

pub fn is_nullable(self, input: bool) -> Self

Indicates whether this field can be nullable or not.

pub fn set_is_nullable(self, input: Option<bool>) -> Self

Indicates whether this field can be nullable or not.

pub fn get_is_nullable(&self) -> &Option<bool>

Indicates whether this field can be nullable or not.

pub fn is_retrievable(self, input: bool) -> Self

Indicates whether this field can be added in Select clause of SQL query or whether it is retrievable or not.

pub fn set_is_retrievable(self, input: Option<bool>) -> Self

Indicates whether this field can be added in Select clause of SQL query or whether it is retrievable or not.

pub fn get_is_retrievable(&self) -> &Option<bool>

Indicates whether this field can be added in Select clause of SQL query or whether it is retrievable or not.

pub fn is_filterable(self, input: bool) -> Self

Indicates whether this field can used in a filter clause (WHERE clause) of a SQL statement when querying data.

pub fn set_is_filterable(self, input: Option<bool>) -> Self

Indicates whether this field can used in a filter clause (WHERE clause) of a SQL statement when querying data.

pub fn get_is_filterable(&self) -> &Option<bool>

Indicates whether this field can used in a filter clause (WHERE clause) of a SQL statement when querying data.

pub fn is_partitionable(self, input: bool) -> Self

Indicates whether a given field can be used in partitioning the query made to SaaS.

pub fn set_is_partitionable(self, input: Option<bool>) -> Self

Indicates whether a given field can be used in partitioning the query made to SaaS.

pub fn get_is_partitionable(&self) -> &Option<bool>

Indicates whether a given field can be used in partitioning the query made to SaaS.

pub fn is_createable(self, input: bool) -> Self

Indicates whether this field can be created as part of a destination write.

pub fn set_is_createable(self, input: Option<bool>) -> Self

Indicates whether this field can be created as part of a destination write.

pub fn get_is_createable(&self) -> &Option<bool>

Indicates whether this field can be created as part of a destination write.

pub fn is_updateable(self, input: bool) -> Self

Indicates whether this field can be updated as part of a destination write.

pub fn set_is_updateable(self, input: Option<bool>) -> Self

Indicates whether this field can be updated as part of a destination write.

pub fn get_is_updateable(&self) -> &Option<bool>

Indicates whether this field can be updated as part of a destination write.

pub fn is_upsertable(self, input: bool) -> Self

Indicates whether this field can be upserted as part of a destination write.

pub fn set_is_upsertable(self, input: Option<bool>) -> Self

Indicates whether this field can be upserted as part of a destination write.

pub fn get_is_upsertable(&self) -> &Option<bool>

Indicates whether this field can be upserted as part of a destination write.

pub fn is_default_on_create(self, input: bool) -> Self

Indicates whether this field is populated automatically when the object is created, such as a created at timestamp.

pub fn set_is_default_on_create(self, input: Option<bool>) -> Self

Indicates whether this field is populated automatically when the object is created, such as a created at timestamp.

pub fn get_is_default_on_create(&self) -> &Option<bool>

Indicates whether this field is populated automatically when the object is created, such as a created at timestamp.

pub fn supported_values(self, input: impl Into<String>) -> Self

Appends an item to supported_values.

To override the contents of this collection use set_supported_values.

A list of supported values for the field.

pub fn set_supported_values(self, input: Option<Vec<String>>) -> Self

A list of supported values for the field.

pub fn get_supported_values(&self) -> &Option<Vec<String>>

A list of supported values for the field.

pub fn supported_filter_operators(self, input: FieldFilterOperator) -> Self

Appends an item to supported_filter_operators.

To override the contents of this collection use set_supported_filter_operators.

Indicates the support filter operators for this field.

pub fn set_supported_filter_operators( self, input: Option<Vec<FieldFilterOperator>>, ) -> Self

Indicates the support filter operators for this field.

pub fn get_supported_filter_operators( &self, ) -> &Option<Vec<FieldFilterOperator>>

Indicates the support filter operators for this field.

pub fn parent_field(self, input: impl Into<String>) -> Self

A parent field name for a nested field.

pub fn set_parent_field(self, input: Option<String>) -> Self

A parent field name for a nested field.

pub fn get_parent_field(&self) -> &Option<String>

A parent field name for a nested field.

pub fn native_data_type(self, input: impl Into<String>) -> Self

The data type returned by the SaaS API, such as “picklist” or “textarea” from Salesforce.

pub fn set_native_data_type(self, input: Option<String>) -> Self

The data type returned by the SaaS API, such as “picklist” or “textarea” from Salesforce.

pub fn get_native_data_type(&self) -> &Option<String>

The data type returned by the SaaS API, such as “picklist” or “textarea” from Salesforce.

pub fn custom_properties( self, k: impl Into<String>, v: impl Into<String>, ) -> Self

Adds a key-value pair to custom_properties.

To override the contents of this collection use set_custom_properties.

Optional map of keys which may be returned.

pub fn set_custom_properties( self, input: Option<HashMap<String, String>>, ) -> Self

Optional map of keys which may be returned.

pub fn get_custom_properties(&self) -> &Option<HashMap<String, String>>

Optional map of keys which may be returned.

pub fn build(self) -> Field

Consumes the builder and constructs a Field.