FieldDefinitionBuilder

Struct FieldDefinitionBuilder 

#[non_exhaustive]
pub struct FieldDefinitionBuilder { /* private fields */ }
A builder for FieldDefinition.

Implementations

Source

impl FieldDefinitionBuilder

pub fn name(self, input: impl Into<String>) -> Self

The name of the field in the entity schema.

This field is required.
pub fn set_name(self, input: Option<String>) -> Self

The name of the field in the entity schema.

pub fn get_name(&self) -> &Option<String>

The name of the field in the entity schema.

pub fn field_data_type(self, input: FieldDataType) -> Self

The data type of the field.

This field is required.
pub fn set_field_data_type(self, input: Option<FieldDataType>) -> Self

The data type of the field.

pub fn get_field_data_type(&self) -> &Option<FieldDataType>

The data type of the field.

pub fn response_date_format(self, input: impl Into<String>) -> Self

The format pattern for parsing date values from API responses. Required when the API uses a non-ISO-8601 format. Accepts Java DateTimeFormatter patterns (for example, EEE, d MMM yyyy HH:mm:ss Z), EPOCH_SECONDS for Unix epoch seconds, or EPOCH_MILLIS for Unix epoch milliseconds.

pub fn set_response_date_format(self, input: Option<String>) -> Self

The format pattern for parsing date values from API responses. Required when the API uses a non-ISO-8601 format. Accepts Java DateTimeFormatter patterns (for example, EEE, d MMM yyyy HH:mm:ss Z), EPOCH_SECONDS for Unix epoch seconds, or EPOCH_MILLIS for Unix epoch milliseconds.

pub fn get_response_date_format(&self) -> &Option<String>

The format pattern for parsing date values from API responses. Required when the API uses a non-ISO-8601 format. Accepts Java DateTimeFormatter patterns (for example, EEE, d MMM yyyy HH:mm:ss Z), EPOCH_SECONDS for Unix epoch seconds, or EPOCH_MILLIS for Unix epoch milliseconds.

pub fn is_partitionable(self, input: bool) -> Self

Indicates whether this field can be used for partitioning queries to the data source.

pub fn set_is_partitionable(self, input: Option<bool>) -> Self

Indicates whether this field can be used for partitioning queries to the data source.

pub fn get_is_partitionable(&self) -> &Option<bool>

Indicates whether this field can be used for partitioning queries to the data source.

pub fn is_nullable(self, input: bool) -> Self

Indicates whether this field can contain null values.

pub fn set_is_nullable(self, input: Option<bool>) -> Self

Indicates whether this field can contain null values.

pub fn get_is_nullable(&self) -> &Option<bool>

Indicates whether this field can contain null values.

pub fn is_queryable(self, input: bool) -> Self

Indicates whether this field can be used in filter predicates when querying data.

pub fn set_is_queryable(self, input: Option<bool>) -> Self

Indicates whether this field can be used in filter predicates when querying data.

pub fn get_is_queryable(&self) -> &Option<bool>

Indicates whether this field can be used in filter predicates when querying data.

pub fn is_orderable(self, input: bool) -> Self

Indicates whether this field can be used for ordering results.

pub fn set_is_orderable(self, input: Option<bool>) -> Self

Indicates whether this field can be used for ordering results.

pub fn get_is_orderable(&self) -> &Option<bool>

Indicates whether this field can be used for ordering results.

pub fn filter_overrides(self, input: FilterOverrides) -> Self

Per-field overrides for filter behavior, allowing customization of how filters are applied to this specific field.

pub fn set_filter_overrides(self, input: Option<FilterOverrides>) -> Self

Per-field overrides for filter behavior, allowing customization of how filters are applied to this specific field.

pub fn get_filter_overrides(&self) -> &Option<FilterOverrides>

Per-field overrides for filter behavior, allowing customization of how filters are applied to this specific field.

pub fn build(self) -> Result<FieldDefinition, BuildError>

Consumes the builder and constructs a FieldDefinition. This method will fail if any of the following fields are not set: