#[non_exhaustive]pub struct GlueSchemaBuilder { /* private fields */ }Expand description
A builder for GlueSchema.
Implementations
Sourceimpl GlueSchemaBuilder
impl GlueSchemaBuilder
Sourcepub fn columns(self, input: GlueStudioSchemaColumn) -> Self
pub fn columns(self, input: GlueStudioSchemaColumn) -> Self
Appends an item to columns.
To override the contents of this collection use set_columns.
Specifies the column definitions that make up a Glue schema.
Sourcepub fn set_columns(self, input: Option<Vec<GlueStudioSchemaColumn>>) -> Self
pub fn set_columns(self, input: Option<Vec<GlueStudioSchemaColumn>>) -> Self
Specifies the column definitions that make up a Glue schema.
Sourcepub fn get_columns(&self) -> &Option<Vec<GlueStudioSchemaColumn>>
pub fn get_columns(&self) -> &Option<Vec<GlueStudioSchemaColumn>>
Specifies the column definitions that make up a Glue schema.
Sourcepub fn build(self) -> GlueSchema
pub fn build(self) -> GlueSchema
Consumes the builder and constructs a GlueSchema.