#[non_exhaustive]pub struct GlueTableBuilder { /* private fields */ }Expand description
A builder for GlueTable.
Implementations
Sourceimpl GlueTableBuilder
impl GlueTableBuilder
Sourcepub fn database_name(self, input: impl Into<String>) -> Self
pub fn database_name(self, input: impl Into<String>) -> Self
A database name in the Glue Data Catalog.
This field is required.Sourcepub fn set_database_name(self, input: Option<String>) -> Self
pub fn set_database_name(self, input: Option<String>) -> Self
A database name in the Glue Data Catalog.
Sourcepub fn get_database_name(&self) -> &Option<String>
pub fn get_database_name(&self) -> &Option<String>
A database name in the Glue Data Catalog.
Sourcepub fn table_name(self, input: impl Into<String>) -> Self
pub fn table_name(self, input: impl Into<String>) -> Self
A table name in the Glue Data Catalog.
This field is required.Sourcepub fn set_table_name(self, input: Option<String>) -> Self
pub fn set_table_name(self, input: Option<String>) -> Self
A table name in the Glue Data Catalog.
Sourcepub fn get_table_name(&self) -> &Option<String>
pub fn get_table_name(&self) -> &Option<String>
A table name in the Glue Data Catalog.
Sourcepub fn catalog_id(self, input: impl Into<String>) -> Self
pub fn catalog_id(self, input: impl Into<String>) -> Self
A unique identifier for the Glue Data Catalog.
Sourcepub fn set_catalog_id(self, input: Option<String>) -> Self
pub fn set_catalog_id(self, input: Option<String>) -> Self
A unique identifier for the Glue Data Catalog.
Sourcepub fn get_catalog_id(&self) -> &Option<String>
pub fn get_catalog_id(&self) -> &Option<String>
A unique identifier for the Glue Data Catalog.
Sourcepub fn connection_name(self, input: impl Into<String>) -> Self
pub fn connection_name(self, input: impl Into<String>) -> Self
The name of the connection to the Glue Data Catalog.
Sourcepub fn set_connection_name(self, input: Option<String>) -> Self
pub fn set_connection_name(self, input: Option<String>) -> Self
The name of the connection to the Glue Data Catalog.
Sourcepub fn get_connection_name(&self) -> &Option<String>
pub fn get_connection_name(&self) -> &Option<String>
The name of the connection to the Glue Data Catalog.
Sourcepub fn additional_options(
self,
k: impl Into<String>,
v: impl Into<String>,
) -> Self
pub fn additional_options( self, k: impl Into<String>, v: impl Into<String>, ) -> Self
Adds a key-value pair to additional_options.
To override the contents of this collection use set_additional_options.
Additional options for the table. Currently there are two keys supported:
-
pushDownPredicate: to filter on partitions without having to list and read all the files in your dataset. -
catalogPartitionPredicate: to use server-side partition pruning using partition indexes in the Glue Data Catalog.
Sourcepub fn set_additional_options(
self,
input: Option<HashMap<String, String>>,
) -> Self
pub fn set_additional_options( self, input: Option<HashMap<String, String>>, ) -> Self
Additional options for the table. Currently there are two keys supported:
-
pushDownPredicate: to filter on partitions without having to list and read all the files in your dataset. -
catalogPartitionPredicate: to use server-side partition pruning using partition indexes in the Glue Data Catalog.
Sourcepub fn get_additional_options(&self) -> &Option<HashMap<String, String>>
pub fn get_additional_options(&self) -> &Option<HashMap<String, String>>
Additional options for the table. Currently there are two keys supported:
-
pushDownPredicate: to filter on partitions without having to list and read all the files in your dataset. -
catalogPartitionPredicate: to use server-side partition pruning using partition indexes in the Glue Data Catalog.