#[non_exhaustive]pub struct IcebergCompactionConfigurationBuilder { /* private fields */ }Expand description
A builder for IcebergCompactionConfiguration.
Implementations
Sourceimpl IcebergCompactionConfigurationBuilder
impl IcebergCompactionConfigurationBuilder
Sourcepub fn strategy(self, input: CompactionStrategy) -> Self
pub fn strategy(self, input: CompactionStrategy) -> Self
The strategy to use for compaction. Valid values are:
-
binpack: Combines small files into larger files, typically targeting sizes over 100MB, while applying any pending deletes. This is the recommended compaction strategy for most use cases. -
sort: Organizes data based on specified columns which are sorted hierarchically during compaction, improving query performance for filtered operations. This strategy is recommended when your queries frequently filter on specific columns. To use this strategy, you must first define a sort order in your Iceberg table properties using thesort_ordertable property. -
z-order: Optimizes data organization by blending multiple attributes into a single scalar value that can be used for sorting, allowing efficient querying across multiple dimensions. This strategy is recommended when you need to query data across multiple dimensions simultaneously. To use this strategy, you must first define a sort order in your Iceberg table properties using thesort_ordertable property.
If an input is not provided, the default value 'binpack' will be used.
Sourcepub fn set_strategy(self, input: Option<CompactionStrategy>) -> Self
pub fn set_strategy(self, input: Option<CompactionStrategy>) -> Self
The strategy to use for compaction. Valid values are:
-
binpack: Combines small files into larger files, typically targeting sizes over 100MB, while applying any pending deletes. This is the recommended compaction strategy for most use cases. -
sort: Organizes data based on specified columns which are sorted hierarchically during compaction, improving query performance for filtered operations. This strategy is recommended when your queries frequently filter on specific columns. To use this strategy, you must first define a sort order in your Iceberg table properties using thesort_ordertable property. -
z-order: Optimizes data organization by blending multiple attributes into a single scalar value that can be used for sorting, allowing efficient querying across multiple dimensions. This strategy is recommended when you need to query data across multiple dimensions simultaneously. To use this strategy, you must first define a sort order in your Iceberg table properties using thesort_ordertable property.
If an input is not provided, the default value 'binpack' will be used.
Sourcepub fn get_strategy(&self) -> &Option<CompactionStrategy>
pub fn get_strategy(&self) -> &Option<CompactionStrategy>
The strategy to use for compaction. Valid values are:
-
binpack: Combines small files into larger files, typically targeting sizes over 100MB, while applying any pending deletes. This is the recommended compaction strategy for most use cases. -
sort: Organizes data based on specified columns which are sorted hierarchically during compaction, improving query performance for filtered operations. This strategy is recommended when your queries frequently filter on specific columns. To use this strategy, you must first define a sort order in your Iceberg table properties using thesort_ordertable property. -
z-order: Optimizes data organization by blending multiple attributes into a single scalar value that can be used for sorting, allowing efficient querying across multiple dimensions. This strategy is recommended when you need to query data across multiple dimensions simultaneously. To use this strategy, you must first define a sort order in your Iceberg table properties using thesort_ordertable property.
If an input is not provided, the default value 'binpack' will be used.
Sourcepub fn min_input_files(self, input: i32) -> Self
pub fn min_input_files(self, input: i32) -> Self
The minimum number of data files that must be present in a partition before compaction will actually compact files. This parameter helps control when compaction is triggered, preventing unnecessary compaction operations on partitions with few files. If an input is not provided, the default value 100 will be used.
Sourcepub fn set_min_input_files(self, input: Option<i32>) -> Self
pub fn set_min_input_files(self, input: Option<i32>) -> Self
The minimum number of data files that must be present in a partition before compaction will actually compact files. This parameter helps control when compaction is triggered, preventing unnecessary compaction operations on partitions with few files. If an input is not provided, the default value 100 will be used.
Sourcepub fn get_min_input_files(&self) -> &Option<i32>
pub fn get_min_input_files(&self) -> &Option<i32>
The minimum number of data files that must be present in a partition before compaction will actually compact files. This parameter helps control when compaction is triggered, preventing unnecessary compaction operations on partitions with few files. If an input is not provided, the default value 100 will be used.
Sourcepub fn delete_file_threshold(self, input: i32) -> Self
pub fn delete_file_threshold(self, input: i32) -> Self
The minimum number of deletes that must be present in a data file to make it eligible for compaction. This parameter helps optimize compaction by focusing on files that contain a significant number of delete operations, which can improve query performance by removing deleted records. If an input is not provided, the default value 1 will be used.
Sourcepub fn set_delete_file_threshold(self, input: Option<i32>) -> Self
pub fn set_delete_file_threshold(self, input: Option<i32>) -> Self
The minimum number of deletes that must be present in a data file to make it eligible for compaction. This parameter helps optimize compaction by focusing on files that contain a significant number of delete operations, which can improve query performance by removing deleted records. If an input is not provided, the default value 1 will be used.
Sourcepub fn get_delete_file_threshold(&self) -> &Option<i32>
pub fn get_delete_file_threshold(&self) -> &Option<i32>
The minimum number of deletes that must be present in a data file to make it eligible for compaction. This parameter helps optimize compaction by focusing on files that contain a significant number of delete operations, which can improve query performance by removing deleted records. If an input is not provided, the default value 1 will be used.
Sourcepub fn build(self) -> IcebergCompactionConfiguration
pub fn build(self) -> IcebergCompactionConfiguration
Consumes the builder and constructs a IcebergCompactionConfiguration.