#[non_exhaustive]pub struct IcebergCompactionMetricsBuilder { /* private fields */ }Expand description
A builder for IcebergCompactionMetrics.
Implementations
Sourceimpl IcebergCompactionMetricsBuilder
impl IcebergCompactionMetricsBuilder
Sourcepub fn number_of_bytes_compacted(self, input: i64) -> Self
pub fn number_of_bytes_compacted(self, input: i64) -> Self
The number of bytes removed by the compaction job run.
Sourcepub fn set_number_of_bytes_compacted(self, input: Option<i64>) -> Self
pub fn set_number_of_bytes_compacted(self, input: Option<i64>) -> Self
The number of bytes removed by the compaction job run.
Sourcepub fn get_number_of_bytes_compacted(&self) -> &Option<i64>
pub fn get_number_of_bytes_compacted(&self) -> &Option<i64>
The number of bytes removed by the compaction job run.
Sourcepub fn number_of_files_compacted(self, input: i64) -> Self
pub fn number_of_files_compacted(self, input: i64) -> Self
The number of files removed by the compaction job run.
Sourcepub fn set_number_of_files_compacted(self, input: Option<i64>) -> Self
pub fn set_number_of_files_compacted(self, input: Option<i64>) -> Self
The number of files removed by the compaction job run.
Sourcepub fn get_number_of_files_compacted(&self) -> &Option<i64>
pub fn get_number_of_files_compacted(&self) -> &Option<i64>
The number of files removed by the compaction job run.
Sourcepub fn set_dpu_hours(self, input: Option<f64>) -> Self
pub fn set_dpu_hours(self, input: Option<f64>) -> Self
The number of DPU hours consumed by the job.
Sourcepub fn get_dpu_hours(&self) -> &Option<f64>
pub fn get_dpu_hours(&self) -> &Option<f64>
The number of DPU hours consumed by the job.
Sourcepub fn number_of_dpus(self, input: i32) -> Self
pub fn number_of_dpus(self, input: i32) -> Self
The number of DPUs consumed by the job, rounded up to the nearest whole number.
Sourcepub fn set_number_of_dpus(self, input: Option<i32>) -> Self
pub fn set_number_of_dpus(self, input: Option<i32>) -> Self
The number of DPUs consumed by the job, rounded up to the nearest whole number.
Sourcepub fn get_number_of_dpus(&self) -> &Option<i32>
pub fn get_number_of_dpus(&self) -> &Option<i32>
The number of DPUs consumed by the job, rounded up to the nearest whole number.
Sourcepub fn job_duration_in_hour(self, input: f64) -> Self
pub fn job_duration_in_hour(self, input: f64) -> Self
The duration of the job in hours.
Sourcepub fn set_job_duration_in_hour(self, input: Option<f64>) -> Self
pub fn set_job_duration_in_hour(self, input: Option<f64>) -> Self
The duration of the job in hours.
Sourcepub fn get_job_duration_in_hour(&self) -> &Option<f64>
pub fn get_job_duration_in_hour(&self) -> &Option<f64>
The duration of the job in hours.
Sourcepub fn build(self) -> IcebergCompactionMetrics
pub fn build(self) -> IcebergCompactionMetrics
Consumes the builder and constructs a IcebergCompactionMetrics.