#[non_exhaustive]pub struct IcebergInputBuilder { /* private fields */ }Expand description
A builder for IcebergInput.
Implementations
Sourceimpl IcebergInputBuilder
impl IcebergInputBuilder
Sourcepub fn metadata_operation(self, input: MetadataOperation) -> Self
pub fn metadata_operation(self, input: MetadataOperation) -> Self
A required metadata operation. Can only be set to CREATE.
Sourcepub fn set_metadata_operation(self, input: Option<MetadataOperation>) -> Self
pub fn set_metadata_operation(self, input: Option<MetadataOperation>) -> Self
A required metadata operation. Can only be set to CREATE.
Sourcepub fn get_metadata_operation(&self) -> &Option<MetadataOperation>
pub fn get_metadata_operation(&self) -> &Option<MetadataOperation>
A required metadata operation. Can only be set to CREATE.
Sourcepub fn version(self, input: impl Into<String>) -> Self
pub fn version(self, input: impl Into<String>) -> Self
The table version for the Iceberg table. Defaults to 2.
Sourcepub fn set_version(self, input: Option<String>) -> Self
pub fn set_version(self, input: Option<String>) -> Self
The table version for the Iceberg table. Defaults to 2.
Sourcepub fn get_version(&self) -> &Option<String>
pub fn get_version(&self) -> &Option<String>
The table version for the Iceberg table. Defaults to 2.
Sourcepub fn create_iceberg_table_input(self, input: CreateIcebergTableInput) -> Self
pub fn create_iceberg_table_input(self, input: CreateIcebergTableInput) -> Self
The configuration parameters required to create a new Iceberg table in the Glue Data Catalog, including table properties and metadata specifications.
Sourcepub fn set_create_iceberg_table_input(
self,
input: Option<CreateIcebergTableInput>,
) -> Self
pub fn set_create_iceberg_table_input( self, input: Option<CreateIcebergTableInput>, ) -> Self
The configuration parameters required to create a new Iceberg table in the Glue Data Catalog, including table properties and metadata specifications.
Sourcepub fn get_create_iceberg_table_input(&self) -> &Option<CreateIcebergTableInput>
pub fn get_create_iceberg_table_input(&self) -> &Option<CreateIcebergTableInput>
The configuration parameters required to create a new Iceberg table in the Glue Data Catalog, including table properties and metadata specifications.
Sourcepub fn build(self) -> Result<IcebergInput, BuildError>
pub fn build(self) -> Result<IcebergInput, BuildError>
Consumes the builder and constructs a IcebergInput.
This method will fail if any of the following fields are not set: