#[non_exhaustive]pub struct IcebergOptimizationPropertiesOutputBuilder { /* private fields */ }Expand description
A builder for IcebergOptimizationPropertiesOutput.
Implementations
Sourceimpl IcebergOptimizationPropertiesOutputBuilder
impl IcebergOptimizationPropertiesOutputBuilder
Sourcepub fn role_arn(self, input: impl Into<String>) -> Self
pub fn role_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the IAM role that is used to perform Iceberg table optimization operations.
Sourcepub fn set_role_arn(self, input: Option<String>) -> Self
pub fn set_role_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the IAM role that is used to perform Iceberg table optimization operations.
Sourcepub fn get_role_arn(&self) -> &Option<String>
pub fn get_role_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the IAM role that is used to perform Iceberg table optimization operations.
Sourcepub fn compaction(self, k: impl Into<String>, v: impl Into<String>) -> Self
pub fn compaction(self, k: impl Into<String>, v: impl Into<String>) -> Self
Adds a key-value pair to compaction.
To override the contents of this collection use set_compaction.
A map of key-value pairs that specify configuration parameters for Iceberg table compaction operations, which optimize the layout of data files to improve query performance.
Sourcepub fn set_compaction(self, input: Option<HashMap<String, String>>) -> Self
pub fn set_compaction(self, input: Option<HashMap<String, String>>) -> Self
A map of key-value pairs that specify configuration parameters for Iceberg table compaction operations, which optimize the layout of data files to improve query performance.
Sourcepub fn get_compaction(&self) -> &Option<HashMap<String, String>>
pub fn get_compaction(&self) -> &Option<HashMap<String, String>>
A map of key-value pairs that specify configuration parameters for Iceberg table compaction operations, which optimize the layout of data files to improve query performance.
Sourcepub fn retention(self, k: impl Into<String>, v: impl Into<String>) -> Self
pub fn retention(self, k: impl Into<String>, v: impl Into<String>) -> Self
Adds a key-value pair to retention.
To override the contents of this collection use set_retention.
A map of key-value pairs that specify configuration parameters for Iceberg table retention operations, which manage the lifecycle of table snapshots to control storage costs.
Sourcepub fn set_retention(self, input: Option<HashMap<String, String>>) -> Self
pub fn set_retention(self, input: Option<HashMap<String, String>>) -> Self
A map of key-value pairs that specify configuration parameters for Iceberg table retention operations, which manage the lifecycle of table snapshots to control storage costs.
Sourcepub fn get_retention(&self) -> &Option<HashMap<String, String>>
pub fn get_retention(&self) -> &Option<HashMap<String, String>>
A map of key-value pairs that specify configuration parameters for Iceberg table retention operations, which manage the lifecycle of table snapshots to control storage costs.
Sourcepub fn orphan_file_deletion(
self,
k: impl Into<String>,
v: impl Into<String>,
) -> Self
pub fn orphan_file_deletion( self, k: impl Into<String>, v: impl Into<String>, ) -> Self
Adds a key-value pair to orphan_file_deletion.
To override the contents of this collection use set_orphan_file_deletion.
A map of key-value pairs that specify configuration parameters for Iceberg orphan file deletion operations, which identify and remove files that are no longer referenced by the table metadata.
Sourcepub fn set_orphan_file_deletion(
self,
input: Option<HashMap<String, String>>,
) -> Self
pub fn set_orphan_file_deletion( self, input: Option<HashMap<String, String>>, ) -> Self
A map of key-value pairs that specify configuration parameters for Iceberg orphan file deletion operations, which identify and remove files that are no longer referenced by the table metadata.
Sourcepub fn get_orphan_file_deletion(&self) -> &Option<HashMap<String, String>>
pub fn get_orphan_file_deletion(&self) -> &Option<HashMap<String, String>>
A map of key-value pairs that specify configuration parameters for Iceberg orphan file deletion operations, which identify and remove files that are no longer referenced by the table metadata.
Sourcepub fn last_updated_time(self, input: DateTime) -> Self
pub fn last_updated_time(self, input: DateTime) -> Self
The timestamp when the Iceberg optimization properties were last updated.
Sourcepub fn set_last_updated_time(self, input: Option<DateTime>) -> Self
pub fn set_last_updated_time(self, input: Option<DateTime>) -> Self
The timestamp when the Iceberg optimization properties were last updated.
Sourcepub fn get_last_updated_time(&self) -> &Option<DateTime>
pub fn get_last_updated_time(&self) -> &Option<DateTime>
The timestamp when the Iceberg optimization properties were last updated.
Sourcepub fn build(self) -> IcebergOptimizationPropertiesOutput
pub fn build(self) -> IcebergOptimizationPropertiesOutput
Consumes the builder and constructs a IcebergOptimizationPropertiesOutput.