IcebergOrphanFileDeletionConfigurationBuilder

Struct IcebergOrphanFileDeletionConfigurationBuilder 

#[non_exhaustive]
pub struct IcebergOrphanFileDeletionConfigurationBuilder { /* private fields */ }
Implementations

Source

impl IcebergOrphanFileDeletionConfigurationBuilder

pub fn orphan_file_retention_period_in_days(self, input: i32) -> Self

The number of days that orphan files should be retained before file deletion. If an input is not provided, the default value 3 will be used.

pub fn set_orphan_file_retention_period_in_days( self, input: Option<i32>, ) -> Self

The number of days that orphan files should be retained before file deletion. If an input is not provided, the default value 3 will be used.

pub fn get_orphan_file_retention_period_in_days(&self) -> &Option<i32>

The number of days that orphan files should be retained before file deletion. If an input is not provided, the default value 3 will be used.

pub fn location(self, input: impl Into<String>) -> Self

Specifies a directory in which to look for files (defaults to the table's location). You may choose a sub-directory rather than the top-level table location.

pub fn set_location(self, input: Option<String>) -> Self

Specifies a directory in which to look for files (defaults to the table's location). You may choose a sub-directory rather than the top-level table location.

pub fn get_location(&self) -> &Option<String>

Specifies a directory in which to look for files (defaults to the table's location). You may choose a sub-directory rather than the top-level table location.

pub fn run_rate_in_hours(self, input: i32) -> Self

The interval in hours between orphan file deletion job runs. This parameter controls how frequently the orphan file deletion optimizer will run to clean up orphan files. The value must be between 3 and 168 hours (7 days). If an input is not provided, the default value 24 will be used.

pub fn set_run_rate_in_hours(self, input: Option<i32>) -> Self

The interval in hours between orphan file deletion job runs. This parameter controls how frequently the orphan file deletion optimizer will run to clean up orphan files. The value must be between 3 and 168 hours (7 days). If an input is not provided, the default value 24 will be used.

pub fn get_run_rate_in_hours(&self) -> &Option<i32>

The interval in hours between orphan file deletion job runs. This parameter controls how frequently the orphan file deletion optimizer will run to clean up orphan files. The value must be between 3 and 168 hours (7 days). If an input is not provided, the default value 24 will be used.

pub fn build(self) -> IcebergOrphanFileDeletionConfiguration

Consumes the builder and constructs a IcebergOrphanFileDeletionConfiguration.