#[non_exhaustive]pub struct IcebergPartitionSpecBuilder { /* private fields */ }Expand description
A builder for IcebergPartitionSpec.
Implementations
Sourceimpl IcebergPartitionSpecBuilder
impl IcebergPartitionSpecBuilder
Sourcepub fn fields(self, input: IcebergPartitionField) -> Self
pub fn fields(self, input: IcebergPartitionField) -> Self
Appends an item to fields.
To override the contents of this collection use set_fields.
The list of partition fields that define how the table data should be partitioned, including source fields and their transformations.
Sourcepub fn set_fields(self, input: Option<Vec<IcebergPartitionField>>) -> Self
pub fn set_fields(self, input: Option<Vec<IcebergPartitionField>>) -> Self
The list of partition fields that define how the table data should be partitioned, including source fields and their transformations.
Sourcepub fn get_fields(&self) -> &Option<Vec<IcebergPartitionField>>
pub fn get_fields(&self) -> &Option<Vec<IcebergPartitionField>>
The list of partition fields that define how the table data should be partitioned, including source fields and their transformations.
Sourcepub fn spec_id(self, input: i32) -> Self
pub fn spec_id(self, input: i32) -> Self
The unique identifier for this partition specification within the Iceberg table's metadata history.
Sourcepub fn set_spec_id(self, input: Option<i32>) -> Self
pub fn set_spec_id(self, input: Option<i32>) -> Self
The unique identifier for this partition specification within the Iceberg table's metadata history.
Sourcepub fn get_spec_id(&self) -> &Option<i32>
pub fn get_spec_id(&self) -> &Option<i32>
The unique identifier for this partition specification within the Iceberg table's metadata history.
Sourcepub fn build(self) -> Result<IcebergPartitionSpec, BuildError>
pub fn build(self) -> Result<IcebergPartitionSpec, BuildError>
Consumes the builder and constructs a IcebergPartitionSpec.
This method will fail if any of the following fields are not set: