IcebergRetentionConfigurationBuilder

Struct IcebergRetentionConfigurationBuilder 

#[non_exhaustive]
pub struct IcebergRetentionConfigurationBuilder { /* private fields */ }
Implementations

Source

impl IcebergRetentionConfigurationBuilder

pub fn snapshot_retention_period_in_days(self, input: i32) -> Self

The number of days to retain the Iceberg snapshots. If an input is not provided, the corresponding Iceberg table configuration field will be used or if not present, the default value 5 will be used.

pub fn set_snapshot_retention_period_in_days(self, input: Option<i32>) -> Self

The number of days to retain the Iceberg snapshots. If an input is not provided, the corresponding Iceberg table configuration field will be used or if not present, the default value 5 will be used.

pub fn get_snapshot_retention_period_in_days(&self) -> &Option<i32>

The number of days to retain the Iceberg snapshots. If an input is not provided, the corresponding Iceberg table configuration field will be used or if not present, the default value 5 will be used.

pub fn number_of_snapshots_to_retain(self, input: i32) -> Self

The number of Iceberg snapshots to retain within the retention period. If an input is not provided, the corresponding Iceberg table configuration field will be used or if not present, the default value 1 will be used.

pub fn set_number_of_snapshots_to_retain(self, input: Option<i32>) -> Self

The number of Iceberg snapshots to retain within the retention period. If an input is not provided, the corresponding Iceberg table configuration field will be used or if not present, the default value 1 will be used.

pub fn get_number_of_snapshots_to_retain(&self) -> &Option<i32>

The number of Iceberg snapshots to retain within the retention period. If an input is not provided, the corresponding Iceberg table configuration field will be used or if not present, the default value 1 will be used.

pub fn clean_expired_files(self, input: bool) -> Self

If set to false, snapshots are only deleted from table metadata, and the underlying data and metadata files are not deleted.

pub fn set_clean_expired_files(self, input: Option<bool>) -> Self

If set to false, snapshots are only deleted from table metadata, and the underlying data and metadata files are not deleted.

pub fn get_clean_expired_files(&self) -> &Option<bool>

If set to false, snapshots are only deleted from table metadata, and the underlying data and metadata files are not deleted.

pub fn run_rate_in_hours(self, input: i32) -> Self

The interval in hours between retention job runs. This parameter controls how frequently the retention optimizer will run to clean up expired snapshots. The value must be between 3 and 168 hours (7 days). If an input is not provided, the default value 24 will be used.

pub fn set_run_rate_in_hours(self, input: Option<i32>) -> Self

The interval in hours between retention job runs. This parameter controls how frequently the retention optimizer will run to clean up expired snapshots. The value must be between 3 and 168 hours (7 days). If an input is not provided, the default value 24 will be used.

pub fn get_run_rate_in_hours(&self) -> &Option<i32>

The interval in hours between retention job runs. This parameter controls how frequently the retention optimizer will run to clean up expired snapshots. The value must be between 3 and 168 hours (7 days). If an input is not provided, the default value 24 will be used.

pub fn build(self) -> IcebergRetentionConfiguration

Consumes the builder and constructs a IcebergRetentionConfiguration.