#[non_exhaustive]pub struct IcebergSchemaBuilder { /* private fields */ }Expand description
A builder for IcebergSchema.
Implementations
Sourceimpl IcebergSchemaBuilder
impl IcebergSchemaBuilder
Sourcepub fn schema_id(self, input: i32) -> Self
pub fn schema_id(self, input: i32) -> Self
The unique identifier for this schema version within the Iceberg table's schema evolution history.
Sourcepub fn set_schema_id(self, input: Option<i32>) -> Self
pub fn set_schema_id(self, input: Option<i32>) -> Self
The unique identifier for this schema version within the Iceberg table's schema evolution history.
Sourcepub fn get_schema_id(&self) -> &Option<i32>
pub fn get_schema_id(&self) -> &Option<i32>
The unique identifier for this schema version within the Iceberg table's schema evolution history.
Sourcepub fn identifier_field_ids(self, input: i32) -> Self
pub fn identifier_field_ids(self, input: i32) -> Self
Appends an item to identifier_field_ids.
To override the contents of this collection use set_identifier_field_ids.
The list of field identifiers that uniquely identify records in the table, used for row-level operations and deduplication.
Sourcepub fn set_identifier_field_ids(self, input: Option<Vec<i32>>) -> Self
pub fn set_identifier_field_ids(self, input: Option<Vec<i32>>) -> Self
The list of field identifiers that uniquely identify records in the table, used for row-level operations and deduplication.
Sourcepub fn get_identifier_field_ids(&self) -> &Option<Vec<i32>>
pub fn get_identifier_field_ids(&self) -> &Option<Vec<i32>>
The list of field identifiers that uniquely identify records in the table, used for row-level operations and deduplication.
Sourcepub fn type(self, input: IcebergStructTypeEnum) -> Self
pub fn type(self, input: IcebergStructTypeEnum) -> Self
The root type of the schema structure, typically "struct" for Iceberg table schemas.
Sourcepub fn set_type(self, input: Option<IcebergStructTypeEnum>) -> Self
pub fn set_type(self, input: Option<IcebergStructTypeEnum>) -> Self
The root type of the schema structure, typically "struct" for Iceberg table schemas.
Sourcepub fn get_type(&self) -> &Option<IcebergStructTypeEnum>
pub fn get_type(&self) -> &Option<IcebergStructTypeEnum>
The root type of the schema structure, typically "struct" for Iceberg table schemas.
Sourcepub fn fields(self, input: IcebergStructField) -> Self
pub fn fields(self, input: IcebergStructField) -> Self
Appends an item to fields.
To override the contents of this collection use set_fields.
The list of field definitions that make up the table schema, including field names, types, and metadata.
Sourcepub fn set_fields(self, input: Option<Vec<IcebergStructField>>) -> Self
pub fn set_fields(self, input: Option<Vec<IcebergStructField>>) -> Self
The list of field definitions that make up the table schema, including field names, types, and metadata.
Sourcepub fn get_fields(&self) -> &Option<Vec<IcebergStructField>>
pub fn get_fields(&self) -> &Option<Vec<IcebergStructField>>
The list of field definitions that make up the table schema, including field names, types, and metadata.
Sourcepub fn build(self) -> Result<IcebergSchema, BuildError>
pub fn build(self) -> Result<IcebergSchema, BuildError>
Consumes the builder and constructs a IcebergSchema.
This method will fail if any of the following fields are not set: