#[non_exhaustive]pub struct InboundIntegrationBuilder { /* private fields */ }Expand description
A builder for InboundIntegration.
Implementations
Sourceimpl InboundIntegrationBuilder
impl InboundIntegrationBuilder
Sourcepub fn source_arn(self, input: impl Into<String>) -> Self
pub fn source_arn(self, input: impl Into<String>) -> Self
The ARN of the source resource for the integration.
This field is required.Sourcepub fn set_source_arn(self, input: Option<String>) -> Self
pub fn set_source_arn(self, input: Option<String>) -> Self
The ARN of the source resource for the integration.
Sourcepub fn get_source_arn(&self) -> &Option<String>
pub fn get_source_arn(&self) -> &Option<String>
The ARN of the source resource for the integration.
Sourcepub fn target_arn(self, input: impl Into<String>) -> Self
pub fn target_arn(self, input: impl Into<String>) -> Self
The ARN of the target resource for the integration.
This field is required.Sourcepub fn set_target_arn(self, input: Option<String>) -> Self
pub fn set_target_arn(self, input: Option<String>) -> Self
The ARN of the target resource for the integration.
Sourcepub fn get_target_arn(&self) -> &Option<String>
pub fn get_target_arn(&self) -> &Option<String>
The ARN of the target resource for the integration.
Sourcepub fn integration_arn(self, input: impl Into<String>) -> Self
pub fn integration_arn(self, input: impl Into<String>) -> Self
The ARN of the zero-ETL integration.
This field is required.Sourcepub fn set_integration_arn(self, input: Option<String>) -> Self
pub fn set_integration_arn(self, input: Option<String>) -> Self
The ARN of the zero-ETL integration.
Sourcepub fn get_integration_arn(&self) -> &Option<String>
pub fn get_integration_arn(&self) -> &Option<String>
The ARN of the zero-ETL integration.
Sourcepub fn status(self, input: IntegrationStatus) -> Self
pub fn status(self, input: IntegrationStatus) -> Self
The possible statuses are:
-
CREATING: The integration is being created.
-
ACTIVE: The integration creation succeeds.
-
MODIFYING: The integration is being modified.
-
FAILED: The integration creation fails.
-
DELETING: The integration is deleted.
-
SYNCING: The integration is synchronizing.
-
NEEDS_ATTENTION: The integration needs attention, such as synchronization.
Sourcepub fn set_status(self, input: Option<IntegrationStatus>) -> Self
pub fn set_status(self, input: Option<IntegrationStatus>) -> Self
The possible statuses are:
-
CREATING: The integration is being created.
-
ACTIVE: The integration creation succeeds.
-
MODIFYING: The integration is being modified.
-
FAILED: The integration creation fails.
-
DELETING: The integration is deleted.
-
SYNCING: The integration is synchronizing.
-
NEEDS_ATTENTION: The integration needs attention, such as synchronization.
Sourcepub fn get_status(&self) -> &Option<IntegrationStatus>
pub fn get_status(&self) -> &Option<IntegrationStatus>
The possible statuses are:
-
CREATING: The integration is being created.
-
ACTIVE: The integration creation succeeds.
-
MODIFYING: The integration is being modified.
-
FAILED: The integration creation fails.
-
DELETING: The integration is deleted.
-
SYNCING: The integration is synchronizing.
-
NEEDS_ATTENTION: The integration needs attention, such as synchronization.
Sourcepub fn create_time(self, input: DateTime) -> Self
pub fn create_time(self, input: DateTime) -> Self
The time that the integration was created, in UTC.
This field is required.Sourcepub fn set_create_time(self, input: Option<DateTime>) -> Self
pub fn set_create_time(self, input: Option<DateTime>) -> Self
The time that the integration was created, in UTC.
Sourcepub fn get_create_time(&self) -> &Option<DateTime>
pub fn get_create_time(&self) -> &Option<DateTime>
The time that the integration was created, in UTC.
Sourcepub fn integration_config(self, input: IntegrationConfig) -> Self
pub fn integration_config(self, input: IntegrationConfig) -> Self
Properties associated with the integration.
Sourcepub fn set_integration_config(self, input: Option<IntegrationConfig>) -> Self
pub fn set_integration_config(self, input: Option<IntegrationConfig>) -> Self
Properties associated with the integration.
Sourcepub fn get_integration_config(&self) -> &Option<IntegrationConfig>
pub fn get_integration_config(&self) -> &Option<IntegrationConfig>
Properties associated with the integration.
Sourcepub fn errors(self, input: IntegrationError) -> Self
pub fn errors(self, input: IntegrationError) -> Self
Appends an item to errors.
To override the contents of this collection use set_errors.
A list of errors associated with the integration.
Sourcepub fn set_errors(self, input: Option<Vec<IntegrationError>>) -> Self
pub fn set_errors(self, input: Option<Vec<IntegrationError>>) -> Self
A list of errors associated with the integration.
Sourcepub fn get_errors(&self) -> &Option<Vec<IntegrationError>>
pub fn get_errors(&self) -> &Option<Vec<IntegrationError>>
A list of errors associated with the integration.
Sourcepub fn build(self) -> Result<InboundIntegration, BuildError>
pub fn build(self) -> Result<InboundIntegration, BuildError>
Consumes the builder and constructs a InboundIntegration.
This method will fail if any of the following fields are not set: