IntegrationConfigBuilder

Struct IntegrationConfigBuilder 

#[non_exhaustive]
pub struct IntegrationConfigBuilder { /* private fields */ }
A builder for IntegrationConfig.

Implementations

Source

impl IntegrationConfigBuilder

pub fn refresh_interval(self, input: impl Into<String>) -> Self

Specifies the frequency at which CDC (Change Data Capture) pulls or incremental loads should occur. This parameter provides flexibility to align the refresh rate with your specific data update patterns, system load considerations, and performance optimization goals. Time increment can be set from 15 minutes to 8640 minutes (six days).

pub fn set_refresh_interval(self, input: Option<String>) -> Self

Specifies the frequency at which CDC (Change Data Capture) pulls or incremental loads should occur. This parameter provides flexibility to align the refresh rate with your specific data update patterns, system load considerations, and performance optimization goals. Time increment can be set from 15 minutes to 8640 minutes (six days).

pub fn get_refresh_interval(&self) -> &Option<String>

Specifies the frequency at which CDC (Change Data Capture) pulls or incremental loads should occur. This parameter provides flexibility to align the refresh rate with your specific data update patterns, system load considerations, and performance optimization goals. Time increment can be set from 15 minutes to 8640 minutes (six days).

pub fn source_properties( self, k: impl Into<String>, v: impl Into<String>, ) -> Self

Adds a key-value pair to source_properties.

To override the contents of this collection use set_source_properties.

A collection of key-value pairs that specify additional properties for the integration source. These properties provide configuration options that can be used to customize the behavior of the ODB source during data integration operations.

pub fn set_source_properties( self, input: Option<HashMap<String, String>>, ) -> Self

A collection of key-value pairs that specify additional properties for the integration source. These properties provide configuration options that can be used to customize the behavior of the ODB source during data integration operations.

pub fn get_source_properties(&self) -> &Option<HashMap<String, String>>

A collection of key-value pairs that specify additional properties for the integration source. These properties provide configuration options that can be used to customize the behavior of the ODB source during data integration operations.

pub fn continuous_sync(self, input: bool) -> Self

Enables continuous synchronization for on-demand data extractions from SaaS applications to Amazon Web Services data services like Amazon Redshift and Amazon S3.

pub fn set_continuous_sync(self, input: Option<bool>) -> Self

Enables continuous synchronization for on-demand data extractions from SaaS applications to Amazon Web Services data services like Amazon Redshift and Amazon S3.

pub fn get_continuous_sync(&self) -> &Option<bool>

Enables continuous synchronization for on-demand data extractions from SaaS applications to Amazon Web Services data services like Amazon Redshift and Amazon S3.

pub fn build(self) -> IntegrationConfig

Consumes the builder and constructs a IntegrationConfig.