#[non_exhaustive]pub struct IntegrationPartitionBuilder { /* private fields */ }Expand description
A builder for IntegrationPartition.
Implementations
Sourceimpl IntegrationPartitionBuilder
impl IntegrationPartitionBuilder
Sourcepub fn field_name(self, input: impl Into<String>) -> Self
pub fn field_name(self, input: impl Into<String>) -> Self
The field name used to partition data on the target. Avoid using columns that have unique values for each row (for example, `LastModifiedTimestamp`, `SystemModTimeStamp`) as the partition column. These columns are not suitable for partitioning because they create a large number of small partitions, which can lead to performance issues.
Sourcepub fn set_field_name(self, input: Option<String>) -> Self
pub fn set_field_name(self, input: Option<String>) -> Self
The field name used to partition data on the target. Avoid using columns that have unique values for each row (for example, `LastModifiedTimestamp`, `SystemModTimeStamp`) as the partition column. These columns are not suitable for partitioning because they create a large number of small partitions, which can lead to performance issues.
Sourcepub fn get_field_name(&self) -> &Option<String>
pub fn get_field_name(&self) -> &Option<String>
The field name used to partition data on the target. Avoid using columns that have unique values for each row (for example, `LastModifiedTimestamp`, `SystemModTimeStamp`) as the partition column. These columns are not suitable for partitioning because they create a large number of small partitions, which can lead to performance issues.
Sourcepub fn function_spec(self, input: impl Into<String>) -> Self
pub fn function_spec(self, input: impl Into<String>) -> Self
Specifies the function used to partition data on the target. The accepted values for this parameter are:
-
identity- Uses source values directly without transformation -
year- Extracts the year from timestamp values (e.g., 2023) -
month- Extracts the month from timestamp values (e.g., 2023-01) -
day- Extracts the day from timestamp values (e.g., 2023-01-15) -
hour- Extracts the hour from timestamp values (e.g., 2023-01-15-14)
Sourcepub fn set_function_spec(self, input: Option<String>) -> Self
pub fn set_function_spec(self, input: Option<String>) -> Self
Specifies the function used to partition data on the target. The accepted values for this parameter are:
-
identity- Uses source values directly without transformation -
year- Extracts the year from timestamp values (e.g., 2023) -
month- Extracts the month from timestamp values (e.g., 2023-01) -
day- Extracts the day from timestamp values (e.g., 2023-01-15) -
hour- Extracts the hour from timestamp values (e.g., 2023-01-15-14)
Sourcepub fn get_function_spec(&self) -> &Option<String>
pub fn get_function_spec(&self) -> &Option<String>
Specifies the function used to partition data on the target. The accepted values for this parameter are:
-
identity- Uses source values directly without transformation -
year- Extracts the year from timestamp values (e.g., 2023) -
month- Extracts the month from timestamp values (e.g., 2023-01) -
day- Extracts the day from timestamp values (e.g., 2023-01-15) -
hour- Extracts the hour from timestamp values (e.g., 2023-01-15-14)
Sourcepub fn conversion_spec(self, input: impl Into<String>) -> Self
pub fn conversion_spec(self, input: impl Into<String>) -> Self
Specifies the timestamp format of the source data. Valid values are:
-
epoch_sec- Unix epoch timestamp in seconds -
epoch_milli- Unix epoch timestamp in milliseconds -
iso- ISO 8601 formatted timestamp
Only specify ConversionSpec when using timestamp-based partition functions (year, month, day, or hour). Glue Zero-ETL uses this parameter to correctly transform source data into timestamp format before partitioning.
Do not use high-cardinality columns with the identity partition function. High-cardinality columns include:
-
Primary keys
-
Timestamp fields (such as
LastModifiedTimestamp,CreatedDate) -
System-generated timestamps
Using high-cardinality columns with identity partitioning creates many small partitions, which can significantly degrade ingestion performance.
Sourcepub fn set_conversion_spec(self, input: Option<String>) -> Self
pub fn set_conversion_spec(self, input: Option<String>) -> Self
Specifies the timestamp format of the source data. Valid values are:
-
epoch_sec- Unix epoch timestamp in seconds -
epoch_milli- Unix epoch timestamp in milliseconds -
iso- ISO 8601 formatted timestamp
Only specify ConversionSpec when using timestamp-based partition functions (year, month, day, or hour). Glue Zero-ETL uses this parameter to correctly transform source data into timestamp format before partitioning.
Do not use high-cardinality columns with the identity partition function. High-cardinality columns include:
-
Primary keys
-
Timestamp fields (such as
LastModifiedTimestamp,CreatedDate) -
System-generated timestamps
Using high-cardinality columns with identity partitioning creates many small partitions, which can significantly degrade ingestion performance.
Sourcepub fn get_conversion_spec(&self) -> &Option<String>
pub fn get_conversion_spec(&self) -> &Option<String>
Specifies the timestamp format of the source data. Valid values are:
-
epoch_sec- Unix epoch timestamp in seconds -
epoch_milli- Unix epoch timestamp in milliseconds -
iso- ISO 8601 formatted timestamp
Only specify ConversionSpec when using timestamp-based partition functions (year, month, day, or hour). Glue Zero-ETL uses this parameter to correctly transform source data into timestamp format before partitioning.
Do not use high-cardinality columns with the identity partition function. High-cardinality columns include:
-
Primary keys
-
Timestamp fields (such as
LastModifiedTimestamp,CreatedDate) -
System-generated timestamps
Using high-cardinality columns with identity partitioning creates many small partitions, which can significantly degrade ingestion performance.
Sourcepub fn build(self) -> IntegrationPartition
pub fn build(self) -> IntegrationPartition
Consumes the builder and constructs a IntegrationPartition.