#[non_exhaustive]pub struct IntegrationTablePropertiesBuilder { /* private fields */ }Expand description
A builder for IntegrationTableProperties.
Implementations
Sourceimpl IntegrationTablePropertiesBuilder
impl IntegrationTablePropertiesBuilder
Sourcepub fn resource_arn(self, input: impl Into<String>) -> Self
pub fn resource_arn(self, input: impl Into<String>) -> Self
The connection ARN of the source, or the database ARN of the target.
This field is required.Sourcepub fn set_resource_arn(self, input: Option<String>) -> Self
pub fn set_resource_arn(self, input: Option<String>) -> Self
The connection ARN of the source, or the database ARN of the target.
Sourcepub fn get_resource_arn(&self) -> &Option<String>
pub fn get_resource_arn(&self) -> &Option<String>
The connection ARN of the source, or the database ARN of the target.
Sourcepub fn table_name(self, input: impl Into<String>) -> Self
pub fn table_name(self, input: impl Into<String>) -> Self
The name of the source table to be replicated.
This field is required.Sourcepub fn set_table_name(self, input: Option<String>) -> Self
pub fn set_table_name(self, input: Option<String>) -> Self
The name of the source table to be replicated.
Sourcepub fn get_table_name(&self) -> &Option<String>
pub fn get_table_name(&self) -> &Option<String>
The name of the source table to be replicated.
Sourcepub fn source_table_config(self, input: SourceTableConfig) -> Self
pub fn source_table_config(self, input: SourceTableConfig) -> Self
A structure for the source table configuration.
Sourcepub fn set_source_table_config(self, input: Option<SourceTableConfig>) -> Self
pub fn set_source_table_config(self, input: Option<SourceTableConfig>) -> Self
A structure for the source table configuration.
Sourcepub fn get_source_table_config(&self) -> &Option<SourceTableConfig>
pub fn get_source_table_config(&self) -> &Option<SourceTableConfig>
A structure for the source table configuration.
Sourcepub fn target_table_config(self, input: TargetTableConfig) -> Self
pub fn target_table_config(self, input: TargetTableConfig) -> Self
A structure for the target table configuration.
Sourcepub fn set_target_table_config(self, input: Option<TargetTableConfig>) -> Self
pub fn set_target_table_config(self, input: Option<TargetTableConfig>) -> Self
A structure for the target table configuration.
Sourcepub fn get_target_table_config(&self) -> &Option<TargetTableConfig>
pub fn get_target_table_config(&self) -> &Option<TargetTableConfig>
A structure for the target table configuration.
Sourcepub fn build(self) -> Result<IntegrationTableProperties, BuildError>
pub fn build(self) -> Result<IntegrationTableProperties, BuildError>
Consumes the builder and constructs a IntegrationTableProperties.
This method will fail if any of the following fields are not set: