#[non_exhaustive]pub struct JdbcTargetBuilder { /* private fields */ }Expand description
A builder for JdbcTarget.
Implementations
Sourceimpl JdbcTargetBuilder
impl JdbcTargetBuilder
Sourcepub fn connection_name(self, input: impl Into<String>) -> Self
pub fn connection_name(self, input: impl Into<String>) -> Self
The name of the connection to use to connect to the JDBC target.
Sourcepub fn set_connection_name(self, input: Option<String>) -> Self
pub fn set_connection_name(self, input: Option<String>) -> Self
The name of the connection to use to connect to the JDBC target.
Sourcepub fn get_connection_name(&self) -> &Option<String>
pub fn get_connection_name(&self) -> &Option<String>
The name of the connection to use to connect to the JDBC target.
Sourcepub fn exclusions(self, input: impl Into<String>) -> Self
pub fn exclusions(self, input: impl Into<String>) -> Self
Appends an item to exclusions.
To override the contents of this collection use set_exclusions.
A list of glob patterns used to exclude from the crawl. For more information, see Catalog Tables with a Crawler.
Sourcepub fn set_exclusions(self, input: Option<Vec<String>>) -> Self
pub fn set_exclusions(self, input: Option<Vec<String>>) -> Self
A list of glob patterns used to exclude from the crawl. For more information, see Catalog Tables with a Crawler.
Sourcepub fn get_exclusions(&self) -> &Option<Vec<String>>
pub fn get_exclusions(&self) -> &Option<Vec<String>>
A list of glob patterns used to exclude from the crawl. For more information, see Catalog Tables with a Crawler.
Sourcepub fn enable_additional_metadata(self, input: JdbcMetadataEntry) -> Self
pub fn enable_additional_metadata(self, input: JdbcMetadataEntry) -> Self
Appends an item to enable_additional_metadata.
To override the contents of this collection use set_enable_additional_metadata.
Specify a value of RAWTYPES or COMMENTS to enable additional metadata in table responses. RAWTYPES provides the native-level datatype. COMMENTS provides comments associated with a column or table in the database.
If you do not need additional metadata, keep the field empty.
Sourcepub fn set_enable_additional_metadata(
self,
input: Option<Vec<JdbcMetadataEntry>>,
) -> Self
pub fn set_enable_additional_metadata( self, input: Option<Vec<JdbcMetadataEntry>>, ) -> Self
Specify a value of RAWTYPES or COMMENTS to enable additional metadata in table responses. RAWTYPES provides the native-level datatype. COMMENTS provides comments associated with a column or table in the database.
If you do not need additional metadata, keep the field empty.
Sourcepub fn get_enable_additional_metadata(&self) -> &Option<Vec<JdbcMetadataEntry>>
pub fn get_enable_additional_metadata(&self) -> &Option<Vec<JdbcMetadataEntry>>
Specify a value of RAWTYPES or COMMENTS to enable additional metadata in table responses. RAWTYPES provides the native-level datatype. COMMENTS provides comments associated with a column or table in the database.
If you do not need additional metadata, keep the field empty.
Sourcepub fn build(self) -> JdbcTarget
pub fn build(self) -> JdbcTarget
Consumes the builder and constructs a JdbcTarget.