#[non_exhaustive]pub struct JwtBearerPropertiesBuilder { /* private fields */ }Expand description
A builder for JwtBearerProperties.
Implementations
Sourceimpl JwtBearerPropertiesBuilder
impl JwtBearerPropertiesBuilder
Sourcepub fn token_url(self, input: ConnectorProperty) -> Self
pub fn token_url(self, input: ConnectorProperty) -> Self
The token endpoint URL where the JWT bearer token will be exchanged for an access token.
Sourcepub fn set_token_url(self, input: Option<ConnectorProperty>) -> Self
pub fn set_token_url(self, input: Option<ConnectorProperty>) -> Self
The token endpoint URL where the JWT bearer token will be exchanged for an access token.
Sourcepub fn get_token_url(&self) -> &Option<ConnectorProperty>
pub fn get_token_url(&self) -> &Option<ConnectorProperty>
The token endpoint URL where the JWT bearer token will be exchanged for an access token.
Sourcepub fn request_method(self, input: HttpMethod) -> Self
pub fn request_method(self, input: HttpMethod) -> Self
The HTTP method to use when making JWT bearer token requests, typically POST.
Sourcepub fn set_request_method(self, input: Option<HttpMethod>) -> Self
pub fn set_request_method(self, input: Option<HttpMethod>) -> Self
The HTTP method to use when making JWT bearer token requests, typically POST.
Sourcepub fn get_request_method(&self) -> &Option<HttpMethod>
pub fn get_request_method(&self) -> &Option<HttpMethod>
The HTTP method to use when making JWT bearer token requests, typically POST.
Sourcepub fn content_type(self, input: ContentType) -> Self
pub fn content_type(self, input: ContentType) -> Self
The content type to use for JWT bearer token requests, such as application/x-www-form-urlencoded or application/json.
Sourcepub fn set_content_type(self, input: Option<ContentType>) -> Self
pub fn set_content_type(self, input: Option<ContentType>) -> Self
The content type to use for JWT bearer token requests, such as application/x-www-form-urlencoded or application/json.
Sourcepub fn get_content_type(&self) -> &Option<ContentType>
pub fn get_content_type(&self) -> &Option<ContentType>
The content type to use for JWT bearer token requests, such as application/x-www-form-urlencoded or application/json.
Sourcepub fn jwt_token(self, input: ConnectorProperty) -> Self
pub fn jwt_token(self, input: ConnectorProperty) -> Self
The JWT token to be used in the bearer token grant flow for authentication.
Sourcepub fn set_jwt_token(self, input: Option<ConnectorProperty>) -> Self
pub fn set_jwt_token(self, input: Option<ConnectorProperty>) -> Self
The JWT token to be used in the bearer token grant flow for authentication.
Sourcepub fn get_jwt_token(&self) -> &Option<ConnectorProperty>
pub fn get_jwt_token(&self) -> &Option<ConnectorProperty>
The JWT token to be used in the bearer token grant flow for authentication.
Sourcepub fn token_url_parameters(self, input: ConnectorProperty) -> Self
pub fn token_url_parameters(self, input: ConnectorProperty) -> Self
Appends an item to token_url_parameters.
To override the contents of this collection use set_token_url_parameters.
Additional parameters to include in token URL requests as key-value pairs.
Sourcepub fn set_token_url_parameters(
self,
input: Option<Vec<ConnectorProperty>>,
) -> Self
pub fn set_token_url_parameters( self, input: Option<Vec<ConnectorProperty>>, ) -> Self
Additional parameters to include in token URL requests as key-value pairs.
Sourcepub fn get_token_url_parameters(&self) -> &Option<Vec<ConnectorProperty>>
pub fn get_token_url_parameters(&self) -> &Option<Vec<ConnectorProperty>>
Additional parameters to include in token URL requests as key-value pairs.
Sourcepub fn build(self) -> JwtBearerProperties
pub fn build(self) -> JwtBearerProperties
Consumes the builder and constructs a JwtBearerProperties.