MaterializedViewRefreshTaskRunBuilder

Struct MaterializedViewRefreshTaskRunBuilder 

#[non_exhaustive]
pub struct MaterializedViewRefreshTaskRunBuilder { /* private fields */ }
Implementations

Source

impl MaterializedViewRefreshTaskRunBuilder

pub fn customer_id(self, input: impl Into<String>) -> Self

The Amazon Web Services account ID.

pub fn set_customer_id(self, input: Option<String>) -> Self

The Amazon Web Services account ID.

pub fn get_customer_id(&self) -> &Option<String>

The Amazon Web Services account ID.

pub fn materialized_view_refresh_task_run_id( self, input: impl Into<String>, ) -> Self

The identifier of the materialized view refresh task run.

pub fn set_materialized_view_refresh_task_run_id( self, input: Option<String>, ) -> Self

The identifier of the materialized view refresh task run.

pub fn get_materialized_view_refresh_task_run_id(&self) -> &Option<String>

The identifier of the materialized view refresh task run.

pub fn database_name(self, input: impl Into<String>) -> Self

The database where the table resides.

pub fn set_database_name(self, input: Option<String>) -> Self

The database where the table resides.

pub fn get_database_name(&self) -> &Option<String>

The database where the table resides.

pub fn table_name(self, input: impl Into<String>) -> Self

The name of the table for which statistics is generated.

pub fn set_table_name(self, input: Option<String>) -> Self

The name of the table for which statistics is generated.

pub fn get_table_name(&self) -> &Option<String>

The name of the table for which statistics is generated.

pub fn catalog_id(self, input: impl Into<String>) -> Self

The ID of the Data Catalog where the table resides. If none is supplied, the account ID is used by default.

pub fn set_catalog_id(self, input: Option<String>) -> Self

The ID of the Data Catalog where the table resides. If none is supplied, the account ID is used by default.

pub fn get_catalog_id(&self) -> &Option<String>

The ID of the Data Catalog where the table resides. If none is supplied, the account ID is used by default.

pub fn role(self, input: impl Into<String>) -> Self

The IAM role that the service assumes to generate statistics.

pub fn set_role(self, input: Option<String>) -> Self

The IAM role that the service assumes to generate statistics.

pub fn get_role(&self) -> &Option<String>

The IAM role that the service assumes to generate statistics.

pub fn status(self, input: MaterializedViewRefreshState) -> Self

The status of the task run.

pub fn set_status(self, input: Option<MaterializedViewRefreshState>) -> Self

The status of the task run.

pub fn get_status(&self) -> &Option<MaterializedViewRefreshState>

The status of the task run.

pub fn creation_time(self, input: DateTime) -> Self

The time that this task was created.

pub fn set_creation_time(self, input: Option<DateTime>) -> Self

The time that this task was created.

pub fn get_creation_time(&self) -> &Option<DateTime>

The time that this task was created.

pub fn last_updated(self, input: DateTime) -> Self

The last point in time when this task was modified.

pub fn set_last_updated(self, input: Option<DateTime>) -> Self

The last point in time when this task was modified.

pub fn get_last_updated(&self) -> &Option<DateTime>

The last point in time when this task was modified.

pub fn start_time(self, input: DateTime) -> Self

The start time of the task.

pub fn set_start_time(self, input: Option<DateTime>) -> Self

The start time of the task.

pub fn get_start_time(&self) -> &Option<DateTime>

The start time of the task.

pub fn end_time(self, input: DateTime) -> Self

The end time of the task.

pub fn set_end_time(self, input: Option<DateTime>) -> Self

The end time of the task.

pub fn get_end_time(&self) -> &Option<DateTime>

The end time of the task.

pub fn error_message(self, input: impl Into<String>) -> Self

The error message for the job.

pub fn set_error_message(self, input: Option<String>) -> Self

The error message for the job.

pub fn get_error_message(&self) -> &Option<String>

The error message for the job.

pub fn dpu_seconds(self, input: f64) -> Self

The calculated DPU usage in seconds for all autoscaled workers.

pub fn set_dpu_seconds(self, input: Option<f64>) -> Self

The calculated DPU usage in seconds for all autoscaled workers.

pub fn get_dpu_seconds(&self) -> &Option<f64>

The calculated DPU usage in seconds for all autoscaled workers.

pub fn refresh_type(self, input: MaterializedViewRefreshType) -> Self

The type of the refresh task run. Either FULL or INCREMENTAL.

pub fn set_refresh_type( self, input: Option<MaterializedViewRefreshType>, ) -> Self

The type of the refresh task run. Either FULL or INCREMENTAL.

pub fn get_refresh_type(&self) -> &Option<MaterializedViewRefreshType>

The type of the refresh task run. Either FULL or INCREMENTAL.

pub fn processed_bytes(self, input: i64) -> Self

The number of bytes the refresh task run has scanned to refresh the materialized view.

pub fn set_processed_bytes(self, input: Option<i64>) -> Self

The number of bytes the refresh task run has scanned to refresh the materialized view.

pub fn get_processed_bytes(&self) -> &Option<i64>

The number of bytes the refresh task run has scanned to refresh the materialized view.

pub fn build(self) -> MaterializedViewRefreshTaskRun

Consumes the builder and constructs a MaterializedViewRefreshTaskRun.