#[non_exhaustive]pub struct OAuth2CredentialsBuilder { /* private fields */ }Expand description
A builder for OAuth2Credentials.
Implementations
Sourceimpl OAuth2CredentialsBuilder
impl OAuth2CredentialsBuilder
Sourcepub fn user_managed_client_application_client_secret(
self,
input: impl Into<String>,
) -> Self
pub fn user_managed_client_application_client_secret( self, input: impl Into<String>, ) -> Self
The client application client secret if the client application is user managed.
Sourcepub fn set_user_managed_client_application_client_secret(
self,
input: Option<String>,
) -> Self
pub fn set_user_managed_client_application_client_secret( self, input: Option<String>, ) -> Self
The client application client secret if the client application is user managed.
Sourcepub fn get_user_managed_client_application_client_secret(
&self,
) -> &Option<String>
pub fn get_user_managed_client_application_client_secret( &self, ) -> &Option<String>
The client application client secret if the client application is user managed.
Sourcepub fn access_token(self, input: impl Into<String>) -> Self
pub fn access_token(self, input: impl Into<String>) -> Self
The access token used when the authentication type is OAuth2.
Sourcepub fn set_access_token(self, input: Option<String>) -> Self
pub fn set_access_token(self, input: Option<String>) -> Self
The access token used when the authentication type is OAuth2.
Sourcepub fn get_access_token(&self) -> &Option<String>
pub fn get_access_token(&self) -> &Option<String>
The access token used when the authentication type is OAuth2.
Sourcepub fn refresh_token(self, input: impl Into<String>) -> Self
pub fn refresh_token(self, input: impl Into<String>) -> Self
The refresh token used when the authentication type is OAuth2.
Sourcepub fn set_refresh_token(self, input: Option<String>) -> Self
pub fn set_refresh_token(self, input: Option<String>) -> Self
The refresh token used when the authentication type is OAuth2.
Sourcepub fn get_refresh_token(&self) -> &Option<String>
pub fn get_refresh_token(&self) -> &Option<String>
The refresh token used when the authentication type is OAuth2.
Sourcepub fn jwt_token(self, input: impl Into<String>) -> Self
pub fn jwt_token(self, input: impl Into<String>) -> Self
The JSON Web Token (JWT) used when the authentication type is OAuth2.
Sourcepub fn set_jwt_token(self, input: Option<String>) -> Self
pub fn set_jwt_token(self, input: Option<String>) -> Self
The JSON Web Token (JWT) used when the authentication type is OAuth2.
Sourcepub fn get_jwt_token(&self) -> &Option<String>
pub fn get_jwt_token(&self) -> &Option<String>
The JSON Web Token (JWT) used when the authentication type is OAuth2.
Sourcepub fn build(self) -> OAuth2Credentials
pub fn build(self) -> OAuth2Credentials
Consumes the builder and constructs a OAuth2Credentials.