#[non_exhaustive]pub struct ObservationResultsOptionsBuilder { /* private fields */ }Expand description
A builder for ObservationResultsOptions.
Implementations
Sourceimpl ObservationResultsOptionsBuilder
impl ObservationResultsOptionsBuilder
Sourcepub fn write_observation_results_enabled(self, input: bool) -> Self
pub fn write_observation_results_enabled(self, input: bool) -> Self
Set to true to write observation results.
Sourcepub fn set_write_observation_results_enabled(self, input: Option<bool>) -> Self
pub fn set_write_observation_results_enabled(self, input: Option<bool>) -> Self
Set to true to write observation results.
Sourcepub fn get_write_observation_results_enabled(&self) -> &Option<bool>
pub fn get_write_observation_results_enabled(&self) -> &Option<bool>
Set to true to write observation results.
Sourcepub fn catalog_table_config(self, input: CatalogTableConfigOptions) -> Self
pub fn catalog_table_config(self, input: CatalogTableConfigOptions) -> Self
The Glue Data Catalog table configuration for storing the observation results.
Sourcepub fn set_catalog_table_config(
self,
input: Option<CatalogTableConfigOptions>,
) -> Self
pub fn set_catalog_table_config( self, input: Option<CatalogTableConfigOptions>, ) -> Self
The Glue Data Catalog table configuration for storing the observation results.
Sourcepub fn get_catalog_table_config(&self) -> &Option<CatalogTableConfigOptions>
pub fn get_catalog_table_config(&self) -> &Option<CatalogTableConfigOptions>
The Glue Data Catalog table configuration for storing the observation results.
Sourcepub fn build(self) -> ObservationResultsOptions
pub fn build(self) -> ObservationResultsOptions
Consumes the builder and constructs a ObservationResultsOptions.