#[non_exhaustive]pub struct OffsetConfigurationBuilder { /* private fields */ }Expand description
A builder for OffsetConfiguration.
Implementations
Sourceimpl OffsetConfigurationBuilder
impl OffsetConfigurationBuilder
Sourcepub fn offset_parameter(self, input: ExtractedParameter) -> Self
pub fn offset_parameter(self, input: ExtractedParameter) -> Self
The parameter name used to specify the starting position or offset for retrieving results.
This field is required.Sourcepub fn set_offset_parameter(self, input: Option<ExtractedParameter>) -> Self
pub fn set_offset_parameter(self, input: Option<ExtractedParameter>) -> Self
The parameter name used to specify the starting position or offset for retrieving results.
Sourcepub fn get_offset_parameter(&self) -> &Option<ExtractedParameter>
pub fn get_offset_parameter(&self) -> &Option<ExtractedParameter>
The parameter name used to specify the starting position or offset for retrieving results.
Sourcepub fn limit_parameter(self, input: ExtractedParameter) -> Self
pub fn limit_parameter(self, input: ExtractedParameter) -> Self
The parameter name used to specify the maximum number of results to return per page.
This field is required.Sourcepub fn set_limit_parameter(self, input: Option<ExtractedParameter>) -> Self
pub fn set_limit_parameter(self, input: Option<ExtractedParameter>) -> Self
The parameter name used to specify the maximum number of results to return per page.
Sourcepub fn get_limit_parameter(&self) -> &Option<ExtractedParameter>
pub fn get_limit_parameter(&self) -> &Option<ExtractedParameter>
The parameter name used to specify the maximum number of results to return per page.
Sourcepub fn build(self) -> OffsetConfiguration
pub fn build(self) -> OffsetConfiguration
Consumes the builder and constructs a OffsetConfiguration.