#[non_exhaustive]pub struct OrphanFileDeletionConfigurationBuilder { /* private fields */ }Expand description
A builder for OrphanFileDeletionConfiguration.
Implementations
Sourceimpl OrphanFileDeletionConfigurationBuilder
impl OrphanFileDeletionConfigurationBuilder
Sourcepub fn iceberg_configuration(
self,
input: IcebergOrphanFileDeletionConfiguration,
) -> Self
pub fn iceberg_configuration( self, input: IcebergOrphanFileDeletionConfiguration, ) -> Self
The configuration for an Iceberg orphan file deletion optimizer.
Sourcepub fn set_iceberg_configuration(
self,
input: Option<IcebergOrphanFileDeletionConfiguration>,
) -> Self
pub fn set_iceberg_configuration( self, input: Option<IcebergOrphanFileDeletionConfiguration>, ) -> Self
The configuration for an Iceberg orphan file deletion optimizer.
Sourcepub fn get_iceberg_configuration(
&self,
) -> &Option<IcebergOrphanFileDeletionConfiguration>
pub fn get_iceberg_configuration( &self, ) -> &Option<IcebergOrphanFileDeletionConfiguration>
The configuration for an Iceberg orphan file deletion optimizer.
Sourcepub fn build(self) -> OrphanFileDeletionConfiguration
pub fn build(self) -> OrphanFileDeletionConfiguration
Consumes the builder and constructs a OrphanFileDeletionConfiguration.