#[non_exhaustive]pub struct PaginationConfigurationBuilder { /* private fields */ }Expand description
A builder for PaginationConfiguration.
Implementations
Sourceimpl PaginationConfigurationBuilder
impl PaginationConfigurationBuilder
Sourcepub fn cursor_configuration(self, input: CursorConfiguration) -> Self
pub fn cursor_configuration(self, input: CursorConfiguration) -> Self
Configuration for cursor-based pagination, where the API provides a cursor or token to retrieve the next page of results.
Sourcepub fn set_cursor_configuration(
self,
input: Option<CursorConfiguration>,
) -> Self
pub fn set_cursor_configuration( self, input: Option<CursorConfiguration>, ) -> Self
Configuration for cursor-based pagination, where the API provides a cursor or token to retrieve the next page of results.
Sourcepub fn get_cursor_configuration(&self) -> &Option<CursorConfiguration>
pub fn get_cursor_configuration(&self) -> &Option<CursorConfiguration>
Configuration for cursor-based pagination, where the API provides a cursor or token to retrieve the next page of results.
Sourcepub fn offset_configuration(self, input: OffsetConfiguration) -> Self
pub fn offset_configuration(self, input: OffsetConfiguration) -> Self
Configuration for offset-based pagination, where the API uses numeric offsets and limits to control which results are returned.
Sourcepub fn set_offset_configuration(
self,
input: Option<OffsetConfiguration>,
) -> Self
pub fn set_offset_configuration( self, input: Option<OffsetConfiguration>, ) -> Self
Configuration for offset-based pagination, where the API uses numeric offsets and limits to control which results are returned.
Sourcepub fn get_offset_configuration(&self) -> &Option<OffsetConfiguration>
pub fn get_offset_configuration(&self) -> &Option<OffsetConfiguration>
Configuration for offset-based pagination, where the API uses numeric offsets and limits to control which results are returned.
Sourcepub fn build(self) -> PaginationConfiguration
pub fn build(self) -> PaginationConfiguration
Consumes the builder and constructs a PaginationConfiguration.