#[non_exhaustive]pub struct PiiDetectionBuilder { /* private fields */ }Expand description
A builder for PiiDetection.
Implementations
Sourceimpl PiiDetectionBuilder
impl PiiDetectionBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the transform node.
This field is required.Sourcepub fn inputs(self, input: impl Into<String>) -> Self
pub fn inputs(self, input: impl Into<String>) -> Self
Appends an item to inputs.
To override the contents of this collection use set_inputs.
The node ID inputs to the transform.
Sourcepub fn set_inputs(self, input: Option<Vec<String>>) -> Self
pub fn set_inputs(self, input: Option<Vec<String>>) -> Self
The node ID inputs to the transform.
Sourcepub fn get_inputs(&self) -> &Option<Vec<String>>
pub fn get_inputs(&self) -> &Option<Vec<String>>
The node ID inputs to the transform.
Sourcepub fn pii_type(self, input: PiiType) -> Self
pub fn pii_type(self, input: PiiType) -> Self
Indicates the type of PIIDetection transform.
This field is required.Sourcepub fn set_pii_type(self, input: Option<PiiType>) -> Self
pub fn set_pii_type(self, input: Option<PiiType>) -> Self
Indicates the type of PIIDetection transform.
Sourcepub fn get_pii_type(&self) -> &Option<PiiType>
pub fn get_pii_type(&self) -> &Option<PiiType>
Indicates the type of PIIDetection transform.
Sourcepub fn entity_types_to_detect(self, input: impl Into<String>) -> Self
pub fn entity_types_to_detect(self, input: impl Into<String>) -> Self
Appends an item to entity_types_to_detect.
To override the contents of this collection use set_entity_types_to_detect.
Indicates the types of entities the PIIDetection transform will identify as PII data.
PII type entities include: PERSON_NAME, DATE, USA_SNN, EMAIL, USA_ITIN, USA_PASSPORT_NUMBER, PHONE_NUMBER, BANK_ACCOUNT, IP_ADDRESS, MAC_ADDRESS, USA_CPT_CODE, USA_HCPCS_CODE, USA_NATIONAL_DRUG_CODE, USA_MEDICARE_BENEFICIARY_IDENTIFIER, USA_HEALTH_INSURANCE_CLAIM_NUMBER,CREDIT_CARD,USA_NATIONAL_PROVIDER_IDENTIFIER,USA_DEA_NUMBER,USA_DRIVING_LICENSE
Sourcepub fn set_entity_types_to_detect(self, input: Option<Vec<String>>) -> Self
pub fn set_entity_types_to_detect(self, input: Option<Vec<String>>) -> Self
Indicates the types of entities the PIIDetection transform will identify as PII data.
PII type entities include: PERSON_NAME, DATE, USA_SNN, EMAIL, USA_ITIN, USA_PASSPORT_NUMBER, PHONE_NUMBER, BANK_ACCOUNT, IP_ADDRESS, MAC_ADDRESS, USA_CPT_CODE, USA_HCPCS_CODE, USA_NATIONAL_DRUG_CODE, USA_MEDICARE_BENEFICIARY_IDENTIFIER, USA_HEALTH_INSURANCE_CLAIM_NUMBER,CREDIT_CARD,USA_NATIONAL_PROVIDER_IDENTIFIER,USA_DEA_NUMBER,USA_DRIVING_LICENSE
Sourcepub fn get_entity_types_to_detect(&self) -> &Option<Vec<String>>
pub fn get_entity_types_to_detect(&self) -> &Option<Vec<String>>
Indicates the types of entities the PIIDetection transform will identify as PII data.
PII type entities include: PERSON_NAME, DATE, USA_SNN, EMAIL, USA_ITIN, USA_PASSPORT_NUMBER, PHONE_NUMBER, BANK_ACCOUNT, IP_ADDRESS, MAC_ADDRESS, USA_CPT_CODE, USA_HCPCS_CODE, USA_NATIONAL_DRUG_CODE, USA_MEDICARE_BENEFICIARY_IDENTIFIER, USA_HEALTH_INSURANCE_CLAIM_NUMBER,CREDIT_CARD,USA_NATIONAL_PROVIDER_IDENTIFIER,USA_DEA_NUMBER,USA_DRIVING_LICENSE
Sourcepub fn output_column_name(self, input: impl Into<String>) -> Self
pub fn output_column_name(self, input: impl Into<String>) -> Self
Indicates the output column name that will contain any entity type detected in that row.
Sourcepub fn set_output_column_name(self, input: Option<String>) -> Self
pub fn set_output_column_name(self, input: Option<String>) -> Self
Indicates the output column name that will contain any entity type detected in that row.
Sourcepub fn get_output_column_name(&self) -> &Option<String>
pub fn get_output_column_name(&self) -> &Option<String>
Indicates the output column name that will contain any entity type detected in that row.
Sourcepub fn sample_fraction(self, input: f64) -> Self
pub fn sample_fraction(self, input: f64) -> Self
Indicates the fraction of the data to sample when scanning for PII entities.
Sourcepub fn set_sample_fraction(self, input: Option<f64>) -> Self
pub fn set_sample_fraction(self, input: Option<f64>) -> Self
Indicates the fraction of the data to sample when scanning for PII entities.
Sourcepub fn get_sample_fraction(&self) -> &Option<f64>
pub fn get_sample_fraction(&self) -> &Option<f64>
Indicates the fraction of the data to sample when scanning for PII entities.
Sourcepub fn threshold_fraction(self, input: f64) -> Self
pub fn threshold_fraction(self, input: f64) -> Self
Indicates the fraction of the data that must be met in order for a column to be identified as PII data.
Sourcepub fn set_threshold_fraction(self, input: Option<f64>) -> Self
pub fn set_threshold_fraction(self, input: Option<f64>) -> Self
Indicates the fraction of the data that must be met in order for a column to be identified as PII data.
Sourcepub fn get_threshold_fraction(&self) -> &Option<f64>
pub fn get_threshold_fraction(&self) -> &Option<f64>
Indicates the fraction of the data that must be met in order for a column to be identified as PII data.
Sourcepub fn mask_value(self, input: impl Into<String>) -> Self
pub fn mask_value(self, input: impl Into<String>) -> Self
Indicates the value that will replace the detected entity.
Sourcepub fn set_mask_value(self, input: Option<String>) -> Self
pub fn set_mask_value(self, input: Option<String>) -> Self
Indicates the value that will replace the detected entity.
Sourcepub fn get_mask_value(&self) -> &Option<String>
pub fn get_mask_value(&self) -> &Option<String>
Indicates the value that will replace the detected entity.
Sourcepub fn redact_text(self, input: impl Into<String>) -> Self
pub fn redact_text(self, input: impl Into<String>) -> Self
Specifies whether to redact the detected PII text. When set to true, PII content is replaced with redaction characters.
Sourcepub fn set_redact_text(self, input: Option<String>) -> Self
pub fn set_redact_text(self, input: Option<String>) -> Self
Specifies whether to redact the detected PII text. When set to true, PII content is replaced with redaction characters.
Sourcepub fn get_redact_text(&self) -> &Option<String>
pub fn get_redact_text(&self) -> &Option<String>
Specifies whether to redact the detected PII text. When set to true, PII content is replaced with redaction characters.
Sourcepub fn redact_char(self, input: impl Into<String>) -> Self
pub fn redact_char(self, input: impl Into<String>) -> Self
The character used to replace detected PII content when redaction is enabled. The default redaction character is *.
Sourcepub fn set_redact_char(self, input: Option<String>) -> Self
pub fn set_redact_char(self, input: Option<String>) -> Self
The character used to replace detected PII content when redaction is enabled. The default redaction character is *.
Sourcepub fn get_redact_char(&self) -> &Option<String>
pub fn get_redact_char(&self) -> &Option<String>
The character used to replace detected PII content when redaction is enabled. The default redaction character is *.
Sourcepub fn match_pattern(self, input: impl Into<String>) -> Self
pub fn match_pattern(self, input: impl Into<String>) -> Self
A regular expression pattern used to identify additional PII content beyond the standard detection algorithms.
Sourcepub fn set_match_pattern(self, input: Option<String>) -> Self
pub fn set_match_pattern(self, input: Option<String>) -> Self
A regular expression pattern used to identify additional PII content beyond the standard detection algorithms.
Sourcepub fn get_match_pattern(&self) -> &Option<String>
pub fn get_match_pattern(&self) -> &Option<String>
A regular expression pattern used to identify additional PII content beyond the standard detection algorithms.
Sourcepub fn num_left_chars_to_exclude(self, input: i32) -> Self
pub fn num_left_chars_to_exclude(self, input: i32) -> Self
The number of characters to exclude from redaction on the left side of detected PII content. This allows preserving context around the sensitive data.
Sourcepub fn set_num_left_chars_to_exclude(self, input: Option<i32>) -> Self
pub fn set_num_left_chars_to_exclude(self, input: Option<i32>) -> Self
The number of characters to exclude from redaction on the left side of detected PII content. This allows preserving context around the sensitive data.
Sourcepub fn get_num_left_chars_to_exclude(&self) -> &Option<i32>
pub fn get_num_left_chars_to_exclude(&self) -> &Option<i32>
The number of characters to exclude from redaction on the left side of detected PII content. This allows preserving context around the sensitive data.
Sourcepub fn num_right_chars_to_exclude(self, input: i32) -> Self
pub fn num_right_chars_to_exclude(self, input: i32) -> Self
The number of characters to exclude from redaction on the right side of detected PII content. This allows preserving context around the sensitive data.
Sourcepub fn set_num_right_chars_to_exclude(self, input: Option<i32>) -> Self
pub fn set_num_right_chars_to_exclude(self, input: Option<i32>) -> Self
The number of characters to exclude from redaction on the right side of detected PII content. This allows preserving context around the sensitive data.
Sourcepub fn get_num_right_chars_to_exclude(&self) -> &Option<i32>
pub fn get_num_right_chars_to_exclude(&self) -> &Option<i32>
The number of characters to exclude from redaction on the right side of detected PII content. This allows preserving context around the sensitive data.
Sourcepub fn detection_parameters(self, input: impl Into<String>) -> Self
pub fn detection_parameters(self, input: impl Into<String>) -> Self
Additional parameters for configuring PII detection behavior and sensitivity settings.
Sourcepub fn set_detection_parameters(self, input: Option<String>) -> Self
pub fn set_detection_parameters(self, input: Option<String>) -> Self
Additional parameters for configuring PII detection behavior and sensitivity settings.
Sourcepub fn get_detection_parameters(&self) -> &Option<String>
pub fn get_detection_parameters(&self) -> &Option<String>
Additional parameters for configuring PII detection behavior and sensitivity settings.
Sourcepub fn detection_sensitivity(self, input: impl Into<String>) -> Self
pub fn detection_sensitivity(self, input: impl Into<String>) -> Self
The sensitivity level for PII detection. Higher sensitivity levels detect more potential PII but may result in more false positives.
Sourcepub fn set_detection_sensitivity(self, input: Option<String>) -> Self
pub fn set_detection_sensitivity(self, input: Option<String>) -> Self
The sensitivity level for PII detection. Higher sensitivity levels detect more potential PII but may result in more false positives.
Sourcepub fn get_detection_sensitivity(&self) -> &Option<String>
pub fn get_detection_sensitivity(&self) -> &Option<String>
The sensitivity level for PII detection. Higher sensitivity levels detect more potential PII but may result in more false positives.
Sourcepub fn build(self) -> Result<PiiDetection, BuildError>
pub fn build(self) -> Result<PiiDetection, BuildError>
Consumes the builder and constructs a PiiDetection.
This method will fail if any of the following fields are not set: