#[non_exhaustive]pub struct ProfilingResultsOptionsBuilder { /* private fields */ }Expand description
A builder for ProfilingResultsOptions.
Implementations
Sourceimpl ProfilingResultsOptionsBuilder
impl ProfilingResultsOptionsBuilder
Sourcepub fn write_profiling_results_enabled(self, input: bool) -> Self
pub fn write_profiling_results_enabled(self, input: bool) -> Self
Set to true to write profiling results.
Sourcepub fn set_write_profiling_results_enabled(self, input: Option<bool>) -> Self
pub fn set_write_profiling_results_enabled(self, input: Option<bool>) -> Self
Set to true to write profiling results.
Sourcepub fn get_write_profiling_results_enabled(&self) -> &Option<bool>
pub fn get_write_profiling_results_enabled(&self) -> &Option<bool>
Set to true to write profiling results.
Sourcepub fn catalog_table_config(self, input: CatalogTableConfigOptions) -> Self
pub fn catalog_table_config(self, input: CatalogTableConfigOptions) -> Self
The Glue Data Catalog table configuration for storing the profiling results.
Sourcepub fn set_catalog_table_config(
self,
input: Option<CatalogTableConfigOptions>,
) -> Self
pub fn set_catalog_table_config( self, input: Option<CatalogTableConfigOptions>, ) -> Self
The Glue Data Catalog table configuration for storing the profiling results.
Sourcepub fn get_catalog_table_config(&self) -> &Option<CatalogTableConfigOptions>
pub fn get_catalog_table_config(&self) -> &Option<CatalogTableConfigOptions>
The Glue Data Catalog table configuration for storing the profiling results.
Sourcepub fn distribution_results(self, input: DistributionResultsOptions) -> Self
pub fn distribution_results(self, input: DistributionResultsOptions) -> Self
The configuration for writing distribution results.
Sourcepub fn set_distribution_results(
self,
input: Option<DistributionResultsOptions>,
) -> Self
pub fn set_distribution_results( self, input: Option<DistributionResultsOptions>, ) -> Self
The configuration for writing distribution results.
Sourcepub fn get_distribution_results(&self) -> &Option<DistributionResultsOptions>
pub fn get_distribution_results(&self) -> &Option<DistributionResultsOptions>
The configuration for writing distribution results.
Sourcepub fn build(self) -> ProfilingResultsOptions
pub fn build(self) -> ProfilingResultsOptions
Consumes the builder and constructs a ProfilingResultsOptions.