#[non_exhaustive]pub struct PropertyBuilder { /* private fields */ }Expand description
A builder for Property.
Implementations
Sourceimpl PropertyBuilder
impl PropertyBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the property.
This field is required.Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
A description of the property.
This field is required.Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
A description of the property.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
A description of the property.
Sourcepub fn required(self, input: bool) -> Self
pub fn required(self, input: bool) -> Self
Indicates whether the property is required.
This field is required.Sourcepub fn set_required(self, input: Option<bool>) -> Self
pub fn set_required(self, input: Option<bool>) -> Self
Indicates whether the property is required.
Sourcepub fn get_required(&self) -> &Option<bool>
pub fn get_required(&self) -> &Option<bool>
Indicates whether the property is required.
Sourcepub fn default_value(self, input: impl Into<String>) -> Self
pub fn default_value(self, input: impl Into<String>) -> Self
The default value for the property.
Sourcepub fn set_default_value(self, input: Option<String>) -> Self
pub fn set_default_value(self, input: Option<String>) -> Self
The default value for the property.
Sourcepub fn get_default_value(&self) -> &Option<String>
pub fn get_default_value(&self) -> &Option<String>
The default value for the property.
Sourcepub fn property_types(self, input: PropertyType) -> Self
pub fn property_types(self, input: PropertyType) -> Self
Appends an item to property_types.
To override the contents of this collection use set_property_types.
Describes the type of property.
Sourcepub fn set_property_types(self, input: Option<Vec<PropertyType>>) -> Self
pub fn set_property_types(self, input: Option<Vec<PropertyType>>) -> Self
Describes the type of property.
Sourcepub fn get_property_types(&self) -> &Option<Vec<PropertyType>>
pub fn get_property_types(&self) -> &Option<Vec<PropertyType>>
Describes the type of property.
Sourcepub fn allowed_values(self, input: AllowedValue) -> Self
pub fn allowed_values(self, input: AllowedValue) -> Self
Appends an item to allowed_values.
To override the contents of this collection use set_allowed_values.
A list of AllowedValue objects representing the values allowed for the property.
Sourcepub fn set_allowed_values(self, input: Option<Vec<AllowedValue>>) -> Self
pub fn set_allowed_values(self, input: Option<Vec<AllowedValue>>) -> Self
A list of AllowedValue objects representing the values allowed for the property.
Sourcepub fn get_allowed_values(&self) -> &Option<Vec<AllowedValue>>
pub fn get_allowed_values(&self) -> &Option<Vec<AllowedValue>>
A list of AllowedValue objects representing the values allowed for the property.
Sourcepub fn data_operation_scopes(self, input: DataOperation) -> Self
pub fn data_operation_scopes(self, input: DataOperation) -> Self
Appends an item to data_operation_scopes.
To override the contents of this collection use set_data_operation_scopes.
Indicates which data operations are applicable to the property.
Sourcepub fn set_data_operation_scopes(
self,
input: Option<Vec<DataOperation>>,
) -> Self
pub fn set_data_operation_scopes( self, input: Option<Vec<DataOperation>>, ) -> Self
Indicates which data operations are applicable to the property.
Sourcepub fn get_data_operation_scopes(&self) -> &Option<Vec<DataOperation>>
pub fn get_data_operation_scopes(&self) -> &Option<Vec<DataOperation>>
Indicates which data operations are applicable to the property.
Sourcepub fn key_override(self, input: impl Into<String>) -> Self
pub fn key_override(self, input: impl Into<String>) -> Self
A key name to use when sending this property in API requests, if different from the display name.
Sourcepub fn set_key_override(self, input: Option<String>) -> Self
pub fn set_key_override(self, input: Option<String>) -> Self
A key name to use when sending this property in API requests, if different from the display name.
Sourcepub fn get_key_override(&self) -> &Option<String>
pub fn get_key_override(&self) -> &Option<String>
A key name to use when sending this property in API requests, if different from the display name.
Sourcepub fn property_location(self, input: PropertyLocation) -> Self
pub fn property_location(self, input: PropertyLocation) -> Self
Specifies where this property should be included in REST requests, such as in headers, query parameters, or request body.
Sourcepub fn set_property_location(self, input: Option<PropertyLocation>) -> Self
pub fn set_property_location(self, input: Option<PropertyLocation>) -> Self
Specifies where this property should be included in REST requests, such as in headers, query parameters, or request body.
Sourcepub fn get_property_location(&self) -> &Option<PropertyLocation>
pub fn get_property_location(&self) -> &Option<PropertyLocation>
Specifies where this property should be included in REST requests, such as in headers, query parameters, or request body.