#[non_exhaustive]pub struct PropertyPredicateBuilder { /* private fields */ }Expand description
A builder for PropertyPredicate.
Implementations
Sourceimpl PropertyPredicateBuilder
impl PropertyPredicateBuilder
Sourcepub fn comparator(self, input: Comparator) -> Self
pub fn comparator(self, input: Comparator) -> Self
The comparator used to compare this property to others.
Sourcepub fn set_comparator(self, input: Option<Comparator>) -> Self
pub fn set_comparator(self, input: Option<Comparator>) -> Self
The comparator used to compare this property to others.
Sourcepub fn get_comparator(&self) -> &Option<Comparator>
pub fn get_comparator(&self) -> &Option<Comparator>
The comparator used to compare this property to others.
Sourcepub fn build(self) -> PropertyPredicate
pub fn build(self) -> PropertyPredicate
Consumes the builder and constructs a PropertyPredicate.