#[non_exhaustive]pub struct QuerySessionContextBuilder { /* private fields */ }Expand description
A builder for QuerySessionContext.
Implementations
Sourceimpl QuerySessionContextBuilder
impl QuerySessionContextBuilder
Sourcepub fn query_id(self, input: impl Into<String>) -> Self
pub fn query_id(self, input: impl Into<String>) -> Self
A unique identifier generated by the query engine for the query.
Sourcepub fn set_query_id(self, input: Option<String>) -> Self
pub fn set_query_id(self, input: Option<String>) -> Self
A unique identifier generated by the query engine for the query.
Sourcepub fn get_query_id(&self) -> &Option<String>
pub fn get_query_id(&self) -> &Option<String>
A unique identifier generated by the query engine for the query.
Sourcepub fn query_start_time(self, input: DateTime) -> Self
pub fn query_start_time(self, input: DateTime) -> Self
A timestamp provided by the query engine for when the query started.
Sourcepub fn set_query_start_time(self, input: Option<DateTime>) -> Self
pub fn set_query_start_time(self, input: Option<DateTime>) -> Self
A timestamp provided by the query engine for when the query started.
Sourcepub fn get_query_start_time(&self) -> &Option<DateTime>
pub fn get_query_start_time(&self) -> &Option<DateTime>
A timestamp provided by the query engine for when the query started.
Sourcepub fn cluster_id(self, input: impl Into<String>) -> Self
pub fn cluster_id(self, input: impl Into<String>) -> Self
An identifier string for the consumer cluster.
Sourcepub fn set_cluster_id(self, input: Option<String>) -> Self
pub fn set_cluster_id(self, input: Option<String>) -> Self
An identifier string for the consumer cluster.
Sourcepub fn get_cluster_id(&self) -> &Option<String>
pub fn get_cluster_id(&self) -> &Option<String>
An identifier string for the consumer cluster.
A cryptographically generated query identifier generated by Glue or Lake Formation.
A cryptographically generated query identifier generated by Glue or Lake Formation.
A cryptographically generated query identifier generated by Glue or Lake Formation.
Sourcepub fn additional_context(
self,
k: impl Into<String>,
v: impl Into<String>,
) -> Self
pub fn additional_context( self, k: impl Into<String>, v: impl Into<String>, ) -> Self
Adds a key-value pair to additional_context.
To override the contents of this collection use set_additional_context.
An opaque string-string map passed by the query engine.
Sourcepub fn set_additional_context(
self,
input: Option<HashMap<String, String>>,
) -> Self
pub fn set_additional_context( self, input: Option<HashMap<String, String>>, ) -> Self
An opaque string-string map passed by the query engine.
Sourcepub fn get_additional_context(&self) -> &Option<HashMap<String, String>>
pub fn get_additional_context(&self) -> &Option<HashMap<String, String>>
An opaque string-string map passed by the query engine.
Sourcepub fn build(self) -> QuerySessionContext
pub fn build(self) -> QuerySessionContext
Consumes the builder and constructs a QuerySessionContext.