#[non_exhaustive]pub struct ResponseConfigurationBuilder { /* private fields */ }Expand description
A builder for ResponseConfiguration.
Implementations
Sourceimpl ResponseConfigurationBuilder
impl ResponseConfigurationBuilder
Sourcepub fn result_path(self, input: impl Into<String>) -> Self
pub fn result_path(self, input: impl Into<String>) -> Self
The JSON path expression that identifies where the actual result data is located within the API response.
This field is required.Sourcepub fn set_result_path(self, input: Option<String>) -> Self
pub fn set_result_path(self, input: Option<String>) -> Self
The JSON path expression that identifies where the actual result data is located within the API response.
Sourcepub fn get_result_path(&self) -> &Option<String>
pub fn get_result_path(&self) -> &Option<String>
The JSON path expression that identifies where the actual result data is located within the API response.
Sourcepub fn error_path(self, input: impl Into<String>) -> Self
pub fn error_path(self, input: impl Into<String>) -> Self
The JSON path expression that identifies where error information is located within API responses when requests fail.
Sourcepub fn set_error_path(self, input: Option<String>) -> Self
pub fn set_error_path(self, input: Option<String>) -> Self
The JSON path expression that identifies where error information is located within API responses when requests fail.
Sourcepub fn get_error_path(&self) -> &Option<String>
pub fn get_error_path(&self) -> &Option<String>
The JSON path expression that identifies where error information is located within API responses when requests fail.
Sourcepub fn build(self) -> Result<ResponseConfiguration, BuildError>
pub fn build(self) -> Result<ResponseConfiguration, BuildError>
Consumes the builder and constructs a ResponseConfiguration.
This method will fail if any of the following fields are not set: