#[non_exhaustive]pub struct ResponseExtractionMappingBuilder { /* private fields */ }Expand description
A builder for ResponseExtractionMapping.
Implementations
Sourceimpl ResponseExtractionMappingBuilder
impl ResponseExtractionMappingBuilder
Sourcepub fn content_path(self, input: impl Into<String>) -> Self
pub fn content_path(self, input: impl Into<String>) -> Self
A JSON path expression that specifies how to extract a value from the response body content.
Sourcepub fn set_content_path(self, input: Option<String>) -> Self
pub fn set_content_path(self, input: Option<String>) -> Self
A JSON path expression that specifies how to extract a value from the response body content.
Sourcepub fn get_content_path(&self) -> &Option<String>
pub fn get_content_path(&self) -> &Option<String>
A JSON path expression that specifies how to extract a value from the response body content.
Sourcepub fn header_key(self, input: impl Into<String>) -> Self
pub fn header_key(self, input: impl Into<String>) -> Self
The name of an HTTP response header from which to extract the value.
Sourcepub fn set_header_key(self, input: Option<String>) -> Self
pub fn set_header_key(self, input: Option<String>) -> Self
The name of an HTTP response header from which to extract the value.
Sourcepub fn get_header_key(&self) -> &Option<String>
pub fn get_header_key(&self) -> &Option<String>
The name of an HTTP response header from which to extract the value.
Sourcepub fn build(self) -> ResponseExtractionMapping
pub fn build(self) -> ResponseExtractionMapping
Consumes the builder and constructs a ResponseExtractionMapping.