#[non_exhaustive]pub struct RestConfigurationBuilder { /* private fields */ }Expand description
A builder for RestConfiguration.
Implementations
Sourceimpl RestConfigurationBuilder
impl RestConfigurationBuilder
Sourcepub fn global_source_configuration(self, input: SourceConfiguration) -> Self
pub fn global_source_configuration(self, input: SourceConfiguration) -> Self
Global configuration settings that apply to all REST API requests for this connection type, including common request methods, paths, and parameters.
Sourcepub fn set_global_source_configuration(
self,
input: Option<SourceConfiguration>,
) -> Self
pub fn set_global_source_configuration( self, input: Option<SourceConfiguration>, ) -> Self
Global configuration settings that apply to all REST API requests for this connection type, including common request methods, paths, and parameters.
Sourcepub fn get_global_source_configuration(&self) -> &Option<SourceConfiguration>
pub fn get_global_source_configuration(&self) -> &Option<SourceConfiguration>
Global configuration settings that apply to all REST API requests for this connection type, including common request methods, paths, and parameters.
Sourcepub fn validation_endpoint_configuration(
self,
input: SourceConfiguration,
) -> Self
pub fn validation_endpoint_configuration( self, input: SourceConfiguration, ) -> Self
Configuration for the endpoint used to validate connection credentials and test connectivity during connection creation.
Sourcepub fn set_validation_endpoint_configuration(
self,
input: Option<SourceConfiguration>,
) -> Self
pub fn set_validation_endpoint_configuration( self, input: Option<SourceConfiguration>, ) -> Self
Configuration for the endpoint used to validate connection credentials and test connectivity during connection creation.
Sourcepub fn get_validation_endpoint_configuration(
&self,
) -> &Option<SourceConfiguration>
pub fn get_validation_endpoint_configuration( &self, ) -> &Option<SourceConfiguration>
Configuration for the endpoint used to validate connection credentials and test connectivity during connection creation.
Sourcepub fn entity_configurations(
self,
k: impl Into<String>,
v: EntityConfiguration,
) -> Self
pub fn entity_configurations( self, k: impl Into<String>, v: EntityConfiguration, ) -> Self
Adds a key-value pair to entity_configurations.
To override the contents of this collection use set_entity_configurations.
A map of entity configurations that define how to interact with different data entities available through the REST API, including their schemas and access patterns.
Sourcepub fn set_entity_configurations(
self,
input: Option<HashMap<String, EntityConfiguration>>,
) -> Self
pub fn set_entity_configurations( self, input: Option<HashMap<String, EntityConfiguration>>, ) -> Self
A map of entity configurations that define how to interact with different data entities available through the REST API, including their schemas and access patterns.
Sourcepub fn get_entity_configurations(
&self,
) -> &Option<HashMap<String, EntityConfiguration>>
pub fn get_entity_configurations( &self, ) -> &Option<HashMap<String, EntityConfiguration>>
A map of entity configurations that define how to interact with different data entities available through the REST API, including their schemas and access patterns.
Sourcepub fn build(self) -> RestConfiguration
pub fn build(self) -> RestConfiguration
Consumes the builder and constructs a RestConfiguration.