#[non_exhaustive]pub struct RetentionMetricsBuilder { /* private fields */ }Expand description
A builder for RetentionMetrics.
Implementations
Sourceimpl RetentionMetricsBuilder
impl RetentionMetricsBuilder
Sourcepub fn iceberg_metrics(self, input: IcebergRetentionMetrics) -> Self
pub fn iceberg_metrics(self, input: IcebergRetentionMetrics) -> Self
A structure containing the Iceberg retention metrics for the optimizer run.
Sourcepub fn set_iceberg_metrics(self, input: Option<IcebergRetentionMetrics>) -> Self
pub fn set_iceberg_metrics(self, input: Option<IcebergRetentionMetrics>) -> Self
A structure containing the Iceberg retention metrics for the optimizer run.
Sourcepub fn get_iceberg_metrics(&self) -> &Option<IcebergRetentionMetrics>
pub fn get_iceberg_metrics(&self) -> &Option<IcebergRetentionMetrics>
A structure containing the Iceberg retention metrics for the optimizer run.
Sourcepub fn build(self) -> RetentionMetrics
pub fn build(self) -> RetentionMetrics
Consumes the builder and constructs a RetentionMetrics.