#[non_exhaustive]pub struct RouteBuilder { /* private fields */ }Expand description
A builder for Route.
Implementations
Sourceimpl RouteBuilder
impl RouteBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the route node.
This field is required.Sourcepub fn inputs(self, input: impl Into<String>) -> Self
pub fn inputs(self, input: impl Into<String>) -> Self
Appends an item to inputs.
To override the contents of this collection use set_inputs.
The input connection for the route node.
Sourcepub fn set_inputs(self, input: Option<Vec<String>>) -> Self
pub fn set_inputs(self, input: Option<Vec<String>>) -> Self
The input connection for the route node.
Sourcepub fn get_inputs(&self) -> &Option<Vec<String>>
pub fn get_inputs(&self) -> &Option<Vec<String>>
The input connection for the route node.
Sourcepub fn group_filters_list(self, input: GroupFilters) -> Self
pub fn group_filters_list(self, input: GroupFilters) -> Self
Appends an item to group_filters_list.
To override the contents of this collection use set_group_filters_list.
A list of group filters that define the routing conditions and criteria for directing data to different output paths.
Sourcepub fn set_group_filters_list(self, input: Option<Vec<GroupFilters>>) -> Self
pub fn set_group_filters_list(self, input: Option<Vec<GroupFilters>>) -> Self
A list of group filters that define the routing conditions and criteria for directing data to different output paths.
Sourcepub fn get_group_filters_list(&self) -> &Option<Vec<GroupFilters>>
pub fn get_group_filters_list(&self) -> &Option<Vec<GroupFilters>>
A list of group filters that define the routing conditions and criteria for directing data to different output paths.