#[non_exhaustive]pub struct RowLevelResultsOptionsBuilder { /* private fields */ }Expand description
A builder for RowLevelResultsOptions.
Implementations
Sourceimpl RowLevelResultsOptionsBuilder
impl RowLevelResultsOptionsBuilder
Sourcepub fn max_rows_to_write(self, input: i32) -> Self
pub fn max_rows_to_write(self, input: i32) -> Self
The maximum number of rows to write in the results.
Sourcepub fn set_max_rows_to_write(self, input: Option<i32>) -> Self
pub fn set_max_rows_to_write(self, input: Option<i32>) -> Self
The maximum number of rows to write in the results.
Sourcepub fn get_max_rows_to_write(&self) -> &Option<i32>
pub fn get_max_rows_to_write(&self) -> &Option<i32>
The maximum number of rows to write in the results.
Sourcepub fn result_type(self, input: ResultTypeEnum) -> Self
pub fn result_type(self, input: ResultTypeEnum) -> Self
The result type to include in the row-level results output.
Sourcepub fn set_result_type(self, input: Option<ResultTypeEnum>) -> Self
pub fn set_result_type(self, input: Option<ResultTypeEnum>) -> Self
The result type to include in the row-level results output.
Sourcepub fn get_result_type(&self) -> &Option<ResultTypeEnum>
pub fn get_result_type(&self) -> &Option<ResultTypeEnum>
The result type to include in the row-level results output.
Sourcepub fn catalog_table_config(self, input: CatalogTableConfigOptions) -> Self
pub fn catalog_table_config(self, input: CatalogTableConfigOptions) -> Self
The Glue Data Catalog table configuration for storing the results.
Sourcepub fn set_catalog_table_config(
self,
input: Option<CatalogTableConfigOptions>,
) -> Self
pub fn set_catalog_table_config( self, input: Option<CatalogTableConfigOptions>, ) -> Self
The Glue Data Catalog table configuration for storing the results.
Sourcepub fn get_catalog_table_config(&self) -> &Option<CatalogTableConfigOptions>
pub fn get_catalog_table_config(&self) -> &Option<CatalogTableConfigOptions>
The Glue Data Catalog table configuration for storing the results.
Sourcepub fn build(self) -> RowLevelResultsOptions
pub fn build(self) -> RowLevelResultsOptions
Consumes the builder and constructs a RowLevelResultsOptions.