S3ExcelSourceBuilder

Struct S3ExcelSourceBuilder 

#[non_exhaustive]
pub struct S3ExcelSourceBuilder { /* private fields */ }
A builder for S3ExcelSource.

Implementations

Source

impl S3ExcelSourceBuilder

pub fn name(self, input: impl Into<String>) -> Self

The name of the S3 Excel data source.

This field is required.
pub fn set_name(self, input: Option<String>) -> Self

The name of the S3 Excel data source.

pub fn get_name(&self) -> &Option<String>

The name of the S3 Excel data source.

pub fn paths(self, input: impl Into<String>) -> Self

Appends an item to paths.

To override the contents of this collection use set_paths.

The S3 paths where the Excel files are located.

pub fn set_paths(self, input: Option<Vec<String>>) -> Self

The S3 paths where the Excel files are located.

pub fn get_paths(&self) -> &Option<Vec<String>>

The S3 paths where the Excel files are located.

pub fn compression_type(self, input: ParquetCompressionType) -> Self

The compression format used for the Excel files.

pub fn set_compression_type(self, input: Option<ParquetCompressionType>) -> Self

The compression format used for the Excel files.

pub fn get_compression_type(&self) -> &Option<ParquetCompressionType>

The compression format used for the Excel files.

pub fn exclusions(self, input: impl Into<String>) -> Self

Appends an item to exclusions.

To override the contents of this collection use set_exclusions.

Patterns to exclude specific files or paths from processing.

pub fn set_exclusions(self, input: Option<Vec<String>>) -> Self

Patterns to exclude specific files or paths from processing.

pub fn get_exclusions(&self) -> &Option<Vec<String>>

Patterns to exclude specific files or paths from processing.

pub fn group_size(self, input: impl Into<String>) -> Self

Defines the size of file groups for batch processing.

pub fn set_group_size(self, input: Option<String>) -> Self

Defines the size of file groups for batch processing.

pub fn get_group_size(&self) -> &Option<String>

Defines the size of file groups for batch processing.

pub fn group_files(self, input: impl Into<String>) -> Self

Specifies how files should be grouped for processing.

pub fn set_group_files(self, input: Option<String>) -> Self

Specifies how files should be grouped for processing.

pub fn get_group_files(&self) -> &Option<String>

Specifies how files should be grouped for processing.

pub fn recurse(self, input: bool) -> Self

Indicates whether to recursively process subdirectories.

pub fn set_recurse(self, input: Option<bool>) -> Self

Indicates whether to recursively process subdirectories.

pub fn get_recurse(&self) -> &Option<bool>

Indicates whether to recursively process subdirectories.

pub fn max_band(self, input: i32) -> Self

The maximum number of processing bands to use.

pub fn set_max_band(self, input: Option<i32>) -> Self

The maximum number of processing bands to use.

pub fn get_max_band(&self) -> &Option<i32>

The maximum number of processing bands to use.

pub fn max_files_in_band(self, input: i32) -> Self

The maximum number of files to process in each band.

pub fn set_max_files_in_band(self, input: Option<i32>) -> Self

The maximum number of files to process in each band.

pub fn get_max_files_in_band(&self) -> &Option<i32>

The maximum number of files to process in each band.

pub fn additional_options(self, input: S3DirectSourceAdditionalOptions) -> Self

Additional configuration options for S3 direct source processing.

pub fn set_additional_options( self, input: Option<S3DirectSourceAdditionalOptions>, ) -> Self

Additional configuration options for S3 direct source processing.

pub fn get_additional_options(&self) -> &Option<S3DirectSourceAdditionalOptions>

Additional configuration options for S3 direct source processing.

pub fn number_rows(self, input: i64) -> Self

The number of rows to process from each Excel file.

pub fn set_number_rows(self, input: Option<i64>) -> Self

The number of rows to process from each Excel file.

pub fn get_number_rows(&self) -> &Option<i64>

The number of rows to process from each Excel file.

The number of rows to skip at the end of each Excel file.

The number of rows to skip at the end of each Excel file.

The number of rows to skip at the end of each Excel file.

pub fn output_schemas(self, input: GlueSchema) -> Self

Appends an item to output_schemas.

To override the contents of this collection use set_output_schemas.

The Glue schemas to apply to the processed data.

pub fn set_output_schemas(self, input: Option<Vec<GlueSchema>>) -> Self

The Glue schemas to apply to the processed data.

pub fn get_output_schemas(&self) -> &Option<Vec<GlueSchema>>

The Glue schemas to apply to the processed data.

pub fn build(self) -> Result<S3ExcelSource, BuildError>

Consumes the builder and constructs a S3ExcelSource. This method will fail if any of the following fields are not set: