#[non_exhaustive]pub struct S3GlueParquetTargetBuilder { /* private fields */ }Expand description
A builder for S3GlueParquetTarget.
Implementations
Sourceimpl S3GlueParquetTargetBuilder
impl S3GlueParquetTargetBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the data target.
This field is required.Sourcepub fn inputs(self, input: impl Into<String>) -> Self
pub fn inputs(self, input: impl Into<String>) -> Self
Appends an item to inputs.
To override the contents of this collection use set_inputs.
The nodes that are inputs to the data target.
Sourcepub fn set_inputs(self, input: Option<Vec<String>>) -> Self
pub fn set_inputs(self, input: Option<Vec<String>>) -> Self
The nodes that are inputs to the data target.
Sourcepub fn get_inputs(&self) -> &Option<Vec<String>>
pub fn get_inputs(&self) -> &Option<Vec<String>>
The nodes that are inputs to the data target.
Sourcepub fn partition_keys(self, input: Vec<String>) -> Self
pub fn partition_keys(self, input: Vec<String>) -> Self
Appends an item to partition_keys.
To override the contents of this collection use set_partition_keys.
Specifies native partitioning using a sequence of keys.
Sourcepub fn set_partition_keys(self, input: Option<Vec<Vec<String>>>) -> Self
pub fn set_partition_keys(self, input: Option<Vec<Vec<String>>>) -> Self
Specifies native partitioning using a sequence of keys.
Sourcepub fn get_partition_keys(&self) -> &Option<Vec<Vec<String>>>
pub fn get_partition_keys(&self) -> &Option<Vec<Vec<String>>>
Specifies native partitioning using a sequence of keys.
Sourcepub fn path(self, input: impl Into<String>) -> Self
pub fn path(self, input: impl Into<String>) -> Self
A single Amazon S3 path to write to.
This field is required.Sourcepub fn compression(self, input: ParquetCompressionType) -> Self
pub fn compression(self, input: ParquetCompressionType) -> Self
Specifies how the data is compressed. This is generally not necessary if the data has a standard file extension. Possible values are "gzip" and "bzip").
Sourcepub fn set_compression(self, input: Option<ParquetCompressionType>) -> Self
pub fn set_compression(self, input: Option<ParquetCompressionType>) -> Self
Specifies how the data is compressed. This is generally not necessary if the data has a standard file extension. Possible values are "gzip" and "bzip").
Sourcepub fn get_compression(&self) -> &Option<ParquetCompressionType>
pub fn get_compression(&self) -> &Option<ParquetCompressionType>
Specifies how the data is compressed. This is generally not necessary if the data has a standard file extension. Possible values are "gzip" and "bzip").
Sourcepub fn number_target_partitions(self, input: impl Into<String>) -> Self
pub fn number_target_partitions(self, input: impl Into<String>) -> Self
Specifies the number of target partitions for Parquet files when writing to Amazon S3 using Glue.
Sourcepub fn set_number_target_partitions(self, input: Option<String>) -> Self
pub fn set_number_target_partitions(self, input: Option<String>) -> Self
Specifies the number of target partitions for Parquet files when writing to Amazon S3 using Glue.
Sourcepub fn get_number_target_partitions(&self) -> &Option<String>
pub fn get_number_target_partitions(&self) -> &Option<String>
Specifies the number of target partitions for Parquet files when writing to Amazon S3 using Glue.
Sourcepub fn schema_change_policy(self, input: DirectSchemaChangePolicy) -> Self
pub fn schema_change_policy(self, input: DirectSchemaChangePolicy) -> Self
A policy that specifies update behavior for the crawler.
Sourcepub fn set_schema_change_policy(
self,
input: Option<DirectSchemaChangePolicy>,
) -> Self
pub fn set_schema_change_policy( self, input: Option<DirectSchemaChangePolicy>, ) -> Self
A policy that specifies update behavior for the crawler.
Sourcepub fn get_schema_change_policy(&self) -> &Option<DirectSchemaChangePolicy>
pub fn get_schema_change_policy(&self) -> &Option<DirectSchemaChangePolicy>
A policy that specifies update behavior for the crawler.
Sourcepub fn auto_data_quality(self, input: AutoDataQuality) -> Self
pub fn auto_data_quality(self, input: AutoDataQuality) -> Self
Specifies whether to automatically enable data quality evaluation for the S3 Glue Parquet target. When set to true, data quality checks are performed automatically during the write operation.
Sourcepub fn set_auto_data_quality(self, input: Option<AutoDataQuality>) -> Self
pub fn set_auto_data_quality(self, input: Option<AutoDataQuality>) -> Self
Specifies whether to automatically enable data quality evaluation for the S3 Glue Parquet target. When set to true, data quality checks are performed automatically during the write operation.
Sourcepub fn get_auto_data_quality(&self) -> &Option<AutoDataQuality>
pub fn get_auto_data_quality(&self) -> &Option<AutoDataQuality>
Specifies whether to automatically enable data quality evaluation for the S3 Glue Parquet target. When set to true, data quality checks are performed automatically during the write operation.
Sourcepub fn build(self) -> Result<S3GlueParquetTarget, BuildError>
pub fn build(self) -> Result<S3GlueParquetTarget, BuildError>
Consumes the builder and constructs a S3GlueParquetTarget.
This method will fail if any of the following fields are not set: