#[non_exhaustive]pub struct S3HyperDirectTargetBuilder { /* private fields */ }Expand description
A builder for S3HyperDirectTarget.
Implementations
Sourceimpl S3HyperDirectTargetBuilder
impl S3HyperDirectTargetBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The unique identifier for the HyperDirect target node.
This field is required.Sourcepub fn set_name(self, input: Option<String>) -> Self
pub fn set_name(self, input: Option<String>) -> Self
The unique identifier for the HyperDirect target node.
Sourcepub fn get_name(&self) -> &Option<String>
pub fn get_name(&self) -> &Option<String>
The unique identifier for the HyperDirect target node.
Sourcepub fn inputs(self, input: impl Into<String>) -> Self
pub fn inputs(self, input: impl Into<String>) -> Self
Appends an item to inputs.
To override the contents of this collection use set_inputs.
Specifies the input source for the HyperDirect target.
Sourcepub fn set_inputs(self, input: Option<Vec<String>>) -> Self
pub fn set_inputs(self, input: Option<Vec<String>>) -> Self
Specifies the input source for the HyperDirect target.
Sourcepub fn get_inputs(&self) -> &Option<Vec<String>>
pub fn get_inputs(&self) -> &Option<Vec<String>>
Specifies the input source for the HyperDirect target.
Sourcepub fn format(self, input: TargetFormat) -> Self
pub fn format(self, input: TargetFormat) -> Self
Specifies the data output format for the HyperDirect target.
Sourcepub fn set_format(self, input: Option<TargetFormat>) -> Self
pub fn set_format(self, input: Option<TargetFormat>) -> Self
Specifies the data output format for the HyperDirect target.
Sourcepub fn get_format(&self) -> &Option<TargetFormat>
pub fn get_format(&self) -> &Option<TargetFormat>
Specifies the data output format for the HyperDirect target.
Sourcepub fn partition_keys(self, input: Vec<String>) -> Self
pub fn partition_keys(self, input: Vec<String>) -> Self
Appends an item to partition_keys.
To override the contents of this collection use set_partition_keys.
Defines the partitioning strategy for the output data.
Sourcepub fn set_partition_keys(self, input: Option<Vec<Vec<String>>>) -> Self
pub fn set_partition_keys(self, input: Option<Vec<Vec<String>>>) -> Self
Defines the partitioning strategy for the output data.
Sourcepub fn get_partition_keys(&self) -> &Option<Vec<Vec<String>>>
pub fn get_partition_keys(&self) -> &Option<Vec<Vec<String>>>
Defines the partitioning strategy for the output data.
Sourcepub fn path(self, input: impl Into<String>) -> Self
pub fn path(self, input: impl Into<String>) -> Self
The S3 location where the output data will be written.
This field is required.Sourcepub fn set_path(self, input: Option<String>) -> Self
pub fn set_path(self, input: Option<String>) -> Self
The S3 location where the output data will be written.
Sourcepub fn get_path(&self) -> &Option<String>
pub fn get_path(&self) -> &Option<String>
The S3 location where the output data will be written.
Sourcepub fn compression(self, input: HyperTargetCompressionType) -> Self
pub fn compression(self, input: HyperTargetCompressionType) -> Self
The compression type to apply to the output data.
Sourcepub fn set_compression(self, input: Option<HyperTargetCompressionType>) -> Self
pub fn set_compression(self, input: Option<HyperTargetCompressionType>) -> Self
The compression type to apply to the output data.
Sourcepub fn get_compression(&self) -> &Option<HyperTargetCompressionType>
pub fn get_compression(&self) -> &Option<HyperTargetCompressionType>
The compression type to apply to the output data.
Sourcepub fn schema_change_policy(self, input: DirectSchemaChangePolicy) -> Self
pub fn schema_change_policy(self, input: DirectSchemaChangePolicy) -> Self
Defines how schema changes are handled during write operations.
Sourcepub fn set_schema_change_policy(
self,
input: Option<DirectSchemaChangePolicy>,
) -> Self
pub fn set_schema_change_policy( self, input: Option<DirectSchemaChangePolicy>, ) -> Self
Defines how schema changes are handled during write operations.
Sourcepub fn get_schema_change_policy(&self) -> &Option<DirectSchemaChangePolicy>
pub fn get_schema_change_policy(&self) -> &Option<DirectSchemaChangePolicy>
Defines how schema changes are handled during write operations.
Sourcepub fn auto_data_quality(self, input: AutoDataQuality) -> Self
pub fn auto_data_quality(self, input: AutoDataQuality) -> Self
Specifies whether to automatically enable data quality evaluation for the S3 Hyper direct target. When set to true, data quality checks are performed automatically during the write operation.
Sourcepub fn set_auto_data_quality(self, input: Option<AutoDataQuality>) -> Self
pub fn set_auto_data_quality(self, input: Option<AutoDataQuality>) -> Self
Specifies whether to automatically enable data quality evaluation for the S3 Hyper direct target. When set to true, data quality checks are performed automatically during the write operation.
Sourcepub fn get_auto_data_quality(&self) -> &Option<AutoDataQuality>
pub fn get_auto_data_quality(&self) -> &Option<AutoDataQuality>
Specifies whether to automatically enable data quality evaluation for the S3 Hyper direct target. When set to true, data quality checks are performed automatically during the write operation.
Sourcepub fn output_schemas(self, input: GlueSchema) -> Self
pub fn output_schemas(self, input: GlueSchema) -> Self
Appends an item to output_schemas.
To override the contents of this collection use set_output_schemas.
Specifies the data schema for the S3 Hyper direct target.
Sourcepub fn set_output_schemas(self, input: Option<Vec<GlueSchema>>) -> Self
pub fn set_output_schemas(self, input: Option<Vec<GlueSchema>>) -> Self
Specifies the data schema for the S3 Hyper direct target.
Sourcepub fn get_output_schemas(&self) -> &Option<Vec<GlueSchema>>
pub fn get_output_schemas(&self) -> &Option<Vec<GlueSchema>>
Specifies the data schema for the S3 Hyper direct target.
Sourcepub fn build(self) -> Result<S3HyperDirectTarget, BuildError>
pub fn build(self) -> Result<S3HyperDirectTarget, BuildError>
Consumes the builder and constructs a S3HyperDirectTarget.
This method will fail if any of the following fields are not set: