#[non_exhaustive]pub struct S3SourceAdditionalOptionsBuilder { /* private fields */ }Expand description
A builder for S3SourceAdditionalOptions.
Implementations
Sourceimpl S3SourceAdditionalOptionsBuilder
impl S3SourceAdditionalOptionsBuilder
Sourcepub fn bounded_size(self, input: i64) -> Self
pub fn bounded_size(self, input: i64) -> Self
Sets the upper limit for the target size of the dataset in bytes that will be processed.
Sourcepub fn set_bounded_size(self, input: Option<i64>) -> Self
pub fn set_bounded_size(self, input: Option<i64>) -> Self
Sets the upper limit for the target size of the dataset in bytes that will be processed.
Sourcepub fn get_bounded_size(&self) -> &Option<i64>
pub fn get_bounded_size(&self) -> &Option<i64>
Sets the upper limit for the target size of the dataset in bytes that will be processed.
Sourcepub fn bounded_files(self, input: i64) -> Self
pub fn bounded_files(self, input: i64) -> Self
Sets the upper limit for the target number of files that will be processed.
Sourcepub fn set_bounded_files(self, input: Option<i64>) -> Self
pub fn set_bounded_files(self, input: Option<i64>) -> Self
Sets the upper limit for the target number of files that will be processed.
Sourcepub fn get_bounded_files(&self) -> &Option<i64>
pub fn get_bounded_files(&self) -> &Option<i64>
Sets the upper limit for the target number of files that will be processed.
Sourcepub fn build(self) -> S3SourceAdditionalOptions
pub fn build(self) -> S3SourceAdditionalOptions
Consumes the builder and constructs a S3SourceAdditionalOptions.