#[non_exhaustive]pub struct SearchResultItemBuilder { /* private fields */ }Expand description
A builder for SearchResultItem.
Implementations
Sourceimpl SearchResultItemBuilder
impl SearchResultItemBuilder
Sourcepub fn asset_name(self, input: impl Into<String>) -> Self
pub fn asset_name(self, input: impl Into<String>) -> Self
The name of the matched asset.
Sourcepub fn set_asset_name(self, input: Option<String>) -> Self
pub fn set_asset_name(self, input: Option<String>) -> Self
The name of the matched asset.
Sourcepub fn get_asset_name(&self) -> &Option<String>
pub fn get_asset_name(&self) -> &Option<String>
The name of the matched asset.
Sourcepub fn asset_description(self, input: impl Into<String>) -> Self
pub fn asset_description(self, input: impl Into<String>) -> Self
The description of the matched asset.
Sourcepub fn set_asset_description(self, input: Option<String>) -> Self
pub fn set_asset_description(self, input: Option<String>) -> Self
The description of the matched asset.
Sourcepub fn get_asset_description(&self) -> &Option<String>
pub fn get_asset_description(&self) -> &Option<String>
The description of the matched asset.
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
The timestamp at which the matched asset was last updated.
Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
The timestamp at which the matched asset was last updated.
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
The timestamp at which the matched asset was last updated.
Sourcepub fn asset_type_id(self, input: impl Into<String>) -> Self
pub fn asset_type_id(self, input: impl Into<String>) -> Self
The identifier of the asset type for the matched asset.
Sourcepub fn set_asset_type_id(self, input: Option<String>) -> Self
pub fn set_asset_type_id(self, input: Option<String>) -> Self
The identifier of the asset type for the matched asset.
Sourcepub fn get_asset_type_id(&self) -> &Option<String>
pub fn get_asset_type_id(&self) -> &Option<String>
The identifier of the asset type for the matched asset.
Sourcepub fn build(self) -> SearchResultItem
pub fn build(self) -> SearchResultItem
Consumes the builder and constructs a SearchResultItem.