#[non_exhaustive]pub struct SessionEndpointBuilder { /* private fields */ }Expand description
A builder for SessionEndpoint.
Implementations
Sourceimpl SessionEndpointBuilder
impl SessionEndpointBuilder
Sourcepub fn url(self, input: impl Into<String>) -> Self
pub fn url(self, input: impl Into<String>) -> Self
The Spark Connect endpoint URL for the session.
This field is required.Sourcepub fn set_url(self, input: Option<String>) -> Self
pub fn set_url(self, input: Option<String>) -> Self
The Spark Connect endpoint URL for the session.
Sourcepub fn auth_token(self, input: impl Into<String>) -> Self
pub fn auth_token(self, input: impl Into<String>) -> Self
The authentication token to include in requests to the Spark Connect endpoint.
This field is required.Sourcepub fn set_auth_token(self, input: Option<String>) -> Self
pub fn set_auth_token(self, input: Option<String>) -> Self
The authentication token to include in requests to the Spark Connect endpoint.
Sourcepub fn get_auth_token(&self) -> &Option<String>
pub fn get_auth_token(&self) -> &Option<String>
The authentication token to include in requests to the Spark Connect endpoint.
Sourcepub fn auth_token_expiration_time(self, input: DateTime) -> Self
pub fn auth_token_expiration_time(self, input: DateTime) -> Self
The time at which the authentication token expires.
This field is required.Sourcepub fn set_auth_token_expiration_time(self, input: Option<DateTime>) -> Self
pub fn set_auth_token_expiration_time(self, input: Option<DateTime>) -> Self
The time at which the authentication token expires.
Sourcepub fn get_auth_token_expiration_time(&self) -> &Option<DateTime>
pub fn get_auth_token_expiration_time(&self) -> &Option<DateTime>
The time at which the authentication token expires.
Sourcepub fn build(self) -> Result<SessionEndpoint, BuildError>
pub fn build(self) -> Result<SessionEndpoint, BuildError>
Consumes the builder and constructs a SessionEndpoint.
This method will fail if any of the following fields are not set: