#[non_exhaustive]pub struct SkewedInfoBuilder { /* private fields */ }Expand description
A builder for SkewedInfo.
Implementations
Sourceimpl SkewedInfoBuilder
impl SkewedInfoBuilder
Sourcepub fn skewed_column_names(self, input: impl Into<String>) -> Self
pub fn skewed_column_names(self, input: impl Into<String>) -> Self
Appends an item to skewed_column_names.
To override the contents of this collection use set_skewed_column_names.
A list of names of columns that contain skewed values.
Sourcepub fn set_skewed_column_names(self, input: Option<Vec<String>>) -> Self
pub fn set_skewed_column_names(self, input: Option<Vec<String>>) -> Self
A list of names of columns that contain skewed values.
Sourcepub fn get_skewed_column_names(&self) -> &Option<Vec<String>>
pub fn get_skewed_column_names(&self) -> &Option<Vec<String>>
A list of names of columns that contain skewed values.
Sourcepub fn skewed_column_values(self, input: impl Into<String>) -> Self
pub fn skewed_column_values(self, input: impl Into<String>) -> Self
Appends an item to skewed_column_values.
To override the contents of this collection use set_skewed_column_values.
A list of values that appear so frequently as to be considered skewed.
Sourcepub fn set_skewed_column_values(self, input: Option<Vec<String>>) -> Self
pub fn set_skewed_column_values(self, input: Option<Vec<String>>) -> Self
A list of values that appear so frequently as to be considered skewed.
Sourcepub fn get_skewed_column_values(&self) -> &Option<Vec<String>>
pub fn get_skewed_column_values(&self) -> &Option<Vec<String>>
A list of values that appear so frequently as to be considered skewed.
Sourcepub fn skewed_column_value_location_maps(
self,
k: impl Into<String>,
v: impl Into<String>,
) -> Self
pub fn skewed_column_value_location_maps( self, k: impl Into<String>, v: impl Into<String>, ) -> Self
Adds a key-value pair to skewed_column_value_location_maps.
To override the contents of this collection use set_skewed_column_value_location_maps.
A mapping of skewed values to the columns that contain them.
Sourcepub fn set_skewed_column_value_location_maps(
self,
input: Option<HashMap<String, String>>,
) -> Self
pub fn set_skewed_column_value_location_maps( self, input: Option<HashMap<String, String>>, ) -> Self
A mapping of skewed values to the columns that contain them.
Sourcepub fn get_skewed_column_value_location_maps(
&self,
) -> &Option<HashMap<String, String>>
pub fn get_skewed_column_value_location_maps( &self, ) -> &Option<HashMap<String, String>>
A mapping of skewed values to the columns that contain them.
Sourcepub fn build(self) -> SkewedInfo
pub fn build(self) -> SkewedInfo
Consumes the builder and constructs a SkewedInfo.