#[non_exhaustive]pub struct SourceConfigurationBuilder { /* private fields */ }Expand description
A builder for SourceConfiguration.
Implementations
Sourceimpl SourceConfigurationBuilder
impl SourceConfigurationBuilder
Sourcepub fn request_method(self, input: HttpMethod) -> Self
pub fn request_method(self, input: HttpMethod) -> Self
The HTTP method to use for requests to this endpoint, such as GET, POST.
Sourcepub fn set_request_method(self, input: Option<HttpMethod>) -> Self
pub fn set_request_method(self, input: Option<HttpMethod>) -> Self
The HTTP method to use for requests to this endpoint, such as GET, POST.
Sourcepub fn get_request_method(&self) -> &Option<HttpMethod>
pub fn get_request_method(&self) -> &Option<HttpMethod>
The HTTP method to use for requests to this endpoint, such as GET, POST.
Sourcepub fn request_path(self, input: impl Into<String>) -> Self
pub fn request_path(self, input: impl Into<String>) -> Self
The URL path for the REST endpoint, which may include parameter placeholders that will be replaced with actual values during requests.
Sourcepub fn set_request_path(self, input: Option<String>) -> Self
pub fn set_request_path(self, input: Option<String>) -> Self
The URL path for the REST endpoint, which may include parameter placeholders that will be replaced with actual values during requests.
Sourcepub fn get_request_path(&self) -> &Option<String>
pub fn get_request_path(&self) -> &Option<String>
The URL path for the REST endpoint, which may include parameter placeholders that will be replaced with actual values during requests.
Sourcepub fn request_parameters(self, input: ConnectorProperty) -> Self
pub fn request_parameters(self, input: ConnectorProperty) -> Self
Appends an item to request_parameters.
To override the contents of this collection use set_request_parameters.
Configuration for request parameters that should be included in API calls, such as query parameters, headers, or body content.
Sourcepub fn set_request_parameters(
self,
input: Option<Vec<ConnectorProperty>>,
) -> Self
pub fn set_request_parameters( self, input: Option<Vec<ConnectorProperty>>, ) -> Self
Configuration for request parameters that should be included in API calls, such as query parameters, headers, or body content.
Sourcepub fn get_request_parameters(&self) -> &Option<Vec<ConnectorProperty>>
pub fn get_request_parameters(&self) -> &Option<Vec<ConnectorProperty>>
Configuration for request parameters that should be included in API calls, such as query parameters, headers, or body content.
Sourcepub fn response_configuration(self, input: ResponseConfiguration) -> Self
pub fn response_configuration(self, input: ResponseConfiguration) -> Self
Configuration that defines how to parse and extract data from API responses, including success and error handling.
Sourcepub fn set_response_configuration(
self,
input: Option<ResponseConfiguration>,
) -> Self
pub fn set_response_configuration( self, input: Option<ResponseConfiguration>, ) -> Self
Configuration that defines how to parse and extract data from API responses, including success and error handling.
Sourcepub fn get_response_configuration(&self) -> &Option<ResponseConfiguration>
pub fn get_response_configuration(&self) -> &Option<ResponseConfiguration>
Configuration that defines how to parse and extract data from API responses, including success and error handling.
Sourcepub fn pagination_configuration(self, input: PaginationConfiguration) -> Self
pub fn pagination_configuration(self, input: PaginationConfiguration) -> Self
Configuration for handling paginated responses from the REST API, supporting both cursor-based and offset-based pagination strategies.
Sourcepub fn set_pagination_configuration(
self,
input: Option<PaginationConfiguration>,
) -> Self
pub fn set_pagination_configuration( self, input: Option<PaginationConfiguration>, ) -> Self
Configuration for handling paginated responses from the REST API, supporting both cursor-based and offset-based pagination strategies.
Sourcepub fn get_pagination_configuration(&self) -> &Option<PaginationConfiguration>
pub fn get_pagination_configuration(&self) -> &Option<PaginationConfiguration>
Configuration for handling paginated responses from the REST API, supporting both cursor-based and offset-based pagination strategies.
Sourcepub fn build(self) -> SourceConfiguration
pub fn build(self) -> SourceConfiguration
Consumes the builder and constructs a SourceConfiguration.