#[non_exhaustive]pub struct SourceTableConfigBuilder { /* private fields */ }Expand description
A builder for SourceTableConfig.
Implementations
Sourceimpl SourceTableConfigBuilder
impl SourceTableConfigBuilder
Sourcepub fn fields(self, input: impl Into<String>) -> Self
pub fn fields(self, input: impl Into<String>) -> Self
Appends an item to fields.
To override the contents of this collection use set_fields.
A list of fields used for column-level filtering. Currently unsupported.
Sourcepub fn set_fields(self, input: Option<Vec<String>>) -> Self
pub fn set_fields(self, input: Option<Vec<String>>) -> Self
A list of fields used for column-level filtering. Currently unsupported.
Sourcepub fn get_fields(&self) -> &Option<Vec<String>>
pub fn get_fields(&self) -> &Option<Vec<String>>
A list of fields used for column-level filtering. Currently unsupported.
Sourcepub fn filter_predicate(self, input: impl Into<String>) -> Self
pub fn filter_predicate(self, input: impl Into<String>) -> Self
A condition clause used for row-level filtering. Currently unsupported.
Sourcepub fn set_filter_predicate(self, input: Option<String>) -> Self
pub fn set_filter_predicate(self, input: Option<String>) -> Self
A condition clause used for row-level filtering. Currently unsupported.
Sourcepub fn get_filter_predicate(&self) -> &Option<String>
pub fn get_filter_predicate(&self) -> &Option<String>
A condition clause used for row-level filtering. Currently unsupported.
Sourcepub fn primary_key(self, input: impl Into<String>) -> Self
pub fn primary_key(self, input: impl Into<String>) -> Self
Appends an item to primary_key.
To override the contents of this collection use set_primary_key.
Provide the primary key set for this table. Currently supported specifically for SAP EntityOf entities upon request. Contact Amazon Web Services Support to make this feature available.
Sourcepub fn set_primary_key(self, input: Option<Vec<String>>) -> Self
pub fn set_primary_key(self, input: Option<Vec<String>>) -> Self
Provide the primary key set for this table. Currently supported specifically for SAP EntityOf entities upon request. Contact Amazon Web Services Support to make this feature available.
Sourcepub fn get_primary_key(&self) -> &Option<Vec<String>>
pub fn get_primary_key(&self) -> &Option<Vec<String>>
Provide the primary key set for this table. Currently supported specifically for SAP EntityOf entities upon request. Contact Amazon Web Services Support to make this feature available.
Sourcepub fn record_update_field(self, input: impl Into<String>) -> Self
pub fn record_update_field(self, input: impl Into<String>) -> Self
Incremental pull timestamp-based field. Currently unsupported.
Sourcepub fn set_record_update_field(self, input: Option<String>) -> Self
pub fn set_record_update_field(self, input: Option<String>) -> Self
Incremental pull timestamp-based field. Currently unsupported.
Sourcepub fn get_record_update_field(&self) -> &Option<String>
pub fn get_record_update_field(&self) -> &Option<String>
Incremental pull timestamp-based field. Currently unsupported.
Sourcepub fn build(self) -> SourceTableConfig
pub fn build(self) -> SourceTableConfig
Consumes the builder and constructs a SourceTableConfig.