#[non_exhaustive]pub struct SpigotBuilder { /* private fields */ }Expand description
A builder for Spigot.
Implementations
Sourceimpl SpigotBuilder
impl SpigotBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the transform node.
This field is required.Sourcepub fn inputs(self, input: impl Into<String>) -> Self
pub fn inputs(self, input: impl Into<String>) -> Self
Appends an item to inputs.
To override the contents of this collection use set_inputs.
The data inputs identified by their node names.
Sourcepub fn set_inputs(self, input: Option<Vec<String>>) -> Self
pub fn set_inputs(self, input: Option<Vec<String>>) -> Self
The data inputs identified by their node names.
Sourcepub fn get_inputs(&self) -> &Option<Vec<String>>
pub fn get_inputs(&self) -> &Option<Vec<String>>
The data inputs identified by their node names.
Sourcepub fn path(self, input: impl Into<String>) -> Self
pub fn path(self, input: impl Into<String>) -> Self
A path in Amazon S3 where the transform will write a subset of records from the dataset to a JSON file in an Amazon S3 bucket.
This field is required.Sourcepub fn set_path(self, input: Option<String>) -> Self
pub fn set_path(self, input: Option<String>) -> Self
A path in Amazon S3 where the transform will write a subset of records from the dataset to a JSON file in an Amazon S3 bucket.
Sourcepub fn get_path(&self) -> &Option<String>
pub fn get_path(&self) -> &Option<String>
A path in Amazon S3 where the transform will write a subset of records from the dataset to a JSON file in an Amazon S3 bucket.
Sourcepub fn topk(self, input: i32) -> Self
pub fn topk(self, input: i32) -> Self
Specifies a number of records to write starting from the beginning of the dataset.
Sourcepub fn set_topk(self, input: Option<i32>) -> Self
pub fn set_topk(self, input: Option<i32>) -> Self
Specifies a number of records to write starting from the beginning of the dataset.
Sourcepub fn get_topk(&self) -> &Option<i32>
pub fn get_topk(&self) -> &Option<i32>
Specifies a number of records to write starting from the beginning of the dataset.
Sourcepub fn prob(self, input: f64) -> Self
pub fn prob(self, input: f64) -> Self
The probability (a decimal value with a maximum value of 1) of picking any given record. A value of 1 indicates that each row read from the dataset should be included in the sample output.
Sourcepub fn set_prob(self, input: Option<f64>) -> Self
pub fn set_prob(self, input: Option<f64>) -> Self
The probability (a decimal value with a maximum value of 1) of picking any given record. A value of 1 indicates that each row read from the dataset should be included in the sample output.