#[non_exhaustive]pub struct StatisticSummaryBuilder { /* private fields */ }Expand description
A builder for StatisticSummary.
Implementations
Sourceimpl StatisticSummaryBuilder
impl StatisticSummaryBuilder
Sourcepub fn statistic_id(self, input: impl Into<String>) -> Self
pub fn statistic_id(self, input: impl Into<String>) -> Self
The Statistic ID.
Sourcepub fn set_statistic_id(self, input: Option<String>) -> Self
pub fn set_statistic_id(self, input: Option<String>) -> Self
The Statistic ID.
Sourcepub fn get_statistic_id(&self) -> &Option<String>
pub fn get_statistic_id(&self) -> &Option<String>
The Statistic ID.
Sourcepub fn profile_id(self, input: impl Into<String>) -> Self
pub fn profile_id(self, input: impl Into<String>) -> Self
The Profile ID.
Sourcepub fn set_profile_id(self, input: Option<String>) -> Self
pub fn set_profile_id(self, input: Option<String>) -> Self
The Profile ID.
Sourcepub fn get_profile_id(&self) -> &Option<String>
pub fn get_profile_id(&self) -> &Option<String>
The Profile ID.
Sourcepub fn run_identifier(self, input: RunIdentifier) -> Self
pub fn run_identifier(self, input: RunIdentifier) -> Self
The Run Identifier
Sourcepub fn set_run_identifier(self, input: Option<RunIdentifier>) -> Self
pub fn set_run_identifier(self, input: Option<RunIdentifier>) -> Self
The Run Identifier
Sourcepub fn get_run_identifier(&self) -> &Option<RunIdentifier>
pub fn get_run_identifier(&self) -> &Option<RunIdentifier>
The Run Identifier
Sourcepub fn statistic_name(self, input: impl Into<String>) -> Self
pub fn statistic_name(self, input: impl Into<String>) -> Self
The name of the statistic.
Sourcepub fn set_statistic_name(self, input: Option<String>) -> Self
pub fn set_statistic_name(self, input: Option<String>) -> Self
The name of the statistic.
Sourcepub fn get_statistic_name(&self) -> &Option<String>
pub fn get_statistic_name(&self) -> &Option<String>
The name of the statistic.
Sourcepub fn double_value(self, input: f64) -> Self
pub fn double_value(self, input: f64) -> Self
The value of the statistic.
Sourcepub fn set_double_value(self, input: Option<f64>) -> Self
pub fn set_double_value(self, input: Option<f64>) -> Self
The value of the statistic.
Sourcepub fn get_double_value(&self) -> &Option<f64>
pub fn get_double_value(&self) -> &Option<f64>
The value of the statistic.
Sourcepub fn evaluation_level(self, input: StatisticEvaluationLevel) -> Self
pub fn evaluation_level(self, input: StatisticEvaluationLevel) -> Self
The evaluation level of the statistic. Possible values: Dataset, Column, Multicolumn.
Sourcepub fn set_evaluation_level(
self,
input: Option<StatisticEvaluationLevel>,
) -> Self
pub fn set_evaluation_level( self, input: Option<StatisticEvaluationLevel>, ) -> Self
The evaluation level of the statistic. Possible values: Dataset, Column, Multicolumn.
Sourcepub fn get_evaluation_level(&self) -> &Option<StatisticEvaluationLevel>
pub fn get_evaluation_level(&self) -> &Option<StatisticEvaluationLevel>
The evaluation level of the statistic. Possible values: Dataset, Column, Multicolumn.
Sourcepub fn columns_referenced(self, input: impl Into<String>) -> Self
pub fn columns_referenced(self, input: impl Into<String>) -> Self
Appends an item to columns_referenced.
To override the contents of this collection use set_columns_referenced.
The list of columns referenced by the statistic.
Sourcepub fn set_columns_referenced(self, input: Option<Vec<String>>) -> Self
pub fn set_columns_referenced(self, input: Option<Vec<String>>) -> Self
The list of columns referenced by the statistic.
Sourcepub fn get_columns_referenced(&self) -> &Option<Vec<String>>
pub fn get_columns_referenced(&self) -> &Option<Vec<String>>
The list of columns referenced by the statistic.
Sourcepub fn referenced_datasets(self, input: impl Into<String>) -> Self
pub fn referenced_datasets(self, input: impl Into<String>) -> Self
Appends an item to referenced_datasets.
To override the contents of this collection use set_referenced_datasets.
The list of datasets referenced by the statistic.
Sourcepub fn set_referenced_datasets(self, input: Option<Vec<String>>) -> Self
pub fn set_referenced_datasets(self, input: Option<Vec<String>>) -> Self
The list of datasets referenced by the statistic.
Sourcepub fn get_referenced_datasets(&self) -> &Option<Vec<String>>
pub fn get_referenced_datasets(&self) -> &Option<Vec<String>>
The list of datasets referenced by the statistic.
Sourcepub fn statistic_properties(
self,
k: impl Into<String>,
v: impl Into<String>,
) -> Self
pub fn statistic_properties( self, k: impl Into<String>, v: impl Into<String>, ) -> Self
Adds a key-value pair to statistic_properties.
To override the contents of this collection use set_statistic_properties.
A StatisticPropertiesMap, which contains a NameString and DescriptionString
Sourcepub fn set_statistic_properties(
self,
input: Option<HashMap<String, String>>,
) -> Self
pub fn set_statistic_properties( self, input: Option<HashMap<String, String>>, ) -> Self
A StatisticPropertiesMap, which contains a NameString and DescriptionString
Sourcepub fn get_statistic_properties(&self) -> &Option<HashMap<String, String>>
pub fn get_statistic_properties(&self) -> &Option<HashMap<String, String>>
A StatisticPropertiesMap, which contains a NameString and DescriptionString
Sourcepub fn recorded_on(self, input: DateTime) -> Self
pub fn recorded_on(self, input: DateTime) -> Self
The timestamp when the statistic was recorded.
Sourcepub fn set_recorded_on(self, input: Option<DateTime>) -> Self
pub fn set_recorded_on(self, input: Option<DateTime>) -> Self
The timestamp when the statistic was recorded.
Sourcepub fn get_recorded_on(&self) -> &Option<DateTime>
pub fn get_recorded_on(&self) -> &Option<DateTime>
The timestamp when the statistic was recorded.
Sourcepub fn inclusion_annotation(self, input: TimestampedInclusionAnnotation) -> Self
pub fn inclusion_annotation(self, input: TimestampedInclusionAnnotation) -> Self
The inclusion annotation for the statistic.
Sourcepub fn set_inclusion_annotation(
self,
input: Option<TimestampedInclusionAnnotation>,
) -> Self
pub fn set_inclusion_annotation( self, input: Option<TimestampedInclusionAnnotation>, ) -> Self
The inclusion annotation for the statistic.
Sourcepub fn get_inclusion_annotation(
&self,
) -> &Option<TimestampedInclusionAnnotation>
pub fn get_inclusion_annotation( &self, ) -> &Option<TimestampedInclusionAnnotation>
The inclusion annotation for the statistic.
Sourcepub fn build(self) -> StatisticSummary
pub fn build(self) -> StatisticSummary
Consumes the builder and constructs a StatisticSummary.