#[non_exhaustive]pub struct StatusDetailsBuilder { /* private fields */ }Expand description
A builder for StatusDetails.
Implementations
Sourceimpl StatusDetailsBuilder
impl StatusDetailsBuilder
Sourcepub fn requested_change(self, input: impl Into<Box<Table>>) -> Self
pub fn requested_change(self, input: impl Into<Box<Table>>) -> Self
A Table object representing the requested changes.
Sourcepub fn set_requested_change(self, input: Option<Box<Table>>) -> Self
pub fn set_requested_change(self, input: Option<Box<Table>>) -> Self
A Table object representing the requested changes.
Sourcepub fn get_requested_change(&self) -> &Option<Box<Table>>
pub fn get_requested_change(&self) -> &Option<Box<Table>>
A Table object representing the requested changes.
Sourcepub fn view_validations(self, input: ViewValidation) -> Self
pub fn view_validations(self, input: ViewValidation) -> Self
Appends an item to view_validations.
To override the contents of this collection use set_view_validations.
A list of ViewValidation objects that contain information for an analytical engine to validate a view.
Sourcepub fn set_view_validations(self, input: Option<Vec<ViewValidation>>) -> Self
pub fn set_view_validations(self, input: Option<Vec<ViewValidation>>) -> Self
A list of ViewValidation objects that contain information for an analytical engine to validate a view.
Sourcepub fn get_view_validations(&self) -> &Option<Vec<ViewValidation>>
pub fn get_view_validations(&self) -> &Option<Vec<ViewValidation>>
A list of ViewValidation objects that contain information for an analytical engine to validate a view.
Sourcepub fn build(self) -> StatusDetails
pub fn build(self) -> StatusDetails
Consumes the builder and constructs a StatusDetails.