#[non_exhaustive]pub struct SubObjectStatisticsBuilder { /* private fields */ }Expand description
A builder for SubObjectStatistics.
Implementations
Sourceimpl SubObjectStatisticsBuilder
impl SubObjectStatisticsBuilder
Sourcepub fn source_type(self, input: SubObjectSourceType) -> Self
pub fn source_type(self, input: SubObjectSourceType) -> Self
The source type of the sub-object (for example, its table format), which identifies the sub-object.
Sourcepub fn set_source_type(self, input: Option<SubObjectSourceType>) -> Self
pub fn set_source_type(self, input: Option<SubObjectSourceType>) -> Self
The source type of the sub-object (for example, its table format), which identifies the sub-object.
Sourcepub fn get_source_type(&self) -> &Option<SubObjectSourceType>
pub fn get_source_type(&self) -> &Option<SubObjectSourceType>
The source type of the sub-object (for example, its table format), which identifies the sub-object.
Sourcepub fn glue_version_id(self, input: impl Into<String>) -> Self
pub fn glue_version_id(self, input: impl Into<String>) -> Self
The Glue version ID of the sub-object that the statistics were captured for.
Sourcepub fn set_glue_version_id(self, input: Option<String>) -> Self
pub fn set_glue_version_id(self, input: Option<String>) -> Self
The Glue version ID of the sub-object that the statistics were captured for.
Sourcepub fn get_glue_version_id(&self) -> &Option<String>
pub fn get_glue_version_id(&self) -> &Option<String>
The Glue version ID of the sub-object that the statistics were captured for.
Sourcepub fn partition_count(self, input: i64) -> Self
pub fn partition_count(self, input: i64) -> Self
The number of sub-object partitions selected for that refresh. Not present for unpartitioned sub-objects.
Sourcepub fn set_partition_count(self, input: Option<i64>) -> Self
pub fn set_partition_count(self, input: Option<i64>) -> Self
The number of sub-object partitions selected for that refresh. Not present for unpartitioned sub-objects.
Sourcepub fn get_partition_count(&self) -> &Option<i64>
pub fn get_partition_count(&self) -> &Option<i64>
The number of sub-object partitions selected for that refresh. Not present for unpartitioned sub-objects.
Sourcepub fn file_count(self, input: i64) -> Self
pub fn file_count(self, input: i64) -> Self
The number of sub-object data files selected for that refresh.
Sourcepub fn set_file_count(self, input: Option<i64>) -> Self
pub fn set_file_count(self, input: Option<i64>) -> Self
The number of sub-object data files selected for that refresh.
Sourcepub fn get_file_count(&self) -> &Option<i64>
pub fn get_file_count(&self) -> &Option<i64>
The number of sub-object data files selected for that refresh.
Sourcepub fn total_file_bytes(self, input: i64) -> Self
pub fn total_file_bytes(self, input: i64) -> Self
The total size, in bytes, of the data files counted by FileCount.
Sourcepub fn set_total_file_bytes(self, input: Option<i64>) -> Self
pub fn set_total_file_bytes(self, input: Option<i64>) -> Self
The total size, in bytes, of the data files counted by FileCount.
Sourcepub fn get_total_file_bytes(&self) -> &Option<i64>
pub fn get_total_file_bytes(&self) -> &Option<i64>
The total size, in bytes, of the data files counted by FileCount.
Sourcepub fn build(self) -> SubObjectStatistics
pub fn build(self) -> SubObjectStatistics
Consumes the builder and constructs a SubObjectStatistics.