TableBuilder

Struct TableBuilder 

#[non_exhaustive]
pub struct TableBuilder { /* private fields */ }
A builder for Table.

Implementations

Source

impl TableBuilder

pub fn name(self, input: impl Into<String>) -> Self

The table name. For Hive compatibility, this must be entirely lowercase.

This field is required.
pub fn set_name(self, input: Option<String>) -> Self

The table name. For Hive compatibility, this must be entirely lowercase.

pub fn get_name(&self) -> &Option<String>

The table name. For Hive compatibility, this must be entirely lowercase.

pub fn database_name(self, input: impl Into<String>) -> Self

The name of the database where the table metadata resides. For Hive compatibility, this must be all lowercase.

pub fn set_database_name(self, input: Option<String>) -> Self

The name of the database where the table metadata resides. For Hive compatibility, this must be all lowercase.

pub fn get_database_name(&self) -> &Option<String>

The name of the database where the table metadata resides. For Hive compatibility, this must be all lowercase.

pub fn description(self, input: impl Into<String>) -> Self

A description of the table.

pub fn set_description(self, input: Option<String>) -> Self

A description of the table.

pub fn get_description(&self) -> &Option<String>

A description of the table.

pub fn owner(self, input: impl Into<String>) -> Self

The owner of the table.

pub fn set_owner(self, input: Option<String>) -> Self

The owner of the table.

pub fn get_owner(&self) -> &Option<String>

The owner of the table.

pub fn create_time(self, input: DateTime) -> Self

The time when the table definition was created in the Data Catalog.

pub fn set_create_time(self, input: Option<DateTime>) -> Self

The time when the table definition was created in the Data Catalog.

pub fn get_create_time(&self) -> &Option<DateTime>

The time when the table definition was created in the Data Catalog.

pub fn update_time(self, input: DateTime) -> Self

The last time that the table was updated.

pub fn set_update_time(self, input: Option<DateTime>) -> Self

The last time that the table was updated.

pub fn get_update_time(&self) -> &Option<DateTime>

The last time that the table was updated.

pub fn last_access_time(self, input: DateTime) -> Self

The last time that the table was accessed. This is usually taken from HDFS, and might not be reliable.

pub fn set_last_access_time(self, input: Option<DateTime>) -> Self

The last time that the table was accessed. This is usually taken from HDFS, and might not be reliable.

pub fn get_last_access_time(&self) -> &Option<DateTime>

The last time that the table was accessed. This is usually taken from HDFS, and might not be reliable.

pub fn last_analyzed_time(self, input: DateTime) -> Self

The last time that column statistics were computed for this table.

pub fn set_last_analyzed_time(self, input: Option<DateTime>) -> Self

The last time that column statistics were computed for this table.

pub fn get_last_analyzed_time(&self) -> &Option<DateTime>

The last time that column statistics were computed for this table.

pub fn retention(self, input: i32) -> Self

The retention time for this table.

pub fn set_retention(self, input: Option<i32>) -> Self

The retention time for this table.

pub fn get_retention(&self) -> &Option<i32>

The retention time for this table.

pub fn storage_descriptor(self, input: StorageDescriptor) -> Self

A storage descriptor containing information about the physical storage of this table.

pub fn set_storage_descriptor(self, input: Option<StorageDescriptor>) -> Self

A storage descriptor containing information about the physical storage of this table.

pub fn get_storage_descriptor(&self) -> &Option<StorageDescriptor>

A storage descriptor containing information about the physical storage of this table.

pub fn partition_keys(self, input: Column) -> Self

Appends an item to partition_keys.

To override the contents of this collection use set_partition_keys.

A list of columns by which the table is partitioned. Only primitive types are supported as partition keys.

When you create a table used by Amazon Athena, and you do not specify any partitionKeys, you must at least set the value of partitionKeys to an empty list. For example:

"PartitionKeys": \[\]

pub fn set_partition_keys(self, input: Option<Vec<Column>>) -> Self

A list of columns by which the table is partitioned. Only primitive types are supported as partition keys.

When you create a table used by Amazon Athena, and you do not specify any partitionKeys, you must at least set the value of partitionKeys to an empty list. For example:

"PartitionKeys": \[\]

pub fn get_partition_keys(&self) -> &Option<Vec<Column>>

A list of columns by which the table is partitioned. Only primitive types are supported as partition keys.

When you create a table used by Amazon Athena, and you do not specify any partitionKeys, you must at least set the value of partitionKeys to an empty list. For example:

"PartitionKeys": \[\]

pub fn view_original_text(self, input: impl Into<String>) -> Self

Included for Apache Hive compatibility. Not used in the normal course of Glue operations. If the table is a VIRTUAL_VIEW, certain Athena configuration encoded in base64.

pub fn set_view_original_text(self, input: Option<String>) -> Self

Included for Apache Hive compatibility. Not used in the normal course of Glue operations. If the table is a VIRTUAL_VIEW, certain Athena configuration encoded in base64.

pub fn get_view_original_text(&self) -> &Option<String>

Included for Apache Hive compatibility. Not used in the normal course of Glue operations. If the table is a VIRTUAL_VIEW, certain Athena configuration encoded in base64.

pub fn view_expanded_text(self, input: impl Into<String>) -> Self

Included for Apache Hive compatibility. Not used in the normal course of Glue operations.

pub fn set_view_expanded_text(self, input: Option<String>) -> Self

Included for Apache Hive compatibility. Not used in the normal course of Glue operations.

pub fn get_view_expanded_text(&self) -> &Option<String>

Included for Apache Hive compatibility. Not used in the normal course of Glue operations.

pub fn table_type(self, input: impl Into<String>) -> Self

The type of this table. Glue will create tables with the EXTERNAL_TABLE type. Other services, such as Athena, may create tables with additional table types.

Glue related table types:

EXTERNAL_TABLE

Hive compatible attribute - indicates a non-Hive managed table.

GOVERNED

Used by Lake Formation. The Glue Data Catalog understands GOVERNED.

pub fn set_table_type(self, input: Option<String>) -> Self

The type of this table. Glue will create tables with the EXTERNAL_TABLE type. Other services, such as Athena, may create tables with additional table types.

Glue related table types:

EXTERNAL_TABLE

Hive compatible attribute - indicates a non-Hive managed table.

GOVERNED

Used by Lake Formation. The Glue Data Catalog understands GOVERNED.

pub fn get_table_type(&self) -> &Option<String>

The type of this table. Glue will create tables with the EXTERNAL_TABLE type. Other services, such as Athena, may create tables with additional table types.

Glue related table types:

EXTERNAL_TABLE

Hive compatible attribute - indicates a non-Hive managed table.

GOVERNED

Used by Lake Formation. The Glue Data Catalog understands GOVERNED.

pub fn parameters(self, k: impl Into<String>, v: impl Into<String>) -> Self

Adds a key-value pair to parameters.

To override the contents of this collection use set_parameters.

These key-value pairs define properties associated with the table.

pub fn set_parameters(self, input: Option<HashMap<String, String>>) -> Self

These key-value pairs define properties associated with the table.

pub fn get_parameters(&self) -> &Option<HashMap<String, String>>

These key-value pairs define properties associated with the table.

pub fn created_by(self, input: impl Into<String>) -> Self

The person or entity who created the table.

pub fn set_created_by(self, input: Option<String>) -> Self

The person or entity who created the table.

pub fn get_created_by(&self) -> &Option<String>

The person or entity who created the table.

pub fn is_registered_with_lake_formation(self, input: bool) -> Self

Indicates whether the table has been registered with Lake Formation.

pub fn set_is_registered_with_lake_formation(self, input: Option<bool>) -> Self

Indicates whether the table has been registered with Lake Formation.

pub fn get_is_registered_with_lake_formation(&self) -> &Option<bool>

Indicates whether the table has been registered with Lake Formation.

pub fn target_table(self, input: TableIdentifier) -> Self

A TableIdentifier structure that describes a target table for resource linking.

pub fn set_target_table(self, input: Option<TableIdentifier>) -> Self

A TableIdentifier structure that describes a target table for resource linking.

pub fn get_target_table(&self) -> &Option<TableIdentifier>

A TableIdentifier structure that describes a target table for resource linking.

pub fn catalog_id(self, input: impl Into<String>) -> Self

The ID of the Data Catalog in which the table resides.

pub fn set_catalog_id(self, input: Option<String>) -> Self

The ID of the Data Catalog in which the table resides.

pub fn get_catalog_id(&self) -> &Option<String>

The ID of the Data Catalog in which the table resides.

pub fn version_id(self, input: impl Into<String>) -> Self

The ID of the table version.

pub fn set_version_id(self, input: Option<String>) -> Self

The ID of the table version.

pub fn get_version_id(&self) -> &Option<String>

The ID of the table version.

pub fn federated_table(self, input: FederatedTable) -> Self

A FederatedTable structure that references an entity outside the Glue Data Catalog.

pub fn set_federated_table(self, input: Option<FederatedTable>) -> Self

A FederatedTable structure that references an entity outside the Glue Data Catalog.

pub fn get_federated_table(&self) -> &Option<FederatedTable>

A FederatedTable structure that references an entity outside the Glue Data Catalog.

pub fn view_definition(self, input: ViewDefinition) -> Self

A structure that contains all the information that defines the view, including the dialect or dialects for the view, and the query.

pub fn set_view_definition(self, input: Option<ViewDefinition>) -> Self

A structure that contains all the information that defines the view, including the dialect or dialects for the view, and the query.

pub fn get_view_definition(&self) -> &Option<ViewDefinition>

A structure that contains all the information that defines the view, including the dialect or dialects for the view, and the query.

pub fn is_multi_dialect_view(self, input: bool) -> Self

Specifies whether the view supports the SQL dialects of one or more different query engines and can therefore be read by those engines.

pub fn set_is_multi_dialect_view(self, input: Option<bool>) -> Self

Specifies whether the view supports the SQL dialects of one or more different query engines and can therefore be read by those engines.

pub fn get_is_multi_dialect_view(&self) -> &Option<bool>

Specifies whether the view supports the SQL dialects of one or more different query engines and can therefore be read by those engines.

pub fn is_materialized_view(self, input: bool) -> Self

Indicates a table is a MaterializedView.

pub fn set_is_materialized_view(self, input: Option<bool>) -> Self

Indicates a table is a MaterializedView.

pub fn get_is_materialized_view(&self) -> &Option<bool>

Indicates a table is a MaterializedView.

pub fn iceberg_table_metadata(self, input: IcebergTableMetadata) -> Self

The latest Apache Iceberg table metadata for the table, including format version, schemas, partition specifications, and sort orders. This field is populated for Iceberg tables and reflects the current state of the table's Iceberg metadata.

pub fn set_iceberg_table_metadata( self, input: Option<IcebergTableMetadata>, ) -> Self

The latest Apache Iceberg table metadata for the table, including format version, schemas, partition specifications, and sort orders. This field is populated for Iceberg tables and reflects the current state of the table's Iceberg metadata.

pub fn get_iceberg_table_metadata(&self) -> &Option<IcebergTableMetadata>

The latest Apache Iceberg table metadata for the table, including format version, schemas, partition specifications, and sort orders. This field is populated for Iceberg tables and reflects the current state of the table's Iceberg metadata.

pub fn status(self, input: TableStatus) -> Self

Indicates the the state of an asynchronous change to a table.

pub fn set_status(self, input: Option<TableStatus>) -> Self

Indicates the the state of an asynchronous change to a table.

pub fn get_status(&self) -> &Option<TableStatus>

Indicates the the state of an asynchronous change to a table.

pub fn build(self) -> Result<Table, BuildError>

Consumes the builder and constructs a Table. This method will fail if any of the following fields are not set: