TableOptimizerRunBuilder

Struct TableOptimizerRunBuilder 

#[non_exhaustive]
pub struct TableOptimizerRunBuilder { /* private fields */ }
A builder for TableOptimizerRun.

Implementations

Source

impl TableOptimizerRunBuilder

pub fn event_type(self, input: TableOptimizerEventType) -> Self

An event type representing the status of the table optimizer run.

pub fn set_event_type(self, input: Option<TableOptimizerEventType>) -> Self

An event type representing the status of the table optimizer run.

pub fn get_event_type(&self) -> &Option<TableOptimizerEventType>

An event type representing the status of the table optimizer run.

pub fn start_timestamp(self, input: DateTime) -> Self

Represents the epoch timestamp at which the compaction job was started within Lake Formation.

pub fn set_start_timestamp(self, input: Option<DateTime>) -> Self

Represents the epoch timestamp at which the compaction job was started within Lake Formation.

pub fn get_start_timestamp(&self) -> &Option<DateTime>

Represents the epoch timestamp at which the compaction job was started within Lake Formation.

pub fn end_timestamp(self, input: DateTime) -> Self

Represents the epoch timestamp at which the compaction job ended.

pub fn set_end_timestamp(self, input: Option<DateTime>) -> Self

Represents the epoch timestamp at which the compaction job ended.

pub fn get_end_timestamp(&self) -> &Option<DateTime>

Represents the epoch timestamp at which the compaction job ended.

pub fn metrics(self, input: RunMetrics) -> Self

👎Deprecated:

Metrics has been replaced by optimizer type specific metrics such as IcebergCompactionMetrics

A RunMetrics object containing metrics for the optimizer run.

This member is deprecated. See the individual metric members for compaction, retention, and orphan file deletion.

pub fn set_metrics(self, input: Option<RunMetrics>) -> Self

👎Deprecated:

Metrics has been replaced by optimizer type specific metrics such as IcebergCompactionMetrics

A RunMetrics object containing metrics for the optimizer run.

This member is deprecated. See the individual metric members for compaction, retention, and orphan file deletion.

pub fn get_metrics(&self) -> &Option<RunMetrics>

👎Deprecated:

Metrics has been replaced by optimizer type specific metrics such as IcebergCompactionMetrics

A RunMetrics object containing metrics for the optimizer run.

This member is deprecated. See the individual metric members for compaction, retention, and orphan file deletion.

pub fn error(self, input: impl Into<String>) -> Self

An error that occured during the optimizer run.

pub fn set_error(self, input: Option<String>) -> Self

An error that occured during the optimizer run.

pub fn get_error(&self) -> &Option<String>

An error that occured during the optimizer run.

pub fn compaction_metrics(self, input: CompactionMetrics) -> Self

A CompactionMetrics object containing metrics for the optimizer run.

pub fn set_compaction_metrics(self, input: Option<CompactionMetrics>) -> Self

A CompactionMetrics object containing metrics for the optimizer run.

pub fn get_compaction_metrics(&self) -> &Option<CompactionMetrics>

A CompactionMetrics object containing metrics for the optimizer run.

pub fn compaction_strategy(self, input: CompactionStrategy) -> Self

The strategy used for the compaction run. Indicates which algorithm was applied to determine how files were selected and combined during the compaction process. Valid values are:

  • binpack: Combines small files into larger files, typically targeting sizes over 100MB, while applying any pending deletes. This is the recommended compaction strategy for most use cases.

  • sort: Organizes data based on specified columns which are sorted hierarchically during compaction, improving query performance for filtered operations. This strategy is recommended when your queries frequently filter on specific columns. To use this strategy, you must first define a sort order in your Iceberg table properties using the sort_order table property.

  • z-order: Optimizes data organization by blending multiple attributes into a single scalar value that can be used for sorting, allowing efficient querying across multiple dimensions. This strategy is recommended when you need to query data across multiple dimensions simultaneously. To use this strategy, you must first define a sort order in your Iceberg table properties using the sort_order table property.

pub fn set_compaction_strategy(self, input: Option<CompactionStrategy>) -> Self

The strategy used for the compaction run. Indicates which algorithm was applied to determine how files were selected and combined during the compaction process. Valid values are:

  • binpack: Combines small files into larger files, typically targeting sizes over 100MB, while applying any pending deletes. This is the recommended compaction strategy for most use cases.

  • sort: Organizes data based on specified columns which are sorted hierarchically during compaction, improving query performance for filtered operations. This strategy is recommended when your queries frequently filter on specific columns. To use this strategy, you must first define a sort order in your Iceberg table properties using the sort_order table property.

  • z-order: Optimizes data organization by blending multiple attributes into a single scalar value that can be used for sorting, allowing efficient querying across multiple dimensions. This strategy is recommended when you need to query data across multiple dimensions simultaneously. To use this strategy, you must first define a sort order in your Iceberg table properties using the sort_order table property.

pub fn get_compaction_strategy(&self) -> &Option<CompactionStrategy>

The strategy used for the compaction run. Indicates which algorithm was applied to determine how files were selected and combined during the compaction process. Valid values are:

  • binpack: Combines small files into larger files, typically targeting sizes over 100MB, while applying any pending deletes. This is the recommended compaction strategy for most use cases.

  • sort: Organizes data based on specified columns which are sorted hierarchically during compaction, improving query performance for filtered operations. This strategy is recommended when your queries frequently filter on specific columns. To use this strategy, you must first define a sort order in your Iceberg table properties using the sort_order table property.

  • z-order: Optimizes data organization by blending multiple attributes into a single scalar value that can be used for sorting, allowing efficient querying across multiple dimensions. This strategy is recommended when you need to query data across multiple dimensions simultaneously. To use this strategy, you must first define a sort order in your Iceberg table properties using the sort_order table property.

pub fn retention_metrics(self, input: RetentionMetrics) -> Self

A RetentionMetrics object containing metrics for the optimizer run.

pub fn set_retention_metrics(self, input: Option<RetentionMetrics>) -> Self

A RetentionMetrics object containing metrics for the optimizer run.

pub fn get_retention_metrics(&self) -> &Option<RetentionMetrics>

A RetentionMetrics object containing metrics for the optimizer run.

pub fn orphan_file_deletion_metrics( self, input: OrphanFileDeletionMetrics, ) -> Self

An OrphanFileDeletionMetrics object containing metrics for the optimizer run.

pub fn set_orphan_file_deletion_metrics( self, input: Option<OrphanFileDeletionMetrics>, ) -> Self

An OrphanFileDeletionMetrics object containing metrics for the optimizer run.

pub fn get_orphan_file_deletion_metrics( &self, ) -> &Option<OrphanFileDeletionMetrics>

An OrphanFileDeletionMetrics object containing metrics for the optimizer run.

pub fn build(self) -> TableOptimizerRun

Consumes the builder and constructs a TableOptimizerRun.