#[non_exhaustive]pub struct TargetProcessingPropertiesBuilder { /* private fields */ }Expand description
A builder for TargetProcessingProperties.
Implementations
Sourceimpl TargetProcessingPropertiesBuilder
impl TargetProcessingPropertiesBuilder
Sourcepub fn role_arn(self, input: impl Into<String>) -> Self
pub fn role_arn(self, input: impl Into<String>) -> Self
The IAM role to access the Glue database.
Sourcepub fn set_role_arn(self, input: Option<String>) -> Self
pub fn set_role_arn(self, input: Option<String>) -> Self
The IAM role to access the Glue database.
Sourcepub fn get_role_arn(&self) -> &Option<String>
pub fn get_role_arn(&self) -> &Option<String>
The IAM role to access the Glue database.
Sourcepub fn kms_arn(self, input: impl Into<String>) -> Self
pub fn kms_arn(self, input: impl Into<String>) -> Self
The ARN of the KMS key used for encryption.
Sourcepub fn set_kms_arn(self, input: Option<String>) -> Self
pub fn set_kms_arn(self, input: Option<String>) -> Self
The ARN of the KMS key used for encryption.
Sourcepub fn get_kms_arn(&self) -> &Option<String>
pub fn get_kms_arn(&self) -> &Option<String>
The ARN of the KMS key used for encryption.
Sourcepub fn connection_name(self, input: impl Into<String>) -> Self
pub fn connection_name(self, input: impl Into<String>) -> Self
The Glue network connection to configure the Glue job running in the customer VPC.
Sourcepub fn set_connection_name(self, input: Option<String>) -> Self
pub fn set_connection_name(self, input: Option<String>) -> Self
The Glue network connection to configure the Glue job running in the customer VPC.
Sourcepub fn get_connection_name(&self) -> &Option<String>
pub fn get_connection_name(&self) -> &Option<String>
The Glue network connection to configure the Glue job running in the customer VPC.
Sourcepub fn event_bus_arn(self, input: impl Into<String>) -> Self
pub fn event_bus_arn(self, input: impl Into<String>) -> Self
The ARN of an Eventbridge event bus to receive the integration status notification.
Sourcepub fn set_event_bus_arn(self, input: Option<String>) -> Self
pub fn set_event_bus_arn(self, input: Option<String>) -> Self
The ARN of an Eventbridge event bus to receive the integration status notification.
Sourcepub fn get_event_bus_arn(&self) -> &Option<String>
pub fn get_event_bus_arn(&self) -> &Option<String>
The ARN of an Eventbridge event bus to receive the integration status notification.
Sourcepub fn build(self) -> TargetProcessingProperties
pub fn build(self) -> TargetProcessingProperties
Consumes the builder and constructs a TargetProcessingProperties.