#[non_exhaustive]pub struct TestConnectionInputBuilder { /* private fields */ }Expand description
A builder for TestConnectionInput.
Implementations
Sourceimpl TestConnectionInputBuilder
impl TestConnectionInputBuilder
Sourcepub fn connection_type(self, input: ConnectionType) -> Self
pub fn connection_type(self, input: ConnectionType) -> Self
The type of connection to test. This operation is only available for the JDBC or SALESFORCE connection types.
Sourcepub fn set_connection_type(self, input: Option<ConnectionType>) -> Self
pub fn set_connection_type(self, input: Option<ConnectionType>) -> Self
The type of connection to test. This operation is only available for the JDBC or SALESFORCE connection types.
Sourcepub fn get_connection_type(&self) -> &Option<ConnectionType>
pub fn get_connection_type(&self) -> &Option<ConnectionType>
The type of connection to test. This operation is only available for the JDBC or SALESFORCE connection types.
Sourcepub fn connection_properties(
self,
k: ConnectionPropertyKey,
v: impl Into<String>,
) -> Self
pub fn connection_properties( self, k: ConnectionPropertyKey, v: impl Into<String>, ) -> Self
Adds a key-value pair to connection_properties.
To override the contents of this collection use set_connection_properties.
The key-value pairs that define parameters for the connection.
JDBC connections use the following connection properties:
-
Required: All of (
HOST,PORT,JDBC_ENGINE) orJDBC_CONNECTION_URL. -
Required: All of (
USERNAME,PASSWORD) orSECRET_ID. -
Optional:
JDBC_ENFORCE_SSL,CUSTOM_JDBC_CERT,CUSTOM_JDBC_CERT_STRING,SKIP_CUSTOM_JDBC_CERT_VALIDATION. These parameters are used to configure SSL with JDBC.
SALESFORCE connections require the AuthenticationConfiguration member to be configured.
Sourcepub fn set_connection_properties(
self,
input: Option<HashMap<ConnectionPropertyKey, String>>,
) -> Self
pub fn set_connection_properties( self, input: Option<HashMap<ConnectionPropertyKey, String>>, ) -> Self
The key-value pairs that define parameters for the connection.
JDBC connections use the following connection properties:
-
Required: All of (
HOST,PORT,JDBC_ENGINE) orJDBC_CONNECTION_URL. -
Required: All of (
USERNAME,PASSWORD) orSECRET_ID. -
Optional:
JDBC_ENFORCE_SSL,CUSTOM_JDBC_CERT,CUSTOM_JDBC_CERT_STRING,SKIP_CUSTOM_JDBC_CERT_VALIDATION. These parameters are used to configure SSL with JDBC.
SALESFORCE connections require the AuthenticationConfiguration member to be configured.
Sourcepub fn get_connection_properties(
&self,
) -> &Option<HashMap<ConnectionPropertyKey, String>>
pub fn get_connection_properties( &self, ) -> &Option<HashMap<ConnectionPropertyKey, String>>
The key-value pairs that define parameters for the connection.
JDBC connections use the following connection properties:
-
Required: All of (
HOST,PORT,JDBC_ENGINE) orJDBC_CONNECTION_URL. -
Required: All of (
USERNAME,PASSWORD) orSECRET_ID. -
Optional:
JDBC_ENFORCE_SSL,CUSTOM_JDBC_CERT,CUSTOM_JDBC_CERT_STRING,SKIP_CUSTOM_JDBC_CERT_VALIDATION. These parameters are used to configure SSL with JDBC.
SALESFORCE connections require the AuthenticationConfiguration member to be configured.
Sourcepub fn authentication_configuration(
self,
input: AuthenticationConfigurationInput,
) -> Self
pub fn authentication_configuration( self, input: AuthenticationConfigurationInput, ) -> Self
A structure containing the authentication configuration in the TestConnection request. Required for a connection to Salesforce using OAuth authentication.
Sourcepub fn set_authentication_configuration(
self,
input: Option<AuthenticationConfigurationInput>,
) -> Self
pub fn set_authentication_configuration( self, input: Option<AuthenticationConfigurationInput>, ) -> Self
A structure containing the authentication configuration in the TestConnection request. Required for a connection to Salesforce using OAuth authentication.
Sourcepub fn get_authentication_configuration(
&self,
) -> &Option<AuthenticationConfigurationInput>
pub fn get_authentication_configuration( &self, ) -> &Option<AuthenticationConfigurationInput>
A structure containing the authentication configuration in the TestConnection request. Required for a connection to Salesforce using OAuth authentication.
Sourcepub fn build(self) -> Result<TestConnectionInput, BuildError>
pub fn build(self) -> Result<TestConnectionInput, BuildError>
Consumes the builder and constructs a TestConnectionInput.
This method will fail if any of the following fields are not set: