#[non_exhaustive]pub struct TimestampedInclusionAnnotationBuilder { /* private fields */ }Expand description
A builder for TimestampedInclusionAnnotation.
Implementations
Sourceimpl TimestampedInclusionAnnotationBuilder
impl TimestampedInclusionAnnotationBuilder
Sourcepub fn value(self, input: InclusionAnnotationValue) -> Self
pub fn value(self, input: InclusionAnnotationValue) -> Self
The inclusion annotation value.
Sourcepub fn set_value(self, input: Option<InclusionAnnotationValue>) -> Self
pub fn set_value(self, input: Option<InclusionAnnotationValue>) -> Self
The inclusion annotation value.
Sourcepub fn get_value(&self) -> &Option<InclusionAnnotationValue>
pub fn get_value(&self) -> &Option<InclusionAnnotationValue>
The inclusion annotation value.
Sourcepub fn last_modified_on(self, input: DateTime) -> Self
pub fn last_modified_on(self, input: DateTime) -> Self
The timestamp when the inclusion annotation was last modified.
Sourcepub fn set_last_modified_on(self, input: Option<DateTime>) -> Self
pub fn set_last_modified_on(self, input: Option<DateTime>) -> Self
The timestamp when the inclusion annotation was last modified.
Sourcepub fn get_last_modified_on(&self) -> &Option<DateTime>
pub fn get_last_modified_on(&self) -> &Option<DateTime>
The timestamp when the inclusion annotation was last modified.
Sourcepub fn build(self) -> TimestampedInclusionAnnotation
pub fn build(self) -> TimestampedInclusionAnnotation
Consumes the builder and constructs a TimestampedInclusionAnnotation.