#[non_exhaustive]pub struct UpdateIcebergInputBuilder { /* private fields */ }Expand description
A builder for UpdateIcebergInput.
Implementations
Sourceimpl UpdateIcebergInputBuilder
impl UpdateIcebergInputBuilder
Sourcepub fn update_iceberg_table_input(self, input: UpdateIcebergTableInput) -> Self
pub fn update_iceberg_table_input(self, input: UpdateIcebergTableInput) -> Self
The specific update operations to be applied to the Iceberg table, containing a list of updates that define the new state of the table including schema, partitions, and properties.
This field is required.Sourcepub fn set_update_iceberg_table_input(
self,
input: Option<UpdateIcebergTableInput>,
) -> Self
pub fn set_update_iceberg_table_input( self, input: Option<UpdateIcebergTableInput>, ) -> Self
The specific update operations to be applied to the Iceberg table, containing a list of updates that define the new state of the table including schema, partitions, and properties.
Sourcepub fn get_update_iceberg_table_input(&self) -> &Option<UpdateIcebergTableInput>
pub fn get_update_iceberg_table_input(&self) -> &Option<UpdateIcebergTableInput>
The specific update operations to be applied to the Iceberg table, containing a list of updates that define the new state of the table including schema, partitions, and properties.
Sourcepub fn build(self) -> UpdateIcebergInput
pub fn build(self) -> UpdateIcebergInput
Consumes the builder and constructs a UpdateIcebergInput.