#[non_exhaustive]pub struct UpdateIcebergTableInputBuilder { /* private fields */ }Expand description
A builder for UpdateIcebergTableInput.
Implementations
Sourceimpl UpdateIcebergTableInputBuilder
impl UpdateIcebergTableInputBuilder
Sourcepub fn updates(self, input: IcebergTableUpdate) -> Self
pub fn updates(self, input: IcebergTableUpdate) -> Self
Appends an item to updates.
To override the contents of this collection use set_updates.
The list of table update operations that specify the changes to be made to the Iceberg table, including schema modifications, partition specifications, and table properties.
Sourcepub fn set_updates(self, input: Option<Vec<IcebergTableUpdate>>) -> Self
pub fn set_updates(self, input: Option<Vec<IcebergTableUpdate>>) -> Self
The list of table update operations that specify the changes to be made to the Iceberg table, including schema modifications, partition specifications, and table properties.
Sourcepub fn get_updates(&self) -> &Option<Vec<IcebergTableUpdate>>
pub fn get_updates(&self) -> &Option<Vec<IcebergTableUpdate>>
The list of table update operations that specify the changes to be made to the Iceberg table, including schema modifications, partition specifications, and table properties.
Sourcepub fn build(self) -> Result<UpdateIcebergTableInput, BuildError>
pub fn build(self) -> Result<UpdateIcebergTableInput, BuildError>
Consumes the builder and constructs a UpdateIcebergTableInput.
This method will fail if any of the following fields are not set: