#[non_exhaustive]pub struct UsageProfileDefinitionBuilder { /* private fields */ }Expand description
A builder for UsageProfileDefinition.
Implementations
Sourceimpl UsageProfileDefinitionBuilder
impl UsageProfileDefinitionBuilder
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
A description of the usage profile.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
A description of the usage profile.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
A description of the usage profile.
Sourcepub fn created_on(self, input: DateTime) -> Self
pub fn created_on(self, input: DateTime) -> Self
The date and time when the usage profile was created.
Sourcepub fn set_created_on(self, input: Option<DateTime>) -> Self
pub fn set_created_on(self, input: Option<DateTime>) -> Self
The date and time when the usage profile was created.
Sourcepub fn get_created_on(&self) -> &Option<DateTime>
pub fn get_created_on(&self) -> &Option<DateTime>
The date and time when the usage profile was created.
Sourcepub fn last_modified_on(self, input: DateTime) -> Self
pub fn last_modified_on(self, input: DateTime) -> Self
The date and time when the usage profile was last modified.
Sourcepub fn set_last_modified_on(self, input: Option<DateTime>) -> Self
pub fn set_last_modified_on(self, input: Option<DateTime>) -> Self
The date and time when the usage profile was last modified.
Sourcepub fn get_last_modified_on(&self) -> &Option<DateTime>
pub fn get_last_modified_on(&self) -> &Option<DateTime>
The date and time when the usage profile was last modified.
Sourcepub fn build(self) -> UsageProfileDefinition
pub fn build(self) -> UsageProfileDefinition
Consumes the builder and constructs a UsageProfileDefinition.