#[non_exhaustive]pub struct ViewDefinitionBuilder { /* private fields */ }Expand description
A builder for ViewDefinition.
Implementations
Sourceimpl ViewDefinitionBuilder
impl ViewDefinitionBuilder
Sourcepub fn is_protected(self, input: bool) -> Self
pub fn is_protected(self, input: bool) -> Self
You can set this flag as true to instruct the engine not to push user-provided operations into the logical plan of the view during query planning. However, setting this flag does not guarantee that the engine will comply. Refer to the engine's documentation to understand the guarantees provided, if any.
Sourcepub fn set_is_protected(self, input: Option<bool>) -> Self
pub fn set_is_protected(self, input: Option<bool>) -> Self
You can set this flag as true to instruct the engine not to push user-provided operations into the logical plan of the view during query planning. However, setting this flag does not guarantee that the engine will comply. Refer to the engine's documentation to understand the guarantees provided, if any.
Sourcepub fn get_is_protected(&self) -> &Option<bool>
pub fn get_is_protected(&self) -> &Option<bool>
You can set this flag as true to instruct the engine not to push user-provided operations into the logical plan of the view during query planning. However, setting this flag does not guarantee that the engine will comply. Refer to the engine's documentation to understand the guarantees provided, if any.
Sourcepub fn set_definer(self, input: Option<String>) -> Self
pub fn set_definer(self, input: Option<String>) -> Self
The definer of a view in SQL.
Sourcepub fn get_definer(&self) -> &Option<String>
pub fn get_definer(&self) -> &Option<String>
The definer of a view in SQL.
Sourcepub fn view_version_id(self, input: i64) -> Self
pub fn view_version_id(self, input: i64) -> Self
The ID value that identifies this view's version. For materialized views, the version ID is the Apache Iceberg table's snapshot ID.
Sourcepub fn set_view_version_id(self, input: Option<i64>) -> Self
pub fn set_view_version_id(self, input: Option<i64>) -> Self
The ID value that identifies this view's version. For materialized views, the version ID is the Apache Iceberg table's snapshot ID.
Sourcepub fn get_view_version_id(&self) -> &Option<i64>
pub fn get_view_version_id(&self) -> &Option<i64>
The ID value that identifies this view's version. For materialized views, the version ID is the Apache Iceberg table's snapshot ID.
Sourcepub fn view_version_token(self, input: impl Into<String>) -> Self
pub fn view_version_token(self, input: impl Into<String>) -> Self
The version ID of the Apache Iceberg table.
Sourcepub fn set_view_version_token(self, input: Option<String>) -> Self
pub fn set_view_version_token(self, input: Option<String>) -> Self
The version ID of the Apache Iceberg table.
Sourcepub fn get_view_version_token(&self) -> &Option<String>
pub fn get_view_version_token(&self) -> &Option<String>
The version ID of the Apache Iceberg table.
Sourcepub fn refresh_seconds(self, input: i64) -> Self
pub fn refresh_seconds(self, input: i64) -> Self
Auto refresh interval in seconds for the materialized view. If not specified, the view will not automatically refresh.
Sourcepub fn set_refresh_seconds(self, input: Option<i64>) -> Self
pub fn set_refresh_seconds(self, input: Option<i64>) -> Self
Auto refresh interval in seconds for the materialized view. If not specified, the view will not automatically refresh.
Sourcepub fn get_refresh_seconds(&self) -> &Option<i64>
pub fn get_refresh_seconds(&self) -> &Option<i64>
Auto refresh interval in seconds for the materialized view. If not specified, the view will not automatically refresh.
Sourcepub fn last_refresh_type(self, input: LastRefreshType) -> Self
pub fn last_refresh_type(self, input: LastRefreshType) -> Self
Sets the method used for the most recent refresh.
Sourcepub fn set_last_refresh_type(self, input: Option<LastRefreshType>) -> Self
pub fn set_last_refresh_type(self, input: Option<LastRefreshType>) -> Self
Sets the method used for the most recent refresh.
Sourcepub fn get_last_refresh_type(&self) -> &Option<LastRefreshType>
pub fn get_last_refresh_type(&self) -> &Option<LastRefreshType>
Sets the method used for the most recent refresh.
Sourcepub fn sub_objects(self, input: impl Into<String>) -> Self
pub fn sub_objects(self, input: impl Into<String>) -> Self
Appends an item to sub_objects.
To override the contents of this collection use set_sub_objects.
A list of table Amazon Resource Names (ARNs).
Sourcepub fn set_sub_objects(self, input: Option<Vec<String>>) -> Self
pub fn set_sub_objects(self, input: Option<Vec<String>>) -> Self
A list of table Amazon Resource Names (ARNs).
Sourcepub fn get_sub_objects(&self) -> &Option<Vec<String>>
pub fn get_sub_objects(&self) -> &Option<Vec<String>>
A list of table Amazon Resource Names (ARNs).
Sourcepub fn sub_object_version_ids(self, input: i64) -> Self
pub fn sub_object_version_ids(self, input: i64) -> Self
Appends an item to sub_object_version_ids.
To override the contents of this collection use set_sub_object_version_ids.
List of the Apache Iceberg table versions referenced by the materialized view.
Sourcepub fn set_sub_object_version_ids(self, input: Option<Vec<i64>>) -> Self
pub fn set_sub_object_version_ids(self, input: Option<Vec<i64>>) -> Self
List of the Apache Iceberg table versions referenced by the materialized view.
Sourcepub fn get_sub_object_version_ids(&self) -> &Option<Vec<i64>>
pub fn get_sub_object_version_ids(&self) -> &Option<Vec<i64>>
List of the Apache Iceberg table versions referenced by the materialized view.
Sourcepub fn representations(self, input: ViewRepresentation) -> Self
pub fn representations(self, input: ViewRepresentation) -> Self
Appends an item to representations.
To override the contents of this collection use set_representations.
A list of representations.
Sourcepub fn set_representations(self, input: Option<Vec<ViewRepresentation>>) -> Self
pub fn set_representations(self, input: Option<Vec<ViewRepresentation>>) -> Self
A list of representations.
Sourcepub fn get_representations(&self) -> &Option<Vec<ViewRepresentation>>
pub fn get_representations(&self) -> &Option<Vec<ViewRepresentation>>
A list of representations.
Sourcepub fn build(self) -> ViewDefinition
pub fn build(self) -> ViewDefinition
Consumes the builder and constructs a ViewDefinition.