#[non_exhaustive]pub struct ViewValidationBuilder { /* private fields */ }Expand description
A builder for ViewValidation.
Implementations
Sourceimpl ViewValidationBuilder
impl ViewValidationBuilder
Sourcepub fn dialect(self, input: ViewDialect) -> Self
pub fn dialect(self, input: ViewDialect) -> Self
The dialect of the query engine.
Sourcepub fn set_dialect(self, input: Option<ViewDialect>) -> Self
pub fn set_dialect(self, input: Option<ViewDialect>) -> Self
The dialect of the query engine.
Sourcepub fn get_dialect(&self) -> &Option<ViewDialect>
pub fn get_dialect(&self) -> &Option<ViewDialect>
The dialect of the query engine.
Sourcepub fn dialect_version(self, input: impl Into<String>) -> Self
pub fn dialect_version(self, input: impl Into<String>) -> Self
The version of the dialect of the query engine. For example, 3.0.0.
Sourcepub fn set_dialect_version(self, input: Option<String>) -> Self
pub fn set_dialect_version(self, input: Option<String>) -> Self
The version of the dialect of the query engine. For example, 3.0.0.
Sourcepub fn get_dialect_version(&self) -> &Option<String>
pub fn get_dialect_version(&self) -> &Option<String>
The version of the dialect of the query engine. For example, 3.0.0.
Sourcepub fn view_validation_text(self, input: impl Into<String>) -> Self
pub fn view_validation_text(self, input: impl Into<String>) -> Self
The SELECT query that defines the view, as provided by the customer.
Sourcepub fn set_view_validation_text(self, input: Option<String>) -> Self
pub fn set_view_validation_text(self, input: Option<String>) -> Self
The SELECT query that defines the view, as provided by the customer.
Sourcepub fn get_view_validation_text(&self) -> &Option<String>
pub fn get_view_validation_text(&self) -> &Option<String>
The SELECT query that defines the view, as provided by the customer.
Sourcepub fn update_time(self, input: DateTime) -> Self
pub fn update_time(self, input: DateTime) -> Self
The time of the last update.
Sourcepub fn set_update_time(self, input: Option<DateTime>) -> Self
pub fn set_update_time(self, input: Option<DateTime>) -> Self
The time of the last update.
Sourcepub fn get_update_time(&self) -> &Option<DateTime>
pub fn get_update_time(&self) -> &Option<DateTime>
The time of the last update.
Sourcepub fn state(self, input: ResourceState) -> Self
pub fn state(self, input: ResourceState) -> Self
The state of the validation.
Sourcepub fn set_state(self, input: Option<ResourceState>) -> Self
pub fn set_state(self, input: Option<ResourceState>) -> Self
The state of the validation.
Sourcepub fn get_state(&self) -> &Option<ResourceState>
pub fn get_state(&self) -> &Option<ResourceState>
The state of the validation.
Sourcepub fn error(self, input: ErrorDetail) -> Self
pub fn error(self, input: ErrorDetail) -> Self
An error associated with the validation.
Sourcepub fn set_error(self, input: Option<ErrorDetail>) -> Self
pub fn set_error(self, input: Option<ErrorDetail>) -> Self
An error associated with the validation.
Sourcepub fn get_error(&self) -> &Option<ErrorDetail>
pub fn get_error(&self) -> &Option<ErrorDetail>
An error associated with the validation.
Sourcepub fn build(self) -> ViewValidation
pub fn build(self) -> ViewValidation
Consumes the builder and constructs a ViewValidation.