#[non_exhaustive]pub enum QuoteChar {
Disabled,
Quillemet,
Quote,
SingleQuote,
Unknown(UnknownVariantValue),
}Expand description
When writing a match expression against QuoteChar, it is important to ensure
your code is forward-compatible. That is, if a match arm handles a case for a
feature that is supported by the service but has not been represented as an enum
variant in a current version of SDK, your code should continue to work when you
upgrade SDK to a future version in which the enum does include a variant for that
feature.
Here is an example of how you can make a match expression forward-compatible:
# let quotechar = unimplemented!();
match quotechar {
QuoteChar::Disabled => { /* ... */ },
QuoteChar::Quillemet => { /* ... */ },
QuoteChar::Quote => { /* ... */ },
QuoteChar::SingleQuote => { /* ... */ },
other @ _ if other.as_str() == "NewFeature" => { /* handles a case for `NewFeature` */ },
_ => { /* ... */ },
}The above code demonstrates that when quotechar represents
NewFeature, the execution path will lead to the second last match arm,
even though the enum does not contain a variant QuoteChar::NewFeature
in the current version of SDK. The reason is that the variable other,
created by the @ operator, is bound to
QuoteChar::Unknown(UnknownVariantValue("NewFeature".to_owned()))
and calling as_str on it yields "NewFeature".
This match expression is forward-compatible when executed with a newer
version of SDK where the variant QuoteChar::NewFeature is defined.
Specifically, when quotechar represents NewFeature,
the execution path will hit the second last match arm as before by virtue of
calling as_str on QuoteChar::NewFeature also yielding "NewFeature".
Explicitly matching on the Unknown variant should
be avoided for two reasons:
- The inner data
UnknownVariantValueis opaque, and no further information can be extracted. - It might inadvertently shadow other intended match arms.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Disabled
Quillemet
Quote
SingleQuote
Unknown(UnknownVariantValue)
Don’t directly match on Unknown. See the docs on this enum for the correct way to handle unknown variants.
Unknown contains new variants that have been added since this code was generated.
Implementations