#[non_exhaustive]pub enum TableOptimizerVpcConfiguration {
GlueConnectionName(String),
#[non_exhaustive] Unknown,
}Expand description
An object that describes the VPC configuration for a table optimizer.
This configuration is necessary to perform optimization on tables that are in a customer VPC.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
GlueConnectionName(String)
The name of the Glue connection used for the VPC for the table optimizer.
#[non_exhaustive]Unknown
The Unknown variant represents cases where new union variant was received. Consider upgrading the SDK to the latest available version.
An unknown enum variant
Note: If you encounter this error, consider upgrading your SDK to the latest version.
The Unknown variant represents cases where the server sent a value that wasn’t recognized
by the client. This can happen when the server adds new functionality, but the client has not been updated.
To investigate this, consider turning on debug logging to print the raw HTTP response.
Implementations
Sourceimpl TableOptimizerVpcConfiguration
impl TableOptimizerVpcConfiguration
Sourcepub fn as_glue_connection_name(&self) -> Result<&String, &Self>
pub fn as_glue_connection_name(&self) -> Result<&String, &Self>
Tries to convert the enum instance into GlueConnectionName, extracting the inner String.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_glue_connection_name(&self) -> bool
pub fn is_glue_connection_name(&self) -> bool
Returns true if this is a GlueConnectionName.
Sourcepub fn is_unknown(&self) -> bool
pub fn is_unknown(&self) -> bool
Returns true if the enum instance is the Unknown variant.