#[non_exhaustive]pub struct AssetFormEntry {
pub form_type_id: Option<String>,
pub content: Option<String>,
}Expand description
A form on an asset, consisting of the form type identifier and its JSON content.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.form_type_id: Option<String>The identifier of the form type that defines this form's schema.
content: Option<String>The JSON content of the form, conforming to the schema of the specified form type.
Implementations
Sourceimpl AssetFormEntry
impl AssetFormEntry
Sourcepub fn builder() -> AssetFormEntryBuilder
pub fn builder() -> AssetFormEntryBuilder
Creates a new builder-style object to manufacture AssetFormEntry.