AuthenticationConfiguration

Struct AuthenticationConfiguration 

#[non_exhaustive]
pub struct AuthenticationConfiguration { pub authentication_type: Option<AuthenticationType>, pub secret_arn: Option<String>, pub kms_key_arn: Option<String>, pub o_auth2_properties: Option<OAuth2Properties>, }
A structure containing the authentication configuration.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
authentication_type: Option<AuthenticationType>

A structure containing the authentication configuration.

secret_arn: Option<String>

The secret manager ARN to store credentials.

kms_key_arn: Option<String>

The Amazon Resource Name (ARN) of the KMS key used to encrypt sensitive authentication information. This key is used to protect credentials and other sensitive data stored within the authentication configuration.

o_auth2_properties: Option<OAuth2Properties>

The properties for OAuth2 authentication.

Implementations

Source

impl AuthenticationConfiguration

pub fn authentication_type(&self) -> Option<&AuthenticationType>

A structure containing the authentication configuration.

pub fn secret_arn(&self) -> Option<&str>

The secret manager ARN to store credentials.

pub fn kms_key_arn(&self) -> Option<&str>

The Amazon Resource Name (ARN) of the KMS key used to encrypt sensitive authentication information. This key is used to protect credentials and other sensitive data stored within the authentication configuration.

pub fn o_auth2_properties(&self) -> Option<&OAuth2Properties>

The properties for OAuth2 authentication.

Source

impl AuthenticationConfiguration

pub fn builder() -> AuthenticationConfigurationBuilder

Creates a new builder-style object to manufacture AuthenticationConfiguration.