AuthenticationConfigurationInput

Struct AuthenticationConfigurationInput 

#[non_exhaustive]
pub struct AuthenticationConfigurationInput { pub authentication_type: Option<AuthenticationType>, pub o_auth2_properties: Option<OAuth2PropertiesInput>, pub secret_arn: Option<String>, pub kms_key_arn: Option<String>, pub basic_authentication_credentials: Option<BasicAuthenticationCredentials>, pub custom_authentication_credentials: Option<HashMap<String, String>>, }
A structure containing the authentication configuration in the CreateConnection request.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
authentication_type: Option<AuthenticationType>

A structure containing the authentication configuration in the CreateConnection request.

o_auth2_properties: Option<OAuth2PropertiesInput>

The properties for OAuth2 authentication in the CreateConnection request.

secret_arn: Option<String>

The secret manager ARN to store credentials in the CreateConnection request.

kms_key_arn: Option<String>

The ARN of the KMS key used to encrypt the connection. Only taken an as input in the request and stored in the Secret Manager.

basic_authentication_credentials: Option<BasicAuthenticationCredentials>

The credentials used when the authentication type is basic authentication.

custom_authentication_credentials: Option<HashMap<String, String>>

The credentials used when the authentication type is custom authentication.

Implementations

Source

impl AuthenticationConfigurationInput

pub fn authentication_type(&self) -> Option<&AuthenticationType>

A structure containing the authentication configuration in the CreateConnection request.

pub fn o_auth2_properties(&self) -> Option<&OAuth2PropertiesInput>

The properties for OAuth2 authentication in the CreateConnection request.

pub fn secret_arn(&self) -> Option<&str>

The secret manager ARN to store credentials in the CreateConnection request.

pub fn kms_key_arn(&self) -> Option<&str>

The ARN of the KMS key used to encrypt the connection. Only taken an as input in the request and stored in the Secret Manager.

pub fn basic_authentication_credentials( &self, ) -> Option<&BasicAuthenticationCredentials>

The credentials used when the authentication type is basic authentication.

pub fn custom_authentication_credentials( &self, ) -> Option<&HashMap<String, String>>

The credentials used when the authentication type is custom authentication.

Source

impl AuthenticationConfigurationInput

pub fn builder() -> AuthenticationConfigurationInputBuilder

Creates a new builder-style object to manufacture AuthenticationConfigurationInput.