#[non_exhaustive]pub struct BetweenConfiguration {
pub low_bound_key: Option<String>,
pub high_bound_key: Option<String>,
pub template: Option<String>,
}Expand description
Configuration that defines how BETWEEN range filter operations are translated into REST API request parameters.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.low_bound_key: Option<String>The parameter name used for the lower bound value in a BETWEEN filter operation.
high_bound_key: Option<String>The parameter name used for the upper bound value in a BETWEEN filter operation.
template: Option<String>A template string for constructing the BETWEEN filter expression.
Implementations
Sourceimpl BetweenConfiguration
impl BetweenConfiguration
Sourcepub fn low_bound_key(&self) -> Option<&str>
pub fn low_bound_key(&self) -> Option<&str>
The parameter name used for the lower bound value in a BETWEEN filter operation.
Sourcepub fn high_bound_key(&self) -> Option<&str>
pub fn high_bound_key(&self) -> Option<&str>
The parameter name used for the upper bound value in a BETWEEN filter operation.
Sourceimpl BetweenConfiguration
impl BetweenConfiguration
Sourcepub fn builder() -> BetweenConfigurationBuilder
pub fn builder() -> BetweenConfigurationBuilder
Creates a new builder-style object to manufacture BetweenConfiguration.