#[non_exhaustive]pub struct ClientCredentialsProperties {
pub token_url: Option<ConnectorProperty>,
pub request_method: Option<HttpMethod>,
pub content_type: Option<ContentType>,
pub client_id: Option<ConnectorProperty>,
pub client_secret: Option<ConnectorProperty>,
pub scope: Option<ConnectorProperty>,
pub token_url_parameters: Option<Vec<ConnectorProperty>>,
}Expand description
OAuth2 client credentials configuration that defines the properties needed for the Client Credentials grant type flow.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.token_url: Option<ConnectorProperty>The token endpoint URL where the client will request access tokens using client credentials.
request_method: Option<HttpMethod>The HTTP method to use when making token requests, typically POST.
content_type: Option<ContentType>The content type to use for token requests, such as application/x-www-form-urlencoded or application/json.
client_id: Option<ConnectorProperty>The OAuth2 client identifier provided by the authorization server.
client_secret: Option<ConnectorProperty>The OAuth2 client secret provided by the authorization server.
scope: Option<ConnectorProperty>The OAuth2 scope that defines the level of access requested for the client credentials flow.
token_url_parameters: Option<Vec<ConnectorProperty>>Additional parameters to include in token URL requests as key-value pairs.
Implementations
Sourceimpl ClientCredentialsProperties
impl ClientCredentialsProperties
Sourcepub fn token_url(&self) -> Option<&ConnectorProperty>
pub fn token_url(&self) -> Option<&ConnectorProperty>
The token endpoint URL where the client will request access tokens using client credentials.
Sourcepub fn request_method(&self) -> Option<&HttpMethod>
pub fn request_method(&self) -> Option<&HttpMethod>
The HTTP method to use when making token requests, typically POST.
Sourcepub fn content_type(&self) -> Option<&ContentType>
pub fn content_type(&self) -> Option<&ContentType>
The content type to use for token requests, such as application/x-www-form-urlencoded or application/json.
Sourcepub fn client_id(&self) -> Option<&ConnectorProperty>
pub fn client_id(&self) -> Option<&ConnectorProperty>
The OAuth2 client identifier provided by the authorization server.
Sourcepub fn client_secret(&self) -> Option<&ConnectorProperty>
pub fn client_secret(&self) -> Option<&ConnectorProperty>
The OAuth2 client secret provided by the authorization server.
Sourcepub fn scope(&self) -> Option<&ConnectorProperty>
pub fn scope(&self) -> Option<&ConnectorProperty>
The OAuth2 scope that defines the level of access requested for the client credentials flow.
Sourcepub fn token_url_parameters(&self) -> &[ConnectorProperty]
pub fn token_url_parameters(&self) -> &[ConnectorProperty]
Additional parameters to include in token URL requests as key-value pairs.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .token_url_parameters.is_none().
Sourceimpl ClientCredentialsProperties
impl ClientCredentialsProperties
Sourcepub fn builder() -> ClientCredentialsPropertiesBuilder
pub fn builder() -> ClientCredentialsPropertiesBuilder
Creates a new builder-style object to manufacture ClientCredentialsProperties.