#[non_exhaustive]pub struct ColumnStatisticsTaskSettings {
pub database_name: Option<String>,
pub table_name: Option<String>,
pub schedule: Option<Schedule>,
pub column_name_list: Option<Vec<String>>,
pub catalog_id: Option<String>,
pub role: Option<String>,
pub sample_size: f64,
pub security_configuration: Option<String>,
pub schedule_type: Option<ScheduleType>,
pub setting_source: Option<SettingSource>,
pub last_execution_attempt: Option<ExecutionAttempt>,
}Expand description
The settings for a column statistics task.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.database_name: Option<String>The name of the database where the table resides.
table_name: Option<String>The name of the table for which to generate column statistics.
schedule: Option<Schedule>A schedule for running the column statistics, specified in CRON syntax.
column_name_list: Option<Vec<String>>A list of column names for which to run statistics.
catalog_id: Option<String>The ID of the Data Catalog in which the database resides.
role: Option<String>The role used for running the column statistics.
sample_size: f64The percentage of data to sample.
security_configuration: Option<String>Name of the security configuration that is used to encrypt CloudWatch logs.
schedule_type: Option<ScheduleType>The type of schedule for a column statistics task. Possible values may be CRON or AUTO.
setting_source: Option<SettingSource>The source of setting the column statistics task. Possible values may be CATALOG or TABLE.
last_execution_attempt: Option<ExecutionAttempt>The last ExecutionAttempt for the column statistics task run.
Implementations
Sourceimpl ColumnStatisticsTaskSettings
impl ColumnStatisticsTaskSettings
Sourcepub fn database_name(&self) -> Option<&str>
pub fn database_name(&self) -> Option<&str>
The name of the database where the table resides.
Sourcepub fn table_name(&self) -> Option<&str>
pub fn table_name(&self) -> Option<&str>
The name of the table for which to generate column statistics.
Sourcepub fn schedule(&self) -> Option<&Schedule>
pub fn schedule(&self) -> Option<&Schedule>
A schedule for running the column statistics, specified in CRON syntax.
Sourcepub fn column_name_list(&self) -> &[String]
pub fn column_name_list(&self) -> &[String]
A list of column names for which to run statistics.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .column_name_list.is_none().
Sourcepub fn catalog_id(&self) -> Option<&str>
pub fn catalog_id(&self) -> Option<&str>
The ID of the Data Catalog in which the database resides.
Sourcepub fn sample_size(&self) -> f64
pub fn sample_size(&self) -> f64
The percentage of data to sample.
Sourcepub fn security_configuration(&self) -> Option<&str>
pub fn security_configuration(&self) -> Option<&str>
Name of the security configuration that is used to encrypt CloudWatch logs.
Sourcepub fn schedule_type(&self) -> Option<&ScheduleType>
pub fn schedule_type(&self) -> Option<&ScheduleType>
The type of schedule for a column statistics task. Possible values may be CRON or AUTO.
Sourcepub fn setting_source(&self) -> Option<&SettingSource>
pub fn setting_source(&self) -> Option<&SettingSource>
The source of setting the column statistics task. Possible values may be CATALOG or TABLE.
Sourcepub fn last_execution_attempt(&self) -> Option<&ExecutionAttempt>
pub fn last_execution_attempt(&self) -> Option<&ExecutionAttempt>
The last ExecutionAttempt for the column statistics task run.
Sourceimpl ColumnStatisticsTaskSettings
impl ColumnStatisticsTaskSettings
Sourcepub fn builder() -> ColumnStatisticsTaskSettingsBuilder
pub fn builder() -> ColumnStatisticsTaskSettingsBuilder
Creates a new builder-style object to manufacture ColumnStatisticsTaskSettings.