#[non_exhaustive]pub struct CompactionConfiguration {
pub iceberg_configuration: Option<IcebergCompactionConfiguration>,
}Expand description
The configuration for a compaction optimizer. This configuration defines how data files in your table will be compacted to improve query performance and reduce storage costs.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.iceberg_configuration: Option<IcebergCompactionConfiguration>The configuration for an Iceberg compaction optimizer.
Implementations
Sourceimpl CompactionConfiguration
impl CompactionConfiguration
Sourcepub fn iceberg_configuration(&self) -> Option<&IcebergCompactionConfiguration>
pub fn iceberg_configuration(&self) -> Option<&IcebergCompactionConfiguration>
The configuration for an Iceberg compaction optimizer.
Sourceimpl CompactionConfiguration
impl CompactionConfiguration
Sourcepub fn builder() -> CompactionConfigurationBuilder
pub fn builder() -> CompactionConfigurationBuilder
Creates a new builder-style object to manufacture CompactionConfiguration.