#[non_exhaustive]pub struct CompactionMetrics {
pub iceberg_metrics: Option<IcebergCompactionMetrics>,
}Expand description
A structure that contains compaction metrics for the optimizer run.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.iceberg_metrics: Option<IcebergCompactionMetrics>A structure containing the Iceberg compaction metrics for the optimizer run.
Implementations
Sourceimpl CompactionMetrics
impl CompactionMetrics
Sourcepub fn iceberg_metrics(&self) -> Option<&IcebergCompactionMetrics>
pub fn iceberg_metrics(&self) -> Option<&IcebergCompactionMetrics>
A structure containing the Iceberg compaction metrics for the optimizer run.
Sourceimpl CompactionMetrics
impl CompactionMetrics
Sourcepub fn builder() -> CompactionMetricsBuilder
pub fn builder() -> CompactionMetricsBuilder
Creates a new builder-style object to manufacture CompactionMetrics.