#[non_exhaustive]pub struct ComputeEnvironmentConfiguration {
pub name: String,
pub description: String,
pub compute_environment: ComputeEnvironment,
pub supported_authentication_types: Vec<AuthenticationType>,
pub connection_options: HashMap<String, Property>,
pub connection_property_name_overrides: HashMap<String, String>,
pub connection_option_name_overrides: HashMap<String, String>,
pub connection_properties_required_overrides: Vec<String>,
pub physical_connection_properties_required: Option<bool>,
}Expand description
An object containing configuration for a compute environment (such as Spark, Python or Athena) returned by the DescribeConnectionType API.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringA name for the compute environment configuration.
description: StringA description of the compute environment.
compute_environment: ComputeEnvironmentThe type of compute environment.
supported_authentication_types: Vec<AuthenticationType>The supported authentication types for the compute environment.
connection_options: HashMap<String, Property>The parameters used as connection options for the compute environment.
connection_property_name_overrides: HashMap<String, String>The connection property name overrides for the compute environment.
connection_option_name_overrides: HashMap<String, String>The connection option name overrides for the compute environment.
connection_properties_required_overrides: Vec<String>The connection properties that are required as overrides for the compute environment.
physical_connection_properties_required: Option<bool>Indicates whether PhysicalConnectionProperties are required for the compute environment.
Implementations
Sourceimpl ComputeEnvironmentConfiguration
impl ComputeEnvironmentConfiguration
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
A description of the compute environment.
Sourcepub fn compute_environment(&self) -> &ComputeEnvironment
pub fn compute_environment(&self) -> &ComputeEnvironment
The type of compute environment.
Sourcepub fn supported_authentication_types(&self) -> &[AuthenticationType]
pub fn supported_authentication_types(&self) -> &[AuthenticationType]
The supported authentication types for the compute environment.
Sourcepub fn connection_options(&self) -> &HashMap<String, Property>
pub fn connection_options(&self) -> &HashMap<String, Property>
The parameters used as connection options for the compute environment.
Sourcepub fn connection_property_name_overrides(&self) -> &HashMap<String, String>
pub fn connection_property_name_overrides(&self) -> &HashMap<String, String>
The connection property name overrides for the compute environment.
Sourcepub fn connection_option_name_overrides(&self) -> &HashMap<String, String>
pub fn connection_option_name_overrides(&self) -> &HashMap<String, String>
The connection option name overrides for the compute environment.
Sourcepub fn connection_properties_required_overrides(&self) -> &[String]
pub fn connection_properties_required_overrides(&self) -> &[String]
The connection properties that are required as overrides for the compute environment.
Sourcepub fn physical_connection_properties_required(&self) -> Option<bool>
pub fn physical_connection_properties_required(&self) -> Option<bool>
Indicates whether PhysicalConnectionProperties are required for the compute environment.
Sourceimpl ComputeEnvironmentConfiguration
impl ComputeEnvironmentConfiguration
Sourcepub fn builder() -> ComputeEnvironmentConfigurationBuilder
pub fn builder() -> ComputeEnvironmentConfigurationBuilder
Creates a new builder-style object to manufacture ComputeEnvironmentConfiguration.