#[non_exhaustive]pub struct ConnectionPropertiesConfiguration {
pub url: Option<ConnectorProperty>,
pub additional_request_parameters: Option<Vec<ConnectorProperty>>,
}Expand description
Configuration that defines the base URL and additional request parameters needed during connection creation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.url: Option<ConnectorProperty>The base instance URL for the endpoint that this connection type will connect to.
additional_request_parameters: Option<Vec<ConnectorProperty>>Key-value pairs of additional request parameters that may be needed during connection creation, such as API versions or service-specific configuration options.
Implementations
Sourceimpl ConnectionPropertiesConfiguration
impl ConnectionPropertiesConfiguration
Sourcepub fn url(&self) -> Option<&ConnectorProperty>
pub fn url(&self) -> Option<&ConnectorProperty>
The base instance URL for the endpoint that this connection type will connect to.
Sourcepub fn additional_request_parameters(&self) -> &[ConnectorProperty]
pub fn additional_request_parameters(&self) -> &[ConnectorProperty]
Key-value pairs of additional request parameters that may be needed during connection creation, such as API versions or service-specific configuration options.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .additional_request_parameters.is_none().
Sourceimpl ConnectionPropertiesConfiguration
impl ConnectionPropertiesConfiguration
Sourcepub fn builder() -> ConnectionPropertiesConfigurationBuilder
pub fn builder() -> ConnectionPropertiesConfigurationBuilder
Creates a new builder-style object to manufacture ConnectionPropertiesConfiguration.