ConnectionTypeBrief

Struct ConnectionTypeBrief 

#[non_exhaustive]
pub struct ConnectionTypeBrief { pub connection_type: Option<ConnectionType>, pub display_name: Option<String>, pub vendor: Option<String>, pub description: Option<String>, pub categories: Option<Vec<String>>, pub capabilities: Option<Capabilities>, pub logo_url: Option<String>, pub connection_type_variants: Option<Vec<ConnectionTypeVariant>>, }
Brief information about a supported connection type returned by the ListConnectionTypes API.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
connection_type: Option<ConnectionType>

The name of the connection type.

display_name: Option<String>

The human-readable name for the connection type that is displayed in the Glue console.

vendor: Option<String>

The name of the vendor or provider that created or maintains this connection type.

description: Option<String>

A description of the connection type.

categories: Option<Vec<String>>

A list of categories that this connection type belongs to. Categories help users filter and find appropriate connection types based on their use cases.

capabilities: Option<Capabilities>

The supported authentication types, data interface types (compute environments), and data operations of the connector.

logo_url: Option<String>

The URL of the logo associated with a connection type.

connection_type_variants: Option<Vec<ConnectionTypeVariant>>

A list of variants available for this connection type. Different variants may provide specialized configurations for specific use cases or implementations of the same general connection type.

Implementations

Source

impl ConnectionTypeBrief

pub fn connection_type(&self) -> Option<&ConnectionType>

The name of the connection type.

pub fn display_name(&self) -> Option<&str>

The human-readable name for the connection type that is displayed in the Glue console.

pub fn vendor(&self) -> Option<&str>

The name of the vendor or provider that created or maintains this connection type.

pub fn description(&self) -> Option<&str>

A description of the connection type.

pub fn categories(&self) -> &[String]

A list of categories that this connection type belongs to. Categories help users filter and find appropriate connection types based on their use cases.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .categories.is_none().

pub fn capabilities(&self) -> Option<&Capabilities>

The supported authentication types, data interface types (compute environments), and data operations of the connector.

pub fn logo_url(&self) -> Option<&str>

The URL of the logo associated with a connection type.

pub fn connection_type_variants(&self) -> &[ConnectionTypeVariant]

A list of variants available for this connection type. Different variants may provide specialized configurations for specific use cases or implementations of the same general connection type.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .connection_type_variants.is_none().

Source

impl ConnectionTypeBrief

pub fn builder() -> ConnectionTypeBriefBuilder

Creates a new builder-style object to manufacture ConnectionTypeBrief.