#[non_exhaustive]pub struct ConnectionTypeVariant {
pub connection_type_variant_name: Option<String>,
pub display_name: Option<String>,
pub description: Option<String>,
pub logo_url: Option<String>,
}Expand description
Represents a variant of a connection type in Glue. Connection type variants provide specific configurations and behaviors for different implementations of the same general connection type.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.connection_type_variant_name: Option<String>The unique identifier for the connection type variant. This name is used internally to identify the specific variant of a connection type.
display_name: Option<String>The human-readable name for the connection type variant that is displayed in the Glue console.
description: Option<String>A detailed description of the connection type variant, including its purpose, use cases, and any specific configuration requirements.
logo_url: Option<String>The URL of the logo associated with a connection type variant.
Implementations
Sourceimpl ConnectionTypeVariant
impl ConnectionTypeVariant
Sourcepub fn connection_type_variant_name(&self) -> Option<&str>
pub fn connection_type_variant_name(&self) -> Option<&str>
The unique identifier for the connection type variant. This name is used internally to identify the specific variant of a connection type.
Sourcepub fn display_name(&self) -> Option<&str>
pub fn display_name(&self) -> Option<&str>
The human-readable name for the connection type variant that is displayed in the Glue console.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A detailed description of the connection type variant, including its purpose, use cases, and any specific configuration requirements.
Sourceimpl ConnectionTypeVariant
impl ConnectionTypeVariant
Sourcepub fn builder() -> ConnectionTypeVariantBuilder
pub fn builder() -> ConnectionTypeVariantBuilder
Creates a new builder-style object to manufacture ConnectionTypeVariant.