#[non_exhaustive]pub struct ConnectorOAuth2Properties {
pub o_auth2_grant_type: ConnectorOAuth2GrantType,
pub client_credentials_properties: Option<ClientCredentialsProperties>,
pub jwt_bearer_properties: Option<JwtBearerProperties>,
pub authorization_code_properties: Option<ConnectorAuthorizationCodeProperties>,
}Expand description
OAuth2 configuration container that defines the authentication properties and flow-specific configurations for OAuth2-based connections.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.o_auth2_grant_type: ConnectorOAuth2GrantTypeThe OAuth2 grant type to use for authentication, such as CLIENT_CREDENTIALS, JWT_BEARER, or AUTHORIZATION_CODE.
client_credentials_properties: Option<ClientCredentialsProperties>Configuration properties specific to the OAuth2 Client Credentials grant type flow.
jwt_bearer_properties: Option<JwtBearerProperties>Configuration properties specific to the OAuth2 JWT Bearer grant type flow.
Configuration properties specific to the OAuth2 Authorization Code grant type flow.
Implementations
Sourceimpl ConnectorOAuth2Properties
impl ConnectorOAuth2Properties
Sourcepub fn o_auth2_grant_type(&self) -> &ConnectorOAuth2GrantType
pub fn o_auth2_grant_type(&self) -> &ConnectorOAuth2GrantType
The OAuth2 grant type to use for authentication, such as CLIENT_CREDENTIALS, JWT_BEARER, or AUTHORIZATION_CODE.
Sourcepub fn client_credentials_properties(
&self,
) -> Option<&ClientCredentialsProperties>
pub fn client_credentials_properties( &self, ) -> Option<&ClientCredentialsProperties>
Configuration properties specific to the OAuth2 Client Credentials grant type flow.
Sourcepub fn jwt_bearer_properties(&self) -> Option<&JwtBearerProperties>
pub fn jwt_bearer_properties(&self) -> Option<&JwtBearerProperties>
Configuration properties specific to the OAuth2 JWT Bearer grant type flow.
Configuration properties specific to the OAuth2 Authorization Code grant type flow.
Sourceimpl ConnectorOAuth2Properties
impl ConnectorOAuth2Properties
Sourcepub fn builder() -> ConnectorOAuth2PropertiesBuilder
pub fn builder() -> ConnectorOAuth2PropertiesBuilder
Creates a new builder-style object to manufacture ConnectorOAuth2Properties.