#[non_exhaustive]pub struct ConnectorProperty {
pub name: String,
pub key_override: Option<String>,
pub required: bool,
pub default_value: Option<String>,
pub allowed_values: Option<Vec<String>>,
pub property_location: Option<PropertyLocation>,
pub property_type: PropertyType,
}Expand description
Defines a property configuration for connection types, default values, and where the property should be used in requests.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name of the property.
key_override: Option<String>A key name to use when sending this property in API requests, if different from the display name.
required: boolIndicates whether the property is required.
default_value: Option<String>The default value for the property.
allowed_values: Option<Vec<String>>A list of AllowedValue objects representing the values allowed for the property.
property_location: Option<PropertyLocation>Specifies where this property should be included in REST requests, such as in headers, query parameters, or request body.
property_type: PropertyTypeThe data type of this property
Implementations
Sourceimpl ConnectorProperty
impl ConnectorProperty
Sourcepub fn key_override(&self) -> Option<&str>
pub fn key_override(&self) -> Option<&str>
A key name to use when sending this property in API requests, if different from the display name.
Sourcepub fn default_value(&self) -> Option<&str>
pub fn default_value(&self) -> Option<&str>
The default value for the property.
Sourcepub fn allowed_values(&self) -> &[String]
pub fn allowed_values(&self) -> &[String]
A list of AllowedValue objects representing the values allowed for the property.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .allowed_values.is_none().
Sourcepub fn property_location(&self) -> Option<&PropertyLocation>
pub fn property_location(&self) -> Option<&PropertyLocation>
Specifies where this property should be included in REST requests, such as in headers, query parameters, or request body.
Sourcepub fn property_type(&self) -> &PropertyType
pub fn property_type(&self) -> &PropertyType
The data type of this property
Sourceimpl ConnectorProperty
impl ConnectorProperty
Sourcepub fn builder() -> ConnectorPropertyBuilder
pub fn builder() -> ConnectorPropertyBuilder
Creates a new builder-style object to manufacture ConnectorProperty.