#[non_exhaustive]pub struct CrawlerHistory {
pub crawl_id: Option<String>,
pub state: Option<CrawlerHistoryState>,
pub start_time: Option<DateTime>,
pub end_time: Option<DateTime>,
pub summary: Option<String>,
pub error_message: Option<String>,
pub log_group: Option<String>,
pub log_stream: Option<String>,
pub message_prefix: Option<String>,
pub dpu_hour: f64,
}Expand description
Contains the information for a run of a crawler.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.crawl_id: Option<String>A UUID identifier for each crawl.
state: Option<CrawlerHistoryState>The state of the crawl.
start_time: Option<DateTime>The date and time on which the crawl started.
end_time: Option<DateTime>The date and time on which the crawl ended.
summary: Option<String>A run summary for the specific crawl in JSON. Contains the catalog tables and partitions that were added, updated, or deleted.
error_message: Option<String>If an error occurred, the error message associated with the crawl.
log_group: Option<String>The log group associated with the crawl.
log_stream: Option<String>The log stream associated with the crawl.
message_prefix: Option<String>The prefix for a CloudWatch message about this crawl.
dpu_hour: f64The number of data processing units (DPU) used in hours for the crawl.
Implementations
Sourceimpl CrawlerHistory
impl CrawlerHistory
Sourcepub fn state(&self) -> Option<&CrawlerHistoryState>
pub fn state(&self) -> Option<&CrawlerHistoryState>
The state of the crawl.
Sourcepub fn start_time(&self) -> Option<&DateTime>
pub fn start_time(&self) -> Option<&DateTime>
The date and time on which the crawl started.
Sourcepub fn summary(&self) -> Option<&str>
pub fn summary(&self) -> Option<&str>
A run summary for the specific crawl in JSON. Contains the catalog tables and partitions that were added, updated, or deleted.
Sourcepub fn error_message(&self) -> Option<&str>
pub fn error_message(&self) -> Option<&str>
If an error occurred, the error message associated with the crawl.
Sourcepub fn log_stream(&self) -> Option<&str>
pub fn log_stream(&self) -> Option<&str>
The log stream associated with the crawl.
Sourcepub fn message_prefix(&self) -> Option<&str>
pub fn message_prefix(&self) -> Option<&str>
The prefix for a CloudWatch message about this crawl.
Sourceimpl CrawlerHistory
impl CrawlerHistory
Sourcepub fn builder() -> CrawlerHistoryBuilder
pub fn builder() -> CrawlerHistoryBuilder
Creates a new builder-style object to manufacture CrawlerHistory.