#[non_exhaustive]pub struct CreateIcebergTableInput {
pub location: String,
pub schema: Option<IcebergSchema>,
pub partition_spec: Option<IcebergPartitionSpec>,
pub write_order: Option<IcebergSortOrder>,
pub properties: Option<HashMap<String, String>>,
}Expand description
The configuration parameters required to create a new Iceberg table in the Glue Data Catalog, including table properties and metadata specifications.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.location: StringThe S3 location where the Iceberg table data will be stored.
schema: Option<IcebergSchema>The schema definition that specifies the structure, field types, and metadata for the Iceberg table.
partition_spec: Option<IcebergPartitionSpec>The partitioning specification that defines how the Iceberg table data will be organized and partitioned for optimal query performance.
write_order: Option<IcebergSortOrder>The sort order specification that defines how data should be ordered within each partition to optimize query performance.
properties: Option<HashMap<String, String>>Key-value pairs of additional table properties and configuration settings for the Iceberg table.
Implementations
Sourceimpl CreateIcebergTableInput
impl CreateIcebergTableInput
Sourcepub fn schema(&self) -> Option<&IcebergSchema>
pub fn schema(&self) -> Option<&IcebergSchema>
The schema definition that specifies the structure, field types, and metadata for the Iceberg table.
Sourcepub fn partition_spec(&self) -> Option<&IcebergPartitionSpec>
pub fn partition_spec(&self) -> Option<&IcebergPartitionSpec>
The partitioning specification that defines how the Iceberg table data will be organized and partitioned for optimal query performance.
Sourcepub fn write_order(&self) -> Option<&IcebergSortOrder>
pub fn write_order(&self) -> Option<&IcebergSortOrder>
The sort order specification that defines how data should be ordered within each partition to optimize query performance.
Sourceimpl CreateIcebergTableInput
impl CreateIcebergTableInput
Sourcepub fn builder() -> CreateIcebergTableInputBuilder
pub fn builder() -> CreateIcebergTableInputBuilder
Creates a new builder-style object to manufacture CreateIcebergTableInput.