#[non_exhaustive]pub struct CustomAuthenticationProperties {
pub authentication_parameters: Vec<ConnectorProperty>,
}Expand description
Custom authentication configuration that allows for flexible authentication mechanisms beyond standard Basic and OAuth2 flows.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.authentication_parameters: Vec<ConnectorProperty>A map of custom authentication parameters that define the specific authentication mechanism and required properties.
Implementations
Sourceimpl CustomAuthenticationProperties
impl CustomAuthenticationProperties
Sourcepub fn authentication_parameters(&self) -> &[ConnectorProperty]
pub fn authentication_parameters(&self) -> &[ConnectorProperty]
A map of custom authentication parameters that define the specific authentication mechanism and required properties.
Sourceimpl CustomAuthenticationProperties
impl CustomAuthenticationProperties
Sourcepub fn builder() -> CustomAuthenticationPropertiesBuilder
pub fn builder() -> CustomAuthenticationPropertiesBuilder
Creates a new builder-style object to manufacture CustomAuthenticationProperties.