#[non_exhaustive]pub struct CustomEntityType {
pub name: String,
pub regex_string: String,
pub context_words: Option<Vec<String>>,
}Expand description
An object representing a custom pattern for detecting sensitive data across the columns and rows of your structured data.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringA name for the custom pattern that allows it to be retrieved or deleted later. This name must be unique per Amazon Web Services account.
regex_string: StringA regular expression string that is used for detecting sensitive data in a custom pattern.
context_words: Option<Vec<String>>A list of context words. If none of these context words are found within the vicinity of the regular expression the data will not be detected as sensitive data.
If no context words are passed only a regular expression is checked.
Implementations
Sourceimpl CustomEntityType
impl CustomEntityType
Sourcepub fn name(&self) -> &str
pub fn name(&self) -> &str
A name for the custom pattern that allows it to be retrieved or deleted later. This name must be unique per Amazon Web Services account.
Sourcepub fn regex_string(&self) -> &str
pub fn regex_string(&self) -> &str
A regular expression string that is used for detecting sensitive data in a custom pattern.
Sourcepub fn context_words(&self) -> &[String]
pub fn context_words(&self) -> &[String]
A list of context words. If none of these context words are found within the vicinity of the regular expression the data will not be detected as sensitive data.
If no context words are passed only a regular expression is checked.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .context_words.is_none().
Sourceimpl CustomEntityType
impl CustomEntityType
Sourcepub fn builder() -> CustomEntityTypeBuilder
pub fn builder() -> CustomEntityTypeBuilder
Creates a new builder-style object to manufacture CustomEntityType.