#[non_exhaustive]pub struct DataLakeAccessProperties {
pub data_lake_access: bool,
pub data_transfer_role: Option<String>,
pub kms_key: Option<String>,
pub catalog_type: Option<String>,
}Expand description
Input properties to configure data lake access for your catalog resource in the Glue Data Catalog.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.data_lake_access: boolTurns on or off data lake access for Apache Spark applications that access Amazon Redshift databases in the Data Catalog from any non-Redshift engine, such as Amazon Athena, Amazon EMR, or Glue ETL.
data_transfer_role: Option<String>A role that will be assumed by Glue for transferring data into/out of the staging bucket during a query.
kms_key: Option<String>An encryption key that will be used for the staging bucket that will be created along with the catalog.
catalog_type: Option<String>Specifies a federated catalog type for the native catalog resource. The currently supported type is aws:redshift.
Implementations
Sourceimpl DataLakeAccessProperties
impl DataLakeAccessProperties
Sourcepub fn data_lake_access(&self) -> bool
pub fn data_lake_access(&self) -> bool
Turns on or off data lake access for Apache Spark applications that access Amazon Redshift databases in the Data Catalog from any non-Redshift engine, such as Amazon Athena, Amazon EMR, or Glue ETL.
Sourcepub fn data_transfer_role(&self) -> Option<&str>
pub fn data_transfer_role(&self) -> Option<&str>
A role that will be assumed by Glue for transferring data into/out of the staging bucket during a query.
Sourcepub fn kms_key(&self) -> Option<&str>
pub fn kms_key(&self) -> Option<&str>
An encryption key that will be used for the staging bucket that will be created along with the catalog.
Sourcepub fn catalog_type(&self) -> Option<&str>
pub fn catalog_type(&self) -> Option<&str>
Specifies a federated catalog type for the native catalog resource. The currently supported type is aws:redshift.
Sourceimpl DataLakeAccessProperties
impl DataLakeAccessProperties
Sourcepub fn builder() -> DataLakeAccessPropertiesBuilder
pub fn builder() -> DataLakeAccessPropertiesBuilder
Creates a new builder-style object to manufacture DataLakeAccessProperties.