DataLakeAccessPropertiesOutput

Struct DataLakeAccessPropertiesOutput 

#[non_exhaustive]
pub struct DataLakeAccessPropertiesOutput { pub data_lake_access: bool, pub data_transfer_role: Option<String>, pub kms_key: Option<String>, pub managed_workgroup_name: Option<String>, pub managed_workgroup_status: Option<String>, pub redshift_database_name: Option<String>, pub status_message: Option<String>, pub catalog_type: Option<String>, }
The output properties of the data lake access configuration for your catalog resource in the Glue Data Catalog.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
data_lake_access: bool

Turns on or off data lake access for Apache Spark applications that access Amazon Redshift databases in the Data Catalog.

data_transfer_role: Option<String>

A role that will be assumed by Glue for transferring data into/out of the staging bucket during a query.

kms_key: Option<String>

An encryption key that will be used for the staging bucket that will be created along with the catalog.

managed_workgroup_name: Option<String>

The managed Redshift Serverless compute name that is created for your catalog resource.

managed_workgroup_status: Option<String>

The managed Redshift Serverless compute status.

redshift_database_name: Option<String>

The default Redshift database resource name in the managed compute.

status_message: Option<String>

A message that gives more detailed information about the managed workgroup status.

catalog_type: Option<String>

Specifies a federated catalog type for the native catalog resource. The currently supported type is aws:redshift.

Implementations

Source

impl DataLakeAccessPropertiesOutput

pub fn data_lake_access(&self) -> bool

Turns on or off data lake access for Apache Spark applications that access Amazon Redshift databases in the Data Catalog.

pub fn data_transfer_role(&self) -> Option<&str>

A role that will be assumed by Glue for transferring data into/out of the staging bucket during a query.

pub fn kms_key(&self) -> Option<&str>

An encryption key that will be used for the staging bucket that will be created along with the catalog.

pub fn managed_workgroup_name(&self) -> Option<&str>

The managed Redshift Serverless compute name that is created for your catalog resource.

pub fn managed_workgroup_status(&self) -> Option<&str>

The managed Redshift Serverless compute status.

pub fn redshift_database_name(&self) -> Option<&str>

The default Redshift database resource name in the managed compute.

pub fn status_message(&self) -> Option<&str>

A message that gives more detailed information about the managed workgroup status.

pub fn catalog_type(&self) -> Option<&str>

Specifies a federated catalog type for the native catalog resource. The currently supported type is aws:redshift.

Source

impl DataLakeAccessPropertiesOutput

pub fn builder() -> DataLakeAccessPropertiesOutputBuilder

Creates a new builder-style object to manufacture DataLakeAccessPropertiesOutput.