#[non_exhaustive]pub struct DataQualityAggregatedMetrics {
pub total_rows_processed: Option<f64>,
pub total_rows_passed: Option<f64>,
pub total_rows_failed: Option<f64>,
pub total_rules_processed: Option<f64>,
pub total_rules_passed: Option<f64>,
pub total_rules_failed: Option<f64>,
}Expand description
A summary of metrics showing the total counts of processed rows and rules, including their pass/fail statistics based on row-level results.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.total_rows_processed: Option<f64>The total number of rows that were processed during the data quality evaluation.
total_rows_passed: Option<f64>The total number of rows that passed all applicable data quality rules.
total_rows_failed: Option<f64>The total number of rows that failed one or more data quality rules.
total_rules_processed: Option<f64>The total number of data quality rules that were evaluated.
total_rules_passed: Option<f64>The total number of data quality rules that passed their evaluation criteria.
total_rules_failed: Option<f64>The total number of data quality rules that failed their evaluation criteria.
Implementations
Sourceimpl DataQualityAggregatedMetrics
impl DataQualityAggregatedMetrics
Sourcepub fn total_rows_processed(&self) -> Option<f64>
pub fn total_rows_processed(&self) -> Option<f64>
The total number of rows that were processed during the data quality evaluation.
Sourcepub fn total_rows_passed(&self) -> Option<f64>
pub fn total_rows_passed(&self) -> Option<f64>
The total number of rows that passed all applicable data quality rules.
Sourcepub fn total_rows_failed(&self) -> Option<f64>
pub fn total_rows_failed(&self) -> Option<f64>
The total number of rows that failed one or more data quality rules.
Sourcepub fn total_rules_processed(&self) -> Option<f64>
pub fn total_rules_processed(&self) -> Option<f64>
The total number of data quality rules that were evaluated.
Sourcepub fn total_rules_passed(&self) -> Option<f64>
pub fn total_rules_passed(&self) -> Option<f64>
The total number of data quality rules that passed their evaluation criteria.
Sourcepub fn total_rules_failed(&self) -> Option<f64>
pub fn total_rules_failed(&self) -> Option<f64>
The total number of data quality rules that failed their evaluation criteria.
Sourceimpl DataQualityAggregatedMetrics
impl DataQualityAggregatedMetrics
Sourcepub fn builder() -> DataQualityAggregatedMetricsBuilder
pub fn builder() -> DataQualityAggregatedMetricsBuilder
Creates a new builder-style object to manufacture DataQualityAggregatedMetrics.