#[non_exhaustive]pub struct DataQualityEncryption {
pub data_quality_encryption_mode: Option<DataQualityEncryptionMode>,
pub kms_key_arn: Option<String>,
}Expand description
Specifies how Data Quality assets in your account should be encrypted.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.data_quality_encryption_mode: Option<DataQualityEncryptionMode>The encryption mode to use for encrypting Data Quality assets. These assets include data quality rulesets, results, statistics, anomaly detection models and observations.
Valid values are SSEKMS for encryption using a customer-managed KMS key, or DISABLED.
kms_key_arn: Option<String>The Amazon Resource Name (ARN) of the KMS key to be used to encrypt the data.
Implementations
Sourceimpl DataQualityEncryption
impl DataQualityEncryption
Sourcepub fn data_quality_encryption_mode(&self) -> Option<&DataQualityEncryptionMode>
pub fn data_quality_encryption_mode(&self) -> Option<&DataQualityEncryptionMode>
The encryption mode to use for encrypting Data Quality assets. These assets include data quality rulesets, results, statistics, anomaly detection models and observations.
Valid values are SSEKMS for encryption using a customer-managed KMS key, or DISABLED.
Sourcepub fn kms_key_arn(&self) -> Option<&str>
pub fn kms_key_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the KMS key to be used to encrypt the data.
Sourceimpl DataQualityEncryption
impl DataQualityEncryption
Sourcepub fn builder() -> DataQualityEncryptionBuilder
pub fn builder() -> DataQualityEncryptionBuilder
Creates a new builder-style object to manufacture DataQualityEncryption.