#[non_exhaustive]pub struct DataQualityEvaluationRunAdditionalRunOptions {
pub cloud_watch_metrics_enabled: Option<bool>,
pub results_s3_prefix: Option<String>,
pub composite_rule_evaluation_method: Option<DqCompositeRuleEvaluationMethod>,
pub custom_log_group_prefix: Option<String>,
pub row_level_results: Option<RowLevelResultsOptions>,
pub profiling_results: Option<ProfilingResultsOptions>,
pub observation_scope: Option<ObservationConfiguration>,
pub observation_mode: Option<ObservationMode>,
pub data_quality_rule_results: Option<DataQualityRuleResultsOptions>,
pub observation_results: Option<ObservationResultsOptions>,
}Expand description
Additional run options you can specify for an evaluation run.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cloud_watch_metrics_enabled: Option<bool>Whether or not to enable CloudWatch metrics.
results_s3_prefix: Option<String>Prefix for Amazon S3 to store results.
composite_rule_evaluation_method: Option<DqCompositeRuleEvaluationMethod>Set the evaluation method for composite rules in the ruleset to ROW/COLUMN
custom_log_group_prefix: Option<String>A custom prefix for the CloudWatch log group names. When specified, evaluation run logs are written to and instead of the default /aws-glue/data-quality/error and /aws-glue/data-quality/output log groups.
row_level_results: Option<RowLevelResultsOptions>The configuration for writing row-level evaluation results to a Glue Data Catalog table.
profiling_results: Option<ProfilingResultsOptions>The configuration for writing profiling results to a Glue Data Catalog table.
observation_scope: Option<ObservationConfiguration>The scope of the observation for the evaluation run. Specifies whether anomaly detection is enabled or disabled.
observation_mode: Option<ObservationMode>The observation mode for the evaluation run. Specifies how anomaly detection bounds are calculated.
data_quality_rule_results: Option<DataQualityRuleResultsOptions>The configuration for writing rule results to a Glue Data Catalog table.
observation_results: Option<ObservationResultsOptions>The configuration for writing observation results to a Glue Data Catalog table.
Implementations
Sourceimpl DataQualityEvaluationRunAdditionalRunOptions
impl DataQualityEvaluationRunAdditionalRunOptions
Sourcepub fn cloud_watch_metrics_enabled(&self) -> Option<bool>
pub fn cloud_watch_metrics_enabled(&self) -> Option<bool>
Whether or not to enable CloudWatch metrics.
Sourcepub fn results_s3_prefix(&self) -> Option<&str>
pub fn results_s3_prefix(&self) -> Option<&str>
Prefix for Amazon S3 to store results.
Sourcepub fn composite_rule_evaluation_method(
&self,
) -> Option<&DqCompositeRuleEvaluationMethod>
pub fn composite_rule_evaluation_method( &self, ) -> Option<&DqCompositeRuleEvaluationMethod>
Set the evaluation method for composite rules in the ruleset to ROW/COLUMN
Sourcepub fn custom_log_group_prefix(&self) -> Option<&str>
pub fn custom_log_group_prefix(&self) -> Option<&str>
A custom prefix for the CloudWatch log group names. When specified, evaluation run logs are written to and instead of the default /aws-glue/data-quality/error and /aws-glue/data-quality/output log groups.
Sourcepub fn row_level_results(&self) -> Option<&RowLevelResultsOptions>
pub fn row_level_results(&self) -> Option<&RowLevelResultsOptions>
The configuration for writing row-level evaluation results to a Glue Data Catalog table.
Sourcepub fn profiling_results(&self) -> Option<&ProfilingResultsOptions>
pub fn profiling_results(&self) -> Option<&ProfilingResultsOptions>
The configuration for writing profiling results to a Glue Data Catalog table.
Sourcepub fn observation_scope(&self) -> Option<&ObservationConfiguration>
pub fn observation_scope(&self) -> Option<&ObservationConfiguration>
The scope of the observation for the evaluation run. Specifies whether anomaly detection is enabled or disabled.
Sourcepub fn observation_mode(&self) -> Option<&ObservationMode>
pub fn observation_mode(&self) -> Option<&ObservationMode>
The observation mode for the evaluation run. Specifies how anomaly detection bounds are calculated.
Sourcepub fn data_quality_rule_results(
&self,
) -> Option<&DataQualityRuleResultsOptions>
pub fn data_quality_rule_results( &self, ) -> Option<&DataQualityRuleResultsOptions>
The configuration for writing rule results to a Glue Data Catalog table.
Sourcepub fn observation_results(&self) -> Option<&ObservationResultsOptions>
pub fn observation_results(&self) -> Option<&ObservationResultsOptions>
The configuration for writing observation results to a Glue Data Catalog table.
Sourceimpl DataQualityEvaluationRunAdditionalRunOptions
impl DataQualityEvaluationRunAdditionalRunOptions
Sourcepub fn builder() -> DataQualityEvaluationRunAdditionalRunOptionsBuilder
pub fn builder() -> DataQualityEvaluationRunAdditionalRunOptionsBuilder
Creates a new builder-style object to manufacture DataQualityEvaluationRunAdditionalRunOptions.