#[non_exhaustive]pub struct DataQualityGlueTable {
pub database_name: String,
pub table_name: String,
pub catalog_id: Option<String>,
pub connection_name: Option<String>,
pub additional_options: Option<HashMap<String, String>>,
pub pre_processing_query: Option<String>,
}Expand description
The database and table in the Glue Data Catalog that is used for input or output data for Data Quality Operations.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.database_name: StringA database name in the Glue Data Catalog.
table_name: StringA table name in the Glue Data Catalog.
catalog_id: Option<String>A unique identifier for the Glue Data Catalog.
connection_name: Option<String>The name of the connection to the Glue Data Catalog.
additional_options: Option<HashMap<String, String>>Additional options for the table. Currently there are two keys supported:
-
pushDownPredicate: to filter on partitions without having to list and read all the files in your dataset. -
catalogPartitionPredicate: to use server-side partition pruning using partition indexes in the Glue Data Catalog.
pre_processing_query: Option<String>SQL Query of SparkSQL format that can be used to pre-process the data for the table in Glue Data Catalog, before running the Data Quality Operation.
Implementations
Sourceimpl DataQualityGlueTable
impl DataQualityGlueTable
Sourcepub fn database_name(&self) -> &str
pub fn database_name(&self) -> &str
A database name in the Glue Data Catalog.
Sourcepub fn table_name(&self) -> &str
pub fn table_name(&self) -> &str
A table name in the Glue Data Catalog.
Sourcepub fn catalog_id(&self) -> Option<&str>
pub fn catalog_id(&self) -> Option<&str>
A unique identifier for the Glue Data Catalog.
Sourcepub fn connection_name(&self) -> Option<&str>
pub fn connection_name(&self) -> Option<&str>
The name of the connection to the Glue Data Catalog.
Sourcepub fn additional_options(&self) -> Option<&HashMap<String, String>>
pub fn additional_options(&self) -> Option<&HashMap<String, String>>
Additional options for the table. Currently there are two keys supported:
-
pushDownPredicate: to filter on partitions without having to list and read all the files in your dataset. -
catalogPartitionPredicate: to use server-side partition pruning using partition indexes in the Glue Data Catalog.
Sourcepub fn pre_processing_query(&self) -> Option<&str>
pub fn pre_processing_query(&self) -> Option<&str>
SQL Query of SparkSQL format that can be used to pre-process the data for the table in Glue Data Catalog, before running the Data Quality Operation.
Sourceimpl DataQualityGlueTable
impl DataQualityGlueTable
Sourcepub fn builder() -> DataQualityGlueTableBuilder
pub fn builder() -> DataQualityGlueTableBuilder
Creates a new builder-style object to manufacture DataQualityGlueTable.