#[non_exhaustive]pub struct DataQualityRuleRecommendationRunAdditionalRunOptions {
pub custom_log_group_prefix: Option<String>,
}Expand description
Additional run options you can specify for a recommendation run.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.custom_log_group_prefix: Option<String>A custom prefix for the CloudWatch log group names. When specified, recommendation run logs are written to and instead of the default /aws-glue/data-quality/error and /aws-glue/data-quality/output log groups.
Implementations
Sourceimpl DataQualityRuleRecommendationRunAdditionalRunOptions
impl DataQualityRuleRecommendationRunAdditionalRunOptions
Sourcepub fn custom_log_group_prefix(&self) -> Option<&str>
pub fn custom_log_group_prefix(&self) -> Option<&str>
A custom prefix for the CloudWatch log group names. When specified, recommendation run logs are written to and instead of the default /aws-glue/data-quality/error and /aws-glue/data-quality/output log groups.
Sourceimpl DataQualityRuleRecommendationRunAdditionalRunOptions
impl DataQualityRuleRecommendationRunAdditionalRunOptions
Sourcepub fn builder() -> DataQualityRuleRecommendationRunAdditionalRunOptionsBuilder
pub fn builder() -> DataQualityRuleRecommendationRunAdditionalRunOptionsBuilder
Creates a new builder-style object to manufacture DataQualityRuleRecommendationRunAdditionalRunOptions.