#[non_exhaustive]pub struct DataQualityRuleRecommendationRunDescription {
pub run_id: Option<String>,
pub status: Option<TaskStatusType>,
pub started_on: Option<DateTime>,
pub data_source: Option<DataSource>,
pub created_ruleset_name: Option<String>,
pub recommendation_mode: Option<RecommendationMode>,
}Expand description
Describes the result of a data quality rule recommendation run.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.run_id: Option<String>The unique run identifier associated with this run.
status: Option<TaskStatusType>The status for this run.
started_on: Option<DateTime>The date and time when this run started.
data_source: Option<DataSource>The data source (Glue table) associated with the recommendation run.
created_ruleset_name: Option<String>The name of the ruleset that was created by the recommendation run.
recommendation_mode: Option<RecommendationMode>The mode that Glue Data Quality uses to recommend rules.
The default is BASIC.
Implementations
Sourceimpl DataQualityRuleRecommendationRunDescription
impl DataQualityRuleRecommendationRunDescription
Sourcepub fn status(&self) -> Option<&TaskStatusType>
pub fn status(&self) -> Option<&TaskStatusType>
The status for this run.
Sourcepub fn started_on(&self) -> Option<&DateTime>
pub fn started_on(&self) -> Option<&DateTime>
The date and time when this run started.
Sourcepub fn data_source(&self) -> Option<&DataSource>
pub fn data_source(&self) -> Option<&DataSource>
The data source (Glue table) associated with the recommendation run.
Sourcepub fn created_ruleset_name(&self) -> Option<&str>
pub fn created_ruleset_name(&self) -> Option<&str>
The name of the ruleset that was created by the recommendation run.
Sourcepub fn recommendation_mode(&self) -> Option<&RecommendationMode>
pub fn recommendation_mode(&self) -> Option<&RecommendationMode>
The mode that Glue Data Quality uses to recommend rules.
The default is BASIC.
Sourceimpl DataQualityRuleRecommendationRunDescription
impl DataQualityRuleRecommendationRunDescription
Sourcepub fn builder() -> DataQualityRuleRecommendationRunDescriptionBuilder
pub fn builder() -> DataQualityRuleRecommendationRunDescriptionBuilder
Creates a new builder-style object to manufacture DataQualityRuleRecommendationRunDescription.