#[non_exhaustive]pub struct DataQualityRuleResultsOptions {
pub write_data_quality_rule_results_enabled: Option<bool>,
pub catalog_table_config: Option<CatalogTableConfigOptions>,
}Expand description
The configuration for writing data quality rule results.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.write_data_quality_rule_results_enabled: Option<bool>Set to true to write data quality rule results.
catalog_table_config: Option<CatalogTableConfigOptions>The Glue Data Catalog table configuration for storing the rule results.
Implementations
Sourceimpl DataQualityRuleResultsOptions
impl DataQualityRuleResultsOptions
Sourcepub fn write_data_quality_rule_results_enabled(&self) -> Option<bool>
pub fn write_data_quality_rule_results_enabled(&self) -> Option<bool>
Set to true to write data quality rule results.
Sourcepub fn catalog_table_config(&self) -> Option<&CatalogTableConfigOptions>
pub fn catalog_table_config(&self) -> Option<&CatalogTableConfigOptions>
The Glue Data Catalog table configuration for storing the rule results.
Sourceimpl DataQualityRuleResultsOptions
impl DataQualityRuleResultsOptions
Sourcepub fn builder() -> DataQualityRuleResultsOptionsBuilder
pub fn builder() -> DataQualityRuleResultsOptionsBuilder
Creates a new builder-style object to manufacture DataQualityRuleResultsOptions.