#[non_exhaustive]pub struct DistributionData {
pub bin_edges: Option<Vec<String>>,
pub count: Option<Vec<i32>>,
pub data_type: Option<String>,
}Expand description
The distribution data for a statistic.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bin_edges: Option<Vec<String>>The bin edge values for the distribution.
count: Option<Vec<i32>>The frequency count for each bin in the distribution.
data_type: Option<String>The data type of the column for the distribution.
Implementations
Sourceimpl DistributionData
impl DistributionData
Sourcepub fn bin_edges(&self) -> &[String]
pub fn bin_edges(&self) -> &[String]
The bin edge values for the distribution.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .bin_edges.is_none().
Sourceimpl DistributionData
impl DistributionData
Sourcepub fn builder() -> DistributionDataBuilder
pub fn builder() -> DistributionDataBuilder
Creates a new builder-style object to manufacture DistributionData.