#[non_exhaustive]pub struct DistributionResultsOptions {
pub write_distribution_results_enabled: Option<bool>,
pub catalog_table_config: Option<CatalogTableConfigOptions>,
}Expand description
The configuration for writing distribution results.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.write_distribution_results_enabled: Option<bool>Set to true to write distribution results.
catalog_table_config: Option<CatalogTableConfigOptions>The Glue Data Catalog table configuration for storing the distribution results.
Implementations
Sourceimpl DistributionResultsOptions
impl DistributionResultsOptions
Sourcepub fn write_distribution_results_enabled(&self) -> Option<bool>
pub fn write_distribution_results_enabled(&self) -> Option<bool>
Set to true to write distribution results.
Sourcepub fn catalog_table_config(&self) -> Option<&CatalogTableConfigOptions>
pub fn catalog_table_config(&self) -> Option<&CatalogTableConfigOptions>
The Glue Data Catalog table configuration for storing the distribution results.
Sourceimpl DistributionResultsOptions
impl DistributionResultsOptions
Sourcepub fn builder() -> DistributionResultsOptionsBuilder
pub fn builder() -> DistributionResultsOptionsBuilder
Creates a new builder-style object to manufacture DistributionResultsOptions.