#[non_exhaustive]pub struct DynamoDbeltConnectorSource {
pub name: String,
pub connection_options: Option<DdbeltConnectionOptions>,
pub output_schemas: Option<Vec<GlueSchema>>,
}Expand description
Specifies a DynamoDB ELT connector source for extracting data from DynamoDB tables.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name of the DynamoDB ELT connector source.
connection_options: Option<DdbeltConnectionOptions>The connection options for the DynamoDB ELT connector source.
output_schemas: Option<Vec<GlueSchema>>Specifies the data schema for the DynamoDB ELT connector source.
Implementations
Sourceimpl DynamoDbeltConnectorSource
impl DynamoDbeltConnectorSource
Sourcepub fn connection_options(&self) -> Option<&DdbeltConnectionOptions>
pub fn connection_options(&self) -> Option<&DdbeltConnectionOptions>
The connection options for the DynamoDB ELT connector source.
Sourcepub fn output_schemas(&self) -> &[GlueSchema]
pub fn output_schemas(&self) -> &[GlueSchema]
Specifies the data schema for the DynamoDB ELT connector source.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .output_schemas.is_none().
Sourceimpl DynamoDbeltConnectorSource
impl DynamoDbeltConnectorSource
Sourcepub fn builder() -> DynamoDbeltConnectorSourceBuilder
pub fn builder() -> DynamoDbeltConnectorSourceBuilder
Creates a new builder-style object to manufacture DynamoDbeltConnectorSource.