#[non_exhaustive]pub struct EncryptionAtRest {
pub catalog_encryption_mode: CatalogEncryptionMode,
pub sse_aws_kms_key_id: Option<String>,
pub catalog_encryption_service_role: Option<String>,
}Expand description
Specifies the encryption-at-rest configuration for the Data Catalog.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.catalog_encryption_mode: CatalogEncryptionModeThe encryption-at-rest mode for encrypting Data Catalog data.
sse_aws_kms_key_id: Option<String>The ID of the KMS key to use for encryption at rest.
catalog_encryption_service_role: Option<String>The role that Glue assumes to encrypt and decrypt the Data Catalog objects on the caller's behalf.
Implementations
Sourceimpl EncryptionAtRest
impl EncryptionAtRest
Sourcepub fn catalog_encryption_mode(&self) -> &CatalogEncryptionMode
pub fn catalog_encryption_mode(&self) -> &CatalogEncryptionMode
The encryption-at-rest mode for encrypting Data Catalog data.
Sourcepub fn sse_aws_kms_key_id(&self) -> Option<&str>
pub fn sse_aws_kms_key_id(&self) -> Option<&str>
The ID of the KMS key to use for encryption at rest.
Sourcepub fn catalog_encryption_service_role(&self) -> Option<&str>
pub fn catalog_encryption_service_role(&self) -> Option<&str>
The role that Glue assumes to encrypt and decrypt the Data Catalog objects on the caller's behalf.
Sourceimpl EncryptionAtRest
impl EncryptionAtRest
Sourcepub fn builder() -> EncryptionAtRestBuilder
pub fn builder() -> EncryptionAtRestBuilder
Creates a new builder-style object to manufacture EncryptionAtRest.