#[non_exhaustive]pub struct Entity {
pub entity_name: Option<String>,
pub label: Option<String>,
pub is_parent_entity: Option<bool>,
pub description: Option<String>,
pub category: Option<String>,
pub custom_properties: Option<HashMap<String, String>>,
}Expand description
An entity supported by a given ConnectionType.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.entity_name: Option<String>The name of the entity.
label: Option<String>Label used for the entity.
is_parent_entity: Option<bool>A Boolean value which helps to determine whether there are sub objects that can be listed.
description: Option<String>A description of the entity.
category: Option<String>The type of entities that are present in the response. This value depends on the source connection. For example this is SObjects for Salesforce and databases or schemas or tables for sources like Amazon Redshift.
custom_properties: Option<HashMap<String, String>>An optional map of keys which may be returned for an entity by a connector.
Implementations
Sourceimpl Entity
impl Entity
Sourcepub fn entity_name(&self) -> Option<&str>
pub fn entity_name(&self) -> Option<&str>
The name of the entity.
Sourcepub fn is_parent_entity(&self) -> Option<bool>
pub fn is_parent_entity(&self) -> Option<bool>
A Boolean value which helps to determine whether there are sub objects that can be listed.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A description of the entity.