#[non_exhaustive]pub struct EntityConfiguration {
pub source_configuration: Option<SourceConfiguration>,
pub schema: Option<HashMap<String, FieldDefinition>>,
}Expand description
Configuration that defines how to interact with a specific data entity through the REST API, including its access patterns and schema definition.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source_configuration: Option<SourceConfiguration>The source configuration that defines how to make requests to access this entity's data through the REST API.
schema: Option<HashMap<String, FieldDefinition>>The schema definition for this entity, including field names, types, and other metadata that describes the structure of the data.
Implementations
Sourceimpl EntityConfiguration
impl EntityConfiguration
Sourcepub fn source_configuration(&self) -> Option<&SourceConfiguration>
pub fn source_configuration(&self) -> Option<&SourceConfiguration>
The source configuration that defines how to make requests to access this entity's data through the REST API.
Sourceimpl EntityConfiguration
impl EntityConfiguration
Sourcepub fn builder() -> EntityConfigurationBuilder
pub fn builder() -> EntityConfigurationBuilder
Creates a new builder-style object to manufacture EntityConfiguration.