#[non_exhaustive]pub struct ExecutionAttempt {
pub status: Option<ExecutionStatus>,
pub column_statistics_task_run_id: Option<String>,
pub execution_timestamp: Option<DateTime>,
pub error_message: Option<String>,
}Expand description
A run attempt for a column statistics task run.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.status: Option<ExecutionStatus>The status of the last column statistics task run.
column_statistics_task_run_id: Option<String>A task run ID for the last column statistics task run.
execution_timestamp: Option<DateTime>A timestamp when the last column statistics task run occurred.
error_message: Option<String>An error message associated with the last column statistics task run.
Implementations
Sourceimpl ExecutionAttempt
impl ExecutionAttempt
Sourcepub fn status(&self) -> Option<&ExecutionStatus>
pub fn status(&self) -> Option<&ExecutionStatus>
The status of the last column statistics task run.
Sourcepub fn column_statistics_task_run_id(&self) -> Option<&str>
pub fn column_statistics_task_run_id(&self) -> Option<&str>
A task run ID for the last column statistics task run.
Sourcepub fn execution_timestamp(&self) -> Option<&DateTime>
pub fn execution_timestamp(&self) -> Option<&DateTime>
A timestamp when the last column statistics task run occurred.
Sourcepub fn error_message(&self) -> Option<&str>
pub fn error_message(&self) -> Option<&str>
An error message associated with the last column statistics task run.
Sourceimpl ExecutionAttempt
impl ExecutionAttempt
Sourcepub fn builder() -> ExecutionAttemptBuilder
pub fn builder() -> ExecutionAttemptBuilder
Creates a new builder-style object to manufacture ExecutionAttempt.