#[non_exhaustive]pub struct ExtractedParameter {
pub key: Option<String>,
pub default_value: Option<String>,
pub property_location: Option<PropertyLocation>,
pub value: Option<ResponseExtractionMapping>,
}Expand description
Parameter extraction configuration that defines how to extract and map values from API responses to request parameters.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.key: Option<String>The parameter key name that will be used in subsequent requests.
default_value: Option<String>The default value to use if the parameter cannot be extracted from the response.
property_location: Option<PropertyLocation>Specifies where this extracted parameter should be placed in subsequent requests, such as in headers, query parameters, or request body.
value: Option<ResponseExtractionMapping>The JSON path or extraction mapping that defines how to extract the parameter value from API responses.
Implementations
Sourceimpl ExtractedParameter
impl ExtractedParameter
Sourcepub fn key(&self) -> Option<&str>
pub fn key(&self) -> Option<&str>
The parameter key name that will be used in subsequent requests.
Sourcepub fn default_value(&self) -> Option<&str>
pub fn default_value(&self) -> Option<&str>
The default value to use if the parameter cannot be extracted from the response.
Sourcepub fn property_location(&self) -> Option<&PropertyLocation>
pub fn property_location(&self) -> Option<&PropertyLocation>
Specifies where this extracted parameter should be placed in subsequent requests, such as in headers, query parameters, or request body.
Sourcepub fn value(&self) -> Option<&ResponseExtractionMapping>
pub fn value(&self) -> Option<&ResponseExtractionMapping>
The JSON path or extraction mapping that defines how to extract the parameter value from API responses.
Sourceimpl ExtractedParameter
impl ExtractedParameter
Sourcepub fn builder() -> ExtractedParameterBuilder
pub fn builder() -> ExtractedParameterBuilder
Creates a new builder-style object to manufacture ExtractedParameter.