Field

Struct Field 

#[non_exhaustive]
pub struct Field {
Show 18 fields pub field_name: Option<String>, pub label: Option<String>, pub description: Option<String>, pub field_type: Option<FieldDataType>, pub is_primary_key: Option<bool>, pub is_nullable: Option<bool>, pub is_retrievable: Option<bool>, pub is_filterable: Option<bool>, pub is_partitionable: Option<bool>, pub is_createable: Option<bool>, pub is_updateable: Option<bool>, pub is_upsertable: Option<bool>, pub is_default_on_create: Option<bool>, pub supported_values: Option<Vec<String>>, pub supported_filter_operators: Option<Vec<FieldFilterOperator>>, pub parent_field: Option<String>, pub native_data_type: Option<String>, pub custom_properties: Option<HashMap<String, String>>,
}
The Field object has information about the different properties associated with a field in the connector.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
field_name: Option<String>

A unique identifier for the field.

label: Option<String>

A readable label used for the field.

description: Option<String>

A description of the field.

field_type: Option<FieldDataType>

The type of data in the field.

is_primary_key: Option<bool>

Indicates whether this field can used as a primary key for the given entity.

is_nullable: Option<bool>

Indicates whether this field can be nullable or not.

is_retrievable: Option<bool>

Indicates whether this field can be added in Select clause of SQL query or whether it is retrievable or not.

is_filterable: Option<bool>

Indicates whether this field can used in a filter clause (WHERE clause) of a SQL statement when querying data.

is_partitionable: Option<bool>

Indicates whether a given field can be used in partitioning the query made to SaaS.

is_createable: Option<bool>

Indicates whether this field can be created as part of a destination write.

is_updateable: Option<bool>

Indicates whether this field can be updated as part of a destination write.

is_upsertable: Option<bool>

Indicates whether this field can be upserted as part of a destination write.

is_default_on_create: Option<bool>

Indicates whether this field is populated automatically when the object is created, such as a created at timestamp.

supported_values: Option<Vec<String>>

A list of supported values for the field.

supported_filter_operators: Option<Vec<FieldFilterOperator>>

Indicates the support filter operators for this field.

parent_field: Option<String>

A parent field name for a nested field.

native_data_type: Option<String>

The data type returned by the SaaS API, such as “picklist” or “textarea” from Salesforce.

custom_properties: Option<HashMap<String, String>>

Optional map of keys which may be returned.

Implementations

Source

impl Field

pub fn field_name(&self) -> Option<&str>

A unique identifier for the field.

pub fn label(&self) -> Option<&str>

A readable label used for the field.

pub fn description(&self) -> Option<&str>

A description of the field.

pub fn field_type(&self) -> Option<&FieldDataType>

The type of data in the field.

pub fn is_primary_key(&self) -> Option<bool>

Indicates whether this field can used as a primary key for the given entity.

pub fn is_nullable(&self) -> Option<bool>

Indicates whether this field can be nullable or not.

pub fn is_retrievable(&self) -> Option<bool>

Indicates whether this field can be added in Select clause of SQL query or whether it is retrievable or not.

pub fn is_filterable(&self) -> Option<bool>

Indicates whether this field can used in a filter clause (WHERE clause) of a SQL statement when querying data.

pub fn is_partitionable(&self) -> Option<bool>

Indicates whether a given field can be used in partitioning the query made to SaaS.

pub fn is_createable(&self) -> Option<bool>

Indicates whether this field can be created as part of a destination write.

pub fn is_updateable(&self) -> Option<bool>

Indicates whether this field can be updated as part of a destination write.

pub fn is_upsertable(&self) -> Option<bool>

Indicates whether this field can be upserted as part of a destination write.

pub fn is_default_on_create(&self) -> Option<bool>

Indicates whether this field is populated automatically when the object is created, such as a created at timestamp.

pub fn supported_values(&self) -> &[String]

A list of supported values for the field.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .supported_values.is_none().

pub fn supported_filter_operators(&self) -> &[FieldFilterOperator]

Indicates the support filter operators for this field.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .supported_filter_operators.is_none().

pub fn parent_field(&self) -> Option<&str>

A parent field name for a nested field.

pub fn native_data_type(&self) -> Option<&str>

The data type returned by the SaaS API, such as “picklist” or “textarea” from Salesforce.

pub fn custom_properties(&self) -> Option<&HashMap<String, String>>

Optional map of keys which may be returned.

Source

impl Field

pub fn builder() -> FieldBuilder

Creates a new builder-style object to manufacture Field.