#[non_exhaustive]pub struct IcebergCompactionMetrics {
pub number_of_bytes_compacted: i64,
pub number_of_files_compacted: i64,
pub dpu_hours: f64,
pub number_of_dpus: i32,
pub job_duration_in_hour: f64,
}Expand description
Compaction metrics for Iceberg for the optimizer run.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.number_of_bytes_compacted: i64The number of bytes removed by the compaction job run.
number_of_files_compacted: i64The number of files removed by the compaction job run.
dpu_hours: f64The number of DPU hours consumed by the job.
number_of_dpus: i32The number of DPUs consumed by the job, rounded up to the nearest whole number.
job_duration_in_hour: f64The duration of the job in hours.
Implementations
Sourceimpl IcebergCompactionMetrics
impl IcebergCompactionMetrics
Sourcepub fn number_of_bytes_compacted(&self) -> i64
pub fn number_of_bytes_compacted(&self) -> i64
The number of bytes removed by the compaction job run.
Sourcepub fn number_of_files_compacted(&self) -> i64
pub fn number_of_files_compacted(&self) -> i64
The number of files removed by the compaction job run.
Sourcepub fn number_of_dpus(&self) -> i32
pub fn number_of_dpus(&self) -> i32
The number of DPUs consumed by the job, rounded up to the nearest whole number.
Sourcepub fn job_duration_in_hour(&self) -> f64
pub fn job_duration_in_hour(&self) -> f64
The duration of the job in hours.
Sourceimpl IcebergCompactionMetrics
impl IcebergCompactionMetrics
Sourcepub fn builder() -> IcebergCompactionMetricsBuilder
pub fn builder() -> IcebergCompactionMetricsBuilder
Creates a new builder-style object to manufacture IcebergCompactionMetrics.