#[non_exhaustive]pub struct IcebergOptimizationPropertiesOutput {
pub role_arn: Option<String>,
pub compaction: Option<HashMap<String, String>>,
pub retention: Option<HashMap<String, String>>,
pub orphan_file_deletion: Option<HashMap<String, String>>,
pub last_updated_time: Option<DateTime>,
}Expand description
A structure that contains the output properties of Iceberg table optimization configuration for your catalog resource in the Glue Data Catalog.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.role_arn: Option<String>The Amazon Resource Name (ARN) of the IAM role that is used to perform Iceberg table optimization operations.
compaction: Option<HashMap<String, String>>A map of key-value pairs that specify configuration parameters for Iceberg table compaction operations, which optimize the layout of data files to improve query performance.
retention: Option<HashMap<String, String>>A map of key-value pairs that specify configuration parameters for Iceberg table retention operations, which manage the lifecycle of table snapshots to control storage costs.
orphan_file_deletion: Option<HashMap<String, String>>A map of key-value pairs that specify configuration parameters for Iceberg orphan file deletion operations, which identify and remove files that are no longer referenced by the table metadata.
last_updated_time: Option<DateTime>The timestamp when the Iceberg optimization properties were last updated.
Implementations
Sourceimpl IcebergOptimizationPropertiesOutput
impl IcebergOptimizationPropertiesOutput
Sourcepub fn role_arn(&self) -> Option<&str>
pub fn role_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the IAM role that is used to perform Iceberg table optimization operations.
Sourcepub fn compaction(&self) -> Option<&HashMap<String, String>>
pub fn compaction(&self) -> Option<&HashMap<String, String>>
A map of key-value pairs that specify configuration parameters for Iceberg table compaction operations, which optimize the layout of data files to improve query performance.
Sourcepub fn retention(&self) -> Option<&HashMap<String, String>>
pub fn retention(&self) -> Option<&HashMap<String, String>>
A map of key-value pairs that specify configuration parameters for Iceberg table retention operations, which manage the lifecycle of table snapshots to control storage costs.
Sourcepub fn orphan_file_deletion(&self) -> Option<&HashMap<String, String>>
pub fn orphan_file_deletion(&self) -> Option<&HashMap<String, String>>
A map of key-value pairs that specify configuration parameters for Iceberg orphan file deletion operations, which identify and remove files that are no longer referenced by the table metadata.
Sourcepub fn last_updated_time(&self) -> Option<&DateTime>
pub fn last_updated_time(&self) -> Option<&DateTime>
The timestamp when the Iceberg optimization properties were last updated.
Sourceimpl IcebergOptimizationPropertiesOutput
impl IcebergOptimizationPropertiesOutput
Sourcepub fn builder() -> IcebergOptimizationPropertiesOutputBuilder
pub fn builder() -> IcebergOptimizationPropertiesOutputBuilder
Creates a new builder-style object to manufacture IcebergOptimizationPropertiesOutput.