#[non_exhaustive]pub struct IcebergOrphanFileDeletionConfiguration {
pub orphan_file_retention_period_in_days: Option<i32>,
pub location: Option<String>,
pub run_rate_in_hours: Option<i32>,
}Expand description
The configuration for an Iceberg orphan file deletion optimizer.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.orphan_file_retention_period_in_days: Option<i32>The number of days that orphan files should be retained before file deletion. If an input is not provided, the default value 3 will be used.
location: Option<String>Specifies a directory in which to look for files (defaults to the table's location). You may choose a sub-directory rather than the top-level table location.
run_rate_in_hours: Option<i32>The interval in hours between orphan file deletion job runs. This parameter controls how frequently the orphan file deletion optimizer will run to clean up orphan files. The value must be between 3 and 168 hours (7 days). If an input is not provided, the default value 24 will be used.
Implementations
Sourceimpl IcebergOrphanFileDeletionConfiguration
impl IcebergOrphanFileDeletionConfiguration
Sourcepub fn orphan_file_retention_period_in_days(&self) -> Option<i32>
pub fn orphan_file_retention_period_in_days(&self) -> Option<i32>
The number of days that orphan files should be retained before file deletion. If an input is not provided, the default value 3 will be used.
Sourcepub fn location(&self) -> Option<&str>
pub fn location(&self) -> Option<&str>
Specifies a directory in which to look for files (defaults to the table's location). You may choose a sub-directory rather than the top-level table location.
Sourcepub fn run_rate_in_hours(&self) -> Option<i32>
pub fn run_rate_in_hours(&self) -> Option<i32>
The interval in hours between orphan file deletion job runs. This parameter controls how frequently the orphan file deletion optimizer will run to clean up orphan files. The value must be between 3 and 168 hours (7 days). If an input is not provided, the default value 24 will be used.
Sourceimpl IcebergOrphanFileDeletionConfiguration
impl IcebergOrphanFileDeletionConfiguration
Sourcepub fn builder() -> IcebergOrphanFileDeletionConfigurationBuilder
pub fn builder() -> IcebergOrphanFileDeletionConfigurationBuilder
Creates a new builder-style object to manufacture IcebergOrphanFileDeletionConfiguration.