#[non_exhaustive]pub struct IcebergPartitionSpec {
pub fields: Vec<IcebergPartitionField>,
pub spec_id: i32,
}Expand description
Defines the partitioning specification for an Iceberg table, determining how table data will be organized and partitioned for optimal query performance.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.fields: Vec<IcebergPartitionField>The list of partition fields that define how the table data should be partitioned, including source fields and their transformations.
spec_id: i32The unique identifier for this partition specification within the Iceberg table's metadata history.
Implementations
Sourceimpl IcebergPartitionSpec
impl IcebergPartitionSpec
Sourcepub fn fields(&self) -> &[IcebergPartitionField]
pub fn fields(&self) -> &[IcebergPartitionField]
The list of partition fields that define how the table data should be partitioned, including source fields and their transformations.
Sourceimpl IcebergPartitionSpec
impl IcebergPartitionSpec
Sourcepub fn builder() -> IcebergPartitionSpecBuilder
pub fn builder() -> IcebergPartitionSpecBuilder
Creates a new builder-style object to manufacture IcebergPartitionSpec.