#[non_exhaustive]pub struct IcebergRetentionConfiguration {
pub snapshot_retention_period_in_days: Option<i32>,
pub number_of_snapshots_to_retain: Option<i32>,
pub clean_expired_files: Option<bool>,
pub run_rate_in_hours: Option<i32>,
}Expand description
The configuration for an Iceberg snapshot retention optimizer.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.snapshot_retention_period_in_days: Option<i32>The number of days to retain the Iceberg snapshots. If an input is not provided, the corresponding Iceberg table configuration field will be used or if not present, the default value 5 will be used.
number_of_snapshots_to_retain: Option<i32>The number of Iceberg snapshots to retain within the retention period. If an input is not provided, the corresponding Iceberg table configuration field will be used or if not present, the default value 1 will be used.
clean_expired_files: Option<bool>If set to false, snapshots are only deleted from table metadata, and the underlying data and metadata files are not deleted.
run_rate_in_hours: Option<i32>The interval in hours between retention job runs. This parameter controls how frequently the retention optimizer will run to clean up expired snapshots. The value must be between 3 and 168 hours (7 days). If an input is not provided, the default value 24 will be used.
Implementations
Sourceimpl IcebergRetentionConfiguration
impl IcebergRetentionConfiguration
Sourcepub fn snapshot_retention_period_in_days(&self) -> Option<i32>
pub fn snapshot_retention_period_in_days(&self) -> Option<i32>
The number of days to retain the Iceberg snapshots. If an input is not provided, the corresponding Iceberg table configuration field will be used or if not present, the default value 5 will be used.
Sourcepub fn number_of_snapshots_to_retain(&self) -> Option<i32>
pub fn number_of_snapshots_to_retain(&self) -> Option<i32>
The number of Iceberg snapshots to retain within the retention period. If an input is not provided, the corresponding Iceberg table configuration field will be used or if not present, the default value 1 will be used.
Sourcepub fn clean_expired_files(&self) -> Option<bool>
pub fn clean_expired_files(&self) -> Option<bool>
If set to false, snapshots are only deleted from table metadata, and the underlying data and metadata files are not deleted.
Sourcepub fn run_rate_in_hours(&self) -> Option<i32>
pub fn run_rate_in_hours(&self) -> Option<i32>
The interval in hours between retention job runs. This parameter controls how frequently the retention optimizer will run to clean up expired snapshots. The value must be between 3 and 168 hours (7 days). If an input is not provided, the default value 24 will be used.
Sourceimpl IcebergRetentionConfiguration
impl IcebergRetentionConfiguration
Sourcepub fn builder() -> IcebergRetentionConfigurationBuilder
pub fn builder() -> IcebergRetentionConfigurationBuilder
Creates a new builder-style object to manufacture IcebergRetentionConfiguration.