#[non_exhaustive]pub struct IcebergRetentionMetrics {
pub number_of_data_files_deleted: i64,
pub number_of_manifest_files_deleted: i64,
pub number_of_manifest_lists_deleted: i64,
pub dpu_hours: f64,
pub number_of_dpus: i32,
pub job_duration_in_hour: f64,
}Expand description
Snapshot retention metrics for Iceberg for the optimizer run.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.number_of_data_files_deleted: i64The number of data files deleted by the retention job run.
number_of_manifest_files_deleted: i64The number of manifest files deleted by the retention job run.
number_of_manifest_lists_deleted: i64The number of manifest lists deleted by the retention job run.
dpu_hours: f64The number of DPU hours consumed by the job.
number_of_dpus: i32The number of DPUs consumed by the job, rounded up to the nearest whole number.
job_duration_in_hour: f64The duration of the job in hours.
Implementations
Sourceimpl IcebergRetentionMetrics
impl IcebergRetentionMetrics
Sourcepub fn number_of_data_files_deleted(&self) -> i64
pub fn number_of_data_files_deleted(&self) -> i64
The number of data files deleted by the retention job run.
Sourcepub fn number_of_manifest_files_deleted(&self) -> i64
pub fn number_of_manifest_files_deleted(&self) -> i64
The number of manifest files deleted by the retention job run.
Sourcepub fn number_of_manifest_lists_deleted(&self) -> i64
pub fn number_of_manifest_lists_deleted(&self) -> i64
The number of manifest lists deleted by the retention job run.
Sourcepub fn number_of_dpus(&self) -> i32
pub fn number_of_dpus(&self) -> i32
The number of DPUs consumed by the job, rounded up to the nearest whole number.
Sourcepub fn job_duration_in_hour(&self) -> f64
pub fn job_duration_in_hour(&self) -> f64
The duration of the job in hours.
Sourceimpl IcebergRetentionMetrics
impl IcebergRetentionMetrics
Sourcepub fn builder() -> IcebergRetentionMetricsBuilder
pub fn builder() -> IcebergRetentionMetricsBuilder
Creates a new builder-style object to manufacture IcebergRetentionMetrics.