#[non_exhaustive]pub struct InboundIntegration {
pub source_arn: String,
pub target_arn: String,
pub integration_arn: String,
pub status: IntegrationStatus,
pub create_time: DateTime,
pub integration_config: Option<IntegrationConfig>,
pub errors: Option<Vec<IntegrationError>>,
}Expand description
A structure for an integration that writes data into a resource.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source_arn: StringThe ARN of the source resource for the integration.
target_arn: StringThe ARN of the target resource for the integration.
integration_arn: StringThe ARN of the zero-ETL integration.
status: IntegrationStatusThe possible statuses are:
-
CREATING: The integration is being created.
-
ACTIVE: The integration creation succeeds.
-
MODIFYING: The integration is being modified.
-
FAILED: The integration creation fails.
-
DELETING: The integration is deleted.
-
SYNCING: The integration is synchronizing.
-
NEEDS_ATTENTION: The integration needs attention, such as synchronization.
create_time: DateTimeThe time that the integration was created, in UTC.
integration_config: Option<IntegrationConfig>Properties associated with the integration.
errors: Option<Vec<IntegrationError>>A list of errors associated with the integration.
Implementations
Sourceimpl InboundIntegration
impl InboundIntegration
Sourcepub fn source_arn(&self) -> &str
pub fn source_arn(&self) -> &str
The ARN of the source resource for the integration.
Sourcepub fn target_arn(&self) -> &str
pub fn target_arn(&self) -> &str
The ARN of the target resource for the integration.
Sourcepub fn integration_arn(&self) -> &str
pub fn integration_arn(&self) -> &str
The ARN of the zero-ETL integration.
Sourcepub fn status(&self) -> &IntegrationStatus
pub fn status(&self) -> &IntegrationStatus
The possible statuses are:
-
CREATING: The integration is being created.
-
ACTIVE: The integration creation succeeds.
-
MODIFYING: The integration is being modified.
-
FAILED: The integration creation fails.
-
DELETING: The integration is deleted.
-
SYNCING: The integration is synchronizing.
-
NEEDS_ATTENTION: The integration needs attention, such as synchronization.
Sourcepub fn create_time(&self) -> &DateTime
pub fn create_time(&self) -> &DateTime
The time that the integration was created, in UTC.
Sourcepub fn integration_config(&self) -> Option<&IntegrationConfig>
pub fn integration_config(&self) -> Option<&IntegrationConfig>
Properties associated with the integration.
Sourcepub fn errors(&self) -> &[IntegrationError]
pub fn errors(&self) -> &[IntegrationError]
A list of errors associated with the integration.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .errors.is_none().
Sourceimpl InboundIntegration
impl InboundIntegration
Sourcepub fn builder() -> InboundIntegrationBuilder
pub fn builder() -> InboundIntegrationBuilder
Creates a new builder-style object to manufacture InboundIntegration.