#[non_exhaustive]pub struct Integration {Show 13 fields
pub source_arn: String,
pub target_arn: String,
pub description: Option<String>,
pub integration_name: String,
pub integration_arn: String,
pub kms_key_id: Option<String>,
pub additional_encryption_context: Option<HashMap<String, String>>,
pub tags: Option<Vec<Tag>>,
pub status: IntegrationStatus,
pub create_time: DateTime,
pub integration_config: Option<IntegrationConfig>,
pub errors: Option<Vec<IntegrationError>>,
pub data_filter: Option<String>,
}Expand description
Describes a zero-ETL integration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source_arn: StringThe ARN for the source of the integration.
target_arn: StringThe ARN for the target of the integration.
description: Option<String>A description for the integration.
integration_name: StringA unique name for the integration.
integration_arn: StringThe Amazon Resource Name (ARN) for the integration.
kms_key_id: Option<String>The ARN of a KMS key used for encrypting the channel.
additional_encryption_context: Option<HashMap<String, String>>An optional set of non-secret key–value pairs that contains additional contextual information for encryption. This can only be provided if KMSKeyId is provided.
Metadata assigned to the resource consisting of a list of key-value pairs.
status: IntegrationStatusThe possible statuses are:
-
CREATING: The integration is being created.
-
ACTIVE: The integration creation succeeds.
-
MODIFYING: The integration is being modified.
-
FAILED: The integration creation fails.
-
DELETING: The integration is deleted.
-
SYNCING: The integration is synchronizing.
-
NEEDS_ATTENTION: The integration needs attention, such as synchronization.
create_time: DateTimeThe time that the integration was created, in UTC.
integration_config: Option<IntegrationConfig>Properties associated with the integration.
errors: Option<Vec<IntegrationError>>A list of errors associated with the integration.
data_filter: Option<String>Selects source tables for the integration using Maxwell filter syntax.
Implementations
Sourceimpl Integration
impl Integration
Sourcepub fn source_arn(&self) -> &str
pub fn source_arn(&self) -> &str
The ARN for the source of the integration.
Sourcepub fn target_arn(&self) -> &str
pub fn target_arn(&self) -> &str
The ARN for the target of the integration.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A description for the integration.
Sourcepub fn integration_name(&self) -> &str
pub fn integration_name(&self) -> &str
A unique name for the integration.
Sourcepub fn integration_arn(&self) -> &str
pub fn integration_arn(&self) -> &str
The Amazon Resource Name (ARN) for the integration.
Sourcepub fn kms_key_id(&self) -> Option<&str>
pub fn kms_key_id(&self) -> Option<&str>
The ARN of a KMS key used for encrypting the channel.
Sourcepub fn additional_encryption_context(&self) -> Option<&HashMap<String, String>>
pub fn additional_encryption_context(&self) -> Option<&HashMap<String, String>>
An optional set of non-secret key–value pairs that contains additional contextual information for encryption. This can only be provided if KMSKeyId is provided.
Metadata assigned to the resource consisting of a list of key-value pairs.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .tags.is_none().
Sourcepub fn status(&self) -> &IntegrationStatus
pub fn status(&self) -> &IntegrationStatus
The possible statuses are:
-
CREATING: The integration is being created.
-
ACTIVE: The integration creation succeeds.
-
MODIFYING: The integration is being modified.
-
FAILED: The integration creation fails.
-
DELETING: The integration is deleted.
-
SYNCING: The integration is synchronizing.
-
NEEDS_ATTENTION: The integration needs attention, such as synchronization.
Sourcepub fn create_time(&self) -> &DateTime
pub fn create_time(&self) -> &DateTime
The time that the integration was created, in UTC.
Sourcepub fn integration_config(&self) -> Option<&IntegrationConfig>
pub fn integration_config(&self) -> Option<&IntegrationConfig>
Properties associated with the integration.
Sourcepub fn errors(&self) -> &[IntegrationError]
pub fn errors(&self) -> &[IntegrationError]
A list of errors associated with the integration.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .errors.is_none().
Sourcepub fn data_filter(&self) -> Option<&str>
pub fn data_filter(&self) -> Option<&str>
Selects source tables for the integration using Maxwell filter syntax.
Sourceimpl Integration
impl Integration
Sourcepub fn builder() -> IntegrationBuilder
pub fn builder() -> IntegrationBuilder
Creates a new builder-style object to manufacture Integration.