#[non_exhaustive]pub struct IntegrationConfig {
pub refresh_interval: Option<String>,
pub source_properties: Option<HashMap<String, String>>,
pub continuous_sync: Option<bool>,
}Expand description
Properties associated with the integration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.refresh_interval: Option<String>Specifies the frequency at which CDC (Change Data Capture) pulls or incremental loads should occur. This parameter provides flexibility to align the refresh rate with your specific data update patterns, system load considerations, and performance optimization goals. Time increment can be set from 15 minutes to 8640 minutes (six days).
source_properties: Option<HashMap<String, String>>A collection of key-value pairs that specify additional properties for the integration source. These properties provide configuration options that can be used to customize the behavior of the ODB source during data integration operations.
continuous_sync: Option<bool>Enables continuous synchronization for on-demand data extractions from SaaS applications to Amazon Web Services data services like Amazon Redshift and Amazon S3.
Implementations
Sourceimpl IntegrationConfig
impl IntegrationConfig
Sourcepub fn refresh_interval(&self) -> Option<&str>
pub fn refresh_interval(&self) -> Option<&str>
Specifies the frequency at which CDC (Change Data Capture) pulls or incremental loads should occur. This parameter provides flexibility to align the refresh rate with your specific data update patterns, system load considerations, and performance optimization goals. Time increment can be set from 15 minutes to 8640 minutes (six days).
Sourcepub fn source_properties(&self) -> Option<&HashMap<String, String>>
pub fn source_properties(&self) -> Option<&HashMap<String, String>>
A collection of key-value pairs that specify additional properties for the integration source. These properties provide configuration options that can be used to customize the behavior of the ODB source during data integration operations.
Sourcepub fn continuous_sync(&self) -> Option<bool>
pub fn continuous_sync(&self) -> Option<bool>
Enables continuous synchronization for on-demand data extractions from SaaS applications to Amazon Web Services data services like Amazon Redshift and Amazon S3.
Sourceimpl IntegrationConfig
impl IntegrationConfig
Sourcepub fn builder() -> IntegrationConfigBuilder
pub fn builder() -> IntegrationConfigBuilder
Creates a new builder-style object to manufacture IntegrationConfig.