#[non_exhaustive]pub struct IntegrationTableProperties {
pub resource_arn: String,
pub table_name: String,
pub source_table_config: Option<SourceTableConfig>,
pub target_table_config: Option<TargetTableConfig>,
}Expand description
The properties of a single integration table, including the resource ARN, the table name, and the source or target table configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.resource_arn: StringThe connection ARN of the source, or the database ARN of the target.
table_name: StringThe name of the source table to be replicated.
source_table_config: Option<SourceTableConfig>A structure for the source table configuration.
target_table_config: Option<TargetTableConfig>A structure for the target table configuration.
Implementations
Sourceimpl IntegrationTableProperties
impl IntegrationTableProperties
Sourcepub fn resource_arn(&self) -> &str
pub fn resource_arn(&self) -> &str
The connection ARN of the source, or the database ARN of the target.
Sourcepub fn table_name(&self) -> &str
pub fn table_name(&self) -> &str
The name of the source table to be replicated.
Sourcepub fn source_table_config(&self) -> Option<&SourceTableConfig>
pub fn source_table_config(&self) -> Option<&SourceTableConfig>
A structure for the source table configuration.
Sourcepub fn target_table_config(&self) -> Option<&TargetTableConfig>
pub fn target_table_config(&self) -> Option<&TargetTableConfig>
A structure for the target table configuration.
Sourceimpl IntegrationTableProperties
impl IntegrationTableProperties
Sourcepub fn builder() -> IntegrationTablePropertiesBuilder
pub fn builder() -> IntegrationTablePropertiesBuilder
Creates a new builder-style object to manufacture IntegrationTableProperties.