#[non_exhaustive]pub struct ItemError {
pub item_identifier: Option<String>,
pub code: Option<String>,
pub message: Option<String>,
}Expand description
An error that occurred when retrieving an iterable form item.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.item_identifier: Option<String>The identifier of the item that caused the error.
code: Option<String>The error code.
message: Option<String>The error message.
Implementations