#[non_exhaustive]pub struct IterableFormEntry {
pub form_type_id: Option<String>,
}Expand description
An iterable form available on an asset, identified by its form type.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.form_type_id: Option<String>The form type identifier of the iterable form (for example, columns), used to retrieve its items via ListIterableForms or BatchGetIterableForms.
Implementations
Sourceimpl IterableFormEntry
impl IterableFormEntry
Sourcepub fn form_type_id(&self) -> Option<&str>
pub fn form_type_id(&self) -> Option<&str>
The form type identifier of the iterable form (for example, columns), used to retrieve its items via ListIterableForms or BatchGetIterableForms.
Sourceimpl IterableFormEntry
impl IterableFormEntry
Sourcepub fn builder() -> IterableFormEntryBuilder
pub fn builder() -> IterableFormEntryBuilder
Creates a new builder-style object to manufacture IterableFormEntry.