#[non_exhaustive]pub struct IterableFormItem {
pub item_id: Option<String>,
pub item_name: Option<String>,
pub glossary_terms: Option<Vec<String>>,
pub forms: Option<HashMap<String, AssetFormEntry>>,
pub attachments: Option<HashMap<String, AssetFormEntry>>,
}Expand description
A full iterable form item with its forms.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.item_id: Option<String>The unique identifier of the item.
item_name: Option<String>The name of the item.
glossary_terms: Option<Vec<String>>The identifiers of the glossary terms associated with the item.
forms: Option<HashMap<String, AssetFormEntry>>The forms on the item, keyed by form name.
attachments: Option<HashMap<String, AssetFormEntry>>Additional attachments on the item for more context, keyed by attachment name.
Implementations
Sourceimpl IterableFormItem
impl IterableFormItem
Sourcepub fn glossary_terms(&self) -> &[String]
pub fn glossary_terms(&self) -> &[String]
The identifiers of the glossary terms associated with the item.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .glossary_terms.is_none().
Sourcepub fn forms(&self) -> Option<&HashMap<String, AssetFormEntry>>
pub fn forms(&self) -> Option<&HashMap<String, AssetFormEntry>>
The forms on the item, keyed by form name.
Sourcepub fn attachments(&self) -> Option<&HashMap<String, AssetFormEntry>>
pub fn attachments(&self) -> Option<&HashMap<String, AssetFormEntry>>
Additional attachments on the item for more context, keyed by attachment name.
Sourceimpl IterableFormItem
impl IterableFormItem
Sourcepub fn builder() -> IterableFormItemBuilder
pub fn builder() -> IterableFormItemBuilder
Creates a new builder-style object to manufacture IterableFormItem.