#[non_exhaustive]pub struct JwtBearerProperties {
pub token_url: Option<ConnectorProperty>,
pub request_method: Option<HttpMethod>,
pub content_type: Option<ContentType>,
pub jwt_token: Option<ConnectorProperty>,
pub token_url_parameters: Option<Vec<ConnectorProperty>>,
}Expand description
JWT bearer token configuration that defines the properties needed for the JWT Bearer grant type flow.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.token_url: Option<ConnectorProperty>The token endpoint URL where the JWT bearer token will be exchanged for an access token.
request_method: Option<HttpMethod>The HTTP method to use when making JWT bearer token requests, typically POST.
content_type: Option<ContentType>The content type to use for JWT bearer token requests, such as application/x-www-form-urlencoded or application/json.
jwt_token: Option<ConnectorProperty>The JWT token to be used in the bearer token grant flow for authentication.
token_url_parameters: Option<Vec<ConnectorProperty>>Additional parameters to include in token URL requests as key-value pairs.
Implementations
Sourceimpl JwtBearerProperties
impl JwtBearerProperties
Sourcepub fn token_url(&self) -> Option<&ConnectorProperty>
pub fn token_url(&self) -> Option<&ConnectorProperty>
The token endpoint URL where the JWT bearer token will be exchanged for an access token.
Sourcepub fn request_method(&self) -> Option<&HttpMethod>
pub fn request_method(&self) -> Option<&HttpMethod>
The HTTP method to use when making JWT bearer token requests, typically POST.
Sourcepub fn content_type(&self) -> Option<&ContentType>
pub fn content_type(&self) -> Option<&ContentType>
The content type to use for JWT bearer token requests, such as application/x-www-form-urlencoded or application/json.
Sourcepub fn jwt_token(&self) -> Option<&ConnectorProperty>
pub fn jwt_token(&self) -> Option<&ConnectorProperty>
The JWT token to be used in the bearer token grant flow for authentication.
Sourcepub fn token_url_parameters(&self) -> &[ConnectorProperty]
pub fn token_url_parameters(&self) -> &[ConnectorProperty]
Additional parameters to include in token URL requests as key-value pairs.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .token_url_parameters.is_none().
Sourceimpl JwtBearerProperties
impl JwtBearerProperties
Sourcepub fn builder() -> JwtBearerPropertiesBuilder
pub fn builder() -> JwtBearerPropertiesBuilder
Creates a new builder-style object to manufacture JwtBearerProperties.