#[non_exhaustive]pub struct OAuth2Credentials {
pub user_managed_client_application_client_secret: Option<String>,
pub access_token: Option<String>,
pub refresh_token: Option<String>,
pub jwt_token: Option<String>,
}Expand description
The credentials used when the authentication type is OAuth2 authentication.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.user_managed_client_application_client_secret: Option<String>The client application client secret if the client application is user managed.
access_token: Option<String>The access token used when the authentication type is OAuth2.
refresh_token: Option<String>The refresh token used when the authentication type is OAuth2.
jwt_token: Option<String>The JSON Web Token (JWT) used when the authentication type is OAuth2.
Implementations
Sourceimpl OAuth2Credentials
impl OAuth2Credentials
Sourcepub fn user_managed_client_application_client_secret(&self) -> Option<&str>
pub fn user_managed_client_application_client_secret(&self) -> Option<&str>
The client application client secret if the client application is user managed.
Sourcepub fn access_token(&self) -> Option<&str>
pub fn access_token(&self) -> Option<&str>
The access token used when the authentication type is OAuth2.
Sourcepub fn refresh_token(&self) -> Option<&str>
pub fn refresh_token(&self) -> Option<&str>
The refresh token used when the authentication type is OAuth2.
Sourceimpl OAuth2Credentials
impl OAuth2Credentials
Sourcepub fn builder() -> OAuth2CredentialsBuilder
pub fn builder() -> OAuth2CredentialsBuilder
Creates a new builder-style object to manufacture OAuth2Credentials.