OAuth2Properties

Struct OAuth2Properties 

#[non_exhaustive]
pub struct OAuth2Properties { pub o_auth2_grant_type: Option<OAuth2GrantType>, pub o_auth2_client_application: Option<OAuth2ClientApplication>, pub token_url: Option<String>, pub token_url_parameters_map: Option<HashMap<String, String>>, }
A structure containing properties for OAuth2 authentication.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
o_auth2_grant_type: Option<OAuth2GrantType>

The OAuth2 grant type. For example, AUTHORIZATION_CODE, JWT_BEARER, or CLIENT_CREDENTIALS.

o_auth2_client_application: Option<OAuth2ClientApplication>

The client application type. For example, AWS_MANAGED or USER_MANAGED.

token_url: Option<String>

The URL of the provider's authentication server, to exchange an authorization code for an access token.

token_url_parameters_map: Option<HashMap<String, String>>

A map of parameters that are added to the token GET request.

Implementations

Source

impl OAuth2Properties

pub fn o_auth2_grant_type(&self) -> Option<&OAuth2GrantType>

The OAuth2 grant type. For example, AUTHORIZATION_CODE, JWT_BEARER, or CLIENT_CREDENTIALS.

pub fn o_auth2_client_application(&self) -> Option<&OAuth2ClientApplication>

The client application type. For example, AWS_MANAGED or USER_MANAGED.

pub fn token_url(&self) -> Option<&str>

The URL of the provider's authentication server, to exchange an authorization code for an access token.

pub fn token_url_parameters_map(&self) -> Option<&HashMap<String, String>>

A map of parameters that are added to the token GET request.

Source

impl OAuth2Properties

pub fn builder() -> OAuth2PropertiesBuilder

Creates a new builder-style object to manufacture OAuth2Properties.