#[non_exhaustive]pub struct ObservationResultsOptions {
pub write_observation_results_enabled: Option<bool>,
pub catalog_table_config: Option<CatalogTableConfigOptions>,
}Expand description
The configuration for writing observation results.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.write_observation_results_enabled: Option<bool>Set to true to write observation results.
catalog_table_config: Option<CatalogTableConfigOptions>The Glue Data Catalog table configuration for storing the observation results.
Implementations
Sourceimpl ObservationResultsOptions
impl ObservationResultsOptions
Sourcepub fn write_observation_results_enabled(&self) -> Option<bool>
pub fn write_observation_results_enabled(&self) -> Option<bool>
Set to true to write observation results.
Sourcepub fn catalog_table_config(&self) -> Option<&CatalogTableConfigOptions>
pub fn catalog_table_config(&self) -> Option<&CatalogTableConfigOptions>
The Glue Data Catalog table configuration for storing the observation results.
Sourceimpl ObservationResultsOptions
impl ObservationResultsOptions
Sourcepub fn builder() -> ObservationResultsOptionsBuilder
pub fn builder() -> ObservationResultsOptionsBuilder
Creates a new builder-style object to manufacture ObservationResultsOptions.