#[non_exhaustive]pub struct OffsetConfiguration {
pub offset_parameter: Option<ExtractedParameter>,
pub limit_parameter: Option<ExtractedParameter>,
}Expand description
Offset-based pagination configuration that defines how to handle pagination using numeric offsets and limits.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.offset_parameter: Option<ExtractedParameter>The parameter name used to specify the starting position or offset for retrieving results.
limit_parameter: Option<ExtractedParameter>The parameter name used to specify the maximum number of results to return per page.
Implementations
Sourceimpl OffsetConfiguration
impl OffsetConfiguration
Sourcepub fn offset_parameter(&self) -> Option<&ExtractedParameter>
pub fn offset_parameter(&self) -> Option<&ExtractedParameter>
The parameter name used to specify the starting position or offset for retrieving results.
Sourcepub fn limit_parameter(&self) -> Option<&ExtractedParameter>
pub fn limit_parameter(&self) -> Option<&ExtractedParameter>
The parameter name used to specify the maximum number of results to return per page.
Sourceimpl OffsetConfiguration
impl OffsetConfiguration
Sourcepub fn builder() -> OffsetConfigurationBuilder
pub fn builder() -> OffsetConfigurationBuilder
Creates a new builder-style object to manufacture OffsetConfiguration.