#[non_exhaustive]pub struct OrphanFileDeletionMetrics {
pub iceberg_metrics: Option<IcebergOrphanFileDeletionMetrics>,
}Expand description
A structure that contains orphan file deletion metrics for the optimizer run.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.iceberg_metrics: Option<IcebergOrphanFileDeletionMetrics>A structure containing the Iceberg orphan file deletion metrics for the optimizer run.
Implementations
Sourceimpl OrphanFileDeletionMetrics
impl OrphanFileDeletionMetrics
Sourcepub fn iceberg_metrics(&self) -> Option<&IcebergOrphanFileDeletionMetrics>
pub fn iceberg_metrics(&self) -> Option<&IcebergOrphanFileDeletionMetrics>
A structure containing the Iceberg orphan file deletion metrics for the optimizer run.
Sourceimpl OrphanFileDeletionMetrics
impl OrphanFileDeletionMetrics
Sourcepub fn builder() -> OrphanFileDeletionMetricsBuilder
pub fn builder() -> OrphanFileDeletionMetricsBuilder
Creates a new builder-style object to manufacture OrphanFileDeletionMetrics.