PiiDetection

Struct PiiDetection 

#[non_exhaustive]
pub struct PiiDetection {
Show 15 fields pub name: String, pub inputs: Vec<String>, pub pii_type: PiiType, pub entity_types_to_detect: Vec<String>, pub output_column_name: Option<String>, pub sample_fraction: Option<f64>, pub threshold_fraction: Option<f64>, pub mask_value: Option<String>, pub redact_text: Option<String>, pub redact_char: Option<String>, pub match_pattern: Option<String>, pub num_left_chars_to_exclude: Option<i32>, pub num_right_chars_to_exclude: Option<i32>, pub detection_parameters: Option<String>, pub detection_sensitivity: Option<String>,
}
Specifies a transform that identifies, removes or masks PII data.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

The name of the transform node.

inputs: Vec<String>

The node ID inputs to the transform.

pii_type: PiiType

Indicates the type of PIIDetection transform.

entity_types_to_detect: Vec<String>

Indicates the types of entities the PIIDetection transform will identify as PII data.

PII type entities include: PERSON_NAME, DATE, USA_SNN, EMAIL, USA_ITIN, USA_PASSPORT_NUMBER, PHONE_NUMBER, BANK_ACCOUNT, IP_ADDRESS, MAC_ADDRESS, USA_CPT_CODE, USA_HCPCS_CODE, USA_NATIONAL_DRUG_CODE, USA_MEDICARE_BENEFICIARY_IDENTIFIER, USA_HEALTH_INSURANCE_CLAIM_NUMBER,CREDIT_CARD,USA_NATIONAL_PROVIDER_IDENTIFIER,USA_DEA_NUMBER,USA_DRIVING_LICENSE

output_column_name: Option<String>

Indicates the output column name that will contain any entity type detected in that row.

sample_fraction: Option<f64>

Indicates the fraction of the data to sample when scanning for PII entities.

threshold_fraction: Option<f64>

Indicates the fraction of the data that must be met in order for a column to be identified as PII data.

mask_value: Option<String>

Indicates the value that will replace the detected entity.

redact_text: Option<String>

Specifies whether to redact the detected PII text. When set to true, PII content is replaced with redaction characters.

redact_char: Option<String>

The character used to replace detected PII content when redaction is enabled. The default redaction character is *.

match_pattern: Option<String>

A regular expression pattern used to identify additional PII content beyond the standard detection algorithms.

num_left_chars_to_exclude: Option<i32>

The number of characters to exclude from redaction on the left side of detected PII content. This allows preserving context around the sensitive data.

num_right_chars_to_exclude: Option<i32>

The number of characters to exclude from redaction on the right side of detected PII content. This allows preserving context around the sensitive data.

detection_parameters: Option<String>

Additional parameters for configuring PII detection behavior and sensitivity settings.

detection_sensitivity: Option<String>

The sensitivity level for PII detection. Higher sensitivity levels detect more potential PII but may result in more false positives.

Implementations

Source

impl PiiDetection

pub fn name(&self) -> &str

The name of the transform node.

pub fn inputs(&self) -> &[String]

The node ID inputs to the transform.

pub fn pii_type(&self) -> &PiiType

Indicates the type of PIIDetection transform.

pub fn entity_types_to_detect(&self) -> &[String]

Indicates the types of entities the PIIDetection transform will identify as PII data.

PII type entities include: PERSON_NAME, DATE, USA_SNN, EMAIL, USA_ITIN, USA_PASSPORT_NUMBER, PHONE_NUMBER, BANK_ACCOUNT, IP_ADDRESS, MAC_ADDRESS, USA_CPT_CODE, USA_HCPCS_CODE, USA_NATIONAL_DRUG_CODE, USA_MEDICARE_BENEFICIARY_IDENTIFIER, USA_HEALTH_INSURANCE_CLAIM_NUMBER,CREDIT_CARD,USA_NATIONAL_PROVIDER_IDENTIFIER,USA_DEA_NUMBER,USA_DRIVING_LICENSE

pub fn output_column_name(&self) -> Option<&str>

Indicates the output column name that will contain any entity type detected in that row.

pub fn sample_fraction(&self) -> Option<f64>

Indicates the fraction of the data to sample when scanning for PII entities.

pub fn threshold_fraction(&self) -> Option<f64>

Indicates the fraction of the data that must be met in order for a column to be identified as PII data.

pub fn mask_value(&self) -> Option<&str>

Indicates the value that will replace the detected entity.

pub fn redact_text(&self) -> Option<&str>

Specifies whether to redact the detected PII text. When set to true, PII content is replaced with redaction characters.

pub fn redact_char(&self) -> Option<&str>

The character used to replace detected PII content when redaction is enabled. The default redaction character is *.

pub fn match_pattern(&self) -> Option<&str>

A regular expression pattern used to identify additional PII content beyond the standard detection algorithms.

pub fn num_left_chars_to_exclude(&self) -> Option<i32>

The number of characters to exclude from redaction on the left side of detected PII content. This allows preserving context around the sensitive data.

pub fn num_right_chars_to_exclude(&self) -> Option<i32>

The number of characters to exclude from redaction on the right side of detected PII content. This allows preserving context around the sensitive data.

pub fn detection_parameters(&self) -> Option<&str>

Additional parameters for configuring PII detection behavior and sensitivity settings.

pub fn detection_sensitivity(&self) -> Option<&str>

The sensitivity level for PII detection. Higher sensitivity levels detect more potential PII but may result in more false positives.

Source

impl PiiDetection

pub fn builder() -> PiiDetectionBuilder

Creates a new builder-style object to manufacture PiiDetection.