#[non_exhaustive]pub struct ProfilingResultsOptions {
pub write_profiling_results_enabled: Option<bool>,
pub catalog_table_config: Option<CatalogTableConfigOptions>,
pub distribution_results: Option<DistributionResultsOptions>,
}Expand description
The configuration for writing profiling results.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.write_profiling_results_enabled: Option<bool>Set to true to write profiling results.
catalog_table_config: Option<CatalogTableConfigOptions>The Glue Data Catalog table configuration for storing the profiling results.
distribution_results: Option<DistributionResultsOptions>The configuration for writing distribution results.
Implementations
Sourceimpl ProfilingResultsOptions
impl ProfilingResultsOptions
Sourcepub fn write_profiling_results_enabled(&self) -> Option<bool>
pub fn write_profiling_results_enabled(&self) -> Option<bool>
Set to true to write profiling results.
Sourcepub fn catalog_table_config(&self) -> Option<&CatalogTableConfigOptions>
pub fn catalog_table_config(&self) -> Option<&CatalogTableConfigOptions>
The Glue Data Catalog table configuration for storing the profiling results.
Sourcepub fn distribution_results(&self) -> Option<&DistributionResultsOptions>
pub fn distribution_results(&self) -> Option<&DistributionResultsOptions>
The configuration for writing distribution results.
Sourceimpl ProfilingResultsOptions
impl ProfilingResultsOptions
Sourcepub fn builder() -> ProfilingResultsOptionsBuilder
pub fn builder() -> ProfilingResultsOptionsBuilder
Creates a new builder-style object to manufacture ProfilingResultsOptions.