#[non_exhaustive]pub struct Property {
pub name: String,
pub description: String,
pub required: bool,
pub default_value: Option<String>,
pub property_types: Vec<PropertyType>,
pub allowed_values: Option<Vec<AllowedValue>>,
pub data_operation_scopes: Option<Vec<DataOperation>>,
pub key_override: Option<String>,
pub property_location: Option<PropertyLocation>,
}Expand description
An object that defines a connection type for a compute environment.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name of the property.
description: StringA description of the property.
required: boolIndicates whether the property is required.
default_value: Option<String>The default value for the property.
property_types: Vec<PropertyType>Describes the type of property.
allowed_values: Option<Vec<AllowedValue>>A list of AllowedValue objects representing the values allowed for the property.
data_operation_scopes: Option<Vec<DataOperation>>Indicates which data operations are applicable to the property.
key_override: Option<String>A key name to use when sending this property in API requests, if different from the display name.
property_location: Option<PropertyLocation>Specifies where this property should be included in REST requests, such as in headers, query parameters, or request body.
Implementations
Sourceimpl Property
impl Property
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
A description of the property.
Sourcepub fn default_value(&self) -> Option<&str>
pub fn default_value(&self) -> Option<&str>
The default value for the property.
Sourcepub fn property_types(&self) -> &[PropertyType]
pub fn property_types(&self) -> &[PropertyType]
Describes the type of property.
Sourcepub fn allowed_values(&self) -> &[AllowedValue]
pub fn allowed_values(&self) -> &[AllowedValue]
A list of AllowedValue objects representing the values allowed for the property.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .allowed_values.is_none().
Sourcepub fn data_operation_scopes(&self) -> &[DataOperation]
pub fn data_operation_scopes(&self) -> &[DataOperation]
Indicates which data operations are applicable to the property.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .data_operation_scopes.is_none().
Sourcepub fn key_override(&self) -> Option<&str>
pub fn key_override(&self) -> Option<&str>
A key name to use when sending this property in API requests, if different from the display name.
Sourcepub fn property_location(&self) -> Option<&PropertyLocation>
pub fn property_location(&self) -> Option<&PropertyLocation>
Specifies where this property should be included in REST requests, such as in headers, query parameters, or request body.