#[non_exhaustive]pub struct QuerySessionContext {
pub query_id: Option<String>,
pub query_start_time: Option<DateTime>,
pub cluster_id: Option<String>,
pub query_authorization_id: Option<String>,
pub additional_context: Option<HashMap<String, String>>,
}Expand description
A structure used as a protocol between query engines and Lake Formation or Glue. Contains both a Lake Formation generated authorization identifier and information from the request's authorization context.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.query_id: Option<String>A unique identifier generated by the query engine for the query.
query_start_time: Option<DateTime>A timestamp provided by the query engine for when the query started.
cluster_id: Option<String>An identifier string for the consumer cluster.
A cryptographically generated query identifier generated by Glue or Lake Formation.
additional_context: Option<HashMap<String, String>>An opaque string-string map passed by the query engine.
Implementations
Sourceimpl QuerySessionContext
impl QuerySessionContext
Sourcepub fn query_id(&self) -> Option<&str>
pub fn query_id(&self) -> Option<&str>
A unique identifier generated by the query engine for the query.
Sourcepub fn query_start_time(&self) -> Option<&DateTime>
pub fn query_start_time(&self) -> Option<&DateTime>
A timestamp provided by the query engine for when the query started.
Sourcepub fn cluster_id(&self) -> Option<&str>
pub fn cluster_id(&self) -> Option<&str>
An identifier string for the consumer cluster.
A cryptographically generated query identifier generated by Glue or Lake Formation.
Sourceimpl QuerySessionContext
impl QuerySessionContext
Sourcepub fn builder() -> QuerySessionContextBuilder
pub fn builder() -> QuerySessionContextBuilder
Creates a new builder-style object to manufacture QuerySessionContext.