#[non_exhaustive]pub struct ResponseConfiguration {
pub result_path: String,
pub error_path: Option<String>,
}Expand description
Configuration that defines how to parse JSON responses from REST API calls, including paths to result data and error information.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.result_path: StringThe JSON path expression that identifies where the actual result data is located within the API response.
error_path: Option<String>The JSON path expression that identifies where error information is located within API responses when requests fail.
Implementations
Sourceimpl ResponseConfiguration
impl ResponseConfiguration
Sourcepub fn result_path(&self) -> &str
pub fn result_path(&self) -> &str
The JSON path expression that identifies where the actual result data is located within the API response.
Sourcepub fn error_path(&self) -> Option<&str>
pub fn error_path(&self) -> Option<&str>
The JSON path expression that identifies where error information is located within API responses when requests fail.
Sourceimpl ResponseConfiguration
impl ResponseConfiguration
Sourcepub fn builder() -> ResponseConfigurationBuilder
pub fn builder() -> ResponseConfigurationBuilder
Creates a new builder-style object to manufacture ResponseConfiguration.