#[non_exhaustive]pub struct ResponseExtractionMapping {
pub content_path: Option<String>,
pub header_key: Option<String>,
}Expand description
Configuration that defines how to extract values from HTTP response content or headers for use in subsequent requests or parameter mapping.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.content_path: Option<String>A JSON path expression that specifies how to extract a value from the response body content.
header_key: Option<String>The name of an HTTP response header from which to extract the value.
Implementations
Sourceimpl ResponseExtractionMapping
impl ResponseExtractionMapping
Sourcepub fn content_path(&self) -> Option<&str>
pub fn content_path(&self) -> Option<&str>
A JSON path expression that specifies how to extract a value from the response body content.
Sourcepub fn header_key(&self) -> Option<&str>
pub fn header_key(&self) -> Option<&str>
The name of an HTTP response header from which to extract the value.
Sourceimpl ResponseExtractionMapping
impl ResponseExtractionMapping
Sourcepub fn builder() -> ResponseExtractionMappingBuilder
pub fn builder() -> ResponseExtractionMappingBuilder
Creates a new builder-style object to manufacture ResponseExtractionMapping.