#[non_exhaustive]pub struct RetentionMetrics {
pub iceberg_metrics: Option<IcebergRetentionMetrics>,
}Expand description
A structure that contains retention metrics for the optimizer run.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.iceberg_metrics: Option<IcebergRetentionMetrics>A structure containing the Iceberg retention metrics for the optimizer run.
Implementations
Sourceimpl RetentionMetrics
impl RetentionMetrics
Sourcepub fn iceberg_metrics(&self) -> Option<&IcebergRetentionMetrics>
pub fn iceberg_metrics(&self) -> Option<&IcebergRetentionMetrics>
A structure containing the Iceberg retention metrics for the optimizer run.
Sourceimpl RetentionMetrics
impl RetentionMetrics
Sourcepub fn builder() -> RetentionMetricsBuilder
pub fn builder() -> RetentionMetricsBuilder
Creates a new builder-style object to manufacture RetentionMetrics.