#[non_exhaustive]pub struct Route {
pub name: String,
pub inputs: Vec<String>,
pub group_filters_list: Vec<GroupFilters>,
}Expand description
Specifies a route node that directs data to different output paths based on defined filtering conditions.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name of the route node.
inputs: Vec<String>The input connection for the route node.
group_filters_list: Vec<GroupFilters>A list of group filters that define the routing conditions and criteria for directing data to different output paths.
Implementations
Sourceimpl Route
impl Route
Sourcepub fn group_filters_list(&self) -> &[GroupFilters]
pub fn group_filters_list(&self) -> &[GroupFilters]
A list of group filters that define the routing conditions and criteria for directing data to different output paths.