#[non_exhaustive]pub struct RowLevelResultsOptions {
pub max_rows_to_write: Option<i32>,
pub result_type: Option<ResultTypeEnum>,
pub catalog_table_config: Option<CatalogTableConfigOptions>,
}Expand description
The configuration for writing row-level evaluation results.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.max_rows_to_write: Option<i32>The maximum number of rows to write in the results.
result_type: Option<ResultTypeEnum>The result type to include in the row-level results output.
catalog_table_config: Option<CatalogTableConfigOptions>The Glue Data Catalog table configuration for storing the results.
Implementations
Sourceimpl RowLevelResultsOptions
impl RowLevelResultsOptions
Sourcepub fn max_rows_to_write(&self) -> Option<i32>
pub fn max_rows_to_write(&self) -> Option<i32>
The maximum number of rows to write in the results.
Sourcepub fn result_type(&self) -> Option<&ResultTypeEnum>
pub fn result_type(&self) -> Option<&ResultTypeEnum>
The result type to include in the row-level results output.
Sourcepub fn catalog_table_config(&self) -> Option<&CatalogTableConfigOptions>
pub fn catalog_table_config(&self) -> Option<&CatalogTableConfigOptions>
The Glue Data Catalog table configuration for storing the results.
Sourceimpl RowLevelResultsOptions
impl RowLevelResultsOptions
Sourcepub fn builder() -> RowLevelResultsOptionsBuilder
pub fn builder() -> RowLevelResultsOptionsBuilder
Creates a new builder-style object to manufacture RowLevelResultsOptions.