#[non_exhaustive]pub struct RunMetrics {
pub number_of_bytes_compacted: Option<String>,
pub number_of_files_compacted: Option<String>,
pub number_of_dpus: Option<String>,
pub job_duration_in_hour: Option<String>,
}Expand description
Metrics for the optimizer run.
This structure is deprecated. See the individual metric members for compaction, retention, and orphan file deletion.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.number_of_bytes_compacted: Option<String>The number of bytes removed by the compaction job run.
number_of_files_compacted: Option<String>The number of files removed by the compaction job run.
number_of_dpus: Option<String>The number of DPUs consumed by the job, rounded up to the nearest whole number.
job_duration_in_hour: Option<String>The duration of the job in hours.
Implementations
Sourceimpl RunMetrics
impl RunMetrics
Sourcepub fn number_of_bytes_compacted(&self) -> Option<&str>
pub fn number_of_bytes_compacted(&self) -> Option<&str>
The number of bytes removed by the compaction job run.
Sourcepub fn number_of_files_compacted(&self) -> Option<&str>
pub fn number_of_files_compacted(&self) -> Option<&str>
The number of files removed by the compaction job run.
Sourcepub fn number_of_dpus(&self) -> Option<&str>
pub fn number_of_dpus(&self) -> Option<&str>
The number of DPUs consumed by the job, rounded up to the nearest whole number.
Sourcepub fn job_duration_in_hour(&self) -> Option<&str>
pub fn job_duration_in_hour(&self) -> Option<&str>
The duration of the job in hours.
Sourceimpl RunMetrics
impl RunMetrics
Sourcepub fn builder() -> RunMetricsBuilder
pub fn builder() -> RunMetricsBuilder
Creates a new builder-style object to manufacture RunMetrics.