#[non_exhaustive]pub struct S3DeltaDirectTarget {
pub name: String,
pub inputs: Vec<String>,
pub partition_keys: Option<Vec<Vec<String>>>,
pub path: String,
pub compression: DeltaTargetCompressionType,
pub number_target_partitions: Option<String>,
pub format: TargetFormat,
pub additional_options: Option<HashMap<String, String>>,
pub schema_change_policy: Option<DirectSchemaChangePolicy>,
pub auto_data_quality: Option<AutoDataQuality>,
}Expand description
Specifies a target that writes to a Delta Lake data source in Amazon S3.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name of the data target.
inputs: Vec<String>The nodes that are inputs to the data target.
partition_keys: Option<Vec<Vec<String>>>Specifies native partitioning using a sequence of keys.
path: StringThe Amazon S3 path of your Delta Lake data source to write to.
compression: DeltaTargetCompressionTypeSpecifies how the data is compressed. This is generally not necessary if the data has a standard file extension. Possible values are "gzip" and "bzip").
number_target_partitions: Option<String>Specifies the number of target partitions for distributing Delta Lake dataset files across Amazon S3.
format: TargetFormatSpecifies the data output format for the target.
additional_options: Option<HashMap<String, String>>Specifies additional connection options for the connector.
schema_change_policy: Option<DirectSchemaChangePolicy>A policy that specifies update behavior for the crawler.
auto_data_quality: Option<AutoDataQuality>Specifies whether to automatically enable data quality evaluation for the S3 Delta direct target. When set to true, data quality checks are performed automatically during the write operation.
Implementations
Sourceimpl S3DeltaDirectTarget
impl S3DeltaDirectTarget
Sourcepub fn partition_keys(&self) -> &[Vec<String>]
pub fn partition_keys(&self) -> &[Vec<String>]
Specifies native partitioning using a sequence of keys.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .partition_keys.is_none().
Sourcepub fn compression(&self) -> &DeltaTargetCompressionType
pub fn compression(&self) -> &DeltaTargetCompressionType
Specifies how the data is compressed. This is generally not necessary if the data has a standard file extension. Possible values are "gzip" and "bzip").
Sourcepub fn number_target_partitions(&self) -> Option<&str>
pub fn number_target_partitions(&self) -> Option<&str>
Specifies the number of target partitions for distributing Delta Lake dataset files across Amazon S3.
Sourcepub fn format(&self) -> &TargetFormat
pub fn format(&self) -> &TargetFormat
Specifies the data output format for the target.
Sourcepub fn additional_options(&self) -> Option<&HashMap<String, String>>
pub fn additional_options(&self) -> Option<&HashMap<String, String>>
Specifies additional connection options for the connector.
Sourcepub fn schema_change_policy(&self) -> Option<&DirectSchemaChangePolicy>
pub fn schema_change_policy(&self) -> Option<&DirectSchemaChangePolicy>
A policy that specifies update behavior for the crawler.
Sourcepub fn auto_data_quality(&self) -> Option<&AutoDataQuality>
pub fn auto_data_quality(&self) -> Option<&AutoDataQuality>
Specifies whether to automatically enable data quality evaluation for the S3 Delta direct target. When set to true, data quality checks are performed automatically during the write operation.
Sourceimpl S3DeltaDirectTarget
impl S3DeltaDirectTarget
Sourcepub fn builder() -> S3DeltaDirectTargetBuilder
pub fn builder() -> S3DeltaDirectTargetBuilder
Creates a new builder-style object to manufacture S3DeltaDirectTarget.