#[non_exhaustive]pub struct S3DirectTarget {
pub name: String,
pub inputs: Vec<String>,
pub partition_keys: Option<Vec<Vec<String>>>,
pub path: String,
pub compression: Option<String>,
pub number_target_partitions: Option<String>,
pub format: TargetFormat,
pub schema_change_policy: Option<DirectSchemaChangePolicy>,
pub auto_data_quality: Option<AutoDataQuality>,
pub output_schemas: Option<Vec<GlueSchema>>,
}Expand description
Specifies a data target that writes to Amazon S3.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name of the data target.
inputs: Vec<String>The nodes that are inputs to the data target.
partition_keys: Option<Vec<Vec<String>>>Specifies native partitioning using a sequence of keys.
path: StringA single Amazon S3 path to write to.
compression: Option<String>Specifies how the data is compressed. This is generally not necessary if the data has a standard file extension. Possible values are "gzip" and "bzip").
number_target_partitions: Option<String>Specifies the number of target partitions when writing data directly to Amazon S3.
format: TargetFormatSpecifies the data output format for the target.
schema_change_policy: Option<DirectSchemaChangePolicy>A policy that specifies update behavior for the crawler.
auto_data_quality: Option<AutoDataQuality>Specifies whether to automatically enable data quality evaluation for the S3 direct target. When set to true, data quality checks are performed automatically during the write operation.
output_schemas: Option<Vec<GlueSchema>>Specifies the data schema for the S3 direct target.
Implementations
Sourceimpl S3DirectTarget
impl S3DirectTarget
Sourcepub fn partition_keys(&self) -> &[Vec<String>]
pub fn partition_keys(&self) -> &[Vec<String>]
Specifies native partitioning using a sequence of keys.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .partition_keys.is_none().
Sourcepub fn compression(&self) -> Option<&str>
pub fn compression(&self) -> Option<&str>
Specifies how the data is compressed. This is generally not necessary if the data has a standard file extension. Possible values are "gzip" and "bzip").
Sourcepub fn number_target_partitions(&self) -> Option<&str>
pub fn number_target_partitions(&self) -> Option<&str>
Specifies the number of target partitions when writing data directly to Amazon S3.
Sourcepub fn format(&self) -> &TargetFormat
pub fn format(&self) -> &TargetFormat
Specifies the data output format for the target.
Sourcepub fn schema_change_policy(&self) -> Option<&DirectSchemaChangePolicy>
pub fn schema_change_policy(&self) -> Option<&DirectSchemaChangePolicy>
A policy that specifies update behavior for the crawler.
Sourcepub fn auto_data_quality(&self) -> Option<&AutoDataQuality>
pub fn auto_data_quality(&self) -> Option<&AutoDataQuality>
Specifies whether to automatically enable data quality evaluation for the S3 direct target. When set to true, data quality checks are performed automatically during the write operation.
Sourcepub fn output_schemas(&self) -> &[GlueSchema]
pub fn output_schemas(&self) -> &[GlueSchema]
Specifies the data schema for the S3 direct target.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .output_schemas.is_none().
Sourceimpl S3DirectTarget
impl S3DirectTarget
Sourcepub fn builder() -> S3DirectTargetBuilder
pub fn builder() -> S3DirectTargetBuilder
Creates a new builder-style object to manufacture S3DirectTarget.