#[non_exhaustive]pub struct S3ExcelSource {Show 13 fields
pub name: String,
pub paths: Vec<String>,
pub compression_type: Option<ParquetCompressionType>,
pub exclusions: Option<Vec<String>>,
pub group_size: Option<String>,
pub group_files: Option<String>,
pub recurse: Option<bool>,
pub max_band: Option<i32>,
pub max_files_in_band: Option<i32>,
pub additional_options: Option<S3DirectSourceAdditionalOptions>,
pub number_rows: Option<i64>,
pub skip_footer: Option<i32>,
pub output_schemas: Option<Vec<GlueSchema>>,
}Expand description
Specifies an S3 Excel data source.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name of the S3 Excel data source.
paths: Vec<String>The S3 paths where the Excel files are located.
compression_type: Option<ParquetCompressionType>The compression format used for the Excel files.
exclusions: Option<Vec<String>>Patterns to exclude specific files or paths from processing.
group_size: Option<String>Defines the size of file groups for batch processing.
group_files: Option<String>Specifies how files should be grouped for processing.
recurse: Option<bool>Indicates whether to recursively process subdirectories.
max_band: Option<i32>The maximum number of processing bands to use.
max_files_in_band: Option<i32>The maximum number of files to process in each band.
additional_options: Option<S3DirectSourceAdditionalOptions>Additional configuration options for S3 direct source processing.
number_rows: Option<i64>The number of rows to process from each Excel file.
The number of rows to skip at the end of each Excel file.
output_schemas: Option<Vec<GlueSchema>>The Glue schemas to apply to the processed data.
Implementations
Sourceimpl S3ExcelSource
impl S3ExcelSource
Sourcepub fn compression_type(&self) -> Option<&ParquetCompressionType>
pub fn compression_type(&self) -> Option<&ParquetCompressionType>
The compression format used for the Excel files.
Sourcepub fn exclusions(&self) -> &[String]
pub fn exclusions(&self) -> &[String]
Patterns to exclude specific files or paths from processing.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .exclusions.is_none().
Sourcepub fn group_size(&self) -> Option<&str>
pub fn group_size(&self) -> Option<&str>
Defines the size of file groups for batch processing.
Sourcepub fn group_files(&self) -> Option<&str>
pub fn group_files(&self) -> Option<&str>
Specifies how files should be grouped for processing.
Sourcepub fn max_files_in_band(&self) -> Option<i32>
pub fn max_files_in_band(&self) -> Option<i32>
The maximum number of files to process in each band.
Sourcepub fn additional_options(&self) -> Option<&S3DirectSourceAdditionalOptions>
pub fn additional_options(&self) -> Option<&S3DirectSourceAdditionalOptions>
Additional configuration options for S3 direct source processing.
Sourcepub fn number_rows(&self) -> Option<i64>
pub fn number_rows(&self) -> Option<i64>
The number of rows to process from each Excel file.
The number of rows to skip at the end of each Excel file.
Sourcepub fn output_schemas(&self) -> &[GlueSchema]
pub fn output_schemas(&self) -> &[GlueSchema]
The Glue schemas to apply to the processed data.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .output_schemas.is_none().
Sourceimpl S3ExcelSource
impl S3ExcelSource
Sourcepub fn builder() -> S3ExcelSourceBuilder
pub fn builder() -> S3ExcelSourceBuilder
Creates a new builder-style object to manufacture S3ExcelSource.