#[non_exhaustive]pub struct S3GlueParquetTarget {
pub name: String,
pub inputs: Vec<String>,
pub partition_keys: Option<Vec<Vec<String>>>,
pub path: String,
pub compression: Option<ParquetCompressionType>,
pub number_target_partitions: Option<String>,
pub schema_change_policy: Option<DirectSchemaChangePolicy>,
pub auto_data_quality: Option<AutoDataQuality>,
}Expand description
Specifies a data target that writes to Amazon S3 in Apache Parquet columnar storage.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name of the data target.
inputs: Vec<String>The nodes that are inputs to the data target.
partition_keys: Option<Vec<Vec<String>>>Specifies native partitioning using a sequence of keys.
path: StringA single Amazon S3 path to write to.
compression: Option<ParquetCompressionType>Specifies how the data is compressed. This is generally not necessary if the data has a standard file extension. Possible values are "gzip" and "bzip").
number_target_partitions: Option<String>Specifies the number of target partitions for Parquet files when writing to Amazon S3 using Glue.
schema_change_policy: Option<DirectSchemaChangePolicy>A policy that specifies update behavior for the crawler.
auto_data_quality: Option<AutoDataQuality>Specifies whether to automatically enable data quality evaluation for the S3 Glue Parquet target. When set to true, data quality checks are performed automatically during the write operation.
Implementations
Sourceimpl S3GlueParquetTarget
impl S3GlueParquetTarget
Sourcepub fn partition_keys(&self) -> &[Vec<String>]
pub fn partition_keys(&self) -> &[Vec<String>]
Specifies native partitioning using a sequence of keys.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .partition_keys.is_none().
Sourcepub fn compression(&self) -> Option<&ParquetCompressionType>
pub fn compression(&self) -> Option<&ParquetCompressionType>
Specifies how the data is compressed. This is generally not necessary if the data has a standard file extension. Possible values are "gzip" and "bzip").
Sourcepub fn number_target_partitions(&self) -> Option<&str>
pub fn number_target_partitions(&self) -> Option<&str>
Specifies the number of target partitions for Parquet files when writing to Amazon S3 using Glue.
Sourcepub fn schema_change_policy(&self) -> Option<&DirectSchemaChangePolicy>
pub fn schema_change_policy(&self) -> Option<&DirectSchemaChangePolicy>
A policy that specifies update behavior for the crawler.
Sourcepub fn auto_data_quality(&self) -> Option<&AutoDataQuality>
pub fn auto_data_quality(&self) -> Option<&AutoDataQuality>
Specifies whether to automatically enable data quality evaluation for the S3 Glue Parquet target. When set to true, data quality checks are performed automatically during the write operation.
Sourceimpl S3GlueParquetTarget
impl S3GlueParquetTarget
Sourcepub fn builder() -> S3GlueParquetTargetBuilder
pub fn builder() -> S3GlueParquetTargetBuilder
Creates a new builder-style object to manufacture S3GlueParquetTarget.