S3HyperDirectTarget

Struct S3HyperDirectTarget 

#[non_exhaustive]
pub struct S3HyperDirectTarget { pub name: String, pub inputs: Vec<String>, pub format: Option<TargetFormat>, pub partition_keys: Option<Vec<Vec<String>>>, pub path: String, pub compression: Option<HyperTargetCompressionType>, pub schema_change_policy: Option<DirectSchemaChangePolicy>, pub auto_data_quality: Option<AutoDataQuality>, pub output_schemas: Option<Vec<GlueSchema>>, }
Specifies a HyperDirect data target that writes to Amazon S3.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

The unique identifier for the HyperDirect target node.

inputs: Vec<String>

Specifies the input source for the HyperDirect target.

format: Option<TargetFormat>

Specifies the data output format for the HyperDirect target.

partition_keys: Option<Vec<Vec<String>>>

Defines the partitioning strategy for the output data.

path: String

The S3 location where the output data will be written.

compression: Option<HyperTargetCompressionType>

The compression type to apply to the output data.

schema_change_policy: Option<DirectSchemaChangePolicy>

Defines how schema changes are handled during write operations.

auto_data_quality: Option<AutoDataQuality>

Specifies whether to automatically enable data quality evaluation for the S3 Hyper direct target. When set to true, data quality checks are performed automatically during the write operation.

output_schemas: Option<Vec<GlueSchema>>

Specifies the data schema for the S3 Hyper direct target.

Implementations

Source

impl S3HyperDirectTarget

pub fn name(&self) -> &str

The unique identifier for the HyperDirect target node.

pub fn inputs(&self) -> &[String]

Specifies the input source for the HyperDirect target.

pub fn format(&self) -> Option<&TargetFormat>

Specifies the data output format for the HyperDirect target.

pub fn partition_keys(&self) -> &[Vec<String>]

Defines the partitioning strategy for the output data.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .partition_keys.is_none().

pub fn path(&self) -> &str

The S3 location where the output data will be written.

pub fn compression(&self) -> Option<&HyperTargetCompressionType>

The compression type to apply to the output data.

pub fn schema_change_policy(&self) -> Option<&DirectSchemaChangePolicy>

Defines how schema changes are handled during write operations.

pub fn auto_data_quality(&self) -> Option<&AutoDataQuality>

Specifies whether to automatically enable data quality evaluation for the S3 Hyper direct target. When set to true, data quality checks are performed automatically during the write operation.

pub fn output_schemas(&self) -> &[GlueSchema]

Specifies the data schema for the S3 Hyper direct target.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .output_schemas.is_none().

Source

impl S3HyperDirectTarget

pub fn builder() -> S3HyperDirectTargetBuilder

Creates a new builder-style object to manufacture S3HyperDirectTarget.