#[non_exhaustive]pub struct S3SourceAdditionalOptions {
pub bounded_size: Option<i64>,
pub bounded_files: Option<i64>,
}Expand description
Specifies additional connection options for the Amazon S3 data store.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bounded_size: Option<i64>Sets the upper limit for the target size of the dataset in bytes that will be processed.
bounded_files: Option<i64>Sets the upper limit for the target number of files that will be processed.
Implementations
Sourceimpl S3SourceAdditionalOptions
impl S3SourceAdditionalOptions
Sourcepub fn bounded_size(&self) -> Option<i64>
pub fn bounded_size(&self) -> Option<i64>
Sets the upper limit for the target size of the dataset in bytes that will be processed.
Sourcepub fn bounded_files(&self) -> Option<i64>
pub fn bounded_files(&self) -> Option<i64>
Sets the upper limit for the target number of files that will be processed.
Sourceimpl S3SourceAdditionalOptions
impl S3SourceAdditionalOptions
Sourcepub fn builder() -> S3SourceAdditionalOptionsBuilder
pub fn builder() -> S3SourceAdditionalOptionsBuilder
Creates a new builder-style object to manufacture S3SourceAdditionalOptions.