#[non_exhaustive]pub struct SearchResultItem {
pub id: Option<String>,
pub asset_name: Option<String>,
pub asset_description: Option<String>,
pub updated_at: Option<DateTime>,
pub asset_type_id: Option<String>,
}Expand description
A single search result item representing a matched asset.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Option<String>The unique identifier of the matched asset.
asset_name: Option<String>The name of the matched asset.
asset_description: Option<String>The description of the matched asset.
updated_at: Option<DateTime>The timestamp at which the matched asset was last updated.
asset_type_id: Option<String>The identifier of the asset type for the matched asset.
Implementations
Sourceimpl SearchResultItem
impl SearchResultItem
Sourcepub fn asset_name(&self) -> Option<&str>
pub fn asset_name(&self) -> Option<&str>
The name of the matched asset.
Sourcepub fn asset_description(&self) -> Option<&str>
pub fn asset_description(&self) -> Option<&str>
The description of the matched asset.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The timestamp at which the matched asset was last updated.
Sourcepub fn asset_type_id(&self) -> Option<&str>
pub fn asset_type_id(&self) -> Option<&str>
The identifier of the asset type for the matched asset.
Sourceimpl SearchResultItem
impl SearchResultItem
Sourcepub fn builder() -> SearchResultItemBuilder
pub fn builder() -> SearchResultItemBuilder
Creates a new builder-style object to manufacture SearchResultItem.