#[non_exhaustive]pub struct SessionEndpoint {
pub url: String,
pub auth_token: String,
pub auth_token_expiration_time: DateTime,
}Expand description
Contains the Spark Connect endpoint details for an interactive session, including the URL and authentication credentials.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.url: StringThe Spark Connect endpoint URL for the session.
auth_token: StringThe authentication token to include in requests to the Spark Connect endpoint.
auth_token_expiration_time: DateTimeThe time at which the authentication token expires.
Implementations
Sourceimpl SessionEndpoint
impl SessionEndpoint
Sourcepub fn auth_token(&self) -> &str
pub fn auth_token(&self) -> &str
The authentication token to include in requests to the Spark Connect endpoint.
Sourcepub fn auth_token_expiration_time(&self) -> &DateTime
pub fn auth_token_expiration_time(&self) -> &DateTime
The time at which the authentication token expires.
Sourceimpl SessionEndpoint
impl SessionEndpoint
Sourcepub fn builder() -> SessionEndpointBuilder
pub fn builder() -> SessionEndpointBuilder
Creates a new builder-style object to manufacture SessionEndpoint.