#[non_exhaustive]pub struct SkewedInfo {
pub skewed_column_names: Option<Vec<String>>,
pub skewed_column_values: Option<Vec<String>>,
pub skewed_column_value_location_maps: Option<HashMap<String, String>>,
}Expand description
Specifies skewed values in a table. Skewed values are those that occur with very high frequency.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.skewed_column_names: Option<Vec<String>>A list of names of columns that contain skewed values.
skewed_column_values: Option<Vec<String>>A list of values that appear so frequently as to be considered skewed.
skewed_column_value_location_maps: Option<HashMap<String, String>>A mapping of skewed values to the columns that contain them.
Implementations
Sourceimpl SkewedInfo
impl SkewedInfo
Sourcepub fn skewed_column_names(&self) -> &[String]
pub fn skewed_column_names(&self) -> &[String]
A list of names of columns that contain skewed values.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .skewed_column_names.is_none().
Sourcepub fn skewed_column_values(&self) -> &[String]
pub fn skewed_column_values(&self) -> &[String]
A list of values that appear so frequently as to be considered skewed.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .skewed_column_values.is_none().
Sourceimpl SkewedInfo
impl SkewedInfo
Sourcepub fn builder() -> SkewedInfoBuilder
pub fn builder() -> SkewedInfoBuilder
Creates a new builder-style object to manufacture SkewedInfo.