#[non_exhaustive]pub struct SourceTableConfig {
pub fields: Option<Vec<String>>,
pub filter_predicate: Option<String>,
pub primary_key: Option<Vec<String>>,
pub record_update_field: Option<String>,
}Expand description
Properties used by the source leg to process data from the source.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.fields: Option<Vec<String>>A list of fields used for column-level filtering. Currently unsupported.
filter_predicate: Option<String>A condition clause used for row-level filtering. Currently unsupported.
primary_key: Option<Vec<String>>Provide the primary key set for this table. Currently supported specifically for SAP EntityOf entities upon request. Contact Amazon Web Services Support to make this feature available.
record_update_field: Option<String>Incremental pull timestamp-based field. Currently unsupported.
Implementations
Sourceimpl SourceTableConfig
impl SourceTableConfig
Sourcepub fn fields(&self) -> &[String]
pub fn fields(&self) -> &[String]
A list of fields used for column-level filtering. Currently unsupported.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .fields.is_none().
Sourcepub fn filter_predicate(&self) -> Option<&str>
pub fn filter_predicate(&self) -> Option<&str>
A condition clause used for row-level filtering. Currently unsupported.
Sourcepub fn primary_key(&self) -> &[String]
pub fn primary_key(&self) -> &[String]
Provide the primary key set for this table. Currently supported specifically for SAP EntityOf entities upon request. Contact Amazon Web Services Support to make this feature available.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .primary_key.is_none().
Sourcepub fn record_update_field(&self) -> Option<&str>
pub fn record_update_field(&self) -> Option<&str>
Incremental pull timestamp-based field. Currently unsupported.
Sourceimpl SourceTableConfig
impl SourceTableConfig
Sourcepub fn builder() -> SourceTableConfigBuilder
pub fn builder() -> SourceTableConfigBuilder
Creates a new builder-style object to manufacture SourceTableConfig.