#[non_exhaustive]pub struct StatusDetails {
pub requested_change: Option<Box<Table>>,
pub view_validations: Option<Vec<ViewValidation>>,
}Expand description
A structure containing information about an asynchronous change to a table.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.requested_change: Option<Box<Table>>A Table object representing the requested changes.
view_validations: Option<Vec<ViewValidation>>A list of ViewValidation objects that contain information for an analytical engine to validate a view.
Implementations
Sourceimpl StatusDetails
impl StatusDetails
Sourcepub fn requested_change(&self) -> Option<&Table>
pub fn requested_change(&self) -> Option<&Table>
A Table object representing the requested changes.
Sourcepub fn view_validations(&self) -> &[ViewValidation]
pub fn view_validations(&self) -> &[ViewValidation]
A list of ViewValidation objects that contain information for an analytical engine to validate a view.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .view_validations.is_none().
Sourceimpl StatusDetails
impl StatusDetails
Sourcepub fn builder() -> StatusDetailsBuilder
pub fn builder() -> StatusDetailsBuilder
Creates a new builder-style object to manufacture StatusDetails.