#[non_exhaustive]pub struct SupportedDialect {
pub dialect: Option<ViewDialect>,
pub dialect_version: Option<String>,
}Expand description
A structure specifying the dialect and dialect version used by the query engine.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.dialect: Option<ViewDialect>The dialect of the query engine.
dialect_version: Option<String>The version of the dialect of the query engine. For example, 3.0.0.
Implementations
Sourceimpl SupportedDialect
impl SupportedDialect
Sourcepub fn dialect(&self) -> Option<&ViewDialect>
pub fn dialect(&self) -> Option<&ViewDialect>
The dialect of the query engine.
Sourcepub fn dialect_version(&self) -> Option<&str>
pub fn dialect_version(&self) -> Option<&str>
The version of the dialect of the query engine. For example, 3.0.0.
Sourceimpl SupportedDialect
impl SupportedDialect
Sourcepub fn builder() -> SupportedDialectBuilder
pub fn builder() -> SupportedDialectBuilder
Creates a new builder-style object to manufacture SupportedDialect.