#[non_exhaustive]pub struct TableOptimizer {
pub type: Option<TableOptimizerType>,
pub configuration: Option<TableOptimizerConfiguration>,
pub last_run: Option<TableOptimizerRun>,
pub configuration_source: Option<ConfigurationSource>,
}Expand description
Contains details about an optimizer associated with a table.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.type: Option<TableOptimizerType>The type of table optimizer. The valid values are:
-
compaction: for managing compaction with a table optimizer. -
retention: for managing the retention of snapshot with a table optimizer. -
orphan_file_deletion: for managing the deletion of orphan files with a table optimizer.
configuration: Option<TableOptimizerConfiguration>A TableOptimizerConfiguration object that was specified when creating or updating a table optimizer.
last_run: Option<TableOptimizerRun>A TableOptimizerRun object representing the last run of the table optimizer.
configuration_source: Option<ConfigurationSource>Specifies the source of the optimizer configuration. This indicates how the table optimizer was configured and which entity or service initiated the configuration.
Implementations
Sourceimpl TableOptimizer
impl TableOptimizer
Sourcepub fn type(&self) -> Option<&TableOptimizerType>
pub fn type(&self) -> Option<&TableOptimizerType>
The type of table optimizer. The valid values are:
-
compaction: for managing compaction with a table optimizer. -
retention: for managing the retention of snapshot with a table optimizer. -
orphan_file_deletion: for managing the deletion of orphan files with a table optimizer.
Sourcepub fn configuration(&self) -> Option<&TableOptimizerConfiguration>
pub fn configuration(&self) -> Option<&TableOptimizerConfiguration>
A TableOptimizerConfiguration object that was specified when creating or updating a table optimizer.
Sourcepub fn last_run(&self) -> Option<&TableOptimizerRun>
pub fn last_run(&self) -> Option<&TableOptimizerRun>
A TableOptimizerRun object representing the last run of the table optimizer.
Sourcepub fn configuration_source(&self) -> Option<&ConfigurationSource>
pub fn configuration_source(&self) -> Option<&ConfigurationSource>
Specifies the source of the optimizer configuration. This indicates how the table optimizer was configured and which entity or service initiated the configuration.
Sourceimpl TableOptimizer
impl TableOptimizer
Sourcepub fn builder() -> TableOptimizerBuilder
pub fn builder() -> TableOptimizerBuilder
Creates a new builder-style object to manufacture TableOptimizer.