#[non_exhaustive]pub struct TableOptimizerConfiguration {
pub role_arn: Option<String>,
pub enabled: Option<bool>,
pub vpc_configuration: Option<TableOptimizerVpcConfiguration>,
pub compaction_configuration: Option<CompactionConfiguration>,
pub retention_configuration: Option<RetentionConfiguration>,
pub orphan_file_deletion_configuration: Option<OrphanFileDeletionConfiguration>,
}Expand description
Contains details on the configuration of a table optimizer. You pass this configuration when creating or updating a table optimizer.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.role_arn: Option<String>A role passed by the caller which gives the service permission to update the resources associated with the optimizer on the caller's behalf.
enabled: Option<bool>Whether table optimization is enabled.
vpc_configuration: Option<TableOptimizerVpcConfiguration>A TableOptimizerVpcConfiguration object representing the VPC configuration for a table optimizer.
This configuration is necessary to perform optimization on tables that are in a customer VPC.
compaction_configuration: Option<CompactionConfiguration>The configuration for a compaction optimizer. This configuration defines how data files in your table will be compacted to improve query performance and reduce storage costs.
retention_configuration: Option<RetentionConfiguration>The configuration for a snapshot retention optimizer.
orphan_file_deletion_configuration: Option<OrphanFileDeletionConfiguration>The configuration for an orphan file deletion optimizer.
Implementations
Sourceimpl TableOptimizerConfiguration
impl TableOptimizerConfiguration
Sourcepub fn role_arn(&self) -> Option<&str>
pub fn role_arn(&self) -> Option<&str>
A role passed by the caller which gives the service permission to update the resources associated with the optimizer on the caller's behalf.
Sourcepub fn vpc_configuration(&self) -> Option<&TableOptimizerVpcConfiguration>
pub fn vpc_configuration(&self) -> Option<&TableOptimizerVpcConfiguration>
A TableOptimizerVpcConfiguration object representing the VPC configuration for a table optimizer.
This configuration is necessary to perform optimization on tables that are in a customer VPC.
Sourcepub fn compaction_configuration(&self) -> Option<&CompactionConfiguration>
pub fn compaction_configuration(&self) -> Option<&CompactionConfiguration>
The configuration for a compaction optimizer. This configuration defines how data files in your table will be compacted to improve query performance and reduce storage costs.
Sourcepub fn retention_configuration(&self) -> Option<&RetentionConfiguration>
pub fn retention_configuration(&self) -> Option<&RetentionConfiguration>
The configuration for a snapshot retention optimizer.
Sourcepub fn orphan_file_deletion_configuration(
&self,
) -> Option<&OrphanFileDeletionConfiguration>
pub fn orphan_file_deletion_configuration( &self, ) -> Option<&OrphanFileDeletionConfiguration>
The configuration for an orphan file deletion optimizer.
Sourceimpl TableOptimizerConfiguration
impl TableOptimizerConfiguration
Sourcepub fn builder() -> TableOptimizerConfigurationBuilder
pub fn builder() -> TableOptimizerConfigurationBuilder
Creates a new builder-style object to manufacture TableOptimizerConfiguration.