TableOptimizerRun

Struct TableOptimizerRun 

#[non_exhaustive]
pub struct TableOptimizerRun { pub event_type: Option<TableOptimizerEventType>, pub start_timestamp: Option<DateTime>, pub end_timestamp: Option<DateTime>, pub metrics: Option<RunMetrics>, pub error: Option<String>, pub compaction_metrics: Option<CompactionMetrics>, pub compaction_strategy: Option<CompactionStrategy>, pub retention_metrics: Option<RetentionMetrics>, pub orphan_file_deletion_metrics: Option<OrphanFileDeletionMetrics>, }
Contains details for a table optimizer run.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
event_type: Option<TableOptimizerEventType>

An event type representing the status of the table optimizer run.

start_timestamp: Option<DateTime>

Represents the epoch timestamp at which the compaction job was started within Lake Formation.

end_timestamp: Option<DateTime>

Represents the epoch timestamp at which the compaction job ended.

metrics: Option<RunMetrics>
👎Deprecated:

Metrics has been replaced by optimizer type specific metrics such as IcebergCompactionMetrics

A RunMetrics object containing metrics for the optimizer run.

This member is deprecated. See the individual metric members for compaction, retention, and orphan file deletion.

error: Option<String>

An error that occured during the optimizer run.

compaction_metrics: Option<CompactionMetrics>

A CompactionMetrics object containing metrics for the optimizer run.

compaction_strategy: Option<CompactionStrategy>

The strategy used for the compaction run. Indicates which algorithm was applied to determine how files were selected and combined during the compaction process. Valid values are:

  • binpack: Combines small files into larger files, typically targeting sizes over 100MB, while applying any pending deletes. This is the recommended compaction strategy for most use cases.

  • sort: Organizes data based on specified columns which are sorted hierarchically during compaction, improving query performance for filtered operations. This strategy is recommended when your queries frequently filter on specific columns. To use this strategy, you must first define a sort order in your Iceberg table properties using the sort_order table property.

  • z-order: Optimizes data organization by blending multiple attributes into a single scalar value that can be used for sorting, allowing efficient querying across multiple dimensions. This strategy is recommended when you need to query data across multiple dimensions simultaneously. To use this strategy, you must first define a sort order in your Iceberg table properties using the sort_order table property.

retention_metrics: Option<RetentionMetrics>

A RetentionMetrics object containing metrics for the optimizer run.

orphan_file_deletion_metrics: Option<OrphanFileDeletionMetrics>

An OrphanFileDeletionMetrics object containing metrics for the optimizer run.

Implementations

Source

impl TableOptimizerRun

pub fn event_type(&self) -> Option<&TableOptimizerEventType>

An event type representing the status of the table optimizer run.

pub fn start_timestamp(&self) -> Option<&DateTime>

Represents the epoch timestamp at which the compaction job was started within Lake Formation.

pub fn end_timestamp(&self) -> Option<&DateTime>

Represents the epoch timestamp at which the compaction job ended.

pub fn metrics(&self) -> Option<&RunMetrics>

👎Deprecated:

Metrics has been replaced by optimizer type specific metrics such as IcebergCompactionMetrics

A RunMetrics object containing metrics for the optimizer run.

This member is deprecated. See the individual metric members for compaction, retention, and orphan file deletion.

pub fn error(&self) -> Option<&str>

An error that occured during the optimizer run.

pub fn compaction_metrics(&self) -> Option<&CompactionMetrics>

A CompactionMetrics object containing metrics for the optimizer run.

pub fn compaction_strategy(&self) -> Option<&CompactionStrategy>

The strategy used for the compaction run. Indicates which algorithm was applied to determine how files were selected and combined during the compaction process. Valid values are:

  • binpack: Combines small files into larger files, typically targeting sizes over 100MB, while applying any pending deletes. This is the recommended compaction strategy for most use cases.

  • sort: Organizes data based on specified columns which are sorted hierarchically during compaction, improving query performance for filtered operations. This strategy is recommended when your queries frequently filter on specific columns. To use this strategy, you must first define a sort order in your Iceberg table properties using the sort_order table property.

  • z-order: Optimizes data organization by blending multiple attributes into a single scalar value that can be used for sorting, allowing efficient querying across multiple dimensions. This strategy is recommended when you need to query data across multiple dimensions simultaneously. To use this strategy, you must first define a sort order in your Iceberg table properties using the sort_order table property.

pub fn retention_metrics(&self) -> Option<&RetentionMetrics>

A RetentionMetrics object containing metrics for the optimizer run.

pub fn orphan_file_deletion_metrics(&self) -> Option<&OrphanFileDeletionMetrics>

An OrphanFileDeletionMetrics object containing metrics for the optimizer run.

Source

impl TableOptimizerRun

pub fn builder() -> TableOptimizerRunBuilder

Creates a new builder-style object to manufacture TableOptimizerRun.