#[non_exhaustive]pub struct TargetProcessingProperties {
pub role_arn: Option<String>,
pub kms_arn: Option<String>,
pub connection_name: Option<String>,
pub event_bus_arn: Option<String>,
}Expand description
The resource properties associated with the integration target.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.role_arn: Option<String>The IAM role to access the Glue database.
kms_arn: Option<String>The ARN of the KMS key used for encryption.
connection_name: Option<String>The Glue network connection to configure the Glue job running in the customer VPC.
event_bus_arn: Option<String>The ARN of an Eventbridge event bus to receive the integration status notification.
Implementations
Sourceimpl TargetProcessingProperties
impl TargetProcessingProperties
Sourcepub fn connection_name(&self) -> Option<&str>
pub fn connection_name(&self) -> Option<&str>
The Glue network connection to configure the Glue job running in the customer VPC.
Sourcepub fn event_bus_arn(&self) -> Option<&str>
pub fn event_bus_arn(&self) -> Option<&str>
The ARN of an Eventbridge event bus to receive the integration status notification.
Sourceimpl TargetProcessingProperties
impl TargetProcessingProperties
Sourcepub fn builder() -> TargetProcessingPropertiesBuilder
pub fn builder() -> TargetProcessingPropertiesBuilder
Creates a new builder-style object to manufacture TargetProcessingProperties.