#[non_exhaustive]pub struct TestConnectionInput {
pub connection_type: ConnectionType,
pub connection_properties: HashMap<ConnectionPropertyKey, String>,
pub authentication_configuration: Option<AuthenticationConfigurationInput>,
}Expand description
A structure that is used to specify testing a connection to a service.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.connection_type: ConnectionTypeThe type of connection to test. This operation is only available for the JDBC or SALESFORCE connection types.
connection_properties: HashMap<ConnectionPropertyKey, String>The key-value pairs that define parameters for the connection.
JDBC connections use the following connection properties:
-
Required: All of (
HOST,PORT,JDBC_ENGINE) orJDBC_CONNECTION_URL. -
Required: All of (
USERNAME,PASSWORD) orSECRET_ID. -
Optional:
JDBC_ENFORCE_SSL,CUSTOM_JDBC_CERT,CUSTOM_JDBC_CERT_STRING,SKIP_CUSTOM_JDBC_CERT_VALIDATION. These parameters are used to configure SSL with JDBC.
SALESFORCE connections require the AuthenticationConfiguration member to be configured.
authentication_configuration: Option<AuthenticationConfigurationInput>A structure containing the authentication configuration in the TestConnection request. Required for a connection to Salesforce using OAuth authentication.
Implementations
Sourceimpl TestConnectionInput
impl TestConnectionInput
Sourcepub fn connection_type(&self) -> &ConnectionType
pub fn connection_type(&self) -> &ConnectionType
The type of connection to test. This operation is only available for the JDBC or SALESFORCE connection types.
Sourcepub fn connection_properties(&self) -> &HashMap<ConnectionPropertyKey, String>
pub fn connection_properties(&self) -> &HashMap<ConnectionPropertyKey, String>
The key-value pairs that define parameters for the connection.
JDBC connections use the following connection properties:
-
Required: All of (
HOST,PORT,JDBC_ENGINE) orJDBC_CONNECTION_URL. -
Required: All of (
USERNAME,PASSWORD) orSECRET_ID. -
Optional:
JDBC_ENFORCE_SSL,CUSTOM_JDBC_CERT,CUSTOM_JDBC_CERT_STRING,SKIP_CUSTOM_JDBC_CERT_VALIDATION. These parameters are used to configure SSL with JDBC.
SALESFORCE connections require the AuthenticationConfiguration member to be configured.
Sourcepub fn authentication_configuration(
&self,
) -> Option<&AuthenticationConfigurationInput>
pub fn authentication_configuration( &self, ) -> Option<&AuthenticationConfigurationInput>
A structure containing the authentication configuration in the TestConnection request. Required for a connection to Salesforce using OAuth authentication.
Sourceimpl TestConnectionInput
impl TestConnectionInput
Sourcepub fn builder() -> TestConnectionInputBuilder
pub fn builder() -> TestConnectionInputBuilder
Creates a new builder-style object to manufacture TestConnectionInput.