#[non_exhaustive]pub struct UpdateIcebergInput {
pub update_iceberg_table_input: Option<UpdateIcebergTableInput>,
}Expand description
Input parameters specific to updating Apache Iceberg tables in Glue Data Catalog, containing the update operations to be applied to an existing Iceberg table.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.update_iceberg_table_input: Option<UpdateIcebergTableInput>The specific update operations to be applied to the Iceberg table, containing a list of updates that define the new state of the table including schema, partitions, and properties.
Implementations
Sourceimpl UpdateIcebergInput
impl UpdateIcebergInput
Sourcepub fn update_iceberg_table_input(&self) -> Option<&UpdateIcebergTableInput>
pub fn update_iceberg_table_input(&self) -> Option<&UpdateIcebergTableInput>
The specific update operations to be applied to the Iceberg table, containing a list of updates that define the new state of the table including schema, partitions, and properties.
Sourceimpl UpdateIcebergInput
impl UpdateIcebergInput
Sourcepub fn builder() -> UpdateIcebergInputBuilder
pub fn builder() -> UpdateIcebergInputBuilder
Creates a new builder-style object to manufacture UpdateIcebergInput.