#[non_exhaustive]pub struct UpdateIcebergTableInput {
pub updates: Vec<IcebergTableUpdate>,
}Expand description
Contains the update operations to be applied to an existing Iceberg table inGlue Data Catalog, defining the new state of the table metadata.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.updates: Vec<IcebergTableUpdate>The list of table update operations that specify the changes to be made to the Iceberg table, including schema modifications, partition specifications, and table properties.
Implementations
Sourceimpl UpdateIcebergTableInput
impl UpdateIcebergTableInput
Sourcepub fn updates(&self) -> &[IcebergTableUpdate]
pub fn updates(&self) -> &[IcebergTableUpdate]
The list of table update operations that specify the changes to be made to the Iceberg table, including schema modifications, partition specifications, and table properties.
Sourceimpl UpdateIcebergTableInput
impl UpdateIcebergTableInput
Sourcepub fn builder() -> UpdateIcebergTableInputBuilder
pub fn builder() -> UpdateIcebergTableInputBuilder
Creates a new builder-style object to manufacture UpdateIcebergTableInput.