#[non_exhaustive]pub struct UsageProfileDefinition {
pub name: Option<String>,
pub description: Option<String>,
pub created_on: Option<DateTime>,
pub last_modified_on: Option<DateTime>,
}Expand description
Describes an Glue usage profile.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>The name of the usage profile.
description: Option<String>A description of the usage profile.
created_on: Option<DateTime>The date and time when the usage profile was created.
last_modified_on: Option<DateTime>The date and time when the usage profile was last modified.
Implementations
Sourceimpl UsageProfileDefinition
impl UsageProfileDefinition
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A description of the usage profile.
Sourcepub fn created_on(&self) -> Option<&DateTime>
pub fn created_on(&self) -> Option<&DateTime>
The date and time when the usage profile was created.
Sourcepub fn last_modified_on(&self) -> Option<&DateTime>
pub fn last_modified_on(&self) -> Option<&DateTime>
The date and time when the usage profile was last modified.
Sourceimpl UsageProfileDefinition
impl UsageProfileDefinition
Sourcepub fn builder() -> UsageProfileDefinitionBuilder
pub fn builder() -> UsageProfileDefinitionBuilder
Creates a new builder-style object to manufacture UsageProfileDefinition.