#[non_exhaustive]pub struct ViewDefinition {
pub is_protected: Option<bool>,
pub definer: Option<String>,
pub view_version_id: i64,
pub view_version_token: Option<String>,
pub refresh_seconds: Option<i64>,
pub last_refresh_type: Option<LastRefreshType>,
pub sub_objects: Option<Vec<String>>,
pub sub_object_version_ids: Option<Vec<i64>>,
pub representations: Option<Vec<ViewRepresentation>>,
}Expand description
A structure containing details for representations.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.is_protected: Option<bool>You can set this flag as true to instruct the engine not to push user-provided operations into the logical plan of the view during query planning. However, setting this flag does not guarantee that the engine will comply. Refer to the engine's documentation to understand the guarantees provided, if any.
definer: Option<String>The definer of a view in SQL.
view_version_id: i64The ID value that identifies this view's version. For materialized views, the version ID is the Apache Iceberg table's snapshot ID.
view_version_token: Option<String>The version ID of the Apache Iceberg table.
refresh_seconds: Option<i64>Auto refresh interval in seconds for the materialized view. If not specified, the view will not automatically refresh.
last_refresh_type: Option<LastRefreshType>Sets the method used for the most recent refresh.
sub_objects: Option<Vec<String>>A list of table Amazon Resource Names (ARNs).
sub_object_version_ids: Option<Vec<i64>>List of the Apache Iceberg table versions referenced by the materialized view.
representations: Option<Vec<ViewRepresentation>>A list of representations.
Implementations
Sourceimpl ViewDefinition
impl ViewDefinition
Sourcepub fn is_protected(&self) -> Option<bool>
pub fn is_protected(&self) -> Option<bool>
You can set this flag as true to instruct the engine not to push user-provided operations into the logical plan of the view during query planning. However, setting this flag does not guarantee that the engine will comply. Refer to the engine's documentation to understand the guarantees provided, if any.
Sourcepub fn view_version_id(&self) -> i64
pub fn view_version_id(&self) -> i64
The ID value that identifies this view's version. For materialized views, the version ID is the Apache Iceberg table's snapshot ID.
Sourcepub fn view_version_token(&self) -> Option<&str>
pub fn view_version_token(&self) -> Option<&str>
The version ID of the Apache Iceberg table.
Sourcepub fn refresh_seconds(&self) -> Option<i64>
pub fn refresh_seconds(&self) -> Option<i64>
Auto refresh interval in seconds for the materialized view. If not specified, the view will not automatically refresh.
Sourcepub fn last_refresh_type(&self) -> Option<&LastRefreshType>
pub fn last_refresh_type(&self) -> Option<&LastRefreshType>
Sets the method used for the most recent refresh.
Sourcepub fn sub_objects(&self) -> &[String]
pub fn sub_objects(&self) -> &[String]
A list of table Amazon Resource Names (ARNs).
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .sub_objects.is_none().
Sourcepub fn sub_object_version_ids(&self) -> &[i64]
pub fn sub_object_version_ids(&self) -> &[i64]
List of the Apache Iceberg table versions referenced by the materialized view.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .sub_object_version_ids.is_none().
Sourcepub fn representations(&self) -> &[ViewRepresentation]
pub fn representations(&self) -> &[ViewRepresentation]
A list of representations.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .representations.is_none().
Sourceimpl ViewDefinition
impl ViewDefinition
Sourcepub fn builder() -> ViewDefinitionBuilder
pub fn builder() -> ViewDefinitionBuilder
Creates a new builder-style object to manufacture ViewDefinition.