#[non_exhaustive]pub struct ViewValidation {
pub dialect: Option<ViewDialect>,
pub dialect_version: Option<String>,
pub view_validation_text: Option<String>,
pub update_time: Option<DateTime>,
pub state: Option<ResourceState>,
pub error: Option<ErrorDetail>,
}Expand description
A structure that contains information for an analytical engine to validate a view, prior to persisting the view metadata. Used in the case of direct UpdateTable or CreateTable API calls.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.dialect: Option<ViewDialect>The dialect of the query engine.
dialect_version: Option<String>The version of the dialect of the query engine. For example, 3.0.0.
view_validation_text: Option<String>The SELECT query that defines the view, as provided by the customer.
update_time: Option<DateTime>The time of the last update.
state: Option<ResourceState>The state of the validation.
error: Option<ErrorDetail>An error associated with the validation.
Implementations
Sourceimpl ViewValidation
impl ViewValidation
Sourcepub fn dialect(&self) -> Option<&ViewDialect>
pub fn dialect(&self) -> Option<&ViewDialect>
The dialect of the query engine.
Sourcepub fn dialect_version(&self) -> Option<&str>
pub fn dialect_version(&self) -> Option<&str>
The version of the dialect of the query engine. For example, 3.0.0.
Sourcepub fn view_validation_text(&self) -> Option<&str>
pub fn view_validation_text(&self) -> Option<&str>
The SELECT query that defines the view, as provided by the customer.
Sourcepub fn update_time(&self) -> Option<&DateTime>
pub fn update_time(&self) -> Option<&DateTime>
The time of the last update.
Sourcepub fn state(&self) -> Option<&ResourceState>
pub fn state(&self) -> Option<&ResourceState>
The state of the validation.
Sourcepub fn error(&self) -> Option<&ErrorDetail>
pub fn error(&self) -> Option<&ErrorDetail>
An error associated with the validation.
Sourceimpl ViewValidation
impl ViewValidation
Sourcepub fn builder() -> ViewValidationBuilder
pub fn builder() -> ViewValidationBuilder
Creates a new builder-style object to manufacture ViewValidation.