pub struct BatchGetIterableFormsFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to BatchGetIterableForms.
Retrieves multiple items from an iterable form on an asset in Glue Data Catalog in a single request.
Implementations
Sourceimpl BatchGetIterableFormsFluentBuilder
impl BatchGetIterableFormsFluentBuilder
Sourcepub fn as_input(&self) -> &BatchGetIterableFormsInputBuilder
pub fn as_input(&self) -> &BatchGetIterableFormsInputBuilder
Access the BatchGetIterableForms as a reference.
Sourcepub async fn send(
self,
) -> Result<BatchGetIterableFormsOutput, SdkError<BatchGetIterableFormsError, HttpResponse>>
pub async fn send( self, ) -> Result<BatchGetIterableFormsOutput, SdkError<BatchGetIterableFormsError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<BatchGetIterableFormsOutput, BatchGetIterableFormsError, Self>
pub fn customize( self, ) -> CustomizableOperation<BatchGetIterableFormsOutput, BatchGetIterableFormsError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn asset_identifier(self, input: impl Into<String>) -> Self
pub fn asset_identifier(self, input: impl Into<String>) -> Self
The unique identifier of the asset.
Sourcepub fn set_asset_identifier(self, input: Option<String>) -> Self
pub fn set_asset_identifier(self, input: Option<String>) -> Self
The unique identifier of the asset.
Sourcepub fn get_asset_identifier(&self) -> &Option<String>
pub fn get_asset_identifier(&self) -> &Option<String>
The unique identifier of the asset.
Sourcepub fn iterable_form_name(self, input: impl Into<String>) -> Self
pub fn iterable_form_name(self, input: impl Into<String>) -> Self
The name of the iterable form to retrieve items from.
Sourcepub fn set_iterable_form_name(self, input: Option<String>) -> Self
pub fn set_iterable_form_name(self, input: Option<String>) -> Self
The name of the iterable form to retrieve items from.
Sourcepub fn get_iterable_form_name(&self) -> &Option<String>
pub fn get_iterable_form_name(&self) -> &Option<String>
The name of the iterable form to retrieve items from.
Sourcepub fn item_identifiers(self, input: impl Into<String>) -> Self
pub fn item_identifiers(self, input: impl Into<String>) -> Self
Appends an item to ItemIdentifiers.
To override the contents of this collection use set_item_identifiers.
The list of item identifiers to retrieve. Each identifier can be an item ID or item name.
Sourcepub fn set_item_identifiers(self, input: Option<Vec<String>>) -> Self
pub fn set_item_identifiers(self, input: Option<Vec<String>>) -> Self
The list of item identifiers to retrieve. Each identifier can be an item ID or item name.
Sourcepub fn get_item_identifiers(&self) -> &Option<Vec<String>>
pub fn get_item_identifiers(&self) -> &Option<Vec<String>>
The list of item identifiers to retrieve. Each identifier can be an item ID or item name.