#[non_exhaustive]pub struct DeleteAttachmentInput {
pub asset_identifier: Option<String>,
pub iterable_form_name: Option<String>,
pub item_identifier: Option<String>,
pub attachment_name: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.asset_identifier: Option<String>The unique identifier of the asset from which to delete the attachment.
iterable_form_name: Option<String>The name of the iterable form. When specified along with itemIdentifier, the attachment is deleted from an item within the iterable form rather than from the asset itself.
item_identifier: Option<String>The identifier of the item within the iterable form. Required when iterableFormName is specified.
attachment_name: Option<String>The name of the attachment to delete.
Implementations
Sourceimpl DeleteAttachmentInput
impl DeleteAttachmentInput
Sourcepub fn asset_identifier(&self) -> Option<&str>
pub fn asset_identifier(&self) -> Option<&str>
The unique identifier of the asset from which to delete the attachment.
Sourcepub fn iterable_form_name(&self) -> Option<&str>
pub fn iterable_form_name(&self) -> Option<&str>
The name of the iterable form. When specified along with itemIdentifier, the attachment is deleted from an item within the iterable form rather than from the asset itself.
Sourcepub fn item_identifier(&self) -> Option<&str>
pub fn item_identifier(&self) -> Option<&str>
The identifier of the item within the iterable form. Required when iterableFormName is specified.
Sourcepub fn attachment_name(&self) -> Option<&str>
pub fn attachment_name(&self) -> Option<&str>
The name of the attachment to delete.
Sourceimpl DeleteAttachmentInput
impl DeleteAttachmentInput
Sourcepub fn builder() -> DeleteAttachmentInputBuilder
pub fn builder() -> DeleteAttachmentInputBuilder
Creates a new builder-style object to manufacture DeleteAttachmentInput.