#[non_exhaustive]pub struct DescribeEntityInputBuilder { /* private fields */ }Expand description
A builder for DescribeEntityInput.
Implementations
Sourceimpl DescribeEntityInputBuilder
impl DescribeEntityInputBuilder
Sourcepub fn connection_name(self, input: impl Into<String>) -> Self
pub fn connection_name(self, input: impl Into<String>) -> Self
The name of the connection that contains the connection type credentials.
This field is required.Sourcepub fn set_connection_name(self, input: Option<String>) -> Self
pub fn set_connection_name(self, input: Option<String>) -> Self
The name of the connection that contains the connection type credentials.
Sourcepub fn get_connection_name(&self) -> &Option<String>
pub fn get_connection_name(&self) -> &Option<String>
The name of the connection that contains the connection type credentials.
Sourcepub fn catalog_id(self, input: impl Into<String>) -> Self
pub fn catalog_id(self, input: impl Into<String>) -> Self
The catalog ID of the catalog that contains the connection. This can be null, By default, the Amazon Web Services Account ID is the catalog ID.
Sourcepub fn set_catalog_id(self, input: Option<String>) -> Self
pub fn set_catalog_id(self, input: Option<String>) -> Self
The catalog ID of the catalog that contains the connection. This can be null, By default, the Amazon Web Services Account ID is the catalog ID.
Sourcepub fn get_catalog_id(&self) -> &Option<String>
pub fn get_catalog_id(&self) -> &Option<String>
The catalog ID of the catalog that contains the connection. This can be null, By default, the Amazon Web Services Account ID is the catalog ID.
Sourcepub fn entity_name(self, input: impl Into<String>) -> Self
pub fn entity_name(self, input: impl Into<String>) -> Self
The name of the entity that you want to describe from the connection type.
This field is required.Sourcepub fn set_entity_name(self, input: Option<String>) -> Self
pub fn set_entity_name(self, input: Option<String>) -> Self
The name of the entity that you want to describe from the connection type.
Sourcepub fn get_entity_name(&self) -> &Option<String>
pub fn get_entity_name(&self) -> &Option<String>
The name of the entity that you want to describe from the connection type.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token, included if this is a continuation call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token, included if this is a continuation call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token, included if this is a continuation call.
Sourcepub fn data_store_api_version(self, input: impl Into<String>) -> Self
pub fn data_store_api_version(self, input: impl Into<String>) -> Self
The version of the API used for the data store.
Sourcepub fn set_data_store_api_version(self, input: Option<String>) -> Self
pub fn set_data_store_api_version(self, input: Option<String>) -> Self
The version of the API used for the data store.
Sourcepub fn get_data_store_api_version(&self) -> &Option<String>
pub fn get_data_store_api_version(&self) -> &Option<String>
The version of the API used for the data store.
Sourcepub fn build(self) -> Result<DescribeEntityInput, BuildError>
pub fn build(self) -> Result<DescribeEntityInput, BuildError>
Consumes the builder and constructs a DescribeEntityInput.
Sourceimpl DescribeEntityInputBuilder
impl DescribeEntityInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<DescribeEntityOutput, SdkError<DescribeEntityError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<DescribeEntityOutput, SdkError<DescribeEntityError, HttpResponse>>
Sends a request with this input using the given client.