pub struct DescribeInboundIntegrationsFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to DescribeInboundIntegrations.
Returns a list of inbound integrations for the specified integration.
Implementations
Sourceimpl DescribeInboundIntegrationsFluentBuilder
impl DescribeInboundIntegrationsFluentBuilder
Sourcepub fn as_input(&self) -> &DescribeInboundIntegrationsInputBuilder
pub fn as_input(&self) -> &DescribeInboundIntegrationsInputBuilder
Access the DescribeInboundIntegrations as a reference.
Sourcepub async fn send(
self,
) -> Result<DescribeInboundIntegrationsOutput, SdkError<DescribeInboundIntegrationsError, HttpResponse>>
pub async fn send( self, ) -> Result<DescribeInboundIntegrationsOutput, SdkError<DescribeInboundIntegrationsError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<DescribeInboundIntegrationsOutput, DescribeInboundIntegrationsError, Self>
pub fn customize( self, ) -> CustomizableOperation<DescribeInboundIntegrationsOutput, DescribeInboundIntegrationsError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn integration_arn(self, input: impl Into<String>) -> Self
pub fn integration_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the integration.
Sourcepub fn set_integration_arn(self, input: Option<String>) -> Self
pub fn set_integration_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the integration.
Sourcepub fn get_integration_arn(&self) -> &Option<String>
pub fn get_integration_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the integration.
Sourcepub fn marker(self, input: impl Into<String>) -> Self
pub fn marker(self, input: impl Into<String>) -> Self
A token to specify where to start paginating. This is the marker from a previously truncated response.
Sourcepub fn set_marker(self, input: Option<String>) -> Self
pub fn set_marker(self, input: Option<String>) -> Self
A token to specify where to start paginating. This is the marker from a previously truncated response.
Sourcepub fn get_marker(&self) -> &Option<String>
pub fn get_marker(&self) -> &Option<String>
A token to specify where to start paginating. This is the marker from a previously truncated response.
Sourcepub fn max_records(self, input: i32) -> Self
pub fn max_records(self, input: i32) -> Self
The total number of items to return in the output.
Sourcepub fn set_max_records(self, input: Option<i32>) -> Self
pub fn set_max_records(self, input: Option<i32>) -> Self
The total number of items to return in the output.
Sourcepub fn get_max_records(&self) -> &Option<i32>
pub fn get_max_records(&self) -> &Option<i32>
The total number of items to return in the output.
Sourcepub fn target_arn(self, input: impl Into<String>) -> Self
pub fn target_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the target resource in the integration.
Sourcepub fn set_target_arn(self, input: Option<String>) -> Self
pub fn set_target_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the target resource in the integration.
Sourcepub fn get_target_arn(&self) -> &Option<String>
pub fn get_target_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the target resource in the integration.