#[non_exhaustive]pub struct GetAssetOutput {
pub id: String,
pub name: Option<String>,
pub description: Option<String>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
pub asset_type_id: String,
pub glossary_terms: Option<Vec<String>>,
pub forms: Option<HashMap<String, AssetFormEntry>>,
pub attachments: Option<HashMap<String, AssetFormEntry>>,
pub iterable_forms: Option<HashMap<String, IterableFormEntry>>,
/* private fields */
}Expand description
The asset metadata returned by the GetAsset operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: StringThe unique identifier of the asset.
name: Option<String>The name of the asset.
description: Option<String>The description of the asset.
created_at: Option<DateTime>The timestamp at which the asset was created.
updated_at: Option<DateTime>The timestamp at which the asset was last updated.
asset_type_id: StringThe identifier of the asset type for this asset.
glossary_terms: Option<Vec<String>>The identifiers of the glossary terms associated with the asset.
forms: Option<HashMap<String, AssetFormEntry>>The forms on the asset, keyed by form name.
attachments: Option<HashMap<String, AssetFormEntry>>Additional attachments on the asset for more context, keyed by attachment name.
iterable_forms: Option<HashMap<String, IterableFormEntry>>The iterable forms available on the asset, keyed by form name (for example, columns). Use the form name with ListIterableForms or BatchGetIterableForms to retrieve the form's items.
Implementations
Sourceimpl GetAssetOutput
impl GetAssetOutput
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The description of the asset.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The timestamp at which the asset was created.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The timestamp at which the asset was last updated.
Sourcepub fn asset_type_id(&self) -> &str
pub fn asset_type_id(&self) -> &str
The identifier of the asset type for this asset.
Sourcepub fn glossary_terms(&self) -> &[String]
pub fn glossary_terms(&self) -> &[String]
The identifiers of the glossary terms associated with the asset.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .glossary_terms.is_none().
Sourcepub fn forms(&self) -> Option<&HashMap<String, AssetFormEntry>>
pub fn forms(&self) -> Option<&HashMap<String, AssetFormEntry>>
The forms on the asset, keyed by form name.
Sourcepub fn attachments(&self) -> Option<&HashMap<String, AssetFormEntry>>
pub fn attachments(&self) -> Option<&HashMap<String, AssetFormEntry>>
Additional attachments on the asset for more context, keyed by attachment name.
Sourcepub fn iterable_forms(&self) -> Option<&HashMap<String, IterableFormEntry>>
pub fn iterable_forms(&self) -> Option<&HashMap<String, IterableFormEntry>>
The iterable forms available on the asset, keyed by form name (for example, columns). Use the form name with ListIterableForms or BatchGetIterableForms to retrieve the form's items.
Sourceimpl GetAssetOutput
impl GetAssetOutput
Sourcepub fn builder() -> GetAssetOutputBuilder
pub fn builder() -> GetAssetOutputBuilder
Creates a new builder-style object to manufacture GetAssetOutput.