#[non_exhaustive]pub struct GetCatalogsInputBuilder { /* private fields */ }Expand description
A builder for GetCatalogsInput.
Implementations
Sourceimpl GetCatalogsInputBuilder
impl GetCatalogsInputBuilder
Sourcepub fn parent_catalog_id(self, input: impl Into<String>) -> Self
pub fn parent_catalog_id(self, input: impl Into<String>) -> Self
The ID of the parent catalog in which the catalog resides. If none is provided, the Amazon Web Services Account Number is used by default.
Sourcepub fn set_parent_catalog_id(self, input: Option<String>) -> Self
pub fn set_parent_catalog_id(self, input: Option<String>) -> Self
The ID of the parent catalog in which the catalog resides. If none is provided, the Amazon Web Services Account Number is used by default.
Sourcepub fn get_parent_catalog_id(&self) -> &Option<String>
pub fn get_parent_catalog_id(&self) -> &Option<String>
The ID of the parent catalog in which the catalog resides. If none is provided, the Amazon Web Services Account Number is used by default.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token, if this is a continuation call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token, if this is a continuation call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token, if this is a continuation call.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum number of catalogs to return in one response.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum number of catalogs to return in one response.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The maximum number of catalogs to return in one response.
Sourcepub fn recursive(self, input: bool) -> Self
pub fn recursive(self, input: bool) -> Self
Whether to list all catalogs across the catalog hierarchy, starting from the ParentCatalogId. Defaults to false . When true, all catalog objects in the ParentCatalogID hierarchy are enumerated in the response.
Sourcepub fn set_recursive(self, input: Option<bool>) -> Self
pub fn set_recursive(self, input: Option<bool>) -> Self
Whether to list all catalogs across the catalog hierarchy, starting from the ParentCatalogId. Defaults to false . When true, all catalog objects in the ParentCatalogID hierarchy are enumerated in the response.
Sourcepub fn get_recursive(&self) -> &Option<bool>
pub fn get_recursive(&self) -> &Option<bool>
Whether to list all catalogs across the catalog hierarchy, starting from the ParentCatalogId. Defaults to false . When true, all catalog objects in the ParentCatalogID hierarchy are enumerated in the response.
Sourcepub fn include_root(self, input: bool) -> Self
pub fn include_root(self, input: bool) -> Self
Whether to list the default catalog in the account and region in the response. Defaults to false. When true and ParentCatalogId = NULL | Amazon Web Services Account ID, all catalogs and the default catalog are enumerated in the response.
When the ParentCatalogId is not equal to null, and this attribute is passed as false or true, an InvalidInputException is thrown.
Sourcepub fn set_include_root(self, input: Option<bool>) -> Self
pub fn set_include_root(self, input: Option<bool>) -> Self
Whether to list the default catalog in the account and region in the response. Defaults to false. When true and ParentCatalogId = NULL | Amazon Web Services Account ID, all catalogs and the default catalog are enumerated in the response.
When the ParentCatalogId is not equal to null, and this attribute is passed as false or true, an InvalidInputException is thrown.
Sourcepub fn get_include_root(&self) -> &Option<bool>
pub fn get_include_root(&self) -> &Option<bool>
Whether to list the default catalog in the account and region in the response. Defaults to false. When true and ParentCatalogId = NULL | Amazon Web Services Account ID, all catalogs and the default catalog are enumerated in the response.
When the ParentCatalogId is not equal to null, and this attribute is passed as false or true, an InvalidInputException is thrown.
Sourcepub fn build(self) -> Result<GetCatalogsInput, BuildError>
pub fn build(self) -> Result<GetCatalogsInput, BuildError>
Consumes the builder and constructs a GetCatalogsInput.
Sourceimpl GetCatalogsInputBuilder
impl GetCatalogsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<GetCatalogsOutput, SdkError<GetCatalogsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<GetCatalogsOutput, SdkError<GetCatalogsError, HttpResponse>>
Sends a request with this input using the given client.