#[non_exhaustive]pub struct GetIntegrationTablePropertiesInputBuilder { /* private fields */ }Expand description
A builder for GetIntegrationTablePropertiesInput.
Implementations
Sourceimpl GetIntegrationTablePropertiesInputBuilder
impl GetIntegrationTablePropertiesInputBuilder
Sourcepub fn resource_arn(self, input: impl Into<String>) -> Self
pub fn resource_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the target table for which to retrieve integration table properties. Currently, this API only supports retrieving properties for target tables, and the provided ARN should be the ARN of the target table in the Glue Data Catalog. Support for retrieving integration table properties for source connections (using the connection ARN) is not yet implemented and will be added in a future release.
This field is required.Sourcepub fn set_resource_arn(self, input: Option<String>) -> Self
pub fn set_resource_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the target table for which to retrieve integration table properties. Currently, this API only supports retrieving properties for target tables, and the provided ARN should be the ARN of the target table in the Glue Data Catalog. Support for retrieving integration table properties for source connections (using the connection ARN) is not yet implemented and will be added in a future release.
Sourcepub fn get_resource_arn(&self) -> &Option<String>
pub fn get_resource_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the target table for which to retrieve integration table properties. Currently, this API only supports retrieving properties for target tables, and the provided ARN should be the ARN of the target table in the Glue Data Catalog. Support for retrieving integration table properties for source connections (using the connection ARN) is not yet implemented and will be added in a future release.
Sourcepub fn table_name(self, input: impl Into<String>) -> Self
pub fn table_name(self, input: impl Into<String>) -> Self
The name of the table to be replicated.
This field is required.Sourcepub fn set_table_name(self, input: Option<String>) -> Self
pub fn set_table_name(self, input: Option<String>) -> Self
The name of the table to be replicated.
Sourcepub fn get_table_name(&self) -> &Option<String>
pub fn get_table_name(&self) -> &Option<String>
The name of the table to be replicated.
Sourcepub fn build(self) -> Result<GetIntegrationTablePropertiesInput, BuildError>
pub fn build(self) -> Result<GetIntegrationTablePropertiesInput, BuildError>
Consumes the builder and constructs a GetIntegrationTablePropertiesInput.
Sourceimpl GetIntegrationTablePropertiesInputBuilder
impl GetIntegrationTablePropertiesInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<GetIntegrationTablePropertiesOutput, SdkError<GetIntegrationTablePropertiesError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<GetIntegrationTablePropertiesOutput, SdkError<GetIntegrationTablePropertiesError, HttpResponse>>
Sends a request with this input using the given client.