#[non_exhaustive]pub struct GetMaterializedViewRefreshTaskRunInputBuilder { /* private fields */ }Expand description
A builder for GetMaterializedViewRefreshTaskRunInput.
Implementations
Sourceimpl GetMaterializedViewRefreshTaskRunInputBuilder
impl GetMaterializedViewRefreshTaskRunInputBuilder
Sourcepub fn catalog_id(self, input: impl Into<String>) -> Self
pub fn catalog_id(self, input: impl Into<String>) -> Self
The ID of the Data Catalog where the table resides. If none is supplied, the account ID is used by default.
This field is required.Sourcepub fn set_catalog_id(self, input: Option<String>) -> Self
pub fn set_catalog_id(self, input: Option<String>) -> Self
The ID of the Data Catalog where the table resides. If none is supplied, the account ID is used by default.
Sourcepub fn get_catalog_id(&self) -> &Option<String>
pub fn get_catalog_id(&self) -> &Option<String>
The ID of the Data Catalog where the table resides. If none is supplied, the account ID is used by default.
Sourcepub fn materialized_view_refresh_task_run_id(
self,
input: impl Into<String>,
) -> Self
pub fn materialized_view_refresh_task_run_id( self, input: impl Into<String>, ) -> Self
The identifier for the particular materialized view refresh task run.
This field is required.Sourcepub fn set_materialized_view_refresh_task_run_id(
self,
input: Option<String>,
) -> Self
pub fn set_materialized_view_refresh_task_run_id( self, input: Option<String>, ) -> Self
The identifier for the particular materialized view refresh task run.
Sourcepub fn get_materialized_view_refresh_task_run_id(&self) -> &Option<String>
pub fn get_materialized_view_refresh_task_run_id(&self) -> &Option<String>
The identifier for the particular materialized view refresh task run.
Sourcepub fn build(self) -> Result<GetMaterializedViewRefreshTaskRunInput, BuildError>
pub fn build(self) -> Result<GetMaterializedViewRefreshTaskRunInput, BuildError>
Consumes the builder and constructs a GetMaterializedViewRefreshTaskRunInput.
Sourceimpl GetMaterializedViewRefreshTaskRunInputBuilder
impl GetMaterializedViewRefreshTaskRunInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<GetMaterializedViewRefreshTaskRunOutput, SdkError<GetMaterializedViewRefreshTaskRunError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<GetMaterializedViewRefreshTaskRunOutput, SdkError<GetMaterializedViewRefreshTaskRunError, HttpResponse>>
Sends a request with this input using the given client.