pub struct ListCrawlsFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to ListCrawls.
Returns all the crawls of a specified crawler. Returns only the crawls that have occurred since the launch date of the crawler history feature, and only retains up to 12 months of crawls. Older crawls will not be returned.
You may use this API to:
-
Retrive all the crawls of a specified crawler.
-
Retrieve all the crawls of a specified crawler within a limited count.
-
Retrieve all the crawls of a specified crawler in a specific time range.
-
Retrieve all the crawls of a specified crawler with a particular state, crawl ID, or DPU hour value.
Implementations
Sourceimpl ListCrawlsFluentBuilder
impl ListCrawlsFluentBuilder
Sourcepub fn as_input(&self) -> &ListCrawlsInputBuilder
pub fn as_input(&self) -> &ListCrawlsInputBuilder
Access the ListCrawls as a reference.
Sourcepub async fn send(
self,
) -> Result<ListCrawlsOutput, SdkError<ListCrawlsError, HttpResponse>>
pub async fn send( self, ) -> Result<ListCrawlsOutput, SdkError<ListCrawlsError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<ListCrawlsOutput, ListCrawlsError, Self>
pub fn customize( self, ) -> CustomizableOperation<ListCrawlsOutput, ListCrawlsError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn crawler_name(self, input: impl Into<String>) -> Self
pub fn crawler_name(self, input: impl Into<String>) -> Self
The name of the crawler whose runs you want to retrieve.
Sourcepub fn set_crawler_name(self, input: Option<String>) -> Self
pub fn set_crawler_name(self, input: Option<String>) -> Self
The name of the crawler whose runs you want to retrieve.
Sourcepub fn get_crawler_name(&self) -> &Option<String>
pub fn get_crawler_name(&self) -> &Option<String>
The name of the crawler whose runs you want to retrieve.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum number of results to return. The default is 20, and maximum is 100.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum number of results to return. The default is 20, and maximum is 100.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The maximum number of results to return. The default is 20, and maximum is 100.
Sourcepub fn filters(self, input: CrawlsFilter) -> Self
pub fn filters(self, input: CrawlsFilter) -> Self
Appends an item to Filters.
To override the contents of this collection use set_filters.
Filters the crawls by the criteria you specify in a list of CrawlsFilter objects.
Sourcepub fn set_filters(self, input: Option<Vec<CrawlsFilter>>) -> Self
pub fn set_filters(self, input: Option<Vec<CrawlsFilter>>) -> Self
Filters the crawls by the criteria you specify in a list of CrawlsFilter objects.
Sourcepub fn get_filters(&self) -> &Option<Vec<CrawlsFilter>>
pub fn get_filters(&self) -> &Option<Vec<CrawlsFilter>>
Filters the crawls by the criteria you specify in a list of CrawlsFilter objects.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A continuation token, if this is a continuation call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A continuation token, if this is a continuation call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A continuation token, if this is a continuation call.