pub struct ListIntegrationResourcePropertiesFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to ListIntegrationResourceProperties.
List integration resource properties for a single customer. It supports the filters, maxRecords and markers.
Implementations
Sourceimpl ListIntegrationResourcePropertiesFluentBuilder
impl ListIntegrationResourcePropertiesFluentBuilder
Sourcepub fn as_input(&self) -> &ListIntegrationResourcePropertiesInputBuilder
pub fn as_input(&self) -> &ListIntegrationResourcePropertiesInputBuilder
Access the ListIntegrationResourceProperties as a reference.
Sourcepub async fn send(
self,
) -> Result<ListIntegrationResourcePropertiesOutput, SdkError<ListIntegrationResourcePropertiesError, HttpResponse>>
pub async fn send( self, ) -> Result<ListIntegrationResourcePropertiesOutput, SdkError<ListIntegrationResourcePropertiesError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<ListIntegrationResourcePropertiesOutput, ListIntegrationResourcePropertiesError, Self>
pub fn customize( self, ) -> CustomizableOperation<ListIntegrationResourcePropertiesOutput, ListIntegrationResourcePropertiesError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn marker(self, input: impl Into<String>) -> Self
pub fn marker(self, input: impl Into<String>) -> Self
This is the pagination token for next page, initial value is null.
Sourcepub fn set_marker(self, input: Option<String>) -> Self
pub fn set_marker(self, input: Option<String>) -> Self
This is the pagination token for next page, initial value is null.
Sourcepub fn get_marker(&self) -> &Option<String>
pub fn get_marker(&self) -> &Option<String>
This is the pagination token for next page, initial value is null.
Sourcepub fn filters(self, input: IntegrationResourcePropertyFilter) -> Self
pub fn filters(self, input: IntegrationResourcePropertyFilter) -> Self
Appends an item to Filters.
To override the contents of this collection use set_filters.
A list of filters, supported filter Key is SourceArn and TargetArn.
Sourcepub fn set_filters(
self,
input: Option<Vec<IntegrationResourcePropertyFilter>>,
) -> Self
pub fn set_filters( self, input: Option<Vec<IntegrationResourcePropertyFilter>>, ) -> Self
A list of filters, supported filter Key is SourceArn and TargetArn.
Sourcepub fn get_filters(&self) -> &Option<Vec<IntegrationResourcePropertyFilter>>
pub fn get_filters(&self) -> &Option<Vec<IntegrationResourcePropertyFilter>>
A list of filters, supported filter Key is SourceArn and TargetArn.
Sourcepub fn max_records(self, input: i32) -> Self
pub fn max_records(self, input: i32) -> Self
This is total number of items to be evaluated.
Sourcepub fn set_max_records(self, input: Option<i32>) -> Self
pub fn set_max_records(self, input: Option<i32>) -> Self
This is total number of items to be evaluated.
Sourcepub fn get_max_records(&self) -> &Option<i32>
pub fn get_max_records(&self) -> &Option<i32>
This is total number of items to be evaluated.