#[non_exhaustive]pub struct ListTriggersInput {
pub next_token: Option<String>,
pub dependent_job_name: Option<String>,
pub max_results: Option<i32>,
pub tags: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.next_token: Option<String>A continuation token, if this is a continuation request.
dependent_job_name: Option<String>The name of the job for which to retrieve triggers. The trigger that can start this job is returned. If there is no such trigger, all triggers are returned.
max_results: Option<i32>The maximum size of a list to return.
Specifies to return only these tagged resources.
Implementations
Sourceimpl ListTriggersInput
impl ListTriggersInput
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A continuation token, if this is a continuation request.
Sourcepub fn dependent_job_name(&self) -> Option<&str>
pub fn dependent_job_name(&self) -> Option<&str>
The name of the job for which to retrieve triggers. The trigger that can start this job is returned. If there is no such trigger, all triggers are returned.
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
The maximum size of a list to return.
Specifies to return only these tagged resources.
Sourceimpl ListTriggersInput
impl ListTriggersInput
Sourcepub fn builder() -> ListTriggersInputBuilder
pub fn builder() -> ListTriggersInputBuilder
Creates a new builder-style object to manufacture ListTriggersInput.