pub struct PutAssetFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to PutAsset.
Creates or updates an asset in Glue Data Catalog. If the asset already exists, this operation updates it; otherwise, a new asset is created.
Implementations
Sourceimpl PutAssetFluentBuilder
impl PutAssetFluentBuilder
Sourcepub fn as_input(&self) -> &PutAssetInputBuilder
pub fn as_input(&self) -> &PutAssetInputBuilder
Access the PutAsset as a reference.
Sourcepub async fn send(
self,
) -> Result<PutAssetOutput, SdkError<PutAssetError, HttpResponse>>
pub async fn send( self, ) -> Result<PutAssetOutput, SdkError<PutAssetError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<PutAssetOutput, PutAssetError, Self>
pub fn customize( self, ) -> CustomizableOperation<PutAssetOutput, PutAssetError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn asset_type_id(self, input: impl Into<String>) -> Self
pub fn asset_type_id(self, input: impl Into<String>) -> Self
The identifier of the asset type for the asset.
Sourcepub fn set_asset_type_id(self, input: Option<String>) -> Self
pub fn set_asset_type_id(self, input: Option<String>) -> Self
The identifier of the asset type for the asset.
Sourcepub fn get_asset_type_id(&self) -> &Option<String>
pub fn get_asset_type_id(&self) -> &Option<String>
The identifier of the asset type for the asset.
Sourcepub fn identifier(self, input: impl Into<String>) -> Self
pub fn identifier(self, input: impl Into<String>) -> Self
The unique identifier of the asset. If an asset with this identifier already exists, it is updated.
Sourcepub fn set_identifier(self, input: Option<String>) -> Self
pub fn set_identifier(self, input: Option<String>) -> Self
The unique identifier of the asset. If an asset with this identifier already exists, it is updated.
Sourcepub fn get_identifier(&self) -> &Option<String>
pub fn get_identifier(&self) -> &Option<String>
The unique identifier of the asset. If an asset with this identifier already exists, it is updated.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
The description of the asset.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
The description of the asset.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
The description of the asset.
Sourcepub fn forms(self, k: impl Into<String>, v: AssetFormEntry) -> Self
pub fn forms(self, k: impl Into<String>, v: AssetFormEntry) -> Self
Adds a key-value pair to Forms.
To override the contents of this collection use set_forms.
The forms to set on the asset, keyed by form name. Each entry specifies the form type and its JSON content.
Sourcepub fn set_forms(self, input: Option<HashMap<String, AssetFormEntry>>) -> Self
pub fn set_forms(self, input: Option<HashMap<String, AssetFormEntry>>) -> Self
The forms to set on the asset, keyed by form name. Each entry specifies the form type and its JSON content.
Sourcepub fn get_forms(&self) -> &Option<HashMap<String, AssetFormEntry>>
pub fn get_forms(&self) -> &Option<HashMap<String, AssetFormEntry>>
The forms to set on the asset, keyed by form name. Each entry specifies the form type and its JSON content.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.