pub struct PutAttachmentFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to PutAttachment.
Attaches a form to an asset or an iterable form item in Glue Data Catalog. If an attachment with the same name already exists, it is overwritten.
Implementations
Sourceimpl PutAttachmentFluentBuilder
impl PutAttachmentFluentBuilder
Sourcepub fn as_input(&self) -> &PutAttachmentInputBuilder
pub fn as_input(&self) -> &PutAttachmentInputBuilder
Access the PutAttachment as a reference.
Sourcepub async fn send(
self,
) -> Result<PutAttachmentOutput, SdkError<PutAttachmentError, HttpResponse>>
pub async fn send( self, ) -> Result<PutAttachmentOutput, SdkError<PutAttachmentError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<PutAttachmentOutput, PutAttachmentError, Self>
pub fn customize( self, ) -> CustomizableOperation<PutAttachmentOutput, PutAttachmentError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn asset_identifier(self, input: impl Into<String>) -> Self
pub fn asset_identifier(self, input: impl Into<String>) -> Self
The unique identifier of the asset to attach the form to.
Sourcepub fn set_asset_identifier(self, input: Option<String>) -> Self
pub fn set_asset_identifier(self, input: Option<String>) -> Self
The unique identifier of the asset to attach the form to.
Sourcepub fn get_asset_identifier(&self) -> &Option<String>
pub fn get_asset_identifier(&self) -> &Option<String>
The unique identifier of the asset to attach the form to.
Sourcepub fn iterable_form_name(self, input: impl Into<String>) -> Self
pub fn iterable_form_name(self, input: impl Into<String>) -> Self
The name of the iterable form. When specified along with itemIdentifier, the attachment targets an item within the iterable form rather than the asset itself.
Sourcepub fn set_iterable_form_name(self, input: Option<String>) -> Self
pub fn set_iterable_form_name(self, input: Option<String>) -> Self
The name of the iterable form. When specified along with itemIdentifier, the attachment targets an item within the iterable form rather than the asset itself.
Sourcepub fn get_iterable_form_name(&self) -> &Option<String>
pub fn get_iterable_form_name(&self) -> &Option<String>
The name of the iterable form. When specified along with itemIdentifier, the attachment targets an item within the iterable form rather than the asset itself.
Sourcepub fn item_identifier(self, input: impl Into<String>) -> Self
pub fn item_identifier(self, input: impl Into<String>) -> Self
The identifier of the item within the iterable form. Required when iterableFormName is specified.
Sourcepub fn set_item_identifier(self, input: Option<String>) -> Self
pub fn set_item_identifier(self, input: Option<String>) -> Self
The identifier of the item within the iterable form. Required when iterableFormName is specified.
Sourcepub fn get_item_identifier(&self) -> &Option<String>
pub fn get_item_identifier(&self) -> &Option<String>
The identifier of the item within the iterable form. Required when iterableFormName is specified.
Sourcepub fn attachment_name(self, input: impl Into<String>) -> Self
pub fn attachment_name(self, input: impl Into<String>) -> Self
The name of the attachment.
Sourcepub fn set_attachment_name(self, input: Option<String>) -> Self
pub fn set_attachment_name(self, input: Option<String>) -> Self
The name of the attachment.
Sourcepub fn get_attachment_name(&self) -> &Option<String>
pub fn get_attachment_name(&self) -> &Option<String>
The name of the attachment.
Sourcepub fn content(self, input: impl Into<String>) -> Self
pub fn content(self, input: impl Into<String>) -> Self
The JSON content of the form, conforming to the schema of the specified form type.
Sourcepub fn set_content(self, input: Option<String>) -> Self
pub fn set_content(self, input: Option<String>) -> Self
The JSON content of the form, conforming to the schema of the specified form type.
Sourcepub fn get_content(&self) -> &Option<String>
pub fn get_content(&self) -> &Option<String>
The JSON content of the form, conforming to the schema of the specified form type.
Sourcepub fn form_type_id(self, input: impl Into<String>) -> Self
pub fn form_type_id(self, input: impl Into<String>) -> Self
The identifier of the form type for this attachment.
Sourcepub fn set_form_type_id(self, input: Option<String>) -> Self
pub fn set_form_type_id(self, input: Option<String>) -> Self
The identifier of the form type for this attachment.
Sourcepub fn get_form_type_id(&self) -> &Option<String>
pub fn get_form_type_id(&self) -> &Option<String>
The identifier of the form type for this attachment.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.