#[non_exhaustive]pub struct StartDataQualityRuleRecommendationRunInputBuilder { /* private fields */ }Expand description
A builder for StartDataQualityRuleRecommendationRunInput.
Implementations
Sourceimpl StartDataQualityRuleRecommendationRunInputBuilder
impl StartDataQualityRuleRecommendationRunInputBuilder
Sourcepub fn data_source(self, input: DataSource) -> Self
pub fn data_source(self, input: DataSource) -> Self
The data source (Glue table) associated with this run.
This field is required.Sourcepub fn set_data_source(self, input: Option<DataSource>) -> Self
pub fn set_data_source(self, input: Option<DataSource>) -> Self
The data source (Glue table) associated with this run.
Sourcepub fn get_data_source(&self) -> &Option<DataSource>
pub fn get_data_source(&self) -> &Option<DataSource>
The data source (Glue table) associated with this run.
Sourcepub fn role(self, input: impl Into<String>) -> Self
pub fn role(self, input: impl Into<String>) -> Self
An IAM role supplied to encrypt the results of the run.
This field is required.Sourcepub fn set_role(self, input: Option<String>) -> Self
pub fn set_role(self, input: Option<String>) -> Self
An IAM role supplied to encrypt the results of the run.
Sourcepub fn get_role(&self) -> &Option<String>
pub fn get_role(&self) -> &Option<String>
An IAM role supplied to encrypt the results of the run.
Sourcepub fn number_of_workers(self, input: i32) -> Self
pub fn number_of_workers(self, input: i32) -> Self
The number of G.1X workers to be used in the run. The default is 5.
Sourcepub fn set_number_of_workers(self, input: Option<i32>) -> Self
pub fn set_number_of_workers(self, input: Option<i32>) -> Self
The number of G.1X workers to be used in the run. The default is 5.
Sourcepub fn get_number_of_workers(&self) -> &Option<i32>
pub fn get_number_of_workers(&self) -> &Option<i32>
The number of G.1X workers to be used in the run. The default is 5.
Sourcepub fn timeout(self, input: i32) -> Self
pub fn timeout(self, input: i32) -> Self
The timeout for a run in minutes. This is the maximum time that a run can consume resources before it is terminated and enters TIMEOUT status. The default is 2,880 minutes (48 hours).
Sourcepub fn set_timeout(self, input: Option<i32>) -> Self
pub fn set_timeout(self, input: Option<i32>) -> Self
The timeout for a run in minutes. This is the maximum time that a run can consume resources before it is terminated and enters TIMEOUT status. The default is 2,880 minutes (48 hours).
Sourcepub fn get_timeout(&self) -> &Option<i32>
pub fn get_timeout(&self) -> &Option<i32>
The timeout for a run in minutes. This is the maximum time that a run can consume resources before it is terminated and enters TIMEOUT status. The default is 2,880 minutes (48 hours).
Sourcepub fn created_ruleset_name(self, input: impl Into<String>) -> Self
pub fn created_ruleset_name(self, input: impl Into<String>) -> Self
A name for the ruleset.
Sourcepub fn set_created_ruleset_name(self, input: Option<String>) -> Self
pub fn set_created_ruleset_name(self, input: Option<String>) -> Self
A name for the ruleset.
Sourcepub fn get_created_ruleset_name(&self) -> &Option<String>
pub fn get_created_ruleset_name(&self) -> &Option<String>
A name for the ruleset.
Sourcepub fn data_quality_security_configuration(
self,
input: impl Into<String>,
) -> Self
pub fn data_quality_security_configuration( self, input: impl Into<String>, ) -> Self
The name of the security configuration created with the data quality encryption option.
Sourcepub fn set_data_quality_security_configuration(
self,
input: Option<String>,
) -> Self
pub fn set_data_quality_security_configuration( self, input: Option<String>, ) -> Self
The name of the security configuration created with the data quality encryption option.
Sourcepub fn get_data_quality_security_configuration(&self) -> &Option<String>
pub fn get_data_quality_security_configuration(&self) -> &Option<String>
The name of the security configuration created with the data quality encryption option.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
Used for idempotency and is recommended to be set to a random ID (such as a UUID) to avoid creating or starting multiple instances of the same resource.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
Used for idempotency and is recommended to be set to a random ID (such as a UUID) to avoid creating or starting multiple instances of the same resource.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
Used for idempotency and is recommended to be set to a random ID (such as a UUID) to avoid creating or starting multiple instances of the same resource.
Sourcepub fn build(
self,
) -> Result<StartDataQualityRuleRecommendationRunInput, BuildError>
pub fn build( self, ) -> Result<StartDataQualityRuleRecommendationRunInput, BuildError>
Consumes the builder and constructs a StartDataQualityRuleRecommendationRunInput.
Sourceimpl StartDataQualityRuleRecommendationRunInputBuilder
impl StartDataQualityRuleRecommendationRunInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<StartDataQualityRuleRecommendationRunOutput, SdkError<StartDataQualityRuleRecommendationRunError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<StartDataQualityRuleRecommendationRunOutput, SdkError<StartDataQualityRuleRecommendationRunError, HttpResponse>>
Sends a request with this input using the given client.