pub struct UpdateGlueIdentityCenterConfigurationFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to UpdateGlueIdentityCenterConfiguration.
Updates the existing Glue Identity Center configuration, allowing modification of scopes and permissions for the integration.
Implementations
Sourceimpl UpdateGlueIdentityCenterConfigurationFluentBuilder
impl UpdateGlueIdentityCenterConfigurationFluentBuilder
Sourcepub fn as_input(&self) -> &UpdateGlueIdentityCenterConfigurationInputBuilder
pub fn as_input(&self) -> &UpdateGlueIdentityCenterConfigurationInputBuilder
Access the UpdateGlueIdentityCenterConfiguration as a reference.
Sourcepub async fn send(
self,
) -> Result<UpdateGlueIdentityCenterConfigurationOutput, SdkError<UpdateGlueIdentityCenterConfigurationError, HttpResponse>>
pub async fn send( self, ) -> Result<UpdateGlueIdentityCenterConfigurationOutput, SdkError<UpdateGlueIdentityCenterConfigurationError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<UpdateGlueIdentityCenterConfigurationOutput, UpdateGlueIdentityCenterConfigurationError, Self>
pub fn customize( self, ) -> CustomizableOperation<UpdateGlueIdentityCenterConfigurationOutput, UpdateGlueIdentityCenterConfigurationError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn scopes(self, input: impl Into<String>) -> Self
pub fn scopes(self, input: impl Into<String>) -> Self
Appends an item to Scopes.
To override the contents of this collection use set_scopes.
A list of Identity Center scopes that define the updated permissions and access levels for the Glue configuration.
Sourcepub fn set_scopes(self, input: Option<Vec<String>>) -> Self
pub fn set_scopes(self, input: Option<Vec<String>>) -> Self
A list of Identity Center scopes that define the updated permissions and access levels for the Glue configuration.
Sourcepub fn get_scopes(&self) -> &Option<Vec<String>>
pub fn get_scopes(&self) -> &Option<Vec<String>>
A list of Identity Center scopes that define the updated permissions and access levels for the Glue configuration.
Sourcepub fn user_background_sessions_enabled(self, input: bool) -> Self
pub fn user_background_sessions_enabled(self, input: bool) -> Self
Specifies whether users can run background sessions when using Identity Center authentication with Glue services.
Sourcepub fn set_user_background_sessions_enabled(self, input: Option<bool>) -> Self
pub fn set_user_background_sessions_enabled(self, input: Option<bool>) -> Self
Specifies whether users can run background sessions when using Identity Center authentication with Glue services.
Sourcepub fn get_user_background_sessions_enabled(&self) -> &Option<bool>
pub fn get_user_background_sessions_enabled(&self) -> &Option<bool>
Specifies whether users can run background sessions when using Identity Center authentication with Glue services.