#[non_exhaustive]pub struct ConnectionTypeBriefBuilder { /* private fields */ }Expand description
A builder for ConnectionTypeBrief.
Implementations
Sourceimpl ConnectionTypeBriefBuilder
impl ConnectionTypeBriefBuilder
Sourcepub fn connection_type(self, input: ConnectionType) -> Self
pub fn connection_type(self, input: ConnectionType) -> Self
The name of the connection type.
Sourcepub fn set_connection_type(self, input: Option<ConnectionType>) -> Self
pub fn set_connection_type(self, input: Option<ConnectionType>) -> Self
The name of the connection type.
Sourcepub fn get_connection_type(&self) -> &Option<ConnectionType>
pub fn get_connection_type(&self) -> &Option<ConnectionType>
The name of the connection type.
Sourcepub fn display_name(self, input: impl Into<String>) -> Self
pub fn display_name(self, input: impl Into<String>) -> Self
The human-readable name for the connection type that is displayed in the Glue console.
Sourcepub fn set_display_name(self, input: Option<String>) -> Self
pub fn set_display_name(self, input: Option<String>) -> Self
The human-readable name for the connection type that is displayed in the Glue console.
Sourcepub fn get_display_name(&self) -> &Option<String>
pub fn get_display_name(&self) -> &Option<String>
The human-readable name for the connection type that is displayed in the Glue console.
Sourcepub fn vendor(self, input: impl Into<String>) -> Self
pub fn vendor(self, input: impl Into<String>) -> Self
The name of the vendor or provider that created or maintains this connection type.
Sourcepub fn set_vendor(self, input: Option<String>) -> Self
pub fn set_vendor(self, input: Option<String>) -> Self
The name of the vendor or provider that created or maintains this connection type.
Sourcepub fn get_vendor(&self) -> &Option<String>
pub fn get_vendor(&self) -> &Option<String>
The name of the vendor or provider that created or maintains this connection type.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
A description of the connection type.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
A description of the connection type.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
A description of the connection type.
Sourcepub fn categories(self, input: impl Into<String>) -> Self
pub fn categories(self, input: impl Into<String>) -> Self
Appends an item to categories.
To override the contents of this collection use set_categories.
A list of categories that this connection type belongs to. Categories help users filter and find appropriate connection types based on their use cases.
Sourcepub fn set_categories(self, input: Option<Vec<String>>) -> Self
pub fn set_categories(self, input: Option<Vec<String>>) -> Self
A list of categories that this connection type belongs to. Categories help users filter and find appropriate connection types based on their use cases.
Sourcepub fn get_categories(&self) -> &Option<Vec<String>>
pub fn get_categories(&self) -> &Option<Vec<String>>
A list of categories that this connection type belongs to. Categories help users filter and find appropriate connection types based on their use cases.
Sourcepub fn capabilities(self, input: Capabilities) -> Self
pub fn capabilities(self, input: Capabilities) -> Self
The supported authentication types, data interface types (compute environments), and data operations of the connector.
Sourcepub fn set_capabilities(self, input: Option<Capabilities>) -> Self
pub fn set_capabilities(self, input: Option<Capabilities>) -> Self
The supported authentication types, data interface types (compute environments), and data operations of the connector.
Sourcepub fn get_capabilities(&self) -> &Option<Capabilities>
pub fn get_capabilities(&self) -> &Option<Capabilities>
The supported authentication types, data interface types (compute environments), and data operations of the connector.
Sourcepub fn logo_url(self, input: impl Into<String>) -> Self
pub fn logo_url(self, input: impl Into<String>) -> Self
The URL of the logo associated with a connection type.
Sourcepub fn set_logo_url(self, input: Option<String>) -> Self
pub fn set_logo_url(self, input: Option<String>) -> Self
The URL of the logo associated with a connection type.
Sourcepub fn get_logo_url(&self) -> &Option<String>
pub fn get_logo_url(&self) -> &Option<String>
The URL of the logo associated with a connection type.
Sourcepub fn connection_type_variants(self, input: ConnectionTypeVariant) -> Self
pub fn connection_type_variants(self, input: ConnectionTypeVariant) -> Self
Appends an item to connection_type_variants.
To override the contents of this collection use set_connection_type_variants.
A list of variants available for this connection type. Different variants may provide specialized configurations for specific use cases or implementations of the same general connection type.
Sourcepub fn set_connection_type_variants(
self,
input: Option<Vec<ConnectionTypeVariant>>,
) -> Self
pub fn set_connection_type_variants( self, input: Option<Vec<ConnectionTypeVariant>>, ) -> Self
A list of variants available for this connection type. Different variants may provide specialized configurations for specific use cases or implementations of the same general connection type.
Sourcepub fn get_connection_type_variants(
&self,
) -> &Option<Vec<ConnectionTypeVariant>>
pub fn get_connection_type_variants( &self, ) -> &Option<Vec<ConnectionTypeVariant>>
A list of variants available for this connection type. Different variants may provide specialized configurations for specific use cases or implementations of the same general connection type.
Sourcepub fn build(self) -> ConnectionTypeBrief
pub fn build(self) -> ConnectionTypeBrief
Consumes the builder and constructs a ConnectionTypeBrief.