#[non_exhaustive]pub struct CreateIcebergTableInputBuilder { /* private fields */ }Expand description
A builder for CreateIcebergTableInput.
Implementations
Sourceimpl CreateIcebergTableInputBuilder
impl CreateIcebergTableInputBuilder
Sourcepub fn location(self, input: impl Into<String>) -> Self
pub fn location(self, input: impl Into<String>) -> Self
The S3 location where the Iceberg table data will be stored.
This field is required.Sourcepub fn set_location(self, input: Option<String>) -> Self
pub fn set_location(self, input: Option<String>) -> Self
The S3 location where the Iceberg table data will be stored.
Sourcepub fn get_location(&self) -> &Option<String>
pub fn get_location(&self) -> &Option<String>
The S3 location where the Iceberg table data will be stored.
Sourcepub fn schema(self, input: IcebergSchema) -> Self
pub fn schema(self, input: IcebergSchema) -> Self
The schema definition that specifies the structure, field types, and metadata for the Iceberg table.
This field is required.Sourcepub fn set_schema(self, input: Option<IcebergSchema>) -> Self
pub fn set_schema(self, input: Option<IcebergSchema>) -> Self
The schema definition that specifies the structure, field types, and metadata for the Iceberg table.
Sourcepub fn get_schema(&self) -> &Option<IcebergSchema>
pub fn get_schema(&self) -> &Option<IcebergSchema>
The schema definition that specifies the structure, field types, and metadata for the Iceberg table.
Sourcepub fn partition_spec(self, input: IcebergPartitionSpec) -> Self
pub fn partition_spec(self, input: IcebergPartitionSpec) -> Self
The partitioning specification that defines how the Iceberg table data will be organized and partitioned for optimal query performance.
Sourcepub fn set_partition_spec(self, input: Option<IcebergPartitionSpec>) -> Self
pub fn set_partition_spec(self, input: Option<IcebergPartitionSpec>) -> Self
The partitioning specification that defines how the Iceberg table data will be organized and partitioned for optimal query performance.
Sourcepub fn get_partition_spec(&self) -> &Option<IcebergPartitionSpec>
pub fn get_partition_spec(&self) -> &Option<IcebergPartitionSpec>
The partitioning specification that defines how the Iceberg table data will be organized and partitioned for optimal query performance.
Sourcepub fn write_order(self, input: IcebergSortOrder) -> Self
pub fn write_order(self, input: IcebergSortOrder) -> Self
The sort order specification that defines how data should be ordered within each partition to optimize query performance.
Sourcepub fn set_write_order(self, input: Option<IcebergSortOrder>) -> Self
pub fn set_write_order(self, input: Option<IcebergSortOrder>) -> Self
The sort order specification that defines how data should be ordered within each partition to optimize query performance.
Sourcepub fn get_write_order(&self) -> &Option<IcebergSortOrder>
pub fn get_write_order(&self) -> &Option<IcebergSortOrder>
The sort order specification that defines how data should be ordered within each partition to optimize query performance.
Sourcepub fn properties(self, k: impl Into<String>, v: impl Into<String>) -> Self
pub fn properties(self, k: impl Into<String>, v: impl Into<String>) -> Self
Adds a key-value pair to properties.
To override the contents of this collection use set_properties.
Key-value pairs of additional table properties and configuration settings for the Iceberg table.
Sourcepub fn set_properties(self, input: Option<HashMap<String, String>>) -> Self
pub fn set_properties(self, input: Option<HashMap<String, String>>) -> Self
Key-value pairs of additional table properties and configuration settings for the Iceberg table.
Sourcepub fn get_properties(&self) -> &Option<HashMap<String, String>>
pub fn get_properties(&self) -> &Option<HashMap<String, String>>
Key-value pairs of additional table properties and configuration settings for the Iceberg table.
Sourcepub fn build(self) -> Result<CreateIcebergTableInput, BuildError>
pub fn build(self) -> Result<CreateIcebergTableInput, BuildError>
Consumes the builder and constructs a CreateIcebergTableInput.
This method will fail if any of the following fields are not set: