#[non_exhaustive]pub struct DataQualityEncryptionBuilder { /* private fields */ }Expand description
A builder for DataQualityEncryption.
Implementations
Sourceimpl DataQualityEncryptionBuilder
impl DataQualityEncryptionBuilder
Sourcepub fn data_quality_encryption_mode(
self,
input: DataQualityEncryptionMode,
) -> Self
pub fn data_quality_encryption_mode( self, input: DataQualityEncryptionMode, ) -> Self
The encryption mode to use for encrypting Data Quality assets. These assets include data quality rulesets, results, statistics, anomaly detection models and observations.
Valid values are SSEKMS for encryption using a customer-managed KMS key, or DISABLED.
Sourcepub fn set_data_quality_encryption_mode(
self,
input: Option<DataQualityEncryptionMode>,
) -> Self
pub fn set_data_quality_encryption_mode( self, input: Option<DataQualityEncryptionMode>, ) -> Self
The encryption mode to use for encrypting Data Quality assets. These assets include data quality rulesets, results, statistics, anomaly detection models and observations.
Valid values are SSEKMS for encryption using a customer-managed KMS key, or DISABLED.
Sourcepub fn get_data_quality_encryption_mode(
&self,
) -> &Option<DataQualityEncryptionMode>
pub fn get_data_quality_encryption_mode( &self, ) -> &Option<DataQualityEncryptionMode>
The encryption mode to use for encrypting Data Quality assets. These assets include data quality rulesets, results, statistics, anomaly detection models and observations.
Valid values are SSEKMS for encryption using a customer-managed KMS key, or DISABLED.
Sourcepub fn kms_key_arn(self, input: impl Into<String>) -> Self
pub fn kms_key_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the KMS key to be used to encrypt the data.
Sourcepub fn set_kms_key_arn(self, input: Option<String>) -> Self
pub fn set_kms_key_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the KMS key to be used to encrypt the data.
Sourcepub fn get_kms_key_arn(&self) -> &Option<String>
pub fn get_kms_key_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the KMS key to be used to encrypt the data.
Sourcepub fn build(self) -> DataQualityEncryption
pub fn build(self) -> DataQualityEncryption
Consumes the builder and constructs a DataQualityEncryption.