#[non_exhaustive]pub struct DataQualityEvaluationRunAdditionalRunOptionsBuilder { /* private fields */ }Expand description
A builder for DataQualityEvaluationRunAdditionalRunOptions.
Implementations
Sourceimpl DataQualityEvaluationRunAdditionalRunOptionsBuilder
impl DataQualityEvaluationRunAdditionalRunOptionsBuilder
Sourcepub fn cloud_watch_metrics_enabled(self, input: bool) -> Self
pub fn cloud_watch_metrics_enabled(self, input: bool) -> Self
Whether or not to enable CloudWatch metrics.
Sourcepub fn set_cloud_watch_metrics_enabled(self, input: Option<bool>) -> Self
pub fn set_cloud_watch_metrics_enabled(self, input: Option<bool>) -> Self
Whether or not to enable CloudWatch metrics.
Sourcepub fn get_cloud_watch_metrics_enabled(&self) -> &Option<bool>
pub fn get_cloud_watch_metrics_enabled(&self) -> &Option<bool>
Whether or not to enable CloudWatch metrics.
Sourcepub fn results_s3_prefix(self, input: impl Into<String>) -> Self
pub fn results_s3_prefix(self, input: impl Into<String>) -> Self
Prefix for Amazon S3 to store results.
Sourcepub fn set_results_s3_prefix(self, input: Option<String>) -> Self
pub fn set_results_s3_prefix(self, input: Option<String>) -> Self
Prefix for Amazon S3 to store results.
Sourcepub fn get_results_s3_prefix(&self) -> &Option<String>
pub fn get_results_s3_prefix(&self) -> &Option<String>
Prefix for Amazon S3 to store results.
Sourcepub fn composite_rule_evaluation_method(
self,
input: DqCompositeRuleEvaluationMethod,
) -> Self
pub fn composite_rule_evaluation_method( self, input: DqCompositeRuleEvaluationMethod, ) -> Self
Set the evaluation method for composite rules in the ruleset to ROW/COLUMN
Sourcepub fn set_composite_rule_evaluation_method(
self,
input: Option<DqCompositeRuleEvaluationMethod>,
) -> Self
pub fn set_composite_rule_evaluation_method( self, input: Option<DqCompositeRuleEvaluationMethod>, ) -> Self
Set the evaluation method for composite rules in the ruleset to ROW/COLUMN
Sourcepub fn get_composite_rule_evaluation_method(
&self,
) -> &Option<DqCompositeRuleEvaluationMethod>
pub fn get_composite_rule_evaluation_method( &self, ) -> &Option<DqCompositeRuleEvaluationMethod>
Set the evaluation method for composite rules in the ruleset to ROW/COLUMN
Sourcepub fn build(self) -> DataQualityEvaluationRunAdditionalRunOptions
pub fn build(self) -> DataQualityEvaluationRunAdditionalRunOptions
Consumes the builder and constructs a DataQualityEvaluationRunAdditionalRunOptions.