#[non_exhaustive]pub struct EntityBuilder { /* private fields */ }Expand description
A builder for Entity.
Implementations
Sourceimpl EntityBuilder
impl EntityBuilder
Sourcepub fn entity_name(self, input: impl Into<String>) -> Self
pub fn entity_name(self, input: impl Into<String>) -> Self
The name of the entity.
Sourcepub fn set_entity_name(self, input: Option<String>) -> Self
pub fn set_entity_name(self, input: Option<String>) -> Self
The name of the entity.
Sourcepub fn get_entity_name(&self) -> &Option<String>
pub fn get_entity_name(&self) -> &Option<String>
The name of the entity.
Sourcepub fn is_parent_entity(self, input: bool) -> Self
pub fn is_parent_entity(self, input: bool) -> Self
A Boolean value which helps to determine whether there are sub objects that can be listed.
Sourcepub fn set_is_parent_entity(self, input: Option<bool>) -> Self
pub fn set_is_parent_entity(self, input: Option<bool>) -> Self
A Boolean value which helps to determine whether there are sub objects that can be listed.
Sourcepub fn get_is_parent_entity(&self) -> &Option<bool>
pub fn get_is_parent_entity(&self) -> &Option<bool>
A Boolean value which helps to determine whether there are sub objects that can be listed.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
A description of the entity.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
A description of the entity.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
A description of the entity.
Sourcepub fn category(self, input: impl Into<String>) -> Self
pub fn category(self, input: impl Into<String>) -> Self
The type of entities that are present in the response. This value depends on the source connection. For example this is SObjects for Salesforce and databases or schemas or tables for sources like Amazon Redshift.
Sourcepub fn set_category(self, input: Option<String>) -> Self
pub fn set_category(self, input: Option<String>) -> Self
The type of entities that are present in the response. This value depends on the source connection. For example this is SObjects for Salesforce and databases or schemas or tables for sources like Amazon Redshift.
Sourcepub fn get_category(&self) -> &Option<String>
pub fn get_category(&self) -> &Option<String>
The type of entities that are present in the response. This value depends on the source connection. For example this is SObjects for Salesforce and databases or schemas or tables for sources like Amazon Redshift.
Sourcepub fn custom_properties(
self,
k: impl Into<String>,
v: impl Into<String>,
) -> Self
pub fn custom_properties( self, k: impl Into<String>, v: impl Into<String>, ) -> Self
Adds a key-value pair to custom_properties.
To override the contents of this collection use set_custom_properties.
An optional map of keys which may be returned for an entity by a connector.
Sourcepub fn set_custom_properties(
self,
input: Option<HashMap<String, String>>,
) -> Self
pub fn set_custom_properties( self, input: Option<HashMap<String, String>>, ) -> Self
An optional map of keys which may be returned for an entity by a connector.