#[non_exhaustive]pub struct FieldDefinitionBuilder { /* private fields */ }Expand description
A builder for FieldDefinition.
Implementations
Sourceimpl FieldDefinitionBuilder
impl FieldDefinitionBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the field in the entity schema.
This field is required.Sourcepub fn set_name(self, input: Option<String>) -> Self
pub fn set_name(self, input: Option<String>) -> Self
The name of the field in the entity schema.
Sourcepub fn field_data_type(self, input: FieldDataType) -> Self
pub fn field_data_type(self, input: FieldDataType) -> Self
The data type of the field.
This field is required.Sourcepub fn set_field_data_type(self, input: Option<FieldDataType>) -> Self
pub fn set_field_data_type(self, input: Option<FieldDataType>) -> Self
The data type of the field.
Sourcepub fn get_field_data_type(&self) -> &Option<FieldDataType>
pub fn get_field_data_type(&self) -> &Option<FieldDataType>
The data type of the field.
Sourcepub fn build(self) -> Result<FieldDefinition, BuildError>
pub fn build(self) -> Result<FieldDefinition, BuildError>
Consumes the builder and constructs a FieldDefinition.
This method will fail if any of the following fields are not set: