#[non_exhaustive]pub struct IcebergEncryptedKeyBuilder { /* private fields */ }Expand description
A builder for IcebergEncryptedKey.
Implementations
Sourceimpl IcebergEncryptedKeyBuilder
impl IcebergEncryptedKeyBuilder
Sourcepub fn key_id(self, input: impl Into<String>) -> Self
pub fn key_id(self, input: impl Into<String>) -> Self
Unique identifier of the encryption key used for Iceberg table encryption. This ID is used to reference the key in table metadata and track which key was used to encrypt specific data.
This field is required.Sourcepub fn set_key_id(self, input: Option<String>) -> Self
pub fn set_key_id(self, input: Option<String>) -> Self
Unique identifier of the encryption key used for Iceberg table encryption. This ID is used to reference the key in table metadata and track which key was used to encrypt specific data.
Sourcepub fn get_key_id(&self) -> &Option<String>
pub fn get_key_id(&self) -> &Option<String>
Unique identifier of the encryption key used for Iceberg table encryption. This ID is used to reference the key in table metadata and track which key was used to encrypt specific data.
Sourcepub fn encrypted_key_metadata(self, input: impl Into<String>) -> Self
pub fn encrypted_key_metadata(self, input: impl Into<String>) -> Self
Encrypted key and metadata, base64 encoded. The format of encrypted key metadata is determined by the table's encryption scheme and can be a wrapped format specific to the table's KMS provider.
This field is required.Sourcepub fn set_encrypted_key_metadata(self, input: Option<String>) -> Self
pub fn set_encrypted_key_metadata(self, input: Option<String>) -> Self
Encrypted key and metadata, base64 encoded. The format of encrypted key metadata is determined by the table's encryption scheme and can be a wrapped format specific to the table's KMS provider.
Sourcepub fn get_encrypted_key_metadata(&self) -> &Option<String>
pub fn get_encrypted_key_metadata(&self) -> &Option<String>
Encrypted key and metadata, base64 encoded. The format of encrypted key metadata is determined by the table's encryption scheme and can be a wrapped format specific to the table's KMS provider.
Sourcepub fn encrypted_by_id(self, input: impl Into<String>) -> Self
pub fn encrypted_by_id(self, input: impl Into<String>) -> Self
Optional ID of the key used to encrypt or wrap the key metadata in Iceberg table encryption. This field references another encryption key that was used to encrypt the current key's metadata.
Sourcepub fn set_encrypted_by_id(self, input: Option<String>) -> Self
pub fn set_encrypted_by_id(self, input: Option<String>) -> Self
Optional ID of the key used to encrypt or wrap the key metadata in Iceberg table encryption. This field references another encryption key that was used to encrypt the current key's metadata.
Sourcepub fn get_encrypted_by_id(&self) -> &Option<String>
pub fn get_encrypted_by_id(&self) -> &Option<String>
Optional ID of the key used to encrypt or wrap the key metadata in Iceberg table encryption. This field references another encryption key that was used to encrypt the current key's metadata.
Sourcepub fn properties(self, k: impl Into<String>, v: impl Into<String>) -> Self
pub fn properties(self, k: impl Into<String>, v: impl Into<String>) -> Self
Adds a key-value pair to properties.
To override the contents of this collection use set_properties.
A string to string map of additional metadata used by the table's encryption scheme. These properties provide additional context and configuration for the encryption key implementation.
Sourcepub fn set_properties(self, input: Option<HashMap<String, String>>) -> Self
pub fn set_properties(self, input: Option<HashMap<String, String>>) -> Self
A string to string map of additional metadata used by the table's encryption scheme. These properties provide additional context and configuration for the encryption key implementation.
Sourcepub fn get_properties(&self) -> &Option<HashMap<String, String>>
pub fn get_properties(&self) -> &Option<HashMap<String, String>>
A string to string map of additional metadata used by the table's encryption scheme. These properties provide additional context and configuration for the encryption key implementation.
Sourcepub fn build(self) -> Result<IcebergEncryptedKey, BuildError>
pub fn build(self) -> Result<IcebergEncryptedKey, BuildError>
Consumes the builder and constructs a IcebergEncryptedKey.
This method will fail if any of the following fields are not set: