#[non_exhaustive]pub struct IcebergTableMetadataBuilder { /* private fields */ }Expand description
A builder for IcebergTableMetadata.
Implementations
Sourceimpl IcebergTableMetadataBuilder
impl IcebergTableMetadataBuilder
Sourcepub fn format_version(self, input: impl Into<String>) -> Self
pub fn format_version(self, input: impl Into<String>) -> Self
The Apache Iceberg table format version, such as 1 or 2. Determines the set of features and on-disk layout supported by the table.
Sourcepub fn set_format_version(self, input: Option<String>) -> Self
pub fn set_format_version(self, input: Option<String>) -> Self
The Apache Iceberg table format version, such as 1 or 2. Determines the set of features and on-disk layout supported by the table.
Sourcepub fn get_format_version(&self) -> &Option<String>
pub fn get_format_version(&self) -> &Option<String>
The Apache Iceberg table format version, such as 1 or 2. Determines the set of features and on-disk layout supported by the table.
Sourcepub fn table_uuid(self, input: impl Into<String>) -> Self
pub fn table_uuid(self, input: impl Into<String>) -> Self
The unique identifier (UUID) for the Iceberg table, assigned when the table is created and used to track the table across metadata updates.
Sourcepub fn set_table_uuid(self, input: Option<String>) -> Self
pub fn set_table_uuid(self, input: Option<String>) -> Self
The unique identifier (UUID) for the Iceberg table, assigned when the table is created and used to track the table across metadata updates.
Sourcepub fn get_table_uuid(&self) -> &Option<String>
pub fn get_table_uuid(&self) -> &Option<String>
The unique identifier (UUID) for the Iceberg table, assigned when the table is created and used to track the table across metadata updates.
Sourcepub fn location(self, input: impl Into<String>) -> Self
pub fn location(self, input: impl Into<String>) -> Self
The base S3 location where the Iceberg table's data and metadata files are stored.
Sourcepub fn set_location(self, input: Option<String>) -> Self
pub fn set_location(self, input: Option<String>) -> Self
The base S3 location where the Iceberg table's data and metadata files are stored.
Sourcepub fn get_location(&self) -> &Option<String>
pub fn get_location(&self) -> &Option<String>
The base S3 location where the Iceberg table's data and metadata files are stored.
Sourcepub fn properties(self, k: impl Into<String>, v: impl Into<String>) -> Self
pub fn properties(self, k: impl Into<String>, v: impl Into<String>) -> Self
Adds a key-value pair to properties.
To override the contents of this collection use set_properties.
A map of key-value pairs that define table-level properties and configuration settings for the Iceberg table.
Sourcepub fn set_properties(self, input: Option<HashMap<String, String>>) -> Self
pub fn set_properties(self, input: Option<HashMap<String, String>>) -> Self
A map of key-value pairs that define table-level properties and configuration settings for the Iceberg table.
Sourcepub fn get_properties(&self) -> &Option<HashMap<String, String>>
pub fn get_properties(&self) -> &Option<HashMap<String, String>>
A map of key-value pairs that define table-level properties and configuration settings for the Iceberg table.
Sourcepub fn schemas(self, input: IcebergSchema) -> Self
pub fn schemas(self, input: IcebergSchema) -> Self
Appends an item to schemas.
To override the contents of this collection use set_schemas.
The list of schemas that have been associated with the Iceberg table over its history, supporting schema evolution.
Sourcepub fn set_schemas(self, input: Option<Vec<IcebergSchema>>) -> Self
pub fn set_schemas(self, input: Option<Vec<IcebergSchema>>) -> Self
The list of schemas that have been associated with the Iceberg table over its history, supporting schema evolution.
Sourcepub fn get_schemas(&self) -> &Option<Vec<IcebergSchema>>
pub fn get_schemas(&self) -> &Option<Vec<IcebergSchema>>
The list of schemas that have been associated with the Iceberg table over its history, supporting schema evolution.
Sourcepub fn current_schema_id(self, input: i32) -> Self
pub fn current_schema_id(self, input: i32) -> Self
The identifier of the schema that is currently active for the Iceberg table. Matches an entry in Schemas.
Sourcepub fn set_current_schema_id(self, input: Option<i32>) -> Self
pub fn set_current_schema_id(self, input: Option<i32>) -> Self
The identifier of the schema that is currently active for the Iceberg table. Matches an entry in Schemas.
Sourcepub fn get_current_schema_id(&self) -> &Option<i32>
pub fn get_current_schema_id(&self) -> &Option<i32>
The identifier of the schema that is currently active for the Iceberg table. Matches an entry in Schemas.
Sourcepub fn last_column_id(self, input: i32) -> Self
pub fn last_column_id(self, input: i32) -> Self
The highest column identifier that has been assigned in the Iceberg table's schema, used to ensure unique IDs as new columns are added.
Sourcepub fn set_last_column_id(self, input: Option<i32>) -> Self
pub fn set_last_column_id(self, input: Option<i32>) -> Self
The highest column identifier that has been assigned in the Iceberg table's schema, used to ensure unique IDs as new columns are added.
Sourcepub fn get_last_column_id(&self) -> &Option<i32>
pub fn get_last_column_id(&self) -> &Option<i32>
The highest column identifier that has been assigned in the Iceberg table's schema, used to ensure unique IDs as new columns are added.
Sourcepub fn partition_specs(self, input: IcebergPartitionSpec) -> Self
pub fn partition_specs(self, input: IcebergPartitionSpec) -> Self
Appends an item to partition_specs.
To override the contents of this collection use set_partition_specs.
The list of partition specifications that have been associated with the Iceberg table over its history, supporting partition evolution.
Sourcepub fn set_partition_specs(
self,
input: Option<Vec<IcebergPartitionSpec>>,
) -> Self
pub fn set_partition_specs( self, input: Option<Vec<IcebergPartitionSpec>>, ) -> Self
The list of partition specifications that have been associated with the Iceberg table over its history, supporting partition evolution.
Sourcepub fn get_partition_specs(&self) -> &Option<Vec<IcebergPartitionSpec>>
pub fn get_partition_specs(&self) -> &Option<Vec<IcebergPartitionSpec>>
The list of partition specifications that have been associated with the Iceberg table over its history, supporting partition evolution.
Sourcepub fn default_spec_id(self, input: i32) -> Self
pub fn default_spec_id(self, input: i32) -> Self
The identifier of the partition specification that is currently used by default when writing new data to the Iceberg table.
Sourcepub fn set_default_spec_id(self, input: Option<i32>) -> Self
pub fn set_default_spec_id(self, input: Option<i32>) -> Self
The identifier of the partition specification that is currently used by default when writing new data to the Iceberg table.
Sourcepub fn get_default_spec_id(&self) -> &Option<i32>
pub fn get_default_spec_id(&self) -> &Option<i32>
The identifier of the partition specification that is currently used by default when writing new data to the Iceberg table.
Sourcepub fn last_partition_id(self, input: i32) -> Self
pub fn last_partition_id(self, input: i32) -> Self
The highest partition field identifier that has been assigned across the table's partition specifications.
Sourcepub fn set_last_partition_id(self, input: Option<i32>) -> Self
pub fn set_last_partition_id(self, input: Option<i32>) -> Self
The highest partition field identifier that has been assigned across the table's partition specifications.
Sourcepub fn get_last_partition_id(&self) -> &Option<i32>
pub fn get_last_partition_id(&self) -> &Option<i32>
The highest partition field identifier that has been assigned across the table's partition specifications.
Sourcepub fn sort_orders(self, input: IcebergSortOrder) -> Self
pub fn sort_orders(self, input: IcebergSortOrder) -> Self
Appends an item to sort_orders.
To override the contents of this collection use set_sort_orders.
The list of sort order specifications that have been associated with the Iceberg table over its history.
Sourcepub fn set_sort_orders(self, input: Option<Vec<IcebergSortOrder>>) -> Self
pub fn set_sort_orders(self, input: Option<Vec<IcebergSortOrder>>) -> Self
The list of sort order specifications that have been associated with the Iceberg table over its history.
Sourcepub fn get_sort_orders(&self) -> &Option<Vec<IcebergSortOrder>>
pub fn get_sort_orders(&self) -> &Option<Vec<IcebergSortOrder>>
The list of sort order specifications that have been associated with the Iceberg table over its history.
Sourcepub fn default_sort_order_id(self, input: i32) -> Self
pub fn default_sort_order_id(self, input: i32) -> Self
The identifier of the sort order that is currently used by default when writing new data to the Iceberg table.
Sourcepub fn set_default_sort_order_id(self, input: Option<i32>) -> Self
pub fn set_default_sort_order_id(self, input: Option<i32>) -> Self
The identifier of the sort order that is currently used by default when writing new data to the Iceberg table.
Sourcepub fn get_default_sort_order_id(&self) -> &Option<i32>
pub fn get_default_sort_order_id(&self) -> &Option<i32>
The identifier of the sort order that is currently used by default when writing new data to the Iceberg table.
Sourcepub fn build(self) -> IcebergTableMetadata
pub fn build(self) -> IcebergTableMetadata
Consumes the builder and constructs a IcebergTableMetadata.