#[non_exhaustive]pub struct IcebergTableUpdateBuilder { /* private fields */ }Expand description
A builder for IcebergTableUpdate.
Implementations
Sourceimpl IcebergTableUpdateBuilder
impl IcebergTableUpdateBuilder
Sourcepub fn schema(self, input: IcebergSchema) -> Self
pub fn schema(self, input: IcebergSchema) -> Self
The updated schema definition for the Iceberg table, specifying any changes to field structure, data types, or schema metadata.
This field is required.Sourcepub fn set_schema(self, input: Option<IcebergSchema>) -> Self
pub fn set_schema(self, input: Option<IcebergSchema>) -> Self
The updated schema definition for the Iceberg table, specifying any changes to field structure, data types, or schema metadata.
Sourcepub fn get_schema(&self) -> &Option<IcebergSchema>
pub fn get_schema(&self) -> &Option<IcebergSchema>
The updated schema definition for the Iceberg table, specifying any changes to field structure, data types, or schema metadata.
Sourcepub fn partition_spec(self, input: IcebergPartitionSpec) -> Self
pub fn partition_spec(self, input: IcebergPartitionSpec) -> Self
The updated partitioning specification that defines how the table data should be reorganized and partitioned.
Sourcepub fn set_partition_spec(self, input: Option<IcebergPartitionSpec>) -> Self
pub fn set_partition_spec(self, input: Option<IcebergPartitionSpec>) -> Self
The updated partitioning specification that defines how the table data should be reorganized and partitioned.
Sourcepub fn get_partition_spec(&self) -> &Option<IcebergPartitionSpec>
pub fn get_partition_spec(&self) -> &Option<IcebergPartitionSpec>
The updated partitioning specification that defines how the table data should be reorganized and partitioned.
Sourcepub fn sort_order(self, input: IcebergSortOrder) -> Self
pub fn sort_order(self, input: IcebergSortOrder) -> Self
The updated sort order specification that defines how data should be ordered within partitions for optimal query performance.
Sourcepub fn set_sort_order(self, input: Option<IcebergSortOrder>) -> Self
pub fn set_sort_order(self, input: Option<IcebergSortOrder>) -> Self
The updated sort order specification that defines how data should be ordered within partitions for optimal query performance.
Sourcepub fn get_sort_order(&self) -> &Option<IcebergSortOrder>
pub fn get_sort_order(&self) -> &Option<IcebergSortOrder>
The updated sort order specification that defines how data should be ordered within partitions for optimal query performance.
Sourcepub fn location(self, input: impl Into<String>) -> Self
pub fn location(self, input: impl Into<String>) -> Self
The updated S3 location where the Iceberg table data will be stored.
This field is required.Sourcepub fn set_location(self, input: Option<String>) -> Self
pub fn set_location(self, input: Option<String>) -> Self
The updated S3 location where the Iceberg table data will be stored.
Sourcepub fn get_location(&self) -> &Option<String>
pub fn get_location(&self) -> &Option<String>
The updated S3 location where the Iceberg table data will be stored.
Sourcepub fn properties(self, k: impl Into<String>, v: impl Into<String>) -> Self
pub fn properties(self, k: impl Into<String>, v: impl Into<String>) -> Self
Adds a key-value pair to properties.
To override the contents of this collection use set_properties.
Updated key-value pairs of table properties and configuration settings for the Iceberg table.
Sourcepub fn set_properties(self, input: Option<HashMap<String, String>>) -> Self
pub fn set_properties(self, input: Option<HashMap<String, String>>) -> Self
Updated key-value pairs of table properties and configuration settings for the Iceberg table.
Sourcepub fn get_properties(&self) -> &Option<HashMap<String, String>>
pub fn get_properties(&self) -> &Option<HashMap<String, String>>
Updated key-value pairs of table properties and configuration settings for the Iceberg table.
Sourcepub fn action(self, input: IcebergUpdateAction) -> Self
pub fn action(self, input: IcebergUpdateAction) -> Self
The type of update action to be performed on the Iceberg table. Defines the specific operation such as adding schema, setting current schema, adding partition spec, or managing encryption keys.
Sourcepub fn set_action(self, input: Option<IcebergUpdateAction>) -> Self
pub fn set_action(self, input: Option<IcebergUpdateAction>) -> Self
The type of update action to be performed on the Iceberg table. Defines the specific operation such as adding schema, setting current schema, adding partition spec, or managing encryption keys.
Sourcepub fn get_action(&self) -> &Option<IcebergUpdateAction>
pub fn get_action(&self) -> &Option<IcebergUpdateAction>
The type of update action to be performed on the Iceberg table. Defines the specific operation such as adding schema, setting current schema, adding partition spec, or managing encryption keys.
Sourcepub fn encryption_key(self, input: IcebergEncryptedKey) -> Self
pub fn encryption_key(self, input: IcebergEncryptedKey) -> Self
Encryption key information associated with an Iceberg table update operation. Used when adding or removing encryption keys from the table metadata during table evolution.
Sourcepub fn set_encryption_key(self, input: Option<IcebergEncryptedKey>) -> Self
pub fn set_encryption_key(self, input: Option<IcebergEncryptedKey>) -> Self
Encryption key information associated with an Iceberg table update operation. Used when adding or removing encryption keys from the table metadata during table evolution.
Sourcepub fn get_encryption_key(&self) -> &Option<IcebergEncryptedKey>
pub fn get_encryption_key(&self) -> &Option<IcebergEncryptedKey>
Encryption key information associated with an Iceberg table update operation. Used when adding or removing encryption keys from the table metadata during table evolution.
Sourcepub fn key_id(self, input: impl Into<String>) -> Self
pub fn key_id(self, input: impl Into<String>) -> Self
Identifier of the encryption key involved in an Iceberg table update operation. References the specific key being added to or removed from the table's encryption configuration.
Sourcepub fn set_key_id(self, input: Option<String>) -> Self
pub fn set_key_id(self, input: Option<String>) -> Self
Identifier of the encryption key involved in an Iceberg table update operation. References the specific key being added to or removed from the table's encryption configuration.
Sourcepub fn get_key_id(&self) -> &Option<String>
pub fn get_key_id(&self) -> &Option<String>
Identifier of the encryption key involved in an Iceberg table update operation. References the specific key being added to or removed from the table's encryption configuration.
Sourcepub fn build(self) -> Result<IcebergTableUpdate, BuildError>
pub fn build(self) -> Result<IcebergTableUpdate, BuildError>
Consumes the builder and constructs a IcebergTableUpdate.
This method will fail if any of the following fields are not set: