#[non_exhaustive]pub struct IntegrationConfigBuilder { /* private fields */ }Expand description
A builder for IntegrationConfig.
Implementations
Sourceimpl IntegrationConfigBuilder
impl IntegrationConfigBuilder
Sourcepub fn refresh_interval(self, input: impl Into<String>) -> Self
pub fn refresh_interval(self, input: impl Into<String>) -> Self
Specifies the frequency at which CDC (Change Data Capture) pulls or incremental loads should occur. This parameter provides flexibility to align the refresh rate with your specific data update patterns, system load considerations, and performance optimization goals. Time increment can be set from 15 minutes to 8640 minutes (six days).
Sourcepub fn set_refresh_interval(self, input: Option<String>) -> Self
pub fn set_refresh_interval(self, input: Option<String>) -> Self
Specifies the frequency at which CDC (Change Data Capture) pulls or incremental loads should occur. This parameter provides flexibility to align the refresh rate with your specific data update patterns, system load considerations, and performance optimization goals. Time increment can be set from 15 minutes to 8640 minutes (six days).
Sourcepub fn get_refresh_interval(&self) -> &Option<String>
pub fn get_refresh_interval(&self) -> &Option<String>
Specifies the frequency at which CDC (Change Data Capture) pulls or incremental loads should occur. This parameter provides flexibility to align the refresh rate with your specific data update patterns, system load considerations, and performance optimization goals. Time increment can be set from 15 minutes to 8640 minutes (six days).
Sourcepub fn source_properties(
self,
k: impl Into<String>,
v: impl Into<String>,
) -> Self
pub fn source_properties( self, k: impl Into<String>, v: impl Into<String>, ) -> Self
Adds a key-value pair to source_properties.
To override the contents of this collection use set_source_properties.
A collection of key-value pairs that specify additional properties for the integration source. These properties provide configuration options that can be used to customize the behavior of the ODB source during data integration operations.
Sourcepub fn set_source_properties(
self,
input: Option<HashMap<String, String>>,
) -> Self
pub fn set_source_properties( self, input: Option<HashMap<String, String>>, ) -> Self
A collection of key-value pairs that specify additional properties for the integration source. These properties provide configuration options that can be used to customize the behavior of the ODB source during data integration operations.
Sourcepub fn get_source_properties(&self) -> &Option<HashMap<String, String>>
pub fn get_source_properties(&self) -> &Option<HashMap<String, String>>
A collection of key-value pairs that specify additional properties for the integration source. These properties provide configuration options that can be used to customize the behavior of the ODB source during data integration operations.
Sourcepub fn continuous_sync(self, input: bool) -> Self
pub fn continuous_sync(self, input: bool) -> Self
Enables continuous synchronization for on-demand data extractions from SaaS applications to Amazon Web Services data services like Amazon Redshift and Amazon S3.
Sourcepub fn set_continuous_sync(self, input: Option<bool>) -> Self
pub fn set_continuous_sync(self, input: Option<bool>) -> Self
Enables continuous synchronization for on-demand data extractions from SaaS applications to Amazon Web Services data services like Amazon Redshift and Amazon S3.
Sourcepub fn get_continuous_sync(&self) -> &Option<bool>
pub fn get_continuous_sync(&self) -> &Option<bool>
Enables continuous synchronization for on-demand data extractions from SaaS applications to Amazon Web Services data services like Amazon Redshift and Amazon S3.
Sourcepub fn build(self) -> IntegrationConfig
pub fn build(self) -> IntegrationConfig
Consumes the builder and constructs a IntegrationConfig.