#[non_exhaustive]pub struct MaterializedViewRefreshTaskRunBuilder { /* private fields */ }Expand description
A builder for MaterializedViewRefreshTaskRun.
Implementations
Sourceimpl MaterializedViewRefreshTaskRunBuilder
impl MaterializedViewRefreshTaskRunBuilder
Sourcepub fn customer_id(self, input: impl Into<String>) -> Self
pub fn customer_id(self, input: impl Into<String>) -> Self
The Amazon Web Services account ID.
Sourcepub fn set_customer_id(self, input: Option<String>) -> Self
pub fn set_customer_id(self, input: Option<String>) -> Self
The Amazon Web Services account ID.
Sourcepub fn get_customer_id(&self) -> &Option<String>
pub fn get_customer_id(&self) -> &Option<String>
The Amazon Web Services account ID.
Sourcepub fn materialized_view_refresh_task_run_id(
self,
input: impl Into<String>,
) -> Self
pub fn materialized_view_refresh_task_run_id( self, input: impl Into<String>, ) -> Self
The identifier of the materialized view refresh task run.
Sourcepub fn set_materialized_view_refresh_task_run_id(
self,
input: Option<String>,
) -> Self
pub fn set_materialized_view_refresh_task_run_id( self, input: Option<String>, ) -> Self
The identifier of the materialized view refresh task run.
Sourcepub fn get_materialized_view_refresh_task_run_id(&self) -> &Option<String>
pub fn get_materialized_view_refresh_task_run_id(&self) -> &Option<String>
The identifier of the materialized view refresh task run.
Sourcepub fn database_name(self, input: impl Into<String>) -> Self
pub fn database_name(self, input: impl Into<String>) -> Self
The database where the table resides.
Sourcepub fn set_database_name(self, input: Option<String>) -> Self
pub fn set_database_name(self, input: Option<String>) -> Self
The database where the table resides.
Sourcepub fn get_database_name(&self) -> &Option<String>
pub fn get_database_name(&self) -> &Option<String>
The database where the table resides.
Sourcepub fn table_name(self, input: impl Into<String>) -> Self
pub fn table_name(self, input: impl Into<String>) -> Self
The name of the table for which statistics is generated.
Sourcepub fn set_table_name(self, input: Option<String>) -> Self
pub fn set_table_name(self, input: Option<String>) -> Self
The name of the table for which statistics is generated.
Sourcepub fn get_table_name(&self) -> &Option<String>
pub fn get_table_name(&self) -> &Option<String>
The name of the table for which statistics is generated.
Sourcepub fn catalog_id(self, input: impl Into<String>) -> Self
pub fn catalog_id(self, input: impl Into<String>) -> Self
The ID of the Data Catalog where the table resides. If none is supplied, the account ID is used by default.
Sourcepub fn set_catalog_id(self, input: Option<String>) -> Self
pub fn set_catalog_id(self, input: Option<String>) -> Self
The ID of the Data Catalog where the table resides. If none is supplied, the account ID is used by default.
Sourcepub fn get_catalog_id(&self) -> &Option<String>
pub fn get_catalog_id(&self) -> &Option<String>
The ID of the Data Catalog where the table resides. If none is supplied, the account ID is used by default.
Sourcepub fn role(self, input: impl Into<String>) -> Self
pub fn role(self, input: impl Into<String>) -> Self
The IAM role that the service assumes to generate statistics.
Sourcepub fn set_role(self, input: Option<String>) -> Self
pub fn set_role(self, input: Option<String>) -> Self
The IAM role that the service assumes to generate statistics.
Sourcepub fn get_role(&self) -> &Option<String>
pub fn get_role(&self) -> &Option<String>
The IAM role that the service assumes to generate statistics.
Sourcepub fn status(self, input: MaterializedViewRefreshState) -> Self
pub fn status(self, input: MaterializedViewRefreshState) -> Self
The status of the task run.
Sourcepub fn set_status(self, input: Option<MaterializedViewRefreshState>) -> Self
pub fn set_status(self, input: Option<MaterializedViewRefreshState>) -> Self
The status of the task run.
Sourcepub fn get_status(&self) -> &Option<MaterializedViewRefreshState>
pub fn get_status(&self) -> &Option<MaterializedViewRefreshState>
The status of the task run.
Sourcepub fn creation_time(self, input: DateTime) -> Self
pub fn creation_time(self, input: DateTime) -> Self
The time that this task was created.
Sourcepub fn set_creation_time(self, input: Option<DateTime>) -> Self
pub fn set_creation_time(self, input: Option<DateTime>) -> Self
The time that this task was created.
Sourcepub fn get_creation_time(&self) -> &Option<DateTime>
pub fn get_creation_time(&self) -> &Option<DateTime>
The time that this task was created.
Sourcepub fn last_updated(self, input: DateTime) -> Self
pub fn last_updated(self, input: DateTime) -> Self
The last point in time when this task was modified.
Sourcepub fn set_last_updated(self, input: Option<DateTime>) -> Self
pub fn set_last_updated(self, input: Option<DateTime>) -> Self
The last point in time when this task was modified.
Sourcepub fn get_last_updated(&self) -> &Option<DateTime>
pub fn get_last_updated(&self) -> &Option<DateTime>
The last point in time when this task was modified.
Sourcepub fn start_time(self, input: DateTime) -> Self
pub fn start_time(self, input: DateTime) -> Self
The start time of the task.
Sourcepub fn set_start_time(self, input: Option<DateTime>) -> Self
pub fn set_start_time(self, input: Option<DateTime>) -> Self
The start time of the task.
Sourcepub fn get_start_time(&self) -> &Option<DateTime>
pub fn get_start_time(&self) -> &Option<DateTime>
The start time of the task.
Sourcepub fn set_end_time(self, input: Option<DateTime>) -> Self
pub fn set_end_time(self, input: Option<DateTime>) -> Self
The end time of the task.
Sourcepub fn get_end_time(&self) -> &Option<DateTime>
pub fn get_end_time(&self) -> &Option<DateTime>
The end time of the task.
Sourcepub fn error_message(self, input: impl Into<String>) -> Self
pub fn error_message(self, input: impl Into<String>) -> Self
The error message for the job.
Sourcepub fn set_error_message(self, input: Option<String>) -> Self
pub fn set_error_message(self, input: Option<String>) -> Self
The error message for the job.
Sourcepub fn get_error_message(&self) -> &Option<String>
pub fn get_error_message(&self) -> &Option<String>
The error message for the job.
Sourcepub fn dpu_seconds(self, input: f64) -> Self
pub fn dpu_seconds(self, input: f64) -> Self
The calculated DPU usage in seconds for all autoscaled workers.
Sourcepub fn set_dpu_seconds(self, input: Option<f64>) -> Self
pub fn set_dpu_seconds(self, input: Option<f64>) -> Self
The calculated DPU usage in seconds for all autoscaled workers.
Sourcepub fn get_dpu_seconds(&self) -> &Option<f64>
pub fn get_dpu_seconds(&self) -> &Option<f64>
The calculated DPU usage in seconds for all autoscaled workers.
Sourcepub fn refresh_type(self, input: MaterializedViewRefreshType) -> Self
pub fn refresh_type(self, input: MaterializedViewRefreshType) -> Self
The type of the refresh task run. Either FULL or INCREMENTAL.
Sourcepub fn set_refresh_type(
self,
input: Option<MaterializedViewRefreshType>,
) -> Self
pub fn set_refresh_type( self, input: Option<MaterializedViewRefreshType>, ) -> Self
The type of the refresh task run. Either FULL or INCREMENTAL.
Sourcepub fn get_refresh_type(&self) -> &Option<MaterializedViewRefreshType>
pub fn get_refresh_type(&self) -> &Option<MaterializedViewRefreshType>
The type of the refresh task run. Either FULL or INCREMENTAL.
Sourcepub fn processed_bytes(self, input: i64) -> Self
pub fn processed_bytes(self, input: i64) -> Self
The number of bytes the refresh task run has scanned to refresh the materialized view.
Sourcepub fn set_processed_bytes(self, input: Option<i64>) -> Self
pub fn set_processed_bytes(self, input: Option<i64>) -> Self
The number of bytes the refresh task run has scanned to refresh the materialized view.
Sourcepub fn get_processed_bytes(&self) -> &Option<i64>
pub fn get_processed_bytes(&self) -> &Option<i64>
The number of bytes the refresh task run has scanned to refresh the materialized view.
Sourcepub fn build(self) -> MaterializedViewRefreshTaskRun
pub fn build(self) -> MaterializedViewRefreshTaskRun
Consumes the builder and constructs a MaterializedViewRefreshTaskRun.