#[non_exhaustive]pub struct S3ExcelSourceBuilder { /* private fields */ }Expand description
A builder for S3ExcelSource.
Implementations
Sourceimpl S3ExcelSourceBuilder
impl S3ExcelSourceBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the S3 Excel data source.
This field is required.Sourcepub fn paths(self, input: impl Into<String>) -> Self
pub fn paths(self, input: impl Into<String>) -> Self
Appends an item to paths.
To override the contents of this collection use set_paths.
The S3 paths where the Excel files are located.
Sourcepub fn set_paths(self, input: Option<Vec<String>>) -> Self
pub fn set_paths(self, input: Option<Vec<String>>) -> Self
The S3 paths where the Excel files are located.
Sourcepub fn get_paths(&self) -> &Option<Vec<String>>
pub fn get_paths(&self) -> &Option<Vec<String>>
The S3 paths where the Excel files are located.
Sourcepub fn compression_type(self, input: ParquetCompressionType) -> Self
pub fn compression_type(self, input: ParquetCompressionType) -> Self
The compression format used for the Excel files.
Sourcepub fn set_compression_type(self, input: Option<ParquetCompressionType>) -> Self
pub fn set_compression_type(self, input: Option<ParquetCompressionType>) -> Self
The compression format used for the Excel files.
Sourcepub fn get_compression_type(&self) -> &Option<ParquetCompressionType>
pub fn get_compression_type(&self) -> &Option<ParquetCompressionType>
The compression format used for the Excel files.
Sourcepub fn exclusions(self, input: impl Into<String>) -> Self
pub fn exclusions(self, input: impl Into<String>) -> Self
Appends an item to exclusions.
To override the contents of this collection use set_exclusions.
Patterns to exclude specific files or paths from processing.
Sourcepub fn set_exclusions(self, input: Option<Vec<String>>) -> Self
pub fn set_exclusions(self, input: Option<Vec<String>>) -> Self
Patterns to exclude specific files or paths from processing.
Sourcepub fn get_exclusions(&self) -> &Option<Vec<String>>
pub fn get_exclusions(&self) -> &Option<Vec<String>>
Patterns to exclude specific files or paths from processing.
Sourcepub fn group_size(self, input: impl Into<String>) -> Self
pub fn group_size(self, input: impl Into<String>) -> Self
Defines the size of file groups for batch processing.
Sourcepub fn set_group_size(self, input: Option<String>) -> Self
pub fn set_group_size(self, input: Option<String>) -> Self
Defines the size of file groups for batch processing.
Sourcepub fn get_group_size(&self) -> &Option<String>
pub fn get_group_size(&self) -> &Option<String>
Defines the size of file groups for batch processing.
Sourcepub fn group_files(self, input: impl Into<String>) -> Self
pub fn group_files(self, input: impl Into<String>) -> Self
Specifies how files should be grouped for processing.
Sourcepub fn set_group_files(self, input: Option<String>) -> Self
pub fn set_group_files(self, input: Option<String>) -> Self
Specifies how files should be grouped for processing.
Sourcepub fn get_group_files(&self) -> &Option<String>
pub fn get_group_files(&self) -> &Option<String>
Specifies how files should be grouped for processing.
Sourcepub fn recurse(self, input: bool) -> Self
pub fn recurse(self, input: bool) -> Self
Indicates whether to recursively process subdirectories.
Sourcepub fn set_recurse(self, input: Option<bool>) -> Self
pub fn set_recurse(self, input: Option<bool>) -> Self
Indicates whether to recursively process subdirectories.
Sourcepub fn get_recurse(&self) -> &Option<bool>
pub fn get_recurse(&self) -> &Option<bool>
Indicates whether to recursively process subdirectories.
Sourcepub fn set_max_band(self, input: Option<i32>) -> Self
pub fn set_max_band(self, input: Option<i32>) -> Self
The maximum number of processing bands to use.
Sourcepub fn get_max_band(&self) -> &Option<i32>
pub fn get_max_band(&self) -> &Option<i32>
The maximum number of processing bands to use.
Sourcepub fn max_files_in_band(self, input: i32) -> Self
pub fn max_files_in_band(self, input: i32) -> Self
The maximum number of files to process in each band.
Sourcepub fn set_max_files_in_band(self, input: Option<i32>) -> Self
pub fn set_max_files_in_band(self, input: Option<i32>) -> Self
The maximum number of files to process in each band.
Sourcepub fn get_max_files_in_band(&self) -> &Option<i32>
pub fn get_max_files_in_band(&self) -> &Option<i32>
The maximum number of files to process in each band.
Sourcepub fn additional_options(self, input: S3DirectSourceAdditionalOptions) -> Self
pub fn additional_options(self, input: S3DirectSourceAdditionalOptions) -> Self
Additional configuration options for S3 direct source processing.
Sourcepub fn set_additional_options(
self,
input: Option<S3DirectSourceAdditionalOptions>,
) -> Self
pub fn set_additional_options( self, input: Option<S3DirectSourceAdditionalOptions>, ) -> Self
Additional configuration options for S3 direct source processing.
Sourcepub fn get_additional_options(&self) -> &Option<S3DirectSourceAdditionalOptions>
pub fn get_additional_options(&self) -> &Option<S3DirectSourceAdditionalOptions>
Additional configuration options for S3 direct source processing.
Sourcepub fn number_rows(self, input: i64) -> Self
pub fn number_rows(self, input: i64) -> Self
The number of rows to process from each Excel file.
Sourcepub fn set_number_rows(self, input: Option<i64>) -> Self
pub fn set_number_rows(self, input: Option<i64>) -> Self
The number of rows to process from each Excel file.
Sourcepub fn get_number_rows(&self) -> &Option<i64>
pub fn get_number_rows(&self) -> &Option<i64>
The number of rows to process from each Excel file.
The number of rows to skip at the end of each Excel file.
The number of rows to skip at the end of each Excel file.
The number of rows to skip at the end of each Excel file.
Sourcepub fn output_schemas(self, input: GlueSchema) -> Self
pub fn output_schemas(self, input: GlueSchema) -> Self
Appends an item to output_schemas.
To override the contents of this collection use set_output_schemas.
The Glue schemas to apply to the processed data.
Sourcepub fn set_output_schemas(self, input: Option<Vec<GlueSchema>>) -> Self
pub fn set_output_schemas(self, input: Option<Vec<GlueSchema>>) -> Self
The Glue schemas to apply to the processed data.
Sourcepub fn get_output_schemas(&self) -> &Option<Vec<GlueSchema>>
pub fn get_output_schemas(&self) -> &Option<Vec<GlueSchema>>
The Glue schemas to apply to the processed data.
Sourcepub fn build(self) -> Result<S3ExcelSource, BuildError>
pub fn build(self) -> Result<S3ExcelSource, BuildError>
Consumes the builder and constructs a S3ExcelSource.
This method will fail if any of the following fields are not set: