#[non_exhaustive]pub struct S3IcebergDirectTargetBuilder { /* private fields */ }Expand description
A builder for S3IcebergDirectTarget.
Implementations
Sourceimpl S3IcebergDirectTargetBuilder
impl S3IcebergDirectTargetBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
Specifies the unique identifier for the Iceberg target node in your data pipeline.
This field is required.Sourcepub fn set_name(self, input: Option<String>) -> Self
pub fn set_name(self, input: Option<String>) -> Self
Specifies the unique identifier for the Iceberg target node in your data pipeline.
Sourcepub fn get_name(&self) -> &Option<String>
pub fn get_name(&self) -> &Option<String>
Specifies the unique identifier for the Iceberg target node in your data pipeline.
Sourcepub fn inputs(self, input: impl Into<String>) -> Self
pub fn inputs(self, input: impl Into<String>) -> Self
Appends an item to inputs.
To override the contents of this collection use set_inputs.
Defines the single input source that provides data to this Iceberg target.
Sourcepub fn set_inputs(self, input: Option<Vec<String>>) -> Self
pub fn set_inputs(self, input: Option<Vec<String>>) -> Self
Defines the single input source that provides data to this Iceberg target.
Sourcepub fn get_inputs(&self) -> &Option<Vec<String>>
pub fn get_inputs(&self) -> &Option<Vec<String>>
Defines the single input source that provides data to this Iceberg target.
Sourcepub fn partition_keys(self, input: Vec<String>) -> Self
pub fn partition_keys(self, input: Vec<String>) -> Self
Appends an item to partition_keys.
To override the contents of this collection use set_partition_keys.
Specifies the columns used to partition the Iceberg table data in S3.
Sourcepub fn set_partition_keys(self, input: Option<Vec<Vec<String>>>) -> Self
pub fn set_partition_keys(self, input: Option<Vec<Vec<String>>>) -> Self
Specifies the columns used to partition the Iceberg table data in S3.
Sourcepub fn get_partition_keys(&self) -> &Option<Vec<Vec<String>>>
pub fn get_partition_keys(&self) -> &Option<Vec<Vec<String>>>
Specifies the columns used to partition the Iceberg table data in S3.
Sourcepub fn path(self, input: impl Into<String>) -> Self
pub fn path(self, input: impl Into<String>) -> Self
Defines the S3 location where the Iceberg table data will be stored.
This field is required.Sourcepub fn set_path(self, input: Option<String>) -> Self
pub fn set_path(self, input: Option<String>) -> Self
Defines the S3 location where the Iceberg table data will be stored.
Sourcepub fn get_path(&self) -> &Option<String>
pub fn get_path(&self) -> &Option<String>
Defines the S3 location where the Iceberg table data will be stored.
Sourcepub fn format(self, input: TargetFormat) -> Self
pub fn format(self, input: TargetFormat) -> Self
Specifies the file format used for storing Iceberg table data (e.g., Parquet, ORC).
This field is required.Sourcepub fn set_format(self, input: Option<TargetFormat>) -> Self
pub fn set_format(self, input: Option<TargetFormat>) -> Self
Specifies the file format used for storing Iceberg table data (e.g., Parquet, ORC).
Sourcepub fn get_format(&self) -> &Option<TargetFormat>
pub fn get_format(&self) -> &Option<TargetFormat>
Specifies the file format used for storing Iceberg table data (e.g., Parquet, ORC).
Sourcepub fn additional_options(
self,
k: impl Into<String>,
v: impl Into<String>,
) -> Self
pub fn additional_options( self, k: impl Into<String>, v: impl Into<String>, ) -> Self
Adds a key-value pair to additional_options.
To override the contents of this collection use set_additional_options.
Provides additional configuration options for customizing the Iceberg table behavior.
Sourcepub fn set_additional_options(
self,
input: Option<HashMap<String, String>>,
) -> Self
pub fn set_additional_options( self, input: Option<HashMap<String, String>>, ) -> Self
Provides additional configuration options for customizing the Iceberg table behavior.
Sourcepub fn get_additional_options(&self) -> &Option<HashMap<String, String>>
pub fn get_additional_options(&self) -> &Option<HashMap<String, String>>
Provides additional configuration options for customizing the Iceberg table behavior.
Sourcepub fn schema_change_policy(self, input: DirectSchemaChangePolicy) -> Self
pub fn schema_change_policy(self, input: DirectSchemaChangePolicy) -> Self
Defines how schema changes are handled when writing data to the Iceberg table.
Sourcepub fn set_schema_change_policy(
self,
input: Option<DirectSchemaChangePolicy>,
) -> Self
pub fn set_schema_change_policy( self, input: Option<DirectSchemaChangePolicy>, ) -> Self
Defines how schema changes are handled when writing data to the Iceberg table.
Sourcepub fn get_schema_change_policy(&self) -> &Option<DirectSchemaChangePolicy>
pub fn get_schema_change_policy(&self) -> &Option<DirectSchemaChangePolicy>
Defines how schema changes are handled when writing data to the Iceberg table.
Sourcepub fn auto_data_quality(self, input: AutoDataQuality) -> Self
pub fn auto_data_quality(self, input: AutoDataQuality) -> Self
Specifies configuration options for automatic data quality evaluation in Glue jobs. This structure enables automated data quality checks and monitoring during ETL operations, helping to ensure data integrity and reliability without manual intervention.
Sourcepub fn set_auto_data_quality(self, input: Option<AutoDataQuality>) -> Self
pub fn set_auto_data_quality(self, input: Option<AutoDataQuality>) -> Self
Specifies configuration options for automatic data quality evaluation in Glue jobs. This structure enables automated data quality checks and monitoring during ETL operations, helping to ensure data integrity and reliability without manual intervention.
Sourcepub fn get_auto_data_quality(&self) -> &Option<AutoDataQuality>
pub fn get_auto_data_quality(&self) -> &Option<AutoDataQuality>
Specifies configuration options for automatic data quality evaluation in Glue jobs. This structure enables automated data quality checks and monitoring during ETL operations, helping to ensure data integrity and reliability without manual intervention.
Sourcepub fn compression(self, input: IcebergTargetCompressionType) -> Self
pub fn compression(self, input: IcebergTargetCompressionType) -> Self
Specifies the compression codec used for Iceberg table files in S3.
This field is required.Sourcepub fn set_compression(
self,
input: Option<IcebergTargetCompressionType>,
) -> Self
pub fn set_compression( self, input: Option<IcebergTargetCompressionType>, ) -> Self
Specifies the compression codec used for Iceberg table files in S3.
Sourcepub fn get_compression(&self) -> &Option<IcebergTargetCompressionType>
pub fn get_compression(&self) -> &Option<IcebergTargetCompressionType>
Specifies the compression codec used for Iceberg table files in S3.
Sourcepub fn number_target_partitions(self, input: impl Into<String>) -> Self
pub fn number_target_partitions(self, input: impl Into<String>) -> Self
Sets the number of target partitions for distributing Iceberg table files across S3.
Sourcepub fn set_number_target_partitions(self, input: Option<String>) -> Self
pub fn set_number_target_partitions(self, input: Option<String>) -> Self
Sets the number of target partitions for distributing Iceberg table files across S3.
Sourcepub fn get_number_target_partitions(&self) -> &Option<String>
pub fn get_number_target_partitions(&self) -> &Option<String>
Sets the number of target partitions for distributing Iceberg table files across S3.
Sourcepub fn output_schemas(self, input: GlueSchema) -> Self
pub fn output_schemas(self, input: GlueSchema) -> Self
Appends an item to output_schemas.
To override the contents of this collection use set_output_schemas.
Specifies the data schema for the S3 Iceberg direct target.
Sourcepub fn set_output_schemas(self, input: Option<Vec<GlueSchema>>) -> Self
pub fn set_output_schemas(self, input: Option<Vec<GlueSchema>>) -> Self
Specifies the data schema for the S3 Iceberg direct target.
Sourcepub fn get_output_schemas(&self) -> &Option<Vec<GlueSchema>>
pub fn get_output_schemas(&self) -> &Option<Vec<GlueSchema>>
Specifies the data schema for the S3 Iceberg direct target.
Sourcepub fn build(self) -> Result<S3IcebergDirectTarget, BuildError>
pub fn build(self) -> Result<S3IcebergDirectTarget, BuildError>
Consumes the builder and constructs a S3IcebergDirectTarget.
This method will fail if any of the following fields are not set: