#[non_exhaustive]pub struct AuthenticationConfiguration {
pub authentication_type: Option<AuthenticationType>,
pub secret_arn: Option<String>,
pub kms_key_arn: Option<String>,
pub o_auth2_properties: Option<OAuth2Properties>,
}Expand description
A structure containing the authentication configuration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.authentication_type: Option<AuthenticationType>A structure containing the authentication configuration.
secret_arn: Option<String>The secret manager ARN to store credentials.
kms_key_arn: Option<String>The Amazon Resource Name (ARN) of the KMS key used to encrypt sensitive authentication information. This key is used to protect credentials and other sensitive data stored within the authentication configuration.
o_auth2_properties: Option<OAuth2Properties>The properties for OAuth2 authentication.
Implementations
Sourceimpl AuthenticationConfiguration
impl AuthenticationConfiguration
Sourcepub fn authentication_type(&self) -> Option<&AuthenticationType>
pub fn authentication_type(&self) -> Option<&AuthenticationType>
A structure containing the authentication configuration.
Sourcepub fn secret_arn(&self) -> Option<&str>
pub fn secret_arn(&self) -> Option<&str>
The secret manager ARN to store credentials.
Sourcepub fn kms_key_arn(&self) -> Option<&str>
pub fn kms_key_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the KMS key used to encrypt sensitive authentication information. This key is used to protect credentials and other sensitive data stored within the authentication configuration.
Sourcepub fn o_auth2_properties(&self) -> Option<&OAuth2Properties>
pub fn o_auth2_properties(&self) -> Option<&OAuth2Properties>
The properties for OAuth2 authentication.
Sourceimpl AuthenticationConfiguration
impl AuthenticationConfiguration
Sourcepub fn builder() -> AuthenticationConfigurationBuilder
pub fn builder() -> AuthenticationConfigurationBuilder
Creates a new builder-style object to manufacture AuthenticationConfiguration.