#[non_exhaustive]pub struct AuthenticationConfigurationInput {
pub authentication_type: Option<AuthenticationType>,
pub o_auth2_properties: Option<OAuth2PropertiesInput>,
pub secret_arn: Option<String>,
pub kms_key_arn: Option<String>,
pub basic_authentication_credentials: Option<BasicAuthenticationCredentials>,
pub custom_authentication_credentials: Option<HashMap<String, String>>,
}Expand description
A structure containing the authentication configuration in the CreateConnection request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.authentication_type: Option<AuthenticationType>A structure containing the authentication configuration in the CreateConnection request.
o_auth2_properties: Option<OAuth2PropertiesInput>The properties for OAuth2 authentication in the CreateConnection request.
secret_arn: Option<String>The secret manager ARN to store credentials in the CreateConnection request.
kms_key_arn: Option<String>The ARN of the KMS key used to encrypt the connection. Only taken an as input in the request and stored in the Secret Manager.
basic_authentication_credentials: Option<BasicAuthenticationCredentials>The credentials used when the authentication type is basic authentication.
custom_authentication_credentials: Option<HashMap<String, String>>The credentials used when the authentication type is custom authentication.
Implementations
Sourceimpl AuthenticationConfigurationInput
impl AuthenticationConfigurationInput
Sourcepub fn authentication_type(&self) -> Option<&AuthenticationType>
pub fn authentication_type(&self) -> Option<&AuthenticationType>
A structure containing the authentication configuration in the CreateConnection request.
Sourcepub fn o_auth2_properties(&self) -> Option<&OAuth2PropertiesInput>
pub fn o_auth2_properties(&self) -> Option<&OAuth2PropertiesInput>
The properties for OAuth2 authentication in the CreateConnection request.
Sourcepub fn secret_arn(&self) -> Option<&str>
pub fn secret_arn(&self) -> Option<&str>
The secret manager ARN to store credentials in the CreateConnection request.
Sourcepub fn kms_key_arn(&self) -> Option<&str>
pub fn kms_key_arn(&self) -> Option<&str>
The ARN of the KMS key used to encrypt the connection. Only taken an as input in the request and stored in the Secret Manager.
Sourcepub fn basic_authentication_credentials(
&self,
) -> Option<&BasicAuthenticationCredentials>
pub fn basic_authentication_credentials( &self, ) -> Option<&BasicAuthenticationCredentials>
The credentials used when the authentication type is basic authentication.
Sourceimpl AuthenticationConfigurationInput
impl AuthenticationConfigurationInput
Sourcepub fn builder() -> AuthenticationConfigurationInputBuilder
pub fn builder() -> AuthenticationConfigurationInputBuilder
Creates a new builder-style object to manufacture AuthenticationConfigurationInput.