#[non_exhaustive]pub struct ConnectorAuthenticationConfiguration {
pub authentication_types: Vec<AuthenticationType>,
pub o_auth2_properties: Option<ConnectorOAuth2Properties>,
pub basic_authentication_properties: Option<BasicAuthenticationProperties>,
pub custom_authentication_properties: Option<CustomAuthenticationProperties>,
}Expand description
Configuration that defines the supported authentication types and required properties for the connection type.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.authentication_types: Vec<AuthenticationType>A list of authentication types supported by this connection type, such as Basic, OAuth2, or Custom authentication methods.
o_auth2_properties: Option<ConnectorOAuth2Properties>OAuth2 configuration container that defines the authentication properties and flow-specific configurations for OAuth2-based connections.
basic_authentication_properties: Option<BasicAuthenticationProperties>Basic authentication configuration that defines the username and password properties for HTTP Basic authentication.
custom_authentication_properties: Option<CustomAuthenticationProperties>Custom authentication configuration that allows for flexible authentication mechanisms beyond standard Basic and OAuth2 flows.
Implementations
Sourceimpl ConnectorAuthenticationConfiguration
impl ConnectorAuthenticationConfiguration
Sourcepub fn authentication_types(&self) -> &[AuthenticationType]
pub fn authentication_types(&self) -> &[AuthenticationType]
A list of authentication types supported by this connection type, such as Basic, OAuth2, or Custom authentication methods.
Sourcepub fn o_auth2_properties(&self) -> Option<&ConnectorOAuth2Properties>
pub fn o_auth2_properties(&self) -> Option<&ConnectorOAuth2Properties>
OAuth2 configuration container that defines the authentication properties and flow-specific configurations for OAuth2-based connections.
Sourcepub fn basic_authentication_properties(
&self,
) -> Option<&BasicAuthenticationProperties>
pub fn basic_authentication_properties( &self, ) -> Option<&BasicAuthenticationProperties>
Basic authentication configuration that defines the username and password properties for HTTP Basic authentication.
Sourcepub fn custom_authentication_properties(
&self,
) -> Option<&CustomAuthenticationProperties>
pub fn custom_authentication_properties( &self, ) -> Option<&CustomAuthenticationProperties>
Custom authentication configuration that allows for flexible authentication mechanisms beyond standard Basic and OAuth2 flows.
Sourceimpl ConnectorAuthenticationConfiguration
impl ConnectorAuthenticationConfiguration
Sourcepub fn builder() -> ConnectorAuthenticationConfigurationBuilder
pub fn builder() -> ConnectorAuthenticationConfigurationBuilder
Creates a new builder-style object to manufacture ConnectorAuthenticationConfiguration.