#[non_exhaustive]pub struct CursorConfiguration {
pub next_page: Option<ExtractedParameter>,
pub limit_parameter: Option<ExtractedParameter>,
}Expand description
Cursor-based pagination configuration that defines how to handle pagination using cursor tokens or next page identifiers.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.next_page: Option<ExtractedParameter>The parameter name or JSON path that contains the cursor or token for retrieving the next page of results.
limit_parameter: Option<ExtractedParameter>The parameter name used to specify the maximum number of results to return per page.
Implementations
Sourceimpl CursorConfiguration
impl CursorConfiguration
Sourcepub fn next_page(&self) -> Option<&ExtractedParameter>
pub fn next_page(&self) -> Option<&ExtractedParameter>
The parameter name or JSON path that contains the cursor or token for retrieving the next page of results.
Sourcepub fn limit_parameter(&self) -> Option<&ExtractedParameter>
pub fn limit_parameter(&self) -> Option<&ExtractedParameter>
The parameter name used to specify the maximum number of results to return per page.
Sourceimpl CursorConfiguration
impl CursorConfiguration
Sourcepub fn builder() -> CursorConfigurationBuilder
pub fn builder() -> CursorConfigurationBuilder
Creates a new builder-style object to manufacture CursorConfiguration.