#[non_exhaustive]pub struct DataQualityEvaluationRunAdditionalRunOptions {
pub cloud_watch_metrics_enabled: Option<bool>,
pub results_s3_prefix: Option<String>,
pub composite_rule_evaluation_method: Option<DqCompositeRuleEvaluationMethod>,
}Expand description
Additional run options you can specify for an evaluation run.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cloud_watch_metrics_enabled: Option<bool>Whether or not to enable CloudWatch metrics.
results_s3_prefix: Option<String>Prefix for Amazon S3 to store results.
composite_rule_evaluation_method: Option<DqCompositeRuleEvaluationMethod>Set the evaluation method for composite rules in the ruleset to ROW/COLUMN
Implementations
Sourceimpl DataQualityEvaluationRunAdditionalRunOptions
impl DataQualityEvaluationRunAdditionalRunOptions
Sourcepub fn cloud_watch_metrics_enabled(&self) -> Option<bool>
pub fn cloud_watch_metrics_enabled(&self) -> Option<bool>
Whether or not to enable CloudWatch metrics.
Sourcepub fn results_s3_prefix(&self) -> Option<&str>
pub fn results_s3_prefix(&self) -> Option<&str>
Prefix for Amazon S3 to store results.
Sourcepub fn composite_rule_evaluation_method(
&self,
) -> Option<&DqCompositeRuleEvaluationMethod>
pub fn composite_rule_evaluation_method( &self, ) -> Option<&DqCompositeRuleEvaluationMethod>
Set the evaluation method for composite rules in the ruleset to ROW/COLUMN
Sourceimpl DataQualityEvaluationRunAdditionalRunOptions
impl DataQualityEvaluationRunAdditionalRunOptions
Sourcepub fn builder() -> DataQualityEvaluationRunAdditionalRunOptionsBuilder
pub fn builder() -> DataQualityEvaluationRunAdditionalRunOptionsBuilder
Creates a new builder-style object to manufacture DataQualityEvaluationRunAdditionalRunOptions.