#[non_exhaustive]pub struct FieldDefinition {
pub name: String,
pub field_data_type: FieldDataType,
}Expand description
Defines a field in an entity schema for REST connector data sources, specifying the field name and data type.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name of the field in the entity schema.
field_data_type: FieldDataTypeThe data type of the field.
Implementations
Sourceimpl FieldDefinition
impl FieldDefinition
Sourcepub fn field_data_type(&self) -> &FieldDataType
pub fn field_data_type(&self) -> &FieldDataType
The data type of the field.
Sourceimpl FieldDefinition
impl FieldDefinition
Sourcepub fn builder() -> FieldDefinitionBuilder
pub fn builder() -> FieldDefinitionBuilder
Creates a new builder-style object to manufacture FieldDefinition.