#[non_exhaustive]pub struct MaterializedViewRefreshTaskRun {Show 15 fields
pub customer_id: Option<String>,
pub materialized_view_refresh_task_run_id: Option<String>,
pub database_name: Option<String>,
pub table_name: Option<String>,
pub catalog_id: Option<String>,
pub role: Option<String>,
pub status: Option<MaterializedViewRefreshState>,
pub creation_time: Option<DateTime>,
pub last_updated: Option<DateTime>,
pub start_time: Option<DateTime>,
pub end_time: Option<DateTime>,
pub error_message: Option<String>,
pub dpu_seconds: f64,
pub refresh_type: Option<MaterializedViewRefreshType>,
pub processed_bytes: Option<i64>,
}Expand description
The object that shows the details of the materialized view refresh task run.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.customer_id: Option<String>The Amazon Web Services account ID.
materialized_view_refresh_task_run_id: Option<String>The identifier of the materialized view refresh task run.
database_name: Option<String>The database where the table resides.
table_name: Option<String>The name of the table for which statistics is generated.
catalog_id: Option<String>The ID of the Data Catalog where the table resides. If none is supplied, the account ID is used by default.
role: Option<String>The IAM role that the service assumes to generate statistics.
status: Option<MaterializedViewRefreshState>The status of the task run.
creation_time: Option<DateTime>The time that this task was created.
last_updated: Option<DateTime>The last point in time when this task was modified.
start_time: Option<DateTime>The start time of the task.
end_time: Option<DateTime>The end time of the task.
error_message: Option<String>The error message for the job.
dpu_seconds: f64The calculated DPU usage in seconds for all autoscaled workers.
refresh_type: Option<MaterializedViewRefreshType>The type of the refresh task run. Either FULL or INCREMENTAL.
processed_bytes: Option<i64>The number of bytes the refresh task run has scanned to refresh the materialized view.
Implementations
Sourceimpl MaterializedViewRefreshTaskRun
impl MaterializedViewRefreshTaskRun
Sourcepub fn customer_id(&self) -> Option<&str>
pub fn customer_id(&self) -> Option<&str>
The Amazon Web Services account ID.
Sourcepub fn materialized_view_refresh_task_run_id(&self) -> Option<&str>
pub fn materialized_view_refresh_task_run_id(&self) -> Option<&str>
The identifier of the materialized view refresh task run.
Sourcepub fn database_name(&self) -> Option<&str>
pub fn database_name(&self) -> Option<&str>
The database where the table resides.
Sourcepub fn table_name(&self) -> Option<&str>
pub fn table_name(&self) -> Option<&str>
The name of the table for which statistics is generated.
Sourcepub fn catalog_id(&self) -> Option<&str>
pub fn catalog_id(&self) -> Option<&str>
The ID of the Data Catalog where the table resides. If none is supplied, the account ID is used by default.
Sourcepub fn role(&self) -> Option<&str>
pub fn role(&self) -> Option<&str>
The IAM role that the service assumes to generate statistics.
Sourcepub fn status(&self) -> Option<&MaterializedViewRefreshState>
pub fn status(&self) -> Option<&MaterializedViewRefreshState>
The status of the task run.
Sourcepub fn creation_time(&self) -> Option<&DateTime>
pub fn creation_time(&self) -> Option<&DateTime>
The time that this task was created.
Sourcepub fn last_updated(&self) -> Option<&DateTime>
pub fn last_updated(&self) -> Option<&DateTime>
The last point in time when this task was modified.
Sourcepub fn start_time(&self) -> Option<&DateTime>
pub fn start_time(&self) -> Option<&DateTime>
The start time of the task.
Sourcepub fn error_message(&self) -> Option<&str>
pub fn error_message(&self) -> Option<&str>
The error message for the job.
Sourcepub fn dpu_seconds(&self) -> f64
pub fn dpu_seconds(&self) -> f64
The calculated DPU usage in seconds for all autoscaled workers.
Sourcepub fn refresh_type(&self) -> Option<&MaterializedViewRefreshType>
pub fn refresh_type(&self) -> Option<&MaterializedViewRefreshType>
The type of the refresh task run. Either FULL or INCREMENTAL.
Sourcepub fn processed_bytes(&self) -> Option<i64>
pub fn processed_bytes(&self) -> Option<i64>
The number of bytes the refresh task run has scanned to refresh the materialized view.
Sourceimpl MaterializedViewRefreshTaskRun
impl MaterializedViewRefreshTaskRun
Sourcepub fn builder() -> MaterializedViewRefreshTaskRunBuilder
pub fn builder() -> MaterializedViewRefreshTaskRunBuilder
Creates a new builder-style object to manufacture MaterializedViewRefreshTaskRun.