#[non_exhaustive]pub struct TargetTableConfig {
pub unnest_spec: Option<UnnestSpec>,
pub partition_spec: Option<Vec<IntegrationPartition>>,
pub target_table_name: Option<String>,
}Expand description
Properties used by the target leg to partition the data on the target.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.unnest_spec: Option<UnnestSpec>Specifies how nested objects are flattened to top-level elements. Valid values are: "TOPLEVEL", "FULL", or "NOUNNEST".
partition_spec: Option<Vec<IntegrationPartition>>Determines the file layout on the target.
target_table_name: Option<String>The optional name of a target table.
Implementations
Sourceimpl TargetTableConfig
impl TargetTableConfig
Sourcepub fn unnest_spec(&self) -> Option<&UnnestSpec>
pub fn unnest_spec(&self) -> Option<&UnnestSpec>
Specifies how nested objects are flattened to top-level elements. Valid values are: "TOPLEVEL", "FULL", or "NOUNNEST".
Sourcepub fn partition_spec(&self) -> &[IntegrationPartition]
pub fn partition_spec(&self) -> &[IntegrationPartition]
Determines the file layout on the target.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .partition_spec.is_none().
Sourcepub fn target_table_name(&self) -> Option<&str>
pub fn target_table_name(&self) -> Option<&str>
The optional name of a target table.
Sourceimpl TargetTableConfig
impl TargetTableConfig
Sourcepub fn builder() -> TargetTableConfigBuilder
pub fn builder() -> TargetTableConfigBuilder
Creates a new builder-style object to manufacture TargetTableConfig.